(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    472495,      11805]*)
(*NotebookOutlinePosition[    516570,      13182]*)
(*  CellTagsIndexPosition[    516526,      13178]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Rewriting Systems", "Title",
  TextAlignment->Left,
  TextJustification->0,
  FontColor->RGBColor[0.990005, 0.970001, 1],
  Background->RGBColor[0.690211, 0.18819, 0.376501]],

Cell["Jaime Rangel-Mondrag\[OAcute]n", "Author",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Faculty of Informatics
Universidad Aut\[OAcute]noma de Quer\[EAcute]taro
Mexico

jrangel@uaq.mx

December 2003\
\>", "Address",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["About the Author", "Section"],

Cell[TextData[{
  "Jaime Rangel-Mondragon earned M. Sc. and Ph. D. degrees in Applied \
Mathematics and Computation from the University College of North Wales in \
Bangor, Great Britain. He has held research positions in the School of \
Informatics at UCNW Bangor, U.K., the College of Mexico, the Center of \
Research and Advanced Studies, the Monterrey Institute of Technology and the \
University of Queretaro in Mexico, where he currently works at the Faculty of \
Informatics. Prolific contributor to ",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  ", his current research include Combinatorics, Theory of Computing, \
Functional Languages, Computational Geometry and Recreational Mathematics."
}], "Abstract"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Acknowledgements", "Section"],

Cell["\<\
This work was finished at Wolfram Research Inc., in Champaign IL, USA, while \
the author was spending two months as a Visiting Scholar. Their assistance \
and enthusiastic support is gratefully acknowledged. My thanks are also given \
for the continuous support received from the University of Queretaro in \
Mexico.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["References",
  FontWeight->"Bold"]], "Section"],

Cell[TextData[{
  "Cellular Automata and Complexity ",
  StyleBox["\nS. Wolfram\nPerseus, 1994\n\nThe Algorithmic Beauty of Plants",
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\nA. Lindenmeyer\t \nSpringer-Verlag, NY, 1990\n\nPower \
Programming with ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  ". The Kernel\nD. B. Wagner\nMcGraw-Hill, 1996\n\nTerm rewriting and \
Programming Paradigms\nR. E. Maeder\nin Mathematics with Vision\nProceedings \
of the First International Mathematica Symposium\nComputational Mechanics \
Publications 1995, pp. 7-19\n\nProgramming in Mathematica\nR. E. Maeder\n\
Addison-Wesley, second edition, 1991\n\nSelf-similar Mosaics\nN. Dolbilin\n\
Quantum, July/August 2000, pp.4-9\n"
}], "Reference"]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduction", "SectionFirst"],

Cell[TextData[{
  StyleBox["Rewriting systems (RS), also called ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Reduction Systems, String Rewriting Systems",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" or ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Term Rewriting Systems",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[", have been widely used in contexts in which formulae \
manipulation plays a prominent role, such as symbolic and functional \
programming, formal grammars (useful in the design of compilers and \
interpreters), computer graphics, simulation, etc. This is due to their \
intrinsic ability to specify, through employing a set of ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["directed transformational equations",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[", the basic mechanism of subterm substitution. Repeated \
applications of this mechanism on a given term are considered as leading to a \
\[OpenCurlyDoubleQuote]simpler form\[CloseCurlyDoubleQuote] of this term. \
However, it is possible that we might never arrive at this simple form - \
called ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["normal",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["form",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[", due to either divergence or cycling of the terms generated.\n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FormatType->StandardForm,
    FontFamily->"Courier New"],
  StyleBox["RS are determined by a series of productions meant to be applied \
to specific objects. This application consists in the substitution of a \
pattern occurring on the object also appearing on the left side of a \
production, by the corresponding pattern on the right side of this \
production. Consider, for example the following simple RS:\n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  "\n\t\t21 \[Rule] 12\n\t\t31 \[Rule] 13\n\t\t32 \[Rule] 23\n\n",
  StyleBox["Throughout its repeated application on a given word w \[Element] \
{1, 2, 3}",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["*",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" (that is, the objects we are considering consist on all strings \
of symbols taken from the alphabet {1, 2, 3}), we obtain a sorted anagram of \
w. It does not matter in which order we apply the rules, the convergence to \
the normal form is inevitable and it leads to a word of the form 1*2*3*. Such \
systems are called ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["confluent",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" or ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Church-Rosser",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[". This paradigm is also present in the study of cellular \
automata, wherein the notion of transitions over discrete state spaces is \
characterized by this approach.\n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  "\n",
  StyleBox["The aim of this work is to illustrate the application of RS on a \
variety of important settings throughout the following sections: \
One-dimensional Checkers,  Group Theory,  Equivalence Relations, Systems of  \
Numeric Productions, Recursive Productions, L systems,  ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  "From Binary Numbers to Compositions and Huffman Coding,",
  StyleBox[" providing a smorgasbord of ideas on this fascinating topic. A \
series of animations supplementing several parts of  the text is also \
provided. We are using ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" version 5",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Abstract",
  TextAlignment->Left,
  TextJustification->0]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.- One-dimensional Checkers", "Section",
  FontColor->RGBColor[1, 0.889998, 0.00999466],
  Background->RGBColor[0.4392, 0.502007, 0.564706]],

Cell["\<\
Not all RS are confluent. Consider, for example, the following:\
\>", "Text"],

Cell["\<\
110 \[Rule] 001
011 \[Rule] 100\
\>", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["which corresponds to the jumps made in the \
one-dimensional version of the game of checkers. If we consider as the normal \
form of a word that one containing only one occurrence of the symbol 1, \
disregarding the number of symbols 0 it contains, then not all words lead to \
normal forms, and even those that do might not reach it due to the \
non-deterministic character of the rewriting rules. Termination is, in \
general an undecidable property of RS. For example, the word 0110011110 \
possess a normal form but applying the first of the above rules to obtain \
0110011001 leads it away from reaching it. \n\nLet us obtain all \"valid\" \
words, that is, those words of a given size n having normal form and hence \
leading to a successful solitaire game of one-dimensional checkers. Valid \
words are of the form 1x1 where x \[Element] {0, 1}* is a word of length n-2. \
We can readily obtain the set of all valid words from an initial list of \
candidates.",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(candidates[n_] := 
      Map[Join[{1}, IntegerDigits[#, 2, n - 2], {1}] &, 
        Range[0, 2\^\(n - 2\) - 1]]\)], "Input",
  CellLabel->"In[1]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(candidates[5]\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \({{1, 0, 0, 0, 1}, {1, 0, 0, 1, 1}, {1, 0, 1, 0, 1}, {1, 0, 1, 1, 
        1}, {1, 1, 0, 0, 1}, {1, 1, 0, 1, 1}, {1, 1, 1, 0, 1}, {1, 1, 1, 1, 
        1}}\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell[TextData[StyleBox["And the rules can be coded as:",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(jump := {{X___, 1, 1, 0, Y__} \[Rule] {X, 0, 0, 1, Y}, {X__, 0, 1, 1, 
            Y___} \[Rule] {X, 1, 0, 0, Y}}\)], "Input",
  CellLabel->"In[3]:=",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "The non-determinism in applying this rule is captured by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s function ",
  StyleBox["ReplaceList", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReplaceList[{1, 1, 1, 0, 1, 1, 1, 1}, jump]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({{1, 0, 0, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 0, 0, 1, 1}}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "In jumping at the end positions, we have to eliminate any leading and \
trailing zeroes that might appear. We accomplish this by making use of \
function ",
  StyleBox["compress", "Input"],
  " and changing the jumping transformations accordingly."
}], "Text"],

Cell[BoxData[{
    \(compress[{0, x__}] := compress[{x}]\), "\[IndentingNewLine]", 
    \(compress[{x__, 0}] := compress[{x}]\), "\[IndentingNewLine]", 
    \(\(\(compress[x_] := x\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(jump := {{X___, 1, 1, 0, Y__} \[RuleDelayed] 
          compress[{X, 0, 0, 1, Y}], {X__, 0, 1, 1, Y___} \[RuleDelayed] 
          compress[{X, 1, 0, 0, Y}], \[IndentingNewLine]{1, 
            1} \[RuleDelayed] \ {1, 1}\ }\)}], "Input",
  CellLabel->"In[5]:="],

Cell[TextData[{
  "We are  interested in succesively applying ",
  StyleBox["junp", "Input"],
  " to get to {1, 1} (or equivalently to 1; we choose this criteria so that \
we always have an ending pair of 1's). By using ",
  StyleBox["FixedPointList", "Input"],
  " we obtain all successive positions from a given starting one."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FixedPointList[
      Flatten[\(ReplaceList[#, jump] &\)\  /@ \ #, 1] &, {{1, 1, 1, 0, 1, 1, 
          1, 1}}]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({{{1, 1, 1, 0, 1, 1, 1, 1}}, {{1, 0, 0, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 0, 
          0, 1, 1}}, {{1, 0, 1, 0, 0, 1, 1, 1}, {1, 1, 0, 0, 1, 0, 1, 1}, {1, 
          1, 1, 1, 0, 1}}, {{1, 0, 1, 0, 1, 0, 0, 1}, {1, 0, 1, 0, 1, 1}, {1, 
          1, 0, 0, 1, 1}, {1, 1, 0, 0, 1, 1}}, {{1, 0, 1, 1}, {1, 0, 1, 
          1}, {1, 1, 0, 1}, {1, 0, 1, 1}, {1, 1, 0, 1}}, {{1, 1}, {1, 1}, {1, 
          1}, {1, 1}, {1, 1}}, {{1, 1}, {1, 1}, {1, 1}, {1, 1}, {1, 
          1}}}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["\<\
This means that there are five ways to succeed, and correspond to the \
building of the game tree\
\>", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000910001SQ000`40O003
h00Oogooogoo@goo003oOoooOom3Ool00?mooomood=oo`00ogooogoo@goo
003oOoooOom3Ool00?mooomood=oo`00ogooogoo@goo003oOoooOom3Ool0
0?mooomood=oo`00ogooogoo@goo003oOoooOom3Ool00?mooomood=oo`00
ogooogoo@goo003oOoooOom3Ool00?mooomood=oo`00ogooogoo@goo003o
OoooOom3Ool00?mooomood=oo`00ogooogoo@goo003oOoooOom3Ool00?mo
oomood=oo`00ogooogoo@goo003oOoooOom3Ool00?mooomood=oo`00ogoo
ogoo@goo003oOoooOom3Ool00?mooomood=oo`00ogooogoo@goo003oOooo
Oom3Ool00?mooomood=oo`00ogooogoo@goo003oOoooOom3Ool00?mooomo
od=oo`00ogooogoo@goo003oOoooOom3Ool00?mooomood=oo`00ogooogoo
@goo003oOoooOom3Ool00?mooomood=oo`00ogooogoo@goo003oOoooOom3
Ool00?mooomood=oo`00ogooogoo@goo003oOoooOom3Ool00?mooomood=o
o`00ogooogoo@goo003oOoooOom3Ool00?mooomood=oo`00ogooogoo@goo
003oOoooOom3Ool00?mooomood=oo`00ogooogoo@goo003oOoooOom3Ool0
0?mooomood=oo`00ogooogoo@goo003oOoooOom3Ool00?moo`aoo`<000Uo
o`<00?moobQoo`00/goo0`002Goo0`00BGoo0`002Goo0`00ogoo:7oo002c
Ool30009Ool30019Ool30009Ool3000mOol30009Ool3000jOol30009Ool3
002BOol00;=oo`<000Uoo`<004Uoo`<000Uoo`<003eoo`<000Uoo`<003Yo
o`<000Uoo`<0099oo`00/goo0`002Goo0`00BGoo0`002Goo0`00?Goo0`00
2Goo0`00>Woo0`002Goo0`00CWoo0`002Goo0`00=Goo002cOol30009Ool3
0019Ool30009Ool3000mOol30009Ool3000jOol30009Ool3001>Ool30009
Ool3000eOol00;=oo`<000Uoo`<004Uoo`<000Uoo`<003eoo`<000Uoo`<0
03Yoo`<000Uoo`<004ioo`<000Uoo`<003Eoo`00/goo0`002Goo0`00BGoo
0`002Goo0`00?Goo0`002Goo0`00>Woo0`002Goo0`00CWoo0`002Goo0`00
=Goo002cOol30009Ool30019Ool30009Ool2000nOol30009Ool3000jOol3
0009Ool3001>Ool30009Ool3000eOol00;=oo`<000Uoo`8004Yoo`<000Yo
o`8003eoo`<000Uoo`<003Yoo`<000Uoo`<004ioo`<000Uoo`<003Eoo`00
/goo0`002Woo0P00BGoo0`002Goo0`00?Goo0`002Goo0P00>goo0`002Goo
0P00Cgoo0`002Goo0`00=Goo002cOol30009Ool30019Ool2000:Ool3000m
Ool3000:Ool2000jOol3000:Ool2001>Ool30009Ool3000eOol00;=oo`80
00Yoo`<004Qoo`04001oo`000007Ool5000mOol30009Ool3000jOol30009
Ool3001>Ool30009Ool2000fOol00;9oo`04001oo`000007Ool50017Ool5
0007Ool5000mOol2000:Ool3000jOol2000:Ool3001>Ool3000:Ool2000e
Ool00;5oo`D000Moo`D004Moo`D000Moo`D003aoo`04001oo`000007Ool5
000iOol01000Ool000001goo1@00CWoo0`002Goo0`00=Goo002aOol50007
Ool50018Ool40008Ool4000kOol50007Ool5000hOol50007Ool5001>Ool2
000:Ool3000eOol00;9oo`@000Qoo`@004Yoo`8000Yoo`8003]oo`D000Mo
o`D003Qoo`D000Moo`D004eoo`04001oo`000007Ool5000eOol00;Aoo`80
00Yoo`8004Yoo`8000Yoo`8003aoo`@000Qoo`@003Uoo`@000Qoo`@004ao
o`D000Moo`D003Eoo`00]7oo0P002Woo0P00UWoo0P002Woo0P00>goo0P00
2Woo0P00C7oo1@001goo1@00=Goo003oOomIOol2000:Ool2000kOol2000:
Ool2001=Ool40008Ool4000eOol00?mooomoo`8000Yoo`8003Eoo`00ogoo
ogoo0P002Woo0P00=Goo003oOoooOom3Ool00?mooomood=oo`00ogoo4Woo
00<007ooOol0ogoo;Woo002iOol00`00Oomoo`1EOol00`00Oomoo`3oOol^
Ool00;Uoo`03001oogoo05Eoo`03001oogoo04Uoo`03001oogoo04Ioo`03
001oogoo09Qoo`00^Goo00<007ooOol0EGoo00<007ooOol0BGoo00<007oo
Ool0AWoo00<007ooOol0V7oo002iOol00`00Oomoo`1EOol00`00Oomoo`19
Ool00`00Oomoo`16Ool00`00Oomoo`1JOol00`00Oomoo`0kOol00;Uoo`03
001oogoo05Eoo`03001oogoo04Uoo`03001oogoo04Ioo`03001oogoo05Yo
o`03001oogoo03]oo`00^Goo00<007ooOol0EGoo00<007ooOol0BGoo00<0
07ooOol0AWoo00<007ooOol0FWoo00<007ooOol0>goo002iOol00`00Oomo
o`1EOol00`00Oomoo`19Ool00`00Oomoo`16Ool00`00Oomoo`1JOol00`00
Oomoo`0kOol00;Uoo`03001oogoo05Eoo`03001oogoo04Uoo`03001oogoo
04Ioo`03001oogoo05Yoo`03001oogoo03]oo`00^Goo00<007ooOol0EGoo
00<007ooOol0BGoo00<007ooOol0AWoo00<007ooOol0FWoo00<007ooOol0
>goo002iOol00`00Oomoo`1EOol00`00Oomoo`19Ool00`00Oomoo`16Ool0
0`00Oomoo`1JOol00`00Oomoo`0kOol00;Uoo`03001oogoo05Eoo`03001o
ogoo04Uoo`03001oogoo04Ioo`03001oogoo05Yoo`03001oogoo03]oo`00
^Goo00<007ooOol0EGoo00<007ooOol0BGoo00<007ooOol0AWoo00<007oo
Ool0FWoo00<007ooOol0>goo002iOol00`00Oomoo`1EOol00`00Oomoo`19
Ool00`00Oomoo`16Ool00`00Oomoo`1JOol00`00Oomoo`0kOol00;Uoo`03
001oogoo05Eoo`03001oogoo04Uoo`03001oogoo04Ioo`03001oogoo05Yo
o`03001oogoo03]oo`00^Goo00<007ooOol0EGoo00<007ooOol0BGoo00<0
07ooOol0AWoo00<007ooOol0FWoo00<007ooOol0>goo002iOol00`00Oomo
o`1EOol00`00Oomoo`19Ool00`00Oomoo`16Ool00`00Oomoo`1JOol00`00
Oomoo`0kOol00;Uoo`03001oogoo05Eoo`03001oogoo04Uoo`03001oogoo
04Ioo`03001oogoo05Yoo`03001oogoo03]oo`00^Goo00<007ooOol0EGoo
00<007ooOol0BGoo00<007ooOol0AWoo00<007ooOol0FWoo00<007ooOol0
>goo002iOol00`00Oomoo`1EOol00`00Oomoo`19Ool00`00Oomoo`16Ool0
0`00Oomoo`1JOol00`00Oomoo`0kOol00;Uoo`03001oogoo05Eoo`03001o
ogoo04Uoo`03001oogoo04Ioo`03001oogoo05Yoo`03001oogoo03]oo`00
^Goo00<007ooOol0EGoo00<007ooOol0BGoo00<007ooOol0AWoo00<007oo
Ool0FWoo00<007ooOol0>goo002iOol00`00Oomoo`1EOol00`00Oomoo`19
Ool00`00Oomoo`16Ool00`00Oomoo`1JOol00`00Oomoo`0kOol00;Uoo`03
001oogoo05Eoo`03001oogoo04Uoo`03001oogoo04Ioo`03001oogoo05Yo
o`03001oogoo03]oo`00^Goo00<007ooOol0EGoo00<007ooOol0BGoo00<0
07ooOol0AWoo00<007ooOol0FWoo00<007ooOol0>goo002iOol00`00Oomo
o`1EOol00`00Oomoo`19Ool00`00Oomoo`16Ool00`00Oomoo`1JOol00`00
Oomoo`0kOol00;Uoo`03001oogoo05Eoo`03001oogoo04Uoo`03001oogoo
04Ioo`03001oogoo05Yoo`03001oogoo03]oo`00^Goo00<007ooOol0XGoo
00<007ooOol0AWoo00<007ooOol0FWoo00<007ooOol0>goo003oOomNOol0
0`00Oomoo`16Ool00`00Oomoo`1JOol00`00Oomoo`0kOol00?mooomoo`Eo
o`03001oogoo03]oo`00ogooogoo1Goo00<007ooOol0>goo003oOoooOom3
Ool00?mooomood=oo`00ogooogoo@goo002XOol30009Ool40009Ool30009
Ool3000^Ool30009Ool40009Ool30009Ool3003oOolLOol00:Qoo`<000Mo
o`P000Moo`<000Uoo`<002ioo`<000Moo`P000Moo`<000Uoo`<0029oo`<0
00Uoo`<000Uoo`@000Uoo`<00=5oo`00Z7oo0`001Woo2P001Woo0`002Goo
0`00;Woo0`001Woo2P001Woo0`002Goo0`008Woo0`002Goo0`001goo2000
1goo0`0097oo0`002Goo10002Goo0`002Goo0`00QGoo002XOol30006Ool4
0002Ool40006Ool30009Ool3000^Ool30006Ool40002Ool40006Ool30009
Ool3000ROol30009Ool30006Ool:0006Ool3000TOol30007Ool80007Ool3
0009Ool3000bOol30009Ool30009Ool40009Ool3000[Ool00:Qoo`<000Eo
o`@000Aoo`<000Ioo`<000Uoo`<002ioo`<000Eoo`@000Aoo`<000Ioo`<0
00Uoo`<0029oo`<000Uoo`<000Ioo`@0009oo`@000Ioo`<002Aoo`<000Io
o`X000Ioo`<000Uoo`<0039oo`<000Uoo`<000Moo`P000Moo`<002]oo`00
Z7oo0`001Goo0`001Goo0`001Woo0`002Goo0`00;Woo0`001Goo0`001Goo
0`001Woo0`002Goo0`008Woo0`002Goo0`001Goo100017oo0`001Woo0`00
97oo0`001Woo10000Woo10001Woo0`002Goo0`00<Woo0`002Goo0`001Woo
2P001Woo0`00:goo002XOol30005Ool30005Ool30006Ool30009Ool3000^
Ool30005Ool30005Ool30006Ool30009Ool3000ROol30009Ool30005Ool3
0005Ool30006Ool3000TOol30005Ool40004Ool30006Ool30009Ool3000b
Ool30009Ool30006Ool40002Ool40006Ool3000[Ool00:Qoo`<000Eoo`<0
00Eoo`<000Ioo`<000Uoo`<002ioo`<000Eoo`<000Eoo`<000Ioo`<000Uo
o`<0029oo`<000Uoo`<000Eoo`<000Eoo`<000Ioo`<002Aoo`<000Eoo`<0
00Eoo`<000Ioo`<000Uoo`<0039oo`<000Uoo`<000Eoo`@000Aoo`<000Io
o`<002]oo`00Z7oo0`001Goo0`001Goo0`001Woo0`002Goo0`00;Woo0`00
1Goo0`001Goo0`001Woo0`002Goo0`008Woo0`002Goo0`001Goo0`001Goo
0`001Woo0`0097oo0`001Goo0`001Goo0`001Woo0`002Goo0`00<Woo0`00
2Goo0`001Goo0`001Goo0`001Woo0`00:goo002XOol30005Ool30005Ool3
0006Ool30009Ool3000^Ool30005Ool30005Ool30006Ool30009Ool3000R
Ool30009Ool30005Ool30005Ool30006Ool3000TOol30005Ool30005Ool3
0006Ool30009Ool3000bOol30009Ool30005Ool30005Ool30006Ool3000[
Ool00:Qoo`<000Eoo`<000Eoo`<000Ioo`<000Uoo`<002ioo`<000Eoo`<0
00Eoo`<000Ioo`<000Uoo`<0029oo`<000Uoo`<000Eoo`<000Eoo`<000Io
o`<002Aoo`<000Eoo`<000Eoo`<000Ioo`<000Uoo`<0039oo`<000Uoo`<0
00Eoo`<000Eoo`<000Ioo`<002]oo`00Z7oo0`001Goo0`001Goo0`001Woo
0`002Goo0`00;Woo0`001Goo0`001Goo0`001Woo0`002Goo0`008Woo0`00
2Goo0`001Goo0`001Goo0`001Woo0`0097oo0`001Goo0`001Goo0`001Woo
0`002Goo0`00<Woo0`002Goo0`001Goo0`001Goo0`001Woo0`00:goo002V
Ool50005Ool30005Ool30004Ool50007Ool5000/Ool50005Ool30005Ool3
0004Ool50007Ool5000ROol30009Ool30005Ool30005Ool30006Ool3000T
Ool30005Ool30005Ool30006Ool30009Ool3000bOol30009Ool30005Ool3
0005Ool30006Ool3000[Ool00:Ioo`D000Eoo`@000Aoo`<000Aoo`D000Mo
o`D002aoo`D000Eoo`@000Aoo`<000Aoo`D000Moo`D0021oo`D000Moo`D0
00Eoo`<000Eoo`<000Aoo`D002Aoo`<000Eoo`<000Eoo`<000Ioo`<000Uo
o`<0039oo`<000Uoo`<000Eoo`<000Eoo`<000Ioo`<002]oo`00YWoo1@00
1Woo10000Woo100017oo1@001goo1@00;7oo1@001Woo10000Woo100017oo
1@001goo1@0087oo1@001goo1@001Goo100017oo0`0017oo1@008Woo1@00
1Goo0`001Goo0`0017oo1@001goo1@00<Woo0`002Goo0`001Goo0`001Goo
0`001Woo0`00:goo002WOol40006Ool:0006Ool30009Ool3000]Ool40006
Ool:0006Ool30009Ool3000POol50007Ool50006Ool40002Ool40004Ool5
000ROol50005Ool40004Ool30004Ool50007Ool5000`Ool50007Ool50005
Ool30005Ool30004Ool5000[Ool00:Uoo`8000Moo`L000Uoo`8000Yoo`80
02moo`8000Moo`L000Uoo`8000Yoo`80025oo`@000Qoo`@000Ioo`X000Io
o`<0029oo`D000Ioo`@0009oo`@000Aoo`D000Moo`D0031oo`D000Moo`D0
00Eoo`@000Aoo`<000Aoo`D002]oo`00ZGoo0P002Goo10002Woo0P002Woo
0P00;goo0P002Goo10002Woo0P002Woo0P008goo0P002Woo0P001goo1`00
2Goo0P008goo10001Woo2P001Woo0`002Goo0`00<7oo1@001goo1@001Woo
10000Woo100017oo1@00:goo003oOom:Ool2000:Ool20009Ool4000:Ool2
000UOol20007Ool70009Ool2000:Ool2000aOol40008Ool40006Ool:0006
Ool3000[Ool00?mooiIoo`8000Uoo`@000Yoo`8000Yoo`8003=oo`8000Yo
o`8000Moo`L000Uoo`8002]oo`00ogool7oo0P002Woo0P002Goo10002Woo
0P00:goo003oOoooOom3Ool00?mooomood=oo`00ogoo4Woo00<007ooOol0
@Goo00<007ooOol0jGoo003oOolCOol00`00Oomoo`0oOol00`00Oomoo`3Z
Ool00;Moo`03001oogoo05Qoo`03001oogoo03ioo`03001oogoo0>]oo`00
]goo00<007ooOol0FGoo00<007ooOol0?7oo00<007ooOol0EWoo00<007oo
Ool0Tgoo002gOol00`00Oomoo`1IOol00`00Oomoo`0kOol00`00Oomoo`1H
Ool00`00Oomoo`2BOol00;Moo`03001oogoo05Yoo`03001oogoo03Yoo`03
001oogoo05Uoo`03001oogoo04eoo`03001oogoo045oo`00]goo00<007oo
Ool0Fgoo00<007ooOol0>7oo00<007ooOol0FWoo00<007ooOol0C7oo00<0
07ooOol0@Woo002gOol00`00Oomoo`1KOol00`00Oomoo`0gOol00`00Oomo
o`1LOol00`00Oomoo`1:Ool00`00Oomoo`13Ool00;Moo`03001oogoo05ao
o`03001oogoo03Eoo`03001oogoo05ioo`03001oogoo04Qoo`03001oogoo
04Aoo`00]goo00<007ooOol0G7oo00<007ooOol0=7oo00<007ooOol0H7oo
00<007ooOol0AWoo00<007ooOol0AGoo002gOol00`00Oomoo`1MOol00`00
Oomoo`0bOol00`00Oomoo`1ROol00`00Oomoo`14Ool00`00Oomoo`16Ool0
0;Moo`03001oogoo05ioo`03001oogoo031oo`03001oogoo06=oo`03001o
ogoo04=oo`03001oogoo04Moo`00]goo00<007ooOol0GWoo00<007ooOol0
;goo00<007ooOol0IGoo00<007ooOol0@Goo00<007ooOol0B7oo002gOol0
0`00Oomoo`1OOol00`00Oomoo`0^Ool00`00Oomoo`1VOol00`00Oomoo`0o
Ool00`00Oomoo`19Ool00;Moo`03001oogoo061oo`03001oogoo02aoo`03
001oogoo06Qoo`03001oogoo03eoo`03001oogoo04Yoo`00]goo00<007oo
Ool0H7oo00<007ooOol0:goo00<007ooOol0JWoo00<007ooOol0>goo00<0
07ooOol0Bgoo002gOol00`00Oomoo`1QOol00`00Oomoo`0YOol00`00Oomo
o`1[Ool00`00Oomoo`0jOol00`00Oomoo`1<Ool00;Moo`03001oogoo065o
o`03001oogoo02Qoo`03001oogoo06eoo`03001oogoo03Qoo`03001oogoo
04eoo`00]goo00<007ooOol0HWoo00<007ooOol09Woo00<007ooOol0Kgoo
00<007ooOol0=Woo00<007ooOol0CWoo002gOol00`00Oomoo`1SOol00`00
Oomoo`0TOol00`00Oomoo`1aOol00`00Oomoo`0dOol00`00Oomoo`1?Ool0
0;Moo`03001oogoo06=oo`03001oogoo02=oo`03001oogoo07=oo`03001o
ogoo039oo`03001oogoo051oo`00]goo00<007ooOol0I7oo00<007ooOol0
8Woo00<007ooOol0Lgoo00<007ooOol0<Goo00<007ooOol0DGoo002gOol0
0`00Oomoo`1TOol00`00Oomoo`0QOol00`00Oomoo`1eOol00`00Oomoo`0_
Ool00`00Oomoo`1BOol00;Moo`03001oogoo06Eoo`03001oogoo01moo`03
001oogoo07Moo`03001oogoo02eoo`03001oogoo05=oo`00]goo00<007oo
Ool0IWoo00<007ooOol07Goo00<007ooOol0NGoo00<007ooOol0:Woo0P00
EWoo002gOol00`00Oomoo`1VOol00`00Oomoo`0LOol00`00Oomoo`1kOol0
0`00Oomoo`0XOol00`00Oomoo`1FOol00;Moo`03001oogoo06Moo`03001o
ogoo01Yoo`03001oogoo07aoo`03001oogoo02Moo`03001oogoo05Moo`00
]goo00<007ooOol0Igoo00<007ooOol06Goo00<007ooOol0OWoo00<007oo
Ool09Goo00<007ooOol0F7oo002gOol00`00Oomoo`1XOol00`00Oomoo`0G
Ool00`00Oomoo`20Ool00`00Oomoo`0SOol00`00Oomoo`1IOol00;Moo`03
001oogoo06Uoo`03001oogoo01Ioo`03001oogoo085oo`03001oogoo025o
o`03001oogoo05Yoo`00]goo00<007ooOol0JGoo00<007ooOol05Goo00<0
07ooOol0Pgoo00<007ooOol07goo00<007ooOol0Fgoo002gOol00`00Oomo
o`1ZOol00`00Oomoo`0COol00`00Oomoo`24Ool00`00Oomoo`0NOol00`00
Oomoo`1LOol00;Moo`03001oogoo06]oo`03001oogoo015oo`03001oogoo
08Ioo`03001oogoo01aoo`03001oogoo05eoo`00]goo00<007ooOol0Jgoo
00<007ooOol047oo00<007ooOol0R7oo00<007ooOol06Woo00<007ooOol0
GWoo002gOol00`00Oomoo`1/Ool00`00Oomoo`0>Ool00`00Oomoo`2:Ool0
0`00Oomoo`0HOol00`00Oomoo`1OOol00;Moo`03001oogoo06aoo`03001o
ogoo00eoo`03001oogoo08aoo`03001oogoo01Ioo`03001oogoo061oo`00
]goo00<007ooOol0KGoo00<007ooOol02goo00<007ooOol0SGoo00<007oo
Ool05Goo00<007ooOol0HGoo002gOol00`00Oomoo`1^Ool00`00Oomoo`0:
Ool00`00Oomoo`2>Ool00`00Oomoo`0COol00`00Oomoo`1ROol00;Moo`03
001oogoo06ioo`03001oogoo00Uoo`03001oogoo091oo`03001oogoo015o
o`03001oogoo06=oo`00ogoo:Woo00<007ooOol01goo00<007ooOol0TWoo
00<007ooOol03goo00<007ooOol0I7oo003oOolZOol00`00Oomoo`06Ool0
0`00Oomoo`2DOol00`00Oomoo`0=Ool00`00Oomoo`1UOol00?moob]oo`03
001oogoo00Aoo`03001oogoo09Eoo`03001oogoo00aoo`03001oogoo06Io
o`00ogoobgoo00<007ooOol02Woo00<007ooOol0Igoo003oOoo<Ool00`00
Oomoo`08Ool00`00Oomoo`1XOol00?mooomood=oo`00ogooogoo@goo000E
Ool30009Ool40009Ool30009Ool4000:Ool30009Ool40009Ool4000:Ool3
003oOoo@Ool001Eoo`<000Moo`P000Moo`<000Moo`P000Qoo`<000Moo`P0
00Eoo`P000Qoo`<002]oo`<000Uoo`@000Uoo`<000Uoo`@000Yoo`<000Uo
o`<00?moof=oo`005Goo0`001Woo2P001Woo0`001Woo2P001goo0`001Woo
2P000goo2P001goo0`00:goo0`001goo20001goo0`001goo200027oo0`00
2Goo0`00;7oo0`002Goo0`002Goo10002Goo10002Woo0`002Goo0`00m7oo
000EOol30006Ool40002Ool40006Ool30006Ool40002Ool40007Ool30006
Ool40002Ool40003Ool40002Ool40007Ool3000[Ool30006Ool:0006Ool3
0006Ool:0007Ool30009Ool3000/Ool30009Ool30007Ool80005Ool80008
Ool30009Ool3003dOol001Eoo`<000Eoo`@000Aoo`<000Ioo`<000Ioo`<0
00Aoo`@000Ioo`<000Eoo`@000Aoo`<000=oo`<000Aoo`@000Ioo`<002]o
o`<000Ioo`@0009oo`@000Ioo`<000Ioo`@0009oo`@000Moo`<000Uoo`<0
02aoo`<000Uoo`<000Ioo`X000=oo`X000Moo`<000Uoo`<006Eoo`<000Uo
o`<000Uoo`@000Uoo`@000Yoo`<000Uoo`<004eoo`005Goo0`001Goo0`00
1Goo0`001Woo0`001Woo0`001Goo0`001Woo0`001Goo0`001Goo0`000goo
0`001Goo0`001Woo0`00:goo0`001Goo100017oo0`001Woo0`001Woo0`00
17oo10001Woo0`002Goo0`00;7oo0`002Goo0`001Woo10000Woo10000goo
10000Woo10001goo0`002Goo0`00IGoo0`002Goo0`001goo20001Goo2000
27oo0`002Goo0`00CGoo000EOol30005Ool30005Ool30006Ool30006Ool3
0005Ool30006Ool30005Ool30005Ool30003Ool30005Ool30006Ool3000[
Ool30005Ool30005Ool30006Ool30006Ool30005Ool30006Ool30009Ool3
000/Ool30009Ool30005Ool40004Ool30003Ool30004Ool40006Ool30009
Ool3001UOol30009Ool30006Ool:0003Ool:0007Ool30009Ool3001=Ool0
01Eoo`<000Eoo`<000Eoo`<000Ioo`<000Ioo`<000Eoo`<000Ioo`<000Eo
o`<000Eoo`<000=oo`<000Eoo`<000Ioo`<002]oo`<000Eoo`<000Eoo`<0
00Ioo`<000Ioo`<000Eoo`<000Ioo`<000Uoo`<002aoo`<000Uoo`<000Eo
o`<000Eoo`<000=oo`<000Eoo`<000Ioo`<000Uoo`<006Eoo`<000Uoo`<0
00Ioo`@0009oo`@000=oo`@0009oo`@000Moo`<000Uoo`<004eoo`005Goo
0`001Goo0`001Goo0`001Woo0`001Woo0`001Goo0`001Woo0`001Goo0`00
1Goo0`000goo0`001Goo0`001Woo0`00:goo0`001Goo0`001Goo0`001Woo
0`001Woo0`001Goo0`001Woo0`002Goo0`00;7oo0`002Goo0`001Goo0`00
1Goo0`000goo0`001Goo0`001Woo0`002Goo0`00IGoo0`002Goo0`001Goo
100017oo0`000goo0`0017oo10001Woo0`002Goo0`00CGoo000EOol30005
Ool30005Ool30006Ool30006Ool30005Ool30006Ool30005Ool30005Ool3
0003Ool30005Ool30006Ool3000[Ool30005Ool30005Ool30006Ool30006
Ool30005Ool30006Ool30009Ool3000/Ool30009Ool30005Ool30005Ool3
0003Ool30005Ool30006Ool30009Ool3001UOol30009Ool30005Ool30005
Ool30003Ool30005Ool30006Ool30009Ool3001=Ool001Eoo`<000Eoo`<0
00Eoo`<000Ioo`<000Ioo`<000Eoo`<000Ioo`<000Eoo`<000Eoo`<000=o
o`<000Eoo`<000Ioo`<002]oo`<000Eoo`<000Eoo`<000Ioo`<000Ioo`<0
00Eoo`<000Ioo`<000Uoo`<002aoo`<000Uoo`<000Eoo`<000Eoo`<000=o
o`<000Eoo`<000Ioo`<000Uoo`<006Eoo`<000Uoo`<000Eoo`<000Eoo`<0
00=oo`<000Eoo`<000Ioo`<000Uoo`<004eoo`005Goo0`001Goo0`001Goo
0`001Woo0`001Woo0`001Goo0`001Woo0`001Goo0`001Goo0`000goo0`00
1Goo0`001Woo0`00:goo0`001Goo0`001Goo0`001Woo0`001Woo0`001Goo
0`001Woo0`002Goo0`00;7oo0`002Goo0`001Goo0`001Goo0`000goo0`00
1Goo0`001Woo0`002Goo0`00IGoo0`002Goo0`001Goo0`001Goo0`000goo
0`001Goo0`001Woo0`002Goo0`00CGoo000COol50005Ool30005Ool30004
Ool50006Ool30005Ool30004Ool50005Ool30005Ool30003Ool30005Ool3
0004Ool5000[Ool30005Ool30005Ool30006Ool30006Ool30005Ool30006
Ool30009Ool3000/Ool30009Ool30005Ool30005Ool30003Ool30005Ool3
0006Ool30009Ool3001UOol30009Ool30005Ool30005Ool30003Ool30005
Ool30006Ool30009Ool3001=Ool001=oo`D000Eoo`@000Aoo`<000Aoo`D0
00Ioo`<000Aoo`@000Aoo`D000Eoo`@000Aoo`<000=oo`<000Aoo`@000Ao
o`D002Uoo`D000Eoo`<000Eoo`<000Aoo`D000Ioo`<000Eoo`<000Aoo`D0
00Moo`D002aoo`<000Uoo`<000Eoo`<000Eoo`<000=oo`<000Eoo`<000Io
o`<000Uoo`<006Eoo`<000Uoo`<000Eoo`<000Eoo`<000=oo`<000Eoo`<0
00Ioo`<000Uoo`<004eoo`004goo1@001Woo10000Woo100017oo1@001Woo
10000Woo10001Goo1@001Woo10000Woo10000goo10000Woo10001Goo1@00
:Goo1@001Goo100017oo0`0017oo1@001Woo0`0017oo100017oo1@001goo
1@00:Woo1@001goo1@001Goo0`001Goo0`000goo0`001Goo0`0017oo1@00
1goo1@00IGoo0`002Goo0`001Goo0`001Goo0`000goo0`001Goo0`001Woo
0`002Goo0`00CGoo000DOol40006Ool:0006Ool30006Ool:0006Ool40006
Ool:0003Ool:0006Ool4000YOol50006Ool40002Ool40004Ool50006Ool4
0002Ool40005Ool50007Ool5000ZOol50007Ool50005Ool40004Ool30003
Ool30004Ool40004Ool50007Ool5001UOol30009Ool30005Ool30005Ool3
0003Ool30005Ool30006Ool30009Ool3001=Ool001Ioo`8000Moo`L000Uo
o`8000Qoo`L000Uoo`8000Moo`L000Moo`L000Uoo`8002Yoo`@000Ioo`X0
00Ioo`<000Ioo`X000Ioo`@000Qoo`@002Yoo`D000Moo`D000Ioo`@0009o
o`@000=oo`@0009oo`@000Eoo`D000Moo`D006=oo`D000Moo`D000Eoo`<0
00Eoo`<000=oo`<000Eoo`<000Aoo`D000Moo`D004eoo`005Woo0P002Goo
10002Woo0P002Goo10002goo0P002Goo10002Goo10002goo0P00;7oo0P00
1goo1`002Goo0P0027oo1`002Goo0P002Woo0P00:goo100027oo10001Woo
2P000goo2P001Woo100027oo1000Hgoo1@001goo1@001Goo100017oo0`00
0goo0`0017oo100017oo1@001goo1@00CGoo002NOol20009Ool4000:Ool2
0009Ool4000;Ool2000:Ool2000]Ool2000:Ool20007Ool70007Ool70009
Ool2000:Ool2001SOol50007Ool50006Ool40002Ool40003Ool40002Ool4
0005Ool50007Ool5001=Ool00?moo`eoo`8000Yoo`8000Uoo`@000Uoo`@0
00]oo`8000Yoo`8006Aoo`@000Qoo`@000Ioo`X000=oo`X000Ioo`@000Qo
o`@004eoo`00ogoo]7oo0P002Woo0P001goo1`001goo1`002Goo0P002Woo
0P00CGoo003oOondOol2000:Ool20009Ool40009Ool4000;Ool2000:Ool2
001=Ool00?mooomood=oo`00>goo00<007ooOol0ogooogoo1Goo000kOol0
0`00Oomoo`28Ool00`00Oomoo`3oOomiOol003]oo`03001oogoo08Uoo`80
065oo`03001oogoo0?mooaEoo`00>goo00<007ooOol0Rgoo00<007ooOol0
G7oo0P00Y7oo00<007ooOol0L7oo000kOol00`00Oomoo`2<Ool2001JOol2
002VOol00`00Oomoo`1`Ool003]oo`03001oogoo08ioo`03001oogoo05Io
o`03001oogoo0:Ioo`03001oogoo071oo`00>goo00<007ooOol0Sgoo00<0
07ooOol0Dgoo0P00ZGoo00<007ooOol0L7oo000kOol00`00Oomoo`2@Ool2
001AOol2002[Ool00`00Oomoo`1`Ool003]oo`03001oogoo099oo`03001o
ogoo04eoo`03001oogoo0:]oo`03001oogoo071oo`00>goo00<007ooOol0
Tgoo0P00Bgoo0P00[Woo00<007ooOol0L7oo000kOol00`00Oomoo`2EOol0
0`00Oomoo`16Ool2002`Ool00`00Oomoo`1`Ool003]oo`03001oogoo09Io
o`8004Eoo`03001oogoo0;1oo`03001oogoo071oo`00>goo00<007ooOol0
V7oo00<007ooOol0@7oo0P00/goo00<007ooOol0L7oo000kOol00`00Oomo
o`2IOol00`00Oomoo`0mOol2002eOol00`00Oomoo`1`Ool003]oo`03001o
ogoo09Yoo`8003aoo`03001oogoo0;Eoo`03001oogoo071oo`00>goo00<0
07ooOol0W7oo00<007ooOol0=goo0P00^7oo00<007ooOol0L7oo000kOol0
0`00Oomoo`2MOol2000eOol2002jOol00`00Oomoo`1`Ool003]oo`03001o
ogoo09moo`03001oogoo035oo`03001oogoo0;Yoo`03001oogoo071oo`00
>goo00<007ooOol0X7oo0P00;goo0P00_Goo00<007ooOol0L7oo000kOol0
0`00Oomoo`2ROol00`00Oomoo`0ZOol2002oOol00`00Oomoo`1`Ool003]o
o`03001oogoo0:=oo`03001oogoo02Qoo`03001oogoo0;moo`03001oogoo
071oo`00>goo00<007ooOol0Y7oo0P009Woo0P00`Woo00<007ooOol0L7oo
000kOol00`00Oomoo`2VOol00`00Oomoo`0QOol20034Ool00`00Oomoo`1`
Ool003]oo`03001oogoo0:Moo`80021oo`03001oogoo0<Aoo`03001oogoo
071oo`00>goo00<007ooOol0ZGoo00<007ooOol06goo0P00agoo00<007oo
Ool0L7oo000kOol00`00Oomoo`2ZOol2000IOol20039Ool00`00Oomoo`1`
Ool003]oo`03001oogoo0:aoo`03001oogoo01Eoo`03001oogoo0<Uoo`03
001oogoo071oo`00>goo00<007ooOol0[Goo00<007ooOol04Woo0P00c7oo
00<007ooOol0L7oo000kOol00`00Oomoo`2^Ool2000@Ool2003>Ool00`00
Oomoo`1`Ool00>ioo`03001oogoo00aoo`03001oogoo0<ioo`03001oogoo
071oo`00kgoo0P00gGoo00<007ooOol0L7oo003aOol00`00Oomoo`3JOol0
0`00Oomoo`1`Ool00?mooomood=oo`00ogooogoo@goo003oOoooOom3Ool0
0?mooomood=oo`00ogooogoo@goo000DOol30009Ool40009Ool30009Ool4
000:Ool40009Ool30009Ool30009Ool3003oOooCOol001Aoo`<000Moo`P0
00Moo`<000Moo`P000Ioo`P000Moo`<000Uoo`<000Uoo`<005]oo`<000Uo
o`<000Uoo`@000Uoo`@000Yoo`<000Uoo`@000Uoo`<000Uoo`<00?mooaeo
o`0057oo0`001Woo2P001Woo0`001Woo2P0017oo2P001Woo0`002Goo0`00
2Goo0`00Fgoo0`002Goo0`001goo20001Goo200027oo0`001goo20001goo
0`002Goo0`00Rgoo0`002Goo0`002Goo0`002Goo0`002Goo10002Goo0`00
DGoo000DOol30006Ool40002Ool40006Ool30006Ool40002Ool40004Ool4
0002Ool40006Ool30009Ool30009Ool3001KOol30009Ool30006Ool:0003
Ool:0007Ool30006Ool:0006Ool30009Ool3002;Ool30009Ool30009Ool3
0009Ool30007Ool80007Ool3001AOol001Aoo`<000Eoo`@000Aoo`<000Io
o`<000Ioo`<000Aoo`@0009oo`@000Aoo`<000Ioo`<000Uoo`<000Uoo`<0
05]oo`<000Uoo`<000Ioo`@0009oo`@000=oo`@0009oo`@000Moo`<000Io
o`@0009oo`@000Ioo`<000Uoo`<008]oo`<000Uoo`<000Uoo`<000Uoo`<0
00Ioo`X000Ioo`<0055oo`0057oo0`001Goo0`001Goo0`001Woo0`001Woo
0`001Goo0`000Woo0`001Goo0`001Woo0`002Goo0`002Goo0`00Fgoo0`00
2Goo0`001Goo100017oo0`000goo0`0017oo10001Woo0`001Goo100017oo
0`001Woo0`002Goo0`00Rgoo0`002Goo0`002Goo0`002Goo0`001Woo1000
0Woo10001Woo0`00DGoo000DOol30005Ool30005Ool30006Ool30006Ool3
0005Ool30002Ool30005Ool30006Ool30009Ool30009Ool3001KOol30009
Ool30005Ool30005Ool30003Ool30005Ool30006Ool30005Ool30005Ool3
0006Ool30009Ool3002;Ool30009Ool30009Ool30009Ool30005Ool40004
Ool30006Ool3001AOol001Aoo`<000Eoo`<000Eoo`<000Ioo`<000Ioo`<0
00Eoo`<0009oo`<000Eoo`<000Ioo`<000Uoo`<000Uoo`<005]oo`<000Uo
o`<000Eoo`<000Eoo`<000=oo`<000Eoo`<000Ioo`<000Eoo`<000Eoo`<0
00Ioo`<000Uoo`<008]oo`<000Uoo`<000Uoo`<000Uoo`<000Eoo`<000Eo
o`<000Ioo`<0055oo`0057oo0`001Goo0`001Goo0`001Woo0`001Woo0`00
1Goo0`000Woo0`001Goo0`001Woo0`002Goo0`002Goo0`00Fgoo0`002Goo
0`001Goo0`001Goo0`000goo0`001Goo0`001Woo0`001Goo0`001Goo0`00
1Woo0`002Goo0`00Rgoo0`002Goo0`002Goo0`002Goo0`001Goo0`001Goo
0`001Woo0`00DGoo000DOol30005Ool30005Ool30006Ool30006Ool30005
Ool30002Ool30005Ool30006Ool30009Ool30009Ool3001KOol30009Ool3
0005Ool30005Ool30003Ool30005Ool30006Ool30005Ool30005Ool30006
Ool30009Ool3002;Ool30009Ool30009Ool30009Ool30005Ool30005Ool3
0006Ool3001AOol001Aoo`<000Eoo`<000Eoo`<000Ioo`<000Ioo`<000Eo
o`<0009oo`<000Eoo`<000Ioo`<000Uoo`<000Uoo`<005]oo`<000Uoo`<0
00Eoo`<000Eoo`<000=oo`<000Eoo`<000Ioo`<000Eoo`<000Eoo`<000Io
o`<000Uoo`<008]oo`<000Uoo`<000Uoo`<000Uoo`<000Eoo`<000Eoo`<0
00Ioo`<0055oo`0057oo0`001Goo0`001Goo0`001Woo0`001Woo0`001Goo
0`000Woo0`001Goo0`001Woo0`002Goo0`002Goo0`00Fgoo0`002Goo0`00
1Goo0`001Goo0`000goo0`001Goo0`001Woo0`001Goo0`001Goo0`001Woo
0`002Goo0`00Rgoo0`002Goo0`002Goo0`002Goo0`001Goo0`001Goo0`00
1Woo0`00DGoo000BOol50005Ool30005Ool30004Ool50006Ool30005Ool3
0002Ool30005Ool30004Ool50007Ool50007Ool5001KOol30009Ool30005
Ool30005Ool30003Ool30005Ool30006Ool30005Ool30005Ool30006Ool3
0009Ool3002;Ool30009Ool30009Ool30009Ool30005Ool30005Ool30006
Ool3001AOol0019oo`D000Eoo`@000Aoo`<000Aoo`D000Ioo`<000Aoo`@0
009oo`@000Aoo`<000Aoo`D000Moo`D000Moo`D005Uoo`D000Moo`D000Eo
o`<000Eoo`<000=oo`<000Eoo`<000Aoo`D000Eoo`<000Eoo`<000Aoo`D0
00Moo`D008]oo`<000Uoo`<000Uoo`<000Uoo`<000Eoo`<000Eoo`<000Io
o`<0055oo`004Woo1@001Woo10000Woo100017oo1@001Woo10000Woo1000
17oo10000Woo100017oo1@001goo1@001goo1@00FGoo1@001goo1@001Goo
100017oo0`000goo0`0017oo100017oo1@001Goo100017oo0`0017oo1@00
1goo1@00RGoo1@001goo1@001goo1@001goo1@001Goo0`001Goo0`0017oo
1@00DGoo000COol40006Ool:0006Ool30006Ool:0004Ool:0006Ool30009
Ool30009Ool3001IOol50007Ool50006Ool40002Ool40003Ool40002Ool4
0005Ool50006Ool40002Ool40004Ool50007Ool50029Ool50007Ool50007
Ool50007Ool50005Ool40004Ool30004Ool5001AOol001Eoo`8000Moo`L0
00Uoo`8000Qoo`L000Ioo`L000Uoo`8000Yoo`8000Yoo`8005Yoo`@000Qo
o`@000Ioo`X000=oo`X000Ioo`@000Ioo`X000Ioo`<000Uoo`<008Uoo`D0
00Moo`D000Moo`D000Moo`D000Ioo`@0009oo`@000Aoo`D0055oo`005Goo
0P002Goo10002Woo0P002Goo10002Woo10002Woo0P002Woo0P002Woo0P00
G7oo0P002Woo0P001goo1`001goo1`002Goo0P001goo1`002Goo0P002Woo
0P00RWoo100027oo100027oo100027oo10001Woo2P001Woo0`00DGoo003;
Ool2000:Ool20009Ool40009Ool4000;Ool20009Ool4000:Ool2000:Ool2
002<Ool2000:Ool2000:Ool2000:Ool20007Ool70009Ool2001AOol00?mo
ok9oo`8000Yoo`8000Yoo`8000Yoo`8000Uoo`@000Yoo`80055oo`00ogoo
ogoo@goo003oOoooOom3Ool00?mooomood=oo`00ogooogoo@goo003mOol2
003:Ool2001fOol003aoo`03001oogoo0<1oo`@00<Aoo`8007Qoo`00?7oo
00<007ooOol0a7oo0`00_goo0P00NWoo000lOol00`00Oomoo`37Ool4002h
Ool3001lOol003aoo`03001oogoo0<]oo`<00;=oo`8007moo`00?7oo00<0
07ooOol0cWoo1000[7oo0`00PGoo000lOol00`00Oomoo`3BOol3002WOol2
0024Ool003aoo`03001oogoo0=Eoo`@00:5oo`8008Ioo`00?7oo00<007oo
Ool0fGoo0`00Vgoo0`00R7oo000lOol00`00Oomoo`3LOol4002EOol2002;
Ool003aoo`03001oogoo0>1oo`<008moo`<008eoo`00?7oo00<007ooOol0
hgoo1000RGoo0P00T7oo000lOol00`00Oomoo`3WOol30024Ool2002BOol0
03aoo`03001oogoo0>Yoo`@007eoo`<009Aoo`00?7oo00<007ooOol0kWoo
0`00N7oo0P00Ugoo000lOol00`00Oomoo`3aOol3001cOol2002IOol003ao
o`03001oogoo0?Aoo`@006aoo`<009]oo`00?7oo00<007ooOol0n7oo0`00
Igoo0P00WWoo000lOol00`00Oomoo`3kOol4001POol3002POol003aoo`03
001oogoo0?moo`<005]oo`800:=oo`00?7oo00<007ooOol0ogoo0goo1000
EGoo0P00YGoo000lOol00`00Oomoo`3oOol7Ool3001?Ool3002WOol003ao
o`03001oogoo0?moo`Yoo`@004Uoo`800:Yoo`00?7oo00<007ooOol0ogoo
3Woo0`00A7oo0P00[7oo000lOol00`00Oomoo`3oOolAOol4000mOol3002^
Ool003aoo`03001oogoo0?mooaEoo`<003Qoo`800;5oo`00?7oo00<007oo
Ool0ogoo67oo1000<Goo0`00/goo003oOomKOol3000/Ool2002fOol00?mo
oeioo`@002Ioo`800;Qoo`00ogooHWoo0`0087oo0`00^Woo003oOomUOol4
000JOol2002mOol00?moofUoo`8001Eoo`<00;moo`00ogooOWoo0P00`Woo
003oOomlOol20034Ool001=oo`<000Uoo`@000Uoo`@000Yoo`<000Uoo`<0
00Uoo`<000Uoo`<000Uoo`<00?moo`eoo`800<Ioo`004goo0`001goo2000
1Goo200027oo0`002Goo0`002Goo0`002Goo0`002Goo0`00ogooeGoo000C
Ool30006Ool:0003Ool:0007Ool30009Ool30009Ool30009Ool30009Ool3
003oOooEOol001=oo`<000Ioo`@0009oo`@000=oo`@0009oo`@000Moo`<0
00Uoo`<000Uoo`<000Uoo`<000Uoo`<00?moomEoo`004goo0`001Goo1000
17oo0`000goo0`0017oo10001Woo0`002Goo0`002Goo0`002Goo0`002Goo
0`00ogooeGoo000COol30005Ool30005Ool30003Ool30005Ool30006Ool3
0009Ool30009Ool30009Ool30009Ool3003oOooEOol001=oo`<000Eoo`<0
00Eoo`<000=oo`<000Eoo`<000Ioo`<000Uoo`<000Uoo`<000Uoo`<000Uo
o`<00=Eoo`<000Uoo`<000Uoo`<000Uoo`<000Uoo`@000Uoo`@000Yoo`<0
00Uoo`<00:Eoo`004goo0`001Goo0`001Goo0`000goo0`001Goo0`001Woo
0`002Goo0`002Goo0`002Goo0`002Goo0`00eGoo0`002Goo0`002Goo0`00
2Goo0`001goo20001Goo200027oo0`002Goo0`00YGoo000COol30005Ool3
0005Ool30003Ool30005Ool30006Ool30009Ool30009Ool30009Ool30009
Ool3003EOol30009Ool30009Ool30009Ool30006Ool:0003Ool:0007Ool3
0009Ool3002UOol001=oo`<000Eoo`<000Eoo`<000=oo`<000Eoo`<000Io
o`<000Uoo`<000Uoo`<000Uoo`<000Uoo`<00=Eoo`<000Uoo`<000Uoo`<0
00Uoo`<000Ioo`@0009oo`@000=oo`@0009oo`@000Moo`<000Uoo`<00:Eo
o`004goo0`001Goo0`001Goo0`000goo0`001Goo0`001Woo0`002Goo0`00
2Goo0`002Goo0`002Goo0`00eGoo0`002Goo0`002Goo0`002Goo0`001Goo
100017oo0`000goo0`0017oo10001Woo0`002Goo0`00YGoo000COol30005
Ool30005Ool30003Ool30005Ool30006Ool30009Ool30009Ool30009Ool3
0009Ool3003EOol30009Ool30009Ool30009Ool30005Ool30005Ool30003
Ool30005Ool30006Ool30009Ool3002UOol0015oo`D000Eoo`<000Eoo`<0
00=oo`<000Eoo`<000Aoo`D000Moo`D000Moo`D000Moo`D000Moo`D00=Eo
o`<000Uoo`<000Uoo`<000Uoo`<000Eoo`<000Eoo`<000=oo`<000Eoo`<0
00Ioo`<000Uoo`<00:Eoo`004Goo1@001Goo100017oo0`000goo0`0017oo
100017oo1@001goo1@001goo1@001goo1@001goo1@00eGoo0`002Goo0`00
2Goo0`002Goo0`001Goo0`001Goo0`000goo0`001Goo0`001Woo0`002Goo
0`00YGoo000AOol50006Ool40002Ool40003Ool40002Ool40005Ool50007
Ool50007Ool50007Ool50007Ool5003EOol30009Ool30009Ool30009Ool3
0005Ool30005Ool30003Ool30005Ool30006Ool30009Ool3002UOol0019o
o`@000Ioo`X000=oo`X000Ioo`@000Qoo`@000Qoo`@000Qoo`@000Qoo`@0
0=Eoo`<000Uoo`<000Uoo`<000Uoo`<000Eoo`<000Eoo`<000=oo`<000Eo
o`<000Ioo`<000Uoo`<00:Eoo`0057oo0P001goo1`001goo1`002Goo0P00
2Woo0P002Woo0P002Woo0P002Woo0P00eGoo0`002Goo0`002Goo0`002Goo
0`001Goo0`001Goo0`000goo0`001Goo0`001Woo0`002Goo0`00YGoo000D
Ool20009Ool40009Ool4000;Ool2000:Ool2000:Ool2000:Ool2000:Ool2
003EOol30009Ool30009Ool30009Ool30005Ool30005Ool30003Ool30005
Ool30006Ool30009Ool3002UOol00?mood5oo`D000Moo`D000Moo`D000Mo
o`D000Eoo`<000Eoo`<000=oo`<000Eoo`<000Aoo`D000Moo`D00:Eoo`00
ogoo@Goo1@001goo1@001goo1@001goo1@001Goo100017oo0`000goo0`00
17oo100017oo1@001goo1@00YGoo003oOom1Ool50007Ool50007Ool50007
Ool50006Ool40002Ool40003Ool40002Ool40005Ool50007Ool5002UOol0
0?mood9oo`@000Qoo`@000Qoo`@000Qoo`@000Ioo`X000=oo`X000Ioo`@0
00Qoo`@00:Eoo`00ogooA7oo0P002Woo0P002Woo0P002Woo0P001goo1`00
1goo1`002Goo0P002Woo0P00YGoo0015Ool00`00Oomoo`3kOol2000:Ool2
000:Ool2000:Ool20009Ool40009Ool4000;Ool2000:Ool2002UOol004Io
o`03001oogoo0?moooUoo`00Agoo00<007ooOol0ogoon7oo0018Ool00`00
Oomoo`3oOoogOol004Uoo`03001oogoo0?moooIoo`00BWoo00<007ooOol0
ogoomGoo001;Ool00`00Oomoo`3oOolHOol5003GOol004aoo`03001oogoo
0?moo`moo`P00=aoo`00CGoo00<007ooOol0ogoo1Woo2000i7oo001=Ool0
0`00Oomoo`3mOol8003/Ool004ioo`03001oogoo0?Aoo`P00?Aoo`00Cgoo
00<007ooOol0jWoo2@00o7oo001@Ool00`00Oomoo`3QOol8003oOol6Ool0
055oo`03001oogoo0=Qoo`P00?moo`ioo`00DWoo00<007ooOol0cgoo2000
ogoo5Woo001COol00`00Oomoo`36Ool8003oOolNOol005Aoo`03001oogoo
0;aoo`T00?moobIoo`00EGoo00<007ooOol0/goo2000ogoo;goo001FOol0
0`00Oomoo`2ZOol8003oOolgOol005Moo`03001oogoo0:5oo`P00?moocmo
o`00F7oo00<007ooOol0V7oo2000ogooAgoo001IOol00`00Oomoo`2>Ool9
003oOom?Ool005Yoo`03001oogoo08Eoo`P00?mooeQoo`00Fgoo00<007oo
Ool0O7oo2000ogooH7oo001LOol00`00Oomoo`1cOol8003oOomXOol005eo
o`03001oogoo06Uoo`T00?moog1oo`00GWoo00<007ooOol0H7oo2000ogoo
NGoo001NOol00`00Oomoo`1HOol8003oOon1Ool005moo`03001oogoo04mo
o`P00?moohUoo`00H7oo00<007ooOol0AWoo2000ogooTGoo001QOol00`00
Oomoo`0lOol9003oOonIOol0069oo`03001oogoo03=oo`P00?mooj9oo`00
Hgoo00<007ooOol0:Woo2000ogooZWoo001TOol00`00Oomoo`0QOol8003o
OonbOol006Eoo`03001oogoo01Qoo`P00?mookYoo`00IWoo00<007ooOol0
4Woo1@00ogoo`Woo003oOoooOom3Ool00?mooomood=oo`00ogooogoo@goo
003oOoooOom3Ool00?mooomood=oo`00ogooogoo@goo0017Ool30009Ool3
0009Ool30009Ool40009Ool30009Ool30009Ool30009Ool3003oOonSOol0
04Moo`<000Uoo`<000Uoo`<000Moo`P000Moo`<000Uoo`<000Uoo`<000Uo
o`<00?mooj=oo`00Agoo0`002Goo0`002Goo0`001Woo2P001Woo0`002Goo
0`002Goo0`002Goo0`00ogooXgoo0017Ool30009Ool30009Ool30006Ool4
0002Ool40006Ool30009Ool30009Ool30009Ool3003oOonSOol004Moo`<0
00Uoo`<000Uoo`<000Eoo`@000Aoo`<000Ioo`<000Uoo`<000Uoo`<000Uo
o`<00?mooj=oo`00Agoo0`002Goo0`002Goo0`001Goo0`001Goo0`001Woo
0`002Goo0`002Goo0`002Goo0`00ogooXgoo0017Ool30009Ool30009Ool3
0005Ool30005Ool30006Ool30009Ool30009Ool30009Ool3003oOonSOol0
04Moo`<000Uoo`<000Uoo`<000Eoo`<000Eoo`<000Ioo`<000Uoo`<000Uo
o`<000Uoo`<00?mooj=oo`00Agoo0`002Goo0`002Goo0`001Goo0`001Goo
0`001Woo0`002Goo0`002Goo0`002Goo0`00ogooXgoo0017Ool30009Ool3
0009Ool30005Ool30005Ool30006Ool30009Ool30009Ool30009Ool3003o
OonSOol004Moo`<000Uoo`<000Uoo`<000Eoo`<000Eoo`<000Ioo`<000Uo
o`<000Uoo`<000Uoo`<00?mooj=oo`00Agoo0`002Goo0`002Goo0`001Goo
0`001Goo0`001Woo0`002Goo0`002Goo0`002Goo0`00ogooXgoo0015Ool5
0007Ool50007Ool50005Ool30005Ool30004Ool50007Ool50007Ool50007
Ool5003oOonSOol004Eoo`D000Moo`D000Moo`D000Eoo`@000Aoo`<000Ao
o`D000Moo`D000Moo`D000Moo`D00?mooj=oo`00AGoo1@001goo1@001goo
1@001Woo10000Woo100017oo1@001goo1@001goo1@001goo1@00ogooXgoo
0016Ool40008Ool40008Ool40006Ool:0006Ool30009Ool30009Ool30009
Ool3003oOonSOol004Qoo`8000Yoo`8000Yoo`8000Moo`L000Uoo`8000Yo
o`8000Yoo`8000Yoo`800?mooj=oo`00B7oo0P002Woo0P002Woo0P002Goo
10002Woo0P002Woo0P002Woo0P002Woo0P00ogooXgoo003oOoooOom3Ool0
0?mooomood=oo`00ogooogoo@goo003oOoooOom3Ool00?mooomood=oo`00
ogooogoo@goo003oOoooOom3Ool00?mooomood=oo`00ogooogoo@goo003o
OoooOom3Ool00?mooomood=oo`00ogooogoo@goo003oOoooOom3Ool00?mo
oomood=oo`00\
\>"], "PlacedGraphics",
  ImageSize->{332, 229},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Let us encapsulate all the above in predicate ",
  StyleBox["validQ", "Input"],
  " which decides whether a given word leads to a winning game."
}], "Text"],

Cell[BoxData[
    \(validQ[
        word_List] := \((FixedPoint[
            Union[Flatten[\(ReplaceList[#, jump] &\)\  /@ \ #, 
                  1]] &, {word}] == {{1, 1}})\)\)], "Input",
  CellLabel->"In[10]:="],

Cell[TextData[{
  "Note we take the ",
  StyleBox["union", "InlineInput"],
  " to expedite the decision, and in doing so we graft several branches of \
the game tree. So, for instance, the valid words of size 8 are obtained as:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FromDigits\  /@ \ Select[candidates[8], validQ]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \({10101011, 10111011, 10111111, 11001011, 11001111, 11010011, 11010101, 
      11011101, 11101111, 11110011, 11110111, 11111101}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["The sequence of valid words begins as:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sort[
      Flatten[Table[
          FromDigits\  /@ \ Select[candidates[n], validQ], {n, 
            10}]]]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({11, 1011, 1101, 101011, 101111, 110011, 110101, 111101, 10101011, 
      10111011, 10111111, 11001011, 11001111, 11010011, 11010101, 11011101, 
      11101111, 11110011, 11110111, 11111101, 1010101011, 1011101011, 
      1011111011, 1011111111, 1100101011, 1100111011, 1100111111, 1101001011, 
      1101001111, 1101010011, 1101010101, 1101011101, 1101101111, 1101110011, 
      1101110111, 1101111101, 1110111011, 1111001011, 1111011011, 1111011111, 
      1111101111, 1111110011, 1111111101}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["(to which we have to include 1 of course)", "Text"],

Cell["\<\
Note that there cannot be three consecutive 0's in any of the above words. \
Similarly, a valid word has to have even length. The reason for this is the \
following. By looking at the reverse process whereby we start at 11 and \
finish at a valid word we observe two kind of moves. Those that extend the \
word sideways - increasing its length by 2 adding a 0 and a 1, and those that \
only rearrange the internal configuration by eliminating a 0 and adding a 1 \
without changing the length of the word. Hence any valid word must have even \
length.
Note also that, if 1X1 is a valid word, then words 110X1 and 1X011 are also \
valid, for any word X (valid or not). Apparently, this could be used to \
generate all valid words by the number of steps they require to reach word \
11.\
\>", "Text"],

Cell[BoxData[{
    \(steps[1] := {{1, 1}}\), "\[IndentingNewLine]", 
    \(steps[n_] := 
      Flatten[Map[{Join[{1, 1, 0}, Rest[#]], 
              Join[Delete[#, \(-1\)], {0, 1, 1}]} &, steps[n - 1]], 
        1]\)}], "Input",
  CellLabel->"In[13]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Table[
        FromDigits\  /@ \ steps[n], {n, 5}]\ ;\)\), "\[IndentingNewLine]", 
    \(Sort[Flatten[%]]\)}], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({11, 1011, 1101, 101011, 110011, 110011, 110101, 10101011, 11001011, 
      11001011, 11001011, 11010011, 11010011, 11010011, 11010101, 1010101011, 
      1100101011, 1100101011, 1100101011, 1100101011, 1101001011, 1101001011, 
      1101001011, 1101001011, 1101001011, 1101001011, 1101010011, 1101010011, 
      1101010011, 1101010011, 1101010101}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[TextData[{
  "However, this approach is flawed (can you see why? hint: how many steps \
needs the word 101111 to reach 1?). An interesting problem is: for what \
numbers n, m such that 0 < n \[LessEqual] m, the word ",
  Cell[BoxData[
      \(TraditionalForm\`1\^n\)]],
  "0",
  Cell[BoxData[
      \(TraditionalForm\`1\^m\)]],
  " is a valid one?"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.- Group Theory", "Section",
  FontColor->RGBColor[1, 0.889998, 0.00999466],
  Background->RGBColor[0.4392, 0.502007, 0.564706]],

Cell[TextData[{
  StyleBox["Roughly speaking, a RS is a non-deterministic, pattern-oriented \
program transforming terms into terms. As an example, let us consider the \
algebraic structure ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["group",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[", by which a set S is classified in accordance to compliance to \
the following axioms (explicit bi-directional commutativity with the identity \
element and inverses is commonly assumed in general but it is not necessary, \
as we aim to show.)",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell["f(e, a)=a       \t", "BulletedList",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "f(",
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  ", a) = e\t"
}], "BulletedList"],

Cell["f(f(a, b), c) = f(a, f(b, c))\t", "BulletedList"],

Cell[TextData[{
  StyleBox["wherein f: S \[Times] S \[Rule] S is a closed",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["binary operation (not necessarily commutative) on S, e is a \
special element of S and a, b and c are arbitrary elements of  S. The first \
axiom asserts the existence of a left identity, the second of a left inverse \
and the third the fact that f is associative. \n\nThese axioms enjoy a dual \
character in their interpretation; the first axiom establishes the way the \
left identity acts on any element of S and can be interpreted as that, \
wherever an f[e, a] appears it can be simplified to a. On the other hand, it \
also can be interpreted as that, wherever an element a appears, it can be \
expanded by f[e, a]. It is possible to derive valid general structural \
equations on S by regarding these axioms as rewriting rules. Let us \
illustrate this by solving the problem of deducing the existence of right \
identity and right inverses, being equal to their left counterparts.\n\nThe \
bi-directional character of the axioms above gives rise to the following six \
productions, wherein for the sake of clarity we have adopted the infix \
notation x \[Bullet] y to stand for f(x, y):",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[StyleBox["e \[Bullet] a \[Rule] a",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "NumberedEquation",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["a \[Rule]  e \[Bullet] a",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "NumberedEquation",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  " ",
  StyleBox["\[Bullet] a \[Rule] e",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "NumberedEquation",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["e \[Rule]",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \ \)\(a\^\(-1\)\)\)\)]],
  StyleBox[" \[Bullet] a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "NumberedEquation",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["(a \[Bullet] b) \[Bullet] c \[Rule] a \[Bullet] (b \
\[Bullet] c)",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "NumberedEquation",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["a \[Bullet] (b \[Bullet] c) \[Rule] (a \[Bullet] b) \
\[Bullet] c",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "NumberedEquation",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["We now proceed to show that a \[Bullet] e \[Rule] a \
through the following sequence of applications in which we indicate above the \
arrow which of the former six productions is being used at each step.",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t\ta",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["e \t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&2\)\)]],
  StyleBox["  (e",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["a)",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["e \n\t\t\t\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&4\)\)]],
  StyleBox[" ((",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(a\^\(-1\)\),
              "TraditionalForm"], ")"}], \(-1\)], TraditionalForm]]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[")",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["a )",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["e \t\n\t\t\t\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&5\)\)]],
  StyleBox[" (",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(a\^\(-1\)\),
              "TraditionalForm"], ")"}], \(-1\)], TraditionalForm]]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["(",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["a ))",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["e\n\t\t\t\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&3\)\)]],
  StyleBox["  (",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(a\^\(-1\)\),
              "TraditionalForm"], ")"}], \(-1\)], TraditionalForm]]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["e )",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["e\n\t\t\t\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&5\)\)]],
  StyleBox["  ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(a\^\(-1\)\),
              "TraditionalForm"], ")"}], \(-1\)], TraditionalForm]]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["( e",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["e )\n\t\t\t\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&1\)\)]],
  StyleBox["  ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(a\^\(-1\)\),
              "TraditionalForm"], ")"}], \(-1\)], TraditionalForm]]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["e\n\t\t\t\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&4\)\)]],
  StyleBox["  ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(a\^\(-1\)\),
              "TraditionalForm"], ")"}], \(-1\)], TraditionalForm]]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["(",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["a )\n\t\t\t\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&6\)\)]],
  StyleBox["  (",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(a\^\(-1\)\),
              "TraditionalForm"], ")"}], \(-1\)], TraditionalForm]]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[")",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["a\n\t\t\t\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&3\)\)]],
  StyleBox["  e",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["a\n\t\t\t\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&1\)\)]],
  StyleBox["  a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Hence f(a, e) = a. Similarly:",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[TextData[{
  StyleBox["\t\ta",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&2\)\)]],
  StyleBox[" e",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["( a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[") ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&4\)\)]],
  StyleBox[" (",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(a\^\(-1\)\),
              "TraditionalForm"], ")"}], \(-1\)], TraditionalForm]]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[") ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["\[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["( a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[") \n\t\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&5\)\)]],
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(a\^\(-1\)\),
              "TraditionalForm"], ")"}], \(-1\)], TraditionalForm]]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["( ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["( a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[")) ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&6\)\)]],
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(a\^\(-1\)\),
              "TraditionalForm"], ")"}], \(-1\)], TraditionalForm]]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["(( ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["a )",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[") \n\t\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&3\)\)]],
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(a\^\(-1\)\),
              "TraditionalForm"], ")"}], \(-1\)], TraditionalForm]]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["( e",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[") ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&1\)\)]],
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(a\^\(-1\)\),
              "TraditionalForm"], ")"}], \(-1\)], TraditionalForm]]],
  StyleBox[" \[Bullet] ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[" ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&3\)\)]],
  StyleBox[" ", "DisplayFormula",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["e",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Hence f(a, ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[") = e.\n\nAnother interesting example is the following proof that \
",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\^-\)\^1\)(a, 
          b) = \(\(f(b\^\(-1\), a\^\(-1\))\)\(:\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox[" \t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\((a\ \[Bullet]\ b)\)\^\(-1\)\), 
          StyleBox["   ",
            FormatType->StandardForm,
            FontFamily->"Times New Roman"]}], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&6\)\)]],
  StyleBox[" e \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\((a\ \[Bullet]\ b)\)\^\(-1\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[" ",
            FormatType->StandardForm,
            FontFamily->"Times New Roman"], 
          RowBox[{
            FormBox[\( \[Rule] \&4\),
              "TraditionalForm"], 
            StyleBox[" ",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"]}]}], TraditionalForm]]],
  StyleBox["(",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`b\^\(-1\)\)]],
  StyleBox[" \[Bullet] b) \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\((a\ \[Bullet]\ b)\)\^\(-1\)\), 
          StyleBox[" ",
            FormatType->StandardForm,
            FontFamily->"Times New Roman"]}], TraditionalForm]]],
  StyleBox[" \n\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  Cell[BoxData[
      FormBox[
        FormBox[\( \[Rule] \&2\),
          "TraditionalForm"], TraditionalForm]]],
  StyleBox[" (",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`b\^\(-1\)\)]],
  StyleBox[" \[Bullet] (e \[Bullet] b)) \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\((a\ \[Bullet]\ b)\)\^\(-1\)\)]],
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&4\)\)]],
  StyleBox[" (",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`b\^\(-1\)\)]],
  StyleBox[" \[Bullet] ((",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[" \[Bullet] a) \[Bullet] b)) \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\((a\ \[Bullet]\ b)\)\^\(-1\)\), 
          StyleBox[" ",
            FormatType->StandardForm,
            FontFamily->"Times New Roman"]}], TraditionalForm]]],
  StyleBox[" \n\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&6\)\)]],
  StyleBox[" ((",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`b\^\(-1\)\)]],
  StyleBox[" \[Bullet] (",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[" \[Bullet] a)) \[Bullet] b) \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\((a\ \[Bullet]\ b)\)\^\(-1\)\)]],
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&6\)\)]],
  StyleBox["  (((",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`b\^\(-1\)\)]],
  StyleBox[" \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[") \[Bullet] a) \[Bullet] b) \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\((a\ \[Bullet]\ b)\)\^\(-1\)\)]],
  " \n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&5\)\)]],
  StyleBox[" ((",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`b\^\(-1\)\)]],
  StyleBox[" \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[") \[Bullet] a) \[Bullet] (b \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\((a\ \[Bullet]\ b)\)\^\(-1\)\)]],
  StyleBox[") ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&5\)\)]],
  StyleBox["  (",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`b\^\(-1\)\)]],
  StyleBox[" \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[") \[Bullet] (a  \[Bullet] (b  \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\((a\ \[Bullet]\ b)\)\^\(-1\)\)]],
  StyleBox["))\n\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&6\)\)]],
  " ",
  StyleBox["(",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`b\^\(-1\)\)]],
  StyleBox[" \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[") \[Bullet] ((a \[Bullet] b) \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\((a\ \[Bullet]\ b)\)\^\(-1\)\)]],
  StyleBox[") ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&II\)\)]],
  StyleBox[" (",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`b\^\(-1\)\)]],
  StyleBox[" \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]],
  StyleBox[") \[Bullet] e \n\t\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&I\)\)]],
  StyleBox["  ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`b\^\(-1\)\)]],
  StyleBox[" \[Bullet] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`a\^\(-1\)\)]]
}], "Text"],

Cell[TextData[StyleBox["wherein productions I and II correspond to the former \
and latter results respectively.\n\nThe above solutions, of so neat an \
appearance, are actually the result of considerable ingenuity in searching \
for a pattern. In following each derivation we realize that productions (2) \
and (4) render the automatic generation of the above steps extremely \
difficult. To appreciate this, consider the following  list of \
transformations encoding the former axioms:\:f35f",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[BoxData[
    \(\(transf = {\[IndentingNewLine]f[x_, e] \[Rule] 
            x, \[IndentingNewLine]x_ \[Rule] 
            f[x, e], \[IndentingNewLine]f[x_, \(-x_\)] \[Rule] 
            e, \[IndentingNewLine]f[f[x_, y_], z_] \[Rule] 
            f[x, f[y, z]], \[IndentingNewLine]f[x_, f[y_, z_]] \[Rule] 
            f[f[x, y], z]};\)\)], "Input",
  CellLabel->"In[17]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "The function ",
  StyleBox["prod", "Input"],
  " below takes an expression x and a transformation ",
  StyleBox["t", "InlineInput"],
  " and produces all possible applications of t in x. Function ",
  StyleBox["disp", "Input"],
  " provides a better-looking output to their use. "
}], "Text"],

Cell[BoxData[{
    \(prod[x_\ , 
        t_] := {x\  /. \ t}\  /; \ \(\(Length[x] == 
          0\)\(\[IndentingNewLine]\)
        \)\), "\n", 
    \(\(\(prod[f[x_, \ y_], t_] := 
      Module[{t1, t2, 
          t3}, \[IndentingNewLine]t1 = {f[x, \ y]\  /. \ 
              t}; \[IndentingNewLine]t2 = prod[x, t]; \[IndentingNewLine]t3 = 
          prod[y, \ t]; \[IndentingNewLine]Union[
          t1, \(f[#, y] &\)\  /@ \ t2, \(f[x, #] &\)\  /@ \ t3]]\)\(\n\)
    \)\), "\n", 
    \(disp[x_] := ToString[x]\  /; \ Length[x] == 0\), "\n", 
    \(disp[f[x_, \ y_]] := 
      StringJoin["\<(\>", disp[x], "\<\[Bullet]\>", 
        disp[y], "\<)\>"]\)}], "Input",
  CellLabel->"In[18]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(prod[f[x, y], 
      transf\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)]\), \
"\[IndentingNewLine]", 
    \(disp\  /@ \ %\)}], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({f[x, f[y, e]], f[f[x, e], y], f[f[x, y], e]}\)], "Output",
  CellLabel->"Out[22]="],

Cell[BoxData[
    \({"(x\[Bullet](y\[Bullet]e))", "((x\[Bullet]e)\[Bullet]y)", 
      "((x\[Bullet]y)\[Bullet]e)"}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[TextData[{
  "Finally, we generate the first three applications of the rules in ",
  StyleBox["transf", "InlineInput"],
  " applied to the expression f(e, x)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(t = {f[e, x]};\)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]t = 
        Complement[Union[Flatten[Outer[prod[#1, #2] &, t, transf], 2]], 
          t]; \[IndentingNewLine]Print[disp\  /@ \ t], {i, 3}]\)}], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({"(e\[Bullet](x\[Bullet]e))", "((e\[Bullet]e)\[Bullet]x)", 
      "((e\[Bullet]x)\[Bullet]e)"}\)], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    \({"(e\[Bullet]x)", "(e\[Bullet](e\[Bullet]x))", 
      "(e\[Bullet](x\[Bullet](e\[Bullet]e)))", 
      "(e\[Bullet]((x\[Bullet]e)\[Bullet]e))", 
      "((e\[Bullet]e)\[Bullet](x\[Bullet]e))", 
      "((e\[Bullet]x)\[Bullet](e\[Bullet]e))", 
      "((e\[Bullet](e\[Bullet]e))\[Bullet]x)", 
      "((e\[Bullet](x\[Bullet]e))\[Bullet]e)", 
      "(((e\[Bullet]e)\[Bullet]e)\[Bullet]x)", 
      "(((e\[Bullet]e)\[Bullet]x)\[Bullet]e)", 
      "(((e\[Bullet]x)\[Bullet]e)\[Bullet]e)"}\)], "Print",
  CellLabel->"From In[24]:="],

Cell[BoxData[
    \({"(e\[Bullet](e\[Bullet](x\[Bullet]e)))", "(e\[Bullet](x\[Bullet]e))", 
      "(e\[Bullet](x\[Bullet](e\[Bullet](e\[Bullet]e))))", 
      "(e\[Bullet](x\[Bullet]((e\[Bullet]e)\[Bullet]e)))", 
      "(e\[Bullet]((e\[Bullet]e)\[Bullet]x))", 
      "(e\[Bullet]((e\[Bullet]x)\[Bullet]e))", 
      "(e\[Bullet]((x\[Bullet]e)\[Bullet](e\[Bullet]e)))", 
      "(e\[Bullet]((x\[Bullet](e\[Bullet]e))\[Bullet]e))", 
      "(e\[Bullet](((x\[Bullet]e)\[Bullet]e)\[Bullet]e))", 
      "((e\[Bullet]e)\[Bullet]x)", "((e\[Bullet]e)\[Bullet](e\[Bullet]x))", 
      "((e\[Bullet]e)\[Bullet](x\[Bullet](e\[Bullet]e)))", 
      "((e\[Bullet]e)\[Bullet]((x\[Bullet]e)\[Bullet]e))", 
      "((e\[Bullet]x)\[Bullet]e)", 
      "((e\[Bullet]x)\[Bullet](e\[Bullet](e\[Bullet]e)))", 
      "((e\[Bullet]x)\[Bullet]((e\[Bullet]e)\[Bullet]e))", 
      "((e\[Bullet](e\[Bullet]e))\[Bullet](x\[Bullet]e))", 
      "((e\[Bullet](e\[Bullet]x))\[Bullet]e)", 
      "((e\[Bullet](e\[Bullet](e\[Bullet]e)))\[Bullet]x)", 
      "((e\[Bullet](x\[Bullet]e))\[Bullet](e\[Bullet]e))", 
      "((e\[Bullet](x\[Bullet](e\[Bullet]e)))\[Bullet]e)", 
      "((e\[Bullet]((e\[Bullet]e)\[Bullet]e))\[Bullet]x)", 
      "((e\[Bullet]((x\[Bullet]e)\[Bullet]e))\[Bullet]e)", 
      "(((e\[Bullet]e)\[Bullet]e)\[Bullet](x\[Bullet]e))", 
      "(((e\[Bullet]e)\[Bullet]x)\[Bullet](e\[Bullet]e))", 
      "(((e\[Bullet]e)\[Bullet](e\[Bullet]e))\[Bullet]x)", 
      "(((e\[Bullet]e)\[Bullet](x\[Bullet]e))\[Bullet]e)", 
      "(((e\[Bullet]x)\[Bullet]e)\[Bullet](e\[Bullet]e))", 
      "(((e\[Bullet]x)\[Bullet](e\[Bullet]e))\[Bullet]e)", 
      "(((e\[Bullet](e\[Bullet]e))\[Bullet]e)\[Bullet]x)", 
      "(((e\[Bullet](e\[Bullet]e))\[Bullet]x)\[Bullet]e)", 
      "(((e\[Bullet](x\[Bullet]e))\[Bullet]e)\[Bullet]e)", 
      "((((e\[Bullet]e)\[Bullet]e)\[Bullet]e)\[Bullet]x)", 
      "((((e\[Bullet]e)\[Bullet]e)\[Bullet]x)\[Bullet]e)", 
      "((((e\[Bullet]e)\[Bullet]x)\[Bullet]e)\[Bullet]e)", 
      "((((e\[Bullet]x)\[Bullet]e)\[Bullet]e)\[Bullet]e)"}\)], "Print",
  CellLabel->"From In[24]:="]
}, Open  ]],

Cell[TextData[{
  StyleBox["\nIn the course of this work, a curious question occurred to us: \
is it possible to furnish the set of prime numbers with a suitable operation \
so that it becomes a group?. Let us first find a closed commutative operation \
on this set. We make use of the following result.\n\n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Theorem",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"Underline"->True}],
  StyleBox[": \t\nLet S be an arbitrary set and let (G, * ) be a group. \
Further, assume S is of the same cardinality than G and let g: S \[Rule] G be \
a bijection. Then (S, \[Bullet]) is a group isomorphic to (G, *) with the \
operation \[Bullet] defined on S as:",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["x \[Bullet] y = ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`g\^\(-1\)\)]],
  StyleBox["( g(x) * g(y) )",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
Taking the set S to be the set of prime numbers and the set G to be the set \
of integer numbers we design function g as follows.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(SetAttributes[g, Listable]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(g[p_] := 
      Module[{n = 1}, \[IndentingNewLine]While[
          Prime[n] \[NotEqual] p, \(n++\)]; \[IndentingNewLine]If[EvenQ[n], 
          n/2, \((1 - n)\)/2]]\)}], "Input",
  CellLabel->"In[26]:="],

Cell[CellGroupData[{

Cell[TextData[StyleBox["g[Prime[Range[20]]]",
  FormatType->StandardForm,
  FontFamily->"Courier New"]], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \({0, 1, \(-1\), 2, \(-2\), 3, \(-3\), 4, \(-4\), 5, \(-5\), 6, \(-6\), 
      7, \(-7\), 8, \(-8\), 9, \(-9\), 10}\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["The inverse of which is:", "Text"],

Cell[TextData[StyleBox["SetAttributes[gInv,Listable]\n\ngInv[0]:=2\n\
gInv[i_]:=If[Positive[i],Prime[2i],Prime[1-2i]]",
  FormatType->StandardForm,
  FontFamily->"Courier New"]], "Input",
  CellLabel->"In[29]:="],

Cell[CellGroupData[{

Cell[TextData[StyleBox["gInv[g[Prime[Range[20]]]]",
  FormatType->StandardForm,
  FontFamily->"Courier New"]], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \({2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47, 53, 59, 61, 
      67, 71}\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell[TextData[{
  "So, the function ",
  StyleBox["f", "InlineInput"],
  " we seek is:"
}], "Text"],

Cell[TextData[StyleBox["f[p1_,p2_]:=gInv[g[p1]+g[p2]]",
  FormatType->StandardForm,
  FontFamily->"Courier New"]], "Input",
  CellLabel->"In[33]:="],

Cell["The corresponding multiplication table starts as follows.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[Table[f[Prime[i], Prime[j]], {i, 10}, {j, 10}], 
      TableHeadings \[Rule] {Prime[Range[10]], Prime[Range[10]]}]\)], "Input",\

  CellLabel->"In[34]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "2", "3", "5", "7", "11", "13", "17", "19", "23", 
            "29"},
          {"2", "2", "3", "5", "7", "11", "13", "17", "19", "23", "29"},
          {"3", "3", "7", "2", "13", "5", "19", "11", "29", "17", "37"},
          {"5", "5", "2", "11", "3", "17", "7", "23", "13", "31", "19"},
          {"7", "7", "13", "3", "19", "2", "29", "5", "37", "11", "43"},
          {"11", "11", "5", "17", "2", "23", "3", "31", "7", "41", "13"},
          {"13", "13", "19", "7", "29", "3", "37", "2", "43", "5", "53"},
          {"17", "17", "11", "23", "5", "31", "2", "41", "3", "47", "7"},
          {"19", "19", "29", "13", "37", "7", "43", "3", "53", "2", "61"},
          {"23", "23", "17", "31", "11", "41", "5", "47", "2", "59", "3"},
          {"29", "29", "37", "19", "43", "13", "53", "7", "61", "3", "71"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{2, 3, 5, 7, 11, 13, 17, 19, 23, 29}, {
          2, 3, 5, 7, 11, 13, 17, 19, 23, 29}}]]]], "Output",
  CellLabel->"Out[34]//TableForm="]
}, Open  ]],

Cell[TextData[StyleBox["We leave this section with two questions for the \
reader. How can we design a non-commutative group operation on the set of \
prime numbers? How do we turn Z into a non-abelian group through finding a \
suitable operation?",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.- Equivalence Relations", "Section",
  FontColor->RGBColor[1, 0.889998, 0.00999466],
  Background->RGBColor[0.4392, 0.502007, 0.564706]],

Cell["\<\
Let us consider the decomposition of a set into disjoint classes  imposed by \
a given equivalence relation defined on it. We can concisely describe the \
procedure to obtain these classes by building them up through successively \
inserting elements as an RS process. Specifically, consider the following set \
of derivations, which defines a function t that, given a pair {u, v} in the \
relation, selects the appropriate transformation to perform on a partially \
constructed set of classes.\
\>", "Text"],

Cell[BoxData[
    \(t[{u_, 
          v_}] := {{a___, {b___, \((u | v)\), c___}, 
            d___, {e___, \((u | v)\), f___}, 
            g___} \[Rule] {a, {b, u, v, c, e, f}, d, 
            g}, \[IndentingNewLine]\ {a___, {b___, \((u | v)\), c___}, 
            d___} \[Rule] {a, {b, u, v, c}, 
            d}, \[IndentingNewLine]{a___} \[Rule] {a, {u, v}}}\)], "Input",
  CellLabel->"In[36]:="],

Cell[TextData[{
  StyleBox["Accordingly, we can define function ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["classes", "InlineInput",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" which, when given a relation, through mapping each of its \
elements to t, produces the required set.  \:f35f",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[
    \(classes[rel_] := 
      Module[{clas = {}}, \[IndentingNewLine]Map[\((clas = \((clas\  /. \ 
                    t[#])\))\) &, \ rel]; \[IndentingNewLine]clas]\)], "Input",\

  CellLabel->"In[38]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(relations = {{1, 5}, {6, 8}, {7, 2}, {9, 8}, {3, 7}, {4, 2}, {9, 
            3}};\)\), "\[IndentingNewLine]", 
    \(classes[relations]\)}], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({{1, 5}, {6, 9, 3, 8, 7, 4, 2}}\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.- Systems of Numeric Productions", "Section",
  FontColor->RGBColor[1, 0.889998, 0.00999466],
  Background->RGBColor[0.4392, 0.502007, 0.564706]],

Cell[TextData[StyleBox["Let n be a positive integer, and x and y be arbitrary \
numbers. Consider the RS:",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[TextData[StyleBox["< n > \[Rule] < n - 1 > x  - \
\[LeftDoubleBracketingBar] n - 1\[RightDoubleBracketingBar] y\n\
\[LeftDoubleBracketingBar] n \[LeftDoubleBracketingBar] \[Rule] \
\[LeftDoubleBracketingBar] n - 1 \[RightDoubleBracketingBar] x + < n - 1 > y\n\
< 0 > \[Rule] 1\n\[LeftDoubleBracketingBar] 0 \[RightDoubleBracketingBar] \
\[Rule] 0",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["where the brackets surrounding n are meant to provide \
two different kinds of contexts and the operations on the right are the usual \
arithmetic ones. The last two derivations make this system terminating. For \
instance, ",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[TextData[{
  StyleBox["< 2 > \[Rule] < 1 > x - \[LeftDoubleBracketingBar] 1\
\[RightDoubleBracketingBar] y ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\( \[Rule] \&*\)\)]],
  StyleBox["  x",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["2",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" - y",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["2",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["Where the star above the arrow means that we have \
omitted internal productions involved in this derivation. Let us denote by A \
\[DoubleRightArrow] N the fact that N is a normal form of A.",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[BoxData[
    \(<< Utilities`Notation`\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[{
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[\(\(<\)\(n_\)\(>\)\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", 
        " ", 
        TagBox[\(b1[n_]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}], "\n", 
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[\(\[LeftDoubleBracketingBar]n_\[RightDoubleBracketingBar]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", 
        " ", 
        TagBox[\(b2[n_]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[{
    \(b1[0] := 1\), "\n", 
    \(b2[0] := 0\), "\n", 
    \(b1[n_] := \(b1[n] = Expand[b1[n - 1] x - b2[n - 1] y]\)\), "\n", 
    \(b2[n_] := \(b2[n] = Expand[b2[n - 1] x + b1[n - 1] y]\)\)}], "Input",
  CellLabel->"In[4]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\(\(<\)\(j\)\(>\)\), {j, 6}]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \({x, x\^2 - y\^2, x\^3 - 3\ x\ y\^2, x\^4 - 6\ x\^2\ y\^2 + y\^4, 
      x\^5 - 10\ x\^3\ y\^2 + 5\ x\ y\^4, 
      x\^6 - 15\ x\^4\ y\^2 + 15\ x\^2\ y\^4 - y\^6}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\[LeftDoubleBracketingBar]j\[RightDoubleBracketingBar], {j, 
        6}]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({y, 2\ x\ y, 3\ x\^2\ y - y\^3, 4\ x\^3\ y - 4\ x\ y\^3, 
      5\ x\^4\ y - 10\ x\^2\ y\^3 + y\^5, 
      6\ x\^5\ y - 20\ x\^3\ y\^3 + 6\ x\ y\^5}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[StyleBox["Theorem",
  FormatType->StandardForm,
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox["a) < n > \[DoubleRightArrow] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(i = 0\)\%\(\[LeftFloor]n\/2\[RightFloor]\)\), 
          RowBox[{\(\((\(-1\))\)\^i\), 
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {"n"},
                  {\(2  i\)}
                  }], "\[NegativeThinSpace]", 
              ")"}], \(x\^\(n - 2  i\)\), \(y\^\(2  i\)\)}]}], 
        TraditionalForm]]],
  StyleBox["\n\nb) \[LeftDoubleBracketingBar] n \[RightDoubleBracketingBar] \
\[DoubleRightArrow] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(i = 
                0\)\%\(\[LeftFloor]\(n - 1\)\/2\[RightFloor]\)\), 
          RowBox[{\(\((\(-1\))\)\^i\), 
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {"n"},
                  {\(2  i + 1\)}
                  }], "\[NegativeThinSpace]", 
              ")"}], \(x\^\(n - 2  i - 1\)\), \(y\^\(2  i + 1\)\)}]}], 
        TraditionalForm]]],
  "\n"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(<\)\(14\)\(>\)\)\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(x\^14 - 91\ x\^12\ y\^2 + 1001\ x\^10\ y\^4 - 3003\ x\^8\ y\^6 + 
      3003\ x\^6\ y\^8 - 1001\ x\^4\ y\^10 + 91\ x\^2\ y\^12 - 
      y\^14\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftDoubleBracketingBar]15\[RightDoubleBracketingBar]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(15\ x\^14\ y - 455\ x\^12\ y\^3 + 3003\ x\^10\ y\^5 - 
      6435\ x\^8\ y\^7 + 5005\ x\^6\ y\^9 - 1365\ x\^4\ y\^11 + 
      105\ x\^2\ y\^13 - y\^15\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
The following animation shows the complexity of function <n>.\
\>", "Text"],

Cell["ANIMATION", "Text",
  FontSize->18,
  FontColor->RGBColor[0.0299992, 0.179995, 0.329992],
  Background->RGBColor[0.737301, 0.5608, 0.5608]],

Cell[BoxData[
    \(\(Map[\(Plot3D[\(\(<\)\(#\)\(>\)\), {x, \(-1\), 1}, {y, \(-1\), 1}, 
              PlotPoints \[Rule] 100, Mesh \[Rule] False, 
              Boxed \[Rule] False, Axes \[Rule] False];\) &, 
        Join[Range[15], Range[15, 1, \(-1\)]]];\)\)], "Input",
  CellLabel->"In[31]:="],

Cell[TextData[{
  StyleBox["Theorem",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"Underline"->True}],
  StyleBox[" \tIf  <n> \[DoubleRightArrow] A and [n] \[DoubleRightArrow] B \
then  A",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["2 ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["+ B",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["2",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" = (x",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["2",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" + y",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["2",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[")",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["\t",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[\((\(<\)\(10\)\(>\))\)\^2 + \ \((\[LeftDoubleBracketingBar]10\
\[RightDoubleBracketingBar])\)\^2]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(\((x\^2 + y\^2)\)\^10\)], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Theorem",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"Underline"->True}],
  StyleBox["  \tIf x=Cos[1], and y=Sin[1]  then",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[StyleBox["<n> \[DoubleRightArrow] Cos[n]  \n[n] \
\[DoubleRightArrow] Sin[n]",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(N[\(\(<\)\(10\)\(>\)\) /. \ {x \[Rule] Cos[1], \ 
          y \[Rule] Sin[1]}]\), "\[IndentingNewLine]", 
    \(N[Cos[10]]\)}], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \(\(-0.8390715290764517`\)\)], "Output",
  CellLabel->"Out[53]="],

Cell[BoxData[
    \(\(-0.8390715290764524`\)\)], "Output",
  CellLabel->"Out[54]="]
}, Open  ]],

Cell[TextData[StyleBox["The truth of the previous theorems comes from the \
identity: ",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(\(\ \ \)\(Cos[2  \[Theta]]\)\)},
              {\(\(\ \)\(Sin[2  \[Theta]]\)\)}
              }], "\[NegativeThinSpace]  ", ")"}], TraditionalForm]]],
  StyleBox[" = ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", " ", GridBox[{
              {\(Cos[\[Theta]]\), \(Sin[\[Theta]]\)},
              {\(\(\ \)\(Sin[\[Theta]]\)\), \(Cos[\[Theta]]\)}
              }], ")"}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", " \[NegativeThinSpace]", GridBox[{
              {\(\(\ \)\(Sin[\[Theta]]\)\)},
              {\(\(\ \)\(Cos[\[Theta]]\)\)}
              }], "\[NegativeThinSpace]  ", ")"}], TraditionalForm]]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["describing a counterclockwise rotation trough an \
angle \[Theta] around the origin. Using this it can be shown that",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(\(<\)\(n\)\(>\)\)},
              {\([n]\)}
              }], "\[NegativeThinSpace]", ")"}], " ", "\[DoubleRightArrow]", 
        " ", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", GridBox[{
                  {"x", \(-y\)},
                  {"y", "x"}
                  }], ")"}], \(n - 1\)], 
          RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                {"x"},
                {"y"}
                }], "\[NegativeThinSpace]", ")"}]}]}], 
      TraditionalForm]]]], "Text",
  TextAlignment->Center,
  TextJustification->0]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.- Recursive Productions", "Section",
  FontColor->RGBColor[1, 0.889998, 0.00999466],
  Background->RGBColor[0.4392, 0.502007, 0.564706]],

Cell[TextData[StyleBox["Consider the following rules, invented by the \
logician Raymond Smullyan:",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[TextData[StyleBox["2X \[Rule] X\nIf  X \[Rule] Y then 3X \[Rule] Y2Y",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[{
    \(smullyan[{"\<2\>", X__}] := {X}\), "\[IndentingNewLine]", 
    \(smullyan[{"\<3\>", X__}] := 
      Module[{Y = smullyan[{X}]}, Join[Y, {"\<2\>"}, Y]]\)}], "Input",
  CellLabel->"In[55]:="],

Cell[TextData[{
  StyleBox["There are novel features in this RS. Those rules are applicable \
to integers regarded as words built from concatenating digits, but not all \
integers are \"acceptable\" words. These rules apply only to words of the \
form 3",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["2X for some n\[GreaterEqual]0 and arbitrary word X. The second \
rule is posed in a conditional manner in a way that does not resemble any \
context dependence. It is this rule that allows us to conclude, through a \
simple application of mathematical induction that:\n\n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Theorem ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"Underline"->True}]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`3\^n\ 2\ X\)]],
  " \[Rule] ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((X\ 2)\)\^\(2\^n - 1\)\) X\)]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(StringJoin\  @@ \ smullyan[Characters["\<3332456\>"]]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \("4562456245624562456245624562456"\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Also, it is easy to find out that there is a unique word N such \
that N \[Rule] N, that is, the RS admits only one",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" fixed point",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[". More generally, we can assert the following.\n\n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Theorem",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"Underline"->True}],
  StyleBox[" (Fixed Point Theorem)  Given any word A, there exists a word Y \
such that Y \[Rule] AY\n\nFor example, if A=332332, then Y=32A3 is such word. \
This Y might not be unique though, for example, Y=33233 also complies with \
the theorem for this particular A. A limited converse of the former theorem \
applies.\n\n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Theorem",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"Underline"->True}],
  StyleBox[" \tLet N= ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              FormBox[\(\(3\^n\ 2\)\()\)\),
                "TraditionalForm"], "m"], "  ", \(3\^n\)}]}], 
        TraditionalForm]]],
  StyleBox[". Then N \[Rule] NA with A =",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"(", 
            RowBox[{"2", " ", 
              SuperscriptBox[
                FormBox[\(\(3\^n\)\()\)\),
                  "TraditionalForm"], \(m\ 2\^m\  - m - 1\)]}]}]}], 
        TraditionalForm]]],
  StyleBox["\n\n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Proof",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"Underline"->True}],
  StyleBox[":\tWe have that ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["N= ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              FormBox[\(\(\(3\^n\) 2\)\()\)\),
                "TraditionalForm"], "m"], " ", \(3\^n\)}]}], 
        TraditionalForm]]],
  StyleBox[" = ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\(3\^n\) 2\)]],
  StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              FormBox[\(\(\(3\^n\) 2\)\()\)\),
                "TraditionalForm"], \(m - 1\)], " ", \(3\^n\)}]}], 
        TraditionalForm]]],
  StyleBox[" \[Rule] ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", " ", 
            RowBox[{
              FormBox[
                RowBox[{"(", 
                  SuperscriptBox[
                    FormBox[\(\(\(3\^n\) 2\)\()\)\),
                      "TraditionalForm"], \(m - 1\)]}],
                "TraditionalForm"], " ", 
              FormBox[\(3\^n\),
                "TraditionalForm"]}], ")"}], \(2\^n - 1\)], 
        TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{"(", 
              SuperscriptBox[
                FormBox[\(\(\(3\^n\) 2\)\()\)\),
                  "TraditionalForm"], \(m - 1\)]}],
            "TraditionalForm"], " ", 
          FormBox[\(3\^n\),
            "TraditionalForm"]}], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{"(", 
              SuperscriptBox[
                FormBox[\(\(\(3\^n\) 2\)\()\)\),
                  "TraditionalForm"], \(m(2\^n - 1) + m - 1\)]}],
            "TraditionalForm"], " ", 
          FormBox[\(3\^n\),
            "TraditionalForm"]}], TraditionalForm]]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["which coincides with the value of the word NA.   \[FilledSquare]\n\
\nNote that not all words have normal forms; among those we can mention words \
of the form 32",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["3 for n>1, which have periodic behavior, or of the form 32",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["32, which have exponential-growth behavior. Moreover we claim \
that:\n\n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Theorem",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"Underline"->True}],
  StyleBox["\t\nA number of the form ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\((32)\)\^a\_1\)]],
  " 2 ",
  Cell[BoxData[
      \(TraditionalForm\`\((32)\)\^a\_2\)]],
  StyleBox[" 2 ... 2 ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\((32)\)\^a\_n\)]],
  StyleBox[" 3, where the exponents are non-negative integers and n>0, does \
not possess a normal form\n\n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Proof",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"Underline"->True}],
  StyleBox[":\tWriting the above form as [a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["1",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[", a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["2",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",\[Ellipsis], a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["] we can deduce that",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["[a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["1",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[", a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["2",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",\[Ellipsis], a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["]  \[Rule] [a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["1",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["-1, a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["2",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[",\[Ellipsis], a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["n-1,",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["1",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["+a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[", a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["2",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[", \[Ellipsis], a",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["n",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox["]",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["which proves our claim. ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["\[FilledSquare]",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["\n\nWe can code this notation as:",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear[a, b, c, t]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(t[{a_, b___, c_}] := {a - 1, b, a + c, b, c}\), "\n", 
    \(t[{0, b__}] := {b}\), "\n", 
    \(t[{a_}] := {2  a - 1}\)}], "Input",
  CellLabel->"In[58]:="],

Cell[TextData[StyleBox["So that, for example:",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[t, {1}, 6]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \({{1}, {1}, {1}, {1}, {1}, {1}, {1}}\)], "Output",
  CellLabel->"Out[62]="]
}, Open  ]],

Cell["corresponding to the behavior of the fixed point 323.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[t, {2}, 6]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \({{2}, {3}, {5}, {9}, {17}, {33}, {65}}\)], "Output",
  CellLabel->"Out[63]="]
}, Open  ]],

Cell[TextData[{
  "corresponding to the productions ",
  Cell[BoxData[
      \(TraditionalForm\`\((32)\)\^2\)]],
  "3 \[Rule] ",
  Cell[BoxData[
      \(TraditionalForm\`\((32)\)\^3\)]],
  "3 \[Rule] ",
  Cell[BoxData[
      \(TraditionalForm\`\((32)\)\^5\)]],
  "3 \[Rule] ..."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[t, {1, 1}, 6]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \({{1, 1}, {0, 2, 1}, {2, 1}, {1, 3, 1}, {0, 3, 2, 3, 1}, {3, 2, 3, 
        1}, {2, 2, 3, 4, 2, 3, 1}}\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell[TextData[{
  "corresponding to the productions ",
  Cell[BoxData[
      \(TraditionalForm\`\((32)\)\^1\)]],
  "2 ",
  Cell[BoxData[
      \(TraditionalForm\`\((32)\)\^1\)]],
  "3 = 322323 \[Rule] 232322323= ",
  Cell[BoxData[
      \(TraditionalForm\`\((32)\)\^0\)]],
  "2 ",
  Cell[BoxData[
      \(TraditionalForm\`\((32)\)\^2\)]],
  "2 ",
  Cell[BoxData[
      \(TraditionalForm\`\((32)\)\^1\)]],
  "3 \[Rule] ..."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.- L Systems", "Section",
  FontColor->RGBColor[1, 0.889998, 0.00999466],
  Background->RGBColor[0.4392, 0.502007, 0.564706]],

Cell[TextData[{
  "Sometimes a useful purpose can be found for RS having no normal form. \
Consider the L systems (also called ",
  StyleBox["Lindenmayer systems",
    FontSlant->"Italic"],
  " or ",
  StyleBox["parallel string-rewrite systems",
    FontSlant->"Italic"],
  ") to generate words that can be interpreted by the LOGO turtle (an \
imaginary graphical entity) in suitable ways as to render eye-catching \
objects. These systems have not normal forms although they often converge to \
fractal curves. Although those forms are not reachable in a finite number of \
steps successive derivations are often intrinsically interesting. An L system \
is created by starting with an axiom and replacing it through some prescribed \
productions so that a more complex expression is formed. This expression is \
assumed to act as LOGO instructions on a starting figure, often a single line \
segment. \n\n",
  StyleBox["Assume the symbol F means drawing a unit-length segment forward \
in the current direction. Assume also that the symbol + conveys a clockwise \
turn by a fixed angle from the direction we are heading and symbol - a \
counterclockwise turn by the same amount. Function ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["logo", "Input",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" below comprises a very small logo interpreter powerful enough to \
render striking graphics.",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[
    \(\(SetOptions[Graphics, \ AspectRatio \[Rule] \ Automatic, 
        PlotRange \[Rule] All];\)\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    RowBox[{\(logo[s_String, \[Theta]_]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({a = {0, 0}, b = {1, 0}, h = Cos[\[Theta]], 
            k = Sin[\[Theta]], t}\), ",", "\[IndentingNewLine]", 
          RowBox[{\(t = {a}\), ";", "\[IndentingNewLine]", 
            RowBox[{"Map", "[", 
              RowBox[{
                RowBox[{
                  RowBox[{"Switch", "[", 
                    RowBox[{
                    "#", ",", "\"\<F\>\"", ",", \(AppendTo[t, a = a + b]\), 
                      ",", "\"\<+\>\"", ",", 
                      RowBox[{"b", "=", 
                        RowBox[{
                          RowBox[{"(", GridBox[{
                                {"h", \(-k\)},
                                {"k", "h"}
                                }], ")"}], ".", "b"}]}], ",", "\"\<-\>\"", 
                      ",", 
                      RowBox[{"b", "=", 
                        RowBox[{
                          RowBox[{"(", GridBox[{
                                {"h", "k"},
                                {\(-k\), "h"}
                                }], ")"}], ".", "b"}]}]}], "]"}], "&"}], " ", 
                ",", \(Characters[s]\)}], "]"}], ";", "\[IndentingNewLine]", 
            "t"}]}], "]"}]}]], "Input",
  CellLabel->"In[134]:="],

Cell[TextData[{
  StyleBox["Take for example the ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Koch Curve",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[", defined by ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  "\[Theta] ",
  StyleBox["= 60",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["o",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[", the single axiom F and the single production F\[Rule]F+F\
\[LongDash]F+F",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[
    \(Koch[s_String] := 
      StringJoin[
        Characters[s]\  /. \ "\<F\>" \[Rule] "\<F+F--F+F\>"]\)], "Input",
  CellLabel->"In[135]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[Koch, "\<F\>", 2]\)], "Input",
  CellLabel->"In[136]:="],

Cell[BoxData[
    \({"F", "F+F--F+F", "F+F--F+F+F+F--F+F--F+F--F+F+F+F--F+F"}\)], "Output",
  CellLabel->"Out[136]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(logo[Nest[Koch, "\<F\>", 2], 60\ \[Degree]]\)], "Input",
  CellLabel->"In[137]:="],

Cell[BoxData[
    \({{0, 0}, {1, 0}, {3\/2, \@3\/2}, {2, 0}, {3, 
        0}, {7\/2, \@3\/2}, {3, \@3}, {4, \@3}, {9\/2, \(3\ \@3\)\/2}, {5, \
\@3}, {6, \@3}, {11\/2, \@3\/2}, {6, 0}, {7, 0}, {15\/2, \@3\/2}, {8, 0}, {9, 
        0}}\)], "Output",
  CellLabel->"Out[137]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[Graphics[Line[%]]];\)\)], "Input",
  CellLabel->"In[138]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .28868 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.00687322 0.10582 [
[ 0 0 0 0 ]
[ 1 .28868 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00687 m
.12963 .00687 L
.18254 .09852 L
.23545 .00687 L
.34127 .00687 L
.39418 .09852 L
.34127 .19016 L
.44709 .19016 L
.5 .2818 L
.55291 .19016 L
.65873 .19016 L
.60582 .09852 L
.65873 .00687 L
.76455 .00687 L
.81746 .09852 L
.87037 .00687 L
.97619 .00687 L
s
0 0 m
1 0 L
1 .28868 L
0 .28868 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[138]:=",
  ImageSize->{221.688, 63.9375},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M0000?b000`400?l00000o`00003og@3oool0
00H0oooo6000000F0?oooaP00000A03ooolI000001H0oooo600000060?ooo`007P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0703oool001h0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01`0oooo
000O0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0M0?ooo`007`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool07@3oool00200oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01h0oooo000Q0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0O0?ooo`008@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool07`3oool00280oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0200oooo000R0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0P0?ooo`008`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08@3oool002@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0280
oooo000T0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0R0?ooo`009@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool08`3oool002D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02<0oooo000V0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`009`3oool01@000000oooo0?ooo`3oool00000
02T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0W0?ooo`050000003oool0oooo
0?ooo`0000009`3oool002L0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool09`3oool01@000000oooo0?ooo`3oool0000002L0oooo000X
0?ooo`030000003oool0000002/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0000002P0oooo000X0?ooo`030000003oool0000002/0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0000002P0oooo000Y0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo02L0oooo001F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
E03oool005H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1D0?ooo`00E@3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05<0oooo001E0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool0D`3oool005@0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`1B0?ooo`00D`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0580oooo
001C0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0D@3oool00580oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`1A0?ooo`00DP3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo0500oooo001A0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0D03oool00500oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1?0?ooo`00D03o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo04h0oooo001?0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0CP3oool004l0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`1=0?ooo`00CP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo04d0
oooo001=0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0C03oool004d0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`1<0?ooo`00C03oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo04/0oooo001<0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool0B`3oool004/0oooo6000000F0?oooaP00000C03oool006<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`1R0?ooo`00H`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0680oooo001T0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0H`3oool0
06@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1S0?ooo`00I@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo06@0oooo001V0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0I03oool006H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`1U0?ooo`00I`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06D0oooo001W0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0IP3oool006P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1W0?ooo`00J@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo06L0oooo001Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0J03o
ool006X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1X0?ooo`00JP3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo06T0oooo001[0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0J@3oool006`0oooo00D000000?ooo`3oool0oooo0000001/0?ooo`00
K03oool01@000000oooo0?ooo`3oool0000006`0oooo001]0?ooo`030000003oool0000006d0oooo
001]0?ooo`030000003oool0000006d0oooo001^0?ooo`030000003oool0oooo06`0oooo003M0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 220.688}, {62.9375, 0}} -> {-0.282898, -0.0649656, \
0.0433455, 0.0433455}}]
}, Open  ]],

Cell[TextData[{
  "In addition to this one, there are other instructive ways of generating \
Kock curves, one of which is provided by function ",
  StyleBox["sF", "Input"],
  " below which sets up the parameters needed for the recursive function ",
  StyleBox["snowFlake", "Input"],
  ". Its advantage is that it offers a finer control on the parameters \
defining this family. Function ",
  StyleBox["snowflake", "InlineInput"],
  "'s first two parameters correspond to the ends of the generated curve and \
the last parameter to its order. The reader might find interesting altering \
the values of the other parameters to find their purpose in generating \
mutated members of this family.   "
}], "Text"],

Cell[BoxData[{\(snowFlake[a_, _, _, _, _, 0] := {a}\), "\[IndentingNewLine]", 
  
    RowBox[{
      RowBox[{\(snowFlake[a_, b_, \[Lambda]_, h_, k_, n_]\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({u, v}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(u = \[Lambda]\ b + \((1 - \[Lambda])\)\ a - a\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"v", "=", 
                RowBox[{"a", "+", "u", "+", 
                  RowBox[{
                    RowBox[{"(", GridBox[{
                          {"h", \(-k\)},
                          {"k", "h"}
                          }], ")"}], ".", "u"}]}]}], ";", 
              "\[IndentingNewLine]", \(Join[
                snowFlake[a, a + u, \[Lambda], h, k, n - 1], 
                snowFlake[a + u, v, \[Lambda], h, k, n - 1], 
                snowFlake[v, b - u, \[Lambda], h, k, n - 1], 
                snowFlake[b - u, b, \[Lambda], h, k, n - 1]]\)}]}], "]"}]}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(sF[\[Theta]_, n_] := 
      Append[snowFlake[{0, 0}, {1, 0}, 1\/\(2 \((1 + Cos[\[Theta]])\)\), 
          Cos[\[Theta]], Sin[\[Theta]], n], {1, 0}]\)}], "Input",
  CellLabel->"In[38]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[Graphics[Line[sF[60\ \[Degree], 4]]]];\)\)], "Input",
  CellLabel->"In[41]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .28868 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.00687322 0.952381 [
[ 0 0 0 0 ]
[ 1 .28868 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00687 m
.03557 .00687 L
.04145 .01706 L
.04733 .00687 L
.05908 .00687 L
.06496 .01706 L
.05908 .02724 L
.07084 .02724 L
.07672 .03742 L
.0826 .02724 L
.09436 .02724 L
.08848 .01706 L
.09436 .00687 L
.10611 .00687 L
.11199 .01706 L
.11787 .00687 L
.12963 .00687 L
.13551 .01706 L
.12963 .02724 L
.14139 .02724 L
.14727 .03742 L
.14139 .0476 L
.12963 .0476 L
.13551 .05779 L
.12963 .06797 L
.14139 .06797 L
.14727 .07815 L
.15315 .06797 L
.1649 .06797 L
.17078 .07815 L
.1649 .08833 L
.17666 .08833 L
.18254 .09852 L
.18842 .08833 L
.20018 .08833 L
.1943 .07815 L
.20018 .06797 L
.21193 .06797 L
.21781 .07815 L
.22369 .06797 L
.23545 .06797 L
.22957 .05779 L
.23545 .0476 L
.22369 .0476 L
.21781 .03742 L
.22369 .02724 L
.23545 .02724 L
.22957 .01706 L
.23545 .00687 L
.24721 .00687 L
Mistroke
.25309 .01706 L
.25897 .00687 L
.27072 .00687 L
.2766 .01706 L
.27072 .02724 L
.28248 .02724 L
.28836 .03742 L
.29424 .02724 L
.306 .02724 L
.30012 .01706 L
.306 .00687 L
.31775 .00687 L
.32363 .01706 L
.32951 .00687 L
.34127 .00687 L
.34715 .01706 L
.34127 .02724 L
.35303 .02724 L
.35891 .03742 L
.35303 .0476 L
.34127 .0476 L
.34715 .05779 L
.34127 .06797 L
.35303 .06797 L
.35891 .07815 L
.36479 .06797 L
.37654 .06797 L
.38242 .07815 L
.37654 .08833 L
.3883 .08833 L
.39418 .09852 L
.3883 .1087 L
.37654 .1087 L
.38242 .11888 L
.37654 .12906 L
.36479 .12906 L
.35891 .11888 L
.35303 .12906 L
.34127 .12906 L
.34715 .13925 L
.34127 .14943 L
.35303 .14943 L
.35891 .15961 L
.35303 .16979 L
.34127 .16979 L
.34715 .17998 L
.34127 .19016 L
.35303 .19016 L
.35891 .20034 L
.36479 .19016 L
Mistroke
.37654 .19016 L
.38242 .20034 L
.37654 .21052 L
.3883 .21052 L
.39418 .22071 L
.40006 .21052 L
.41182 .21052 L
.40594 .20034 L
.41182 .19016 L
.42357 .19016 L
.42945 .20034 L
.43533 .19016 L
.44709 .19016 L
.45297 .20034 L
.44709 .21052 L
.45885 .21052 L
.46473 .22071 L
.45885 .23089 L
.44709 .23089 L
.45297 .24107 L
.44709 .25125 L
.45885 .25125 L
.46473 .26144 L
.47061 .25125 L
.48236 .25125 L
.48824 .26144 L
.48236 .27162 L
.49412 .27162 L
.5 .2818 L
.50588 .27162 L
.51764 .27162 L
.51176 .26144 L
.51764 .25125 L
.52939 .25125 L
.53527 .26144 L
.54115 .25125 L
.55291 .25125 L
.54703 .24107 L
.55291 .23089 L
.54115 .23089 L
.53527 .22071 L
.54115 .21052 L
.55291 .21052 L
.54703 .20034 L
.55291 .19016 L
.56467 .19016 L
.57055 .20034 L
.57643 .19016 L
.58818 .19016 L
.59406 .20034 L
Mistroke
.58818 .21052 L
.59994 .21052 L
.60582 .22071 L
.6117 .21052 L
.62346 .21052 L
.61758 .20034 L
.62346 .19016 L
.63521 .19016 L
.64109 .20034 L
.64697 .19016 L
.65873 .19016 L
.65285 .17998 L
.65873 .16979 L
.64697 .16979 L
.64109 .15961 L
.64697 .14943 L
.65873 .14943 L
.65285 .13925 L
.65873 .12906 L
.64697 .12906 L
.64109 .11888 L
.63521 .12906 L
.62346 .12906 L
.61758 .11888 L
.62346 .1087 L
.6117 .1087 L
.60582 .09852 L
.6117 .08833 L
.62346 .08833 L
.61758 .07815 L
.62346 .06797 L
.63521 .06797 L
.64109 .07815 L
.64697 .06797 L
.65873 .06797 L
.65285 .05779 L
.65873 .0476 L
.64697 .0476 L
.64109 .03742 L
.64697 .02724 L
.65873 .02724 L
.65285 .01706 L
.65873 .00687 L
.67049 .00687 L
.67637 .01706 L
.68225 .00687 L
.694 .00687 L
.69988 .01706 L
.694 .02724 L
.70576 .02724 L
Mistroke
.71164 .03742 L
.71752 .02724 L
.72928 .02724 L
.7234 .01706 L
.72928 .00687 L
.74103 .00687 L
.74691 .01706 L
.75279 .00687 L
.76455 .00687 L
.77043 .01706 L
.76455 .02724 L
.77631 .02724 L
.78219 .03742 L
.77631 .0476 L
.76455 .0476 L
.77043 .05779 L
.76455 .06797 L
.77631 .06797 L
.78219 .07815 L
.78807 .06797 L
.79982 .06797 L
.8057 .07815 L
.79982 .08833 L
.81158 .08833 L
.81746 .09852 L
.82334 .08833 L
.8351 .08833 L
.82922 .07815 L
.8351 .06797 L
.84685 .06797 L
.85273 .07815 L
.85861 .06797 L
.87037 .06797 L
.86449 .05779 L
.87037 .0476 L
.85861 .0476 L
.85273 .03742 L
.85861 .02724 L
.87037 .02724 L
.86449 .01706 L
.87037 .00687 L
.88213 .00687 L
.88801 .01706 L
.89389 .00687 L
.90564 .00687 L
.91152 .01706 L
.90564 .02724 L
.9174 .02724 L
.92328 .03742 L
.92916 .02724 L
Mistroke
.94092 .02724 L
.93504 .01706 L
.94092 .00687 L
.95267 .00687 L
.95855 .01706 L
.96443 .00687 L
.97619 .00687 L
Mfstroke
0 0 m
1 0 L
1 .28868 L
0 .28868 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[41]:=",
  ImageSize->{288, 83.125},
  ImageMargins->{{31, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Db000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00203oool400000080oooo1@0000090?ooo`@000000P3oool5000001d0
oooo100000020?ooo`D000002@3oool4000000<0oooo1000001I0?ooo`D000000P3oool4000000T0
oooo1@0000020?ooo`@000007@3oool500000080oooo100000090?ooo`D000000P3oool4000000T0
oooo000<0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool01P3oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`0J0?ooo`070000003oool0oooo
0?ooo`000000oooo000000040?ooo`030000003oool0oooo00H0oooo00L000000?ooo`3oool0oooo
0000003oool0000000d0oooo000<0?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
0P3oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`030?ooo`800000
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool2000000@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`8000003@3oool000d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303o
ool001<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`004P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo000B0?ooo`@000000P3oool5000000T0
oooo1000000F0?ooo`D000002@3oool400000080oooo1@0000090?ooo`@00000D`3oool4000000T0
oooo1@0000020?ooo`@000002@3oool5000001H0oooo100000090?ooo`D000000P3oool4000001<0
oooo000F0?ooo`030000003oool000000140oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool000000140oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool000000140oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0000001L0oooo000F0?ooo`8000004P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0100oooo0P00000B0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0403oool200000180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0@0?ooo`8000005`3oool001L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool002X0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02T0oooo000Z0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Y0?ooo`00
9P3oool4000001H0oooo1@00000M0?ooo`@00000D`3oool4000001d0oooo1@00000F0?ooo`@00000
9`3oool002H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo02D0oooo000W0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool09P3oool002L0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo02H0oooo000V0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0U0?ooo`009P3oool400000080oooo1@00
00090?ooo`@000000P3oool5000001d0oooo100000030?ooo`@00000A@3oool4000000<0oooo1000
000M0?ooo`D000000P3oool4000000T0oooo1@0000020?ooo`@000009`3oool002X0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000009@3oool00`000000oooo000000040?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0000000U0?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool01P3oool01`000000oooo0?ooo`3oool000000?ooo`000000:`3oool002X0oooo0P00
00050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool2000002H0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000009P3oool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`030?ooo`800000:`3oool002/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02X0oooo000a0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0`0?ooo`00<03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0;`3oool00300oooo100000020?ooo`D00000
<@3oool4000003l0oooo1000000a0?ooo`D000000P3oool400000340oooo000d0?ooo`800000>P3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000=@3o
ool003D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0=03oool00700oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`1_0?ooo`00L03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo06l0
oooo001/0?ooo`@00000?`3oool4000006d0oooo001]0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0K03oool006d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1/
0?ooo`00I`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1V0?ooo`00IP3oool00`000000oooo000000040?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool00P3oool00`000000oooo0000001W0?ooo`00
IP3oool00`000000oooo000000040?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0000001W0?ooo`00HP3oool4000000<0oooo100000150?ooo`@000000`3o
ool4000006<0oooo001S0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0HP3oool0
06<0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo06<0oooo001S0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0HP3oool006<0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1R0?ooo`00HP3oool4000005<0oooo1000001S0?ooo`00IP3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo06D0oooo001V0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0I@3oool006L0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1V0?ooo`00IP3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo06D0oooo001V0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool0I@3oool00680oooo1000001C0?ooo`@00000H`3oool006<0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1R0?ooo`00H`3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0680oooo001T0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool0H`3oool006<0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1R
0?ooo`00HP3oool4000000<0oooo100000090?ooo`@000000`3oool4000001d0oooo100000030?oo
o`@000002@3oool4000000<0oooo1000001S0?ooo`00IP3oool00`000000oooo000000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000001W0?ooo`00
IP3oool00`000000oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0000001W0?ooo`00I`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1V0?ooo`00K@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0K03oool0
06d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
06`0oooo001/0?ooo`@000000`3oool4000000T0oooo1000000G0?ooo`@000002@3oool4000000<0
oooo1000001]0?ooo`00L03oool00`000000oooo0000000A0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0000001a0?ooo`00L03oool00`000000oooo0000
000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0000
001a0?ooo`00L@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`1`0?ooo`00Q03oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo08<0oooo00240?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0P`3oool00800oooo1000000G0?ooo`@00000P@3oool00840oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`200?ooo`00P@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0800oooo00220?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0P@3oool00840
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`200?ooo`00P@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0800oooo00200?ooo`@000000`3oool4000000T0oooo1000
00030?ooo`@00000P@3oool008@0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000Q@3oool008@0oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`000000Q@3oool008D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0Q03oool008/0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`2:0?ooo`00R`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo08X0oooo002:0?ooo`@000000`3oool4000008/0oooo002>0?ooo`030000003oool00000
08l0oooo002>0?ooo`030000003oool0000008l0oooo002?0?ooo`030000003oool0oooo08h0oooo
003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {82.125, 0}} -> {-0.0296474, -0.0072184, \
0.00369092, 0.00369092}}]
}, Open  ]],

Cell["ANIMATION", "Text",
  FontSize->18,
  FontColor->RGBColor[0.0299992, 0.179995, 0.329992],
  Background->RGBColor[0.737301, 0.5608, 0.5608]],

Cell[BoxData[
    \(\(Do[\(Show[Graphics[Line[sF[n\ \[Degree], 6]]]];\), {n, 1. , 360. , 
          10. }];\)\)], "Input",
  CellLabel->"In[59]:="],

Cell[TextData[{
  "The Kock curve is often confused with the ",
  StyleBox["Osgood curve",
    FontSlant->"Italic"],
  " (see \"A Geometrization of Lebesgue's Space-Filling Curve\" by H. Sagan \
in The Mathematical Intelligencer , Vol. 15 num. 4, 1993  pp. 37-43). The \
code for generating this attractive curve is the following. The reader is \
advised to try generating this curve for several values of the parameter \
\[Alpha], firstly between 0 and 1 and then any real number, even a negative \
one."
}], "Text"],

Cell[BoxData[{
    \(osgood[a_, b_, c_, \[Alpha]_, 1] := 
      Module[{d = a + \[Alpha] \((b - a)\), 
          e = b - \[Alpha] \((b - a)\)}, \[IndentingNewLine]{{RGBColor[
              0.529405, \ 0.807794, \ 0.921598], Polygon[{a, c, d}], 
            Polygon[{c, e, b}]}, Line[{a, c, d, a}], 
          Line[{c, e, b, c}]}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(osgood[a_, b_, c_, \[Alpha]_, n_] := 
      Module[{d = a + \[Alpha] \((b - a)\), 
          e = b - \[Alpha] \((b - a)\)}, \[IndentingNewLine]Join[
          osgood[a, c, d, \[Alpha], n - 1], 
          osgood[b, c, e, \[Alpha], n - 1]]]\)}], "Input",
  CellLabel->"In[130]:=",
  Background->RGBColor[0.990005, 0.970001, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        Graphics[osgood[{0, 0}, {2, 0}, {1, \@3}, 0.35, 4]]];\)\)], "Input",
  CellLabel->"In[132]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .86603 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0206197 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.529 .808 .922 r
.02381 .02062 m
.14048 .02062 L
.08214 .12166 L
F
.14048 .02062 m
.13214 .20826 L
.19048 .30929 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02062 m
.14048 .02062 L
.08214 .12166 L
.02381 .02062 L
s
.14048 .02062 m
.13214 .20826 L
.19048 .30929 L
.14048 .02062 L
s
.529 .808 .922 r
.35714 .02062 m
.24048 .02062 L
.29881 .12166 L
F
.24048 .02062 m
.24881 .20826 L
.19048 .30929 L
F
0 g
.35714 .02062 m
.24048 .02062 L
.29881 .12166 L
.35714 .02062 L
s
.24048 .02062 m
.24881 .20826 L
.19048 .30929 L
.24048 .02062 L
s
.529 .808 .922 r
.5 .84541 m
.45 .55673 L
.44167 .74437 L
F
.45 .55673 m
.39167 .65777 L
.33333 .55673 L
F
0 g
.5 .84541 m
.45 .55673 L
.44167 .74437 L
.5 .84541 L
s
.45 .55673 m
.39167 .65777 L
.33333 .55673 L
.45 .55673 L
s
.529 .808 .922 r
.35714 .02062 m
.40714 .30929 L
.34881 .20826 L
F
.40714 .30929 m
.34167 .36909 L
.33333 .55673 L
F
0 g
.35714 .02062 m
.40714 .30929 L
.34881 .20826 L
.35714 .02062 L
s
.40714 .30929 m
.34167 .36909 L
.33333 .55673 L
.40714 .30929 L
s
.529 .808 .922 r
.97619 .02062 m
.85952 .02062 L
.91786 .12166 L
F
.85952 .02062 m
.86786 .20826 L
.80952 .30929 L
F
0 g
.97619 .02062 m
.85952 .02062 L
.91786 .12166 L
.97619 .02062 L
s
.85952 .02062 m
.86786 .20826 L
.80952 .30929 L
.85952 .02062 L
s
.529 .808 .922 r
.64286 .02062 m
.75952 .02062 L
.70119 .12166 L
F
.75952 .02062 m
.75119 .20826 L
.80952 .30929 L
F
0 g
.64286 .02062 m
.75952 .02062 L
.70119 .12166 L
.64286 .02062 L
s
.75952 .02062 m
.75119 .20826 L
.80952 .30929 L
.75952 .02062 L
s
.529 .808 .922 r
.5 .84541 m
.55 .55673 L
.55833 .74437 L
F
.55 .55673 m
.60833 .65777 L
.66667 .55673 L
F
0 g
.5 .84541 m
.55 .55673 L
.55833 .74437 L
.5 .84541 L
s
.55 .55673 m
.60833 .65777 L
.66667 .55673 L
.55 .55673 L
s
.529 .808 .922 r
.64286 .02062 m
.59286 .30929 L
.65119 .20826 L
F
.59286 .30929 m
.65833 .36909 L
.66667 .55673 L
F
0 g
.64286 .02062 m
.59286 .30929 L
.65119 .20826 L
.64286 .02062 L
s
.59286 .30929 m
.65833 .36909 L
.66667 .55673 L
.59286 .30929 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[132]:=",
  ImageSize->{288, 249.375},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000nB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`001P3ooolS000001`0oooo8P00001A0?ooob800000703ooolS000000L0oooo00070?ooo`03
00000027c^`0Qlk/01d0Qlk/0P00000L0?ooo`8000007P27c^`200000540oooo0P00000N08O>k080
0000703oool2000001l0Qlk/00<000000?ooo`3oool01P3oool000L0oooo00<0000008O>k027c^`0
7@27c^`2000001`0oooo0P00000N08O>k0800000D@3oool2000001h0Qlk/0P00000L0?ooo`800000
7`27c^`00`000000oooo0?ooo`060?ooo`00203oool00`000000Qlk/08O>k00K08O>k0040000003o
ool00000000001X0oooo0P0000000`3oool0000008O>k00K08O>k0040000003oool00000000004l0
oooo0P0000000`3oool0000008O>k00K08O>k0040000003oool00000000001X0oooo0P0000000`3o
ool0000008O>k00L08O>k0030000003oool0oooo00L0oooo00080?ooo`0300000027c^`0Qlk/01/0
Qlk/00@000000?ooo`00000000006P3oool2000000030?ooo`000000Qlk/01/0Qlk/00@000000?oo
o`0000000000C`3oool2000000030?ooo`000000Qlk/01/0Qlk/00@000000?ooo`00000000006P3o
ool2000000030?ooo`000000Qlk/01`0Qlk/00<000000?ooo`3oool01`3oool000T0oooo00<00000
08O>k027c^`06@27c^`00`000000oooo0?ooo`02000001X0oooo0P0000020?ooo`0300000027c^`0
Qlk/01P0Qlk/00<000000?ooo`3oool00P00001?0?ooo`8000000P3oool00`000000Qlk/08O>k00H
08O>k0030000003oool0oooo008000006P3oool200000080oooo00<0000008O>k027c^`06@27c^`0
0`000000oooo0?ooo`080?ooo`002P3oool00`000000Qlk/08O>k00G08O>k0040000003oool0oooo
0?ooo`8000006P3oool200000080oooo00<0000008O>k027c^`05`27c^`010000000oooo0?ooo`3o
ool2000004l0oooo0P0000030?ooo`0300000027c^`0Qlk/01L0Qlk/00<000000?ooo`3oool00P00
000J0?ooo`8000000`3oool00`000000Qlk/08O>k00G08O>k0030000003oool0oooo00T0oooo000:
0?ooo`0300000027c^`0Qlk/01L0Qlk/00@000000?ooo`3oool0oooo0P00000J0?ooo`8000000`3o
ool00`000000Qlk/08O>k00F08O>k0040000003oool0oooo0?ooo`800000C`3oool2000000<0oooo
00<0000008O>k027c^`05P27c^`010000000oooo0?ooo`3oool2000001X0oooo0P0000030?ooo`03
00000027c^`0Qlk/01L0Qlk/00<000000?ooo`3oool02@3oool000/0oooo00<0000008O>k027c^`0
5@27c^`00`000000oooo0?ooo`020?ooo`8000006P3oool2000000<0oooo00<0000008O>k027c^`0
5@27c^`00`000000oooo0?ooo`020?ooo`800000C`3oool2000000@0oooo00<0000008O>k027c^`0
5@27c^`010000000oooo0?ooo`3oool2000001X0oooo0P0000040?ooo`0300000027c^`0Qlk/01D0
Qlk/00<000000?ooo`3oool02P3oool000/0oooo00<0000008O>k027c^`05@27c^`00`000000oooo
0?ooo`020?ooo`0300000027c^`0000001P0oooo00<0000008O>k0000000103oool00`000000Qlk/
08O>k00D08O>k0030000003oool0oooo0080oooo00<0000008O>k0000000C@3oool00`000000Qlk/
000000040?ooo`0300000027c^`0Qlk/01@0Qlk/00<000000?ooo`3oool00P3oool00`000000Qlk/
0000000H0?ooo`0300000027c^`0000000@0oooo00<0000008O>k027c^`05@27c^`00`000000oooo
0?ooo`0:0?ooo`00303oool00`000000Qlk/08O>k00C08O>k0030000003oool0oooo00<0oooo00<0
000008O>k0000000603oool00`000000Qlk/000000050?ooo`0300000027c^`0Qlk/0180Qlk/00<0
00000?ooo`3oool00`3oool00`000000Qlk/0000001=0?ooo`0300000027c^`0000000D0oooo00<0
000008O>k027c^`04P27c^`00`000000oooo0?ooo`030?ooo`0300000027c^`0000001P0oooo00@0
000008O>k027c^`00000103oool00`000000Qlk/08O>k00C08O>k0030000003oool0oooo00/0oooo
000<0?ooo`0300000027c^`0Qlk/01<0Qlk/00<000000?ooo`3oool00`3oool00`000000Qlk/0000
000H0?ooo`0300000027c^`0000000D0oooo00<0000008O>k027c^`04P27c^`00`000000oooo0?oo
o`030?ooo`0300000027c^`0000004d0oooo00<0000008O>k00000001@3oool00`000000Qlk/08O>
k00B08O>k0030000003oool0oooo00<0oooo00<0000008O>k0000000603oool010000000Qlk/08O>
k00000040?ooo`0300000027c^`0Qlk/01<0Qlk/00<000000?ooo`3oool02`3oool000d0oooo00<0
000008O>k027c^`04@27c^`00`000000oooo0?ooo`040?ooo`0300000027c^`0000001P0oooo00<0
000008O>k00000001P3oool00`000000Qlk/08O>k00@08O>k0030000003oool0oooo00@0oooo00<0
000008O>k0000000C@3oool00`000000Qlk/000000060?ooo`0300000027c^`0Qlk/0100Qlk/00<0
00000?ooo`3oool0103oool00`000000Qlk/0000000H0?ooo`0400000027c^`0Qlk/000000D0oooo
00<0000008O>k027c^`04@27c^`00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000Qlk/08O>
k00?08O>k0030000003oool0oooo00D0oooo00<0000008O>k0000000603oool00`000000Qlk/0000
00060?ooo`0300000027c^`0Qlk/00l0Qlk/00<000000?ooo`3oool01@3oool00`000000Qlk/0000
001=0?ooo`0300000027c^`0000000L0oooo00<0000008O>k027c^`03`27c^`00`000000oooo0?oo
o`040?ooo`0300000027c^`0000001P0oooo00@0000008O>k027c^`000001P3oool00`000000Qlk/
08O>k00?08O>k0030000003oool0oooo00d0oooo000>0?ooo`0300000027c^`0Qlk/00l0Qlk/00<0
00000?ooo`3oool0103oool010000000Qlk/08O>k000000G0?ooo`0500000027c^`0Qlk/08O>k000
00001P3oool00`000000Qlk/08O>k00>08O>k0030000003oool0oooo00@0oooo00@0000008O>k027
c^`00000C@3oool010000000Qlk/08O>k00000060?ooo`0300000027c^`0Qlk/00h0Qlk/00<00000
0?ooo`3oool0103oool01@000000Qlk/08O>k027c^`0000001L0oooo00@0000008O>k027c^`00000
1P3oool00`000000Qlk/08O>k00?08O>k0030000003oool0oooo00d0oooo000?0?ooo`0300000027
c^`0Qlk/00d0Qlk/00<000000?ooo`3oool01@3oool01@000000Qlk/08O>k027c^`0000001H0oooo
00D0000008O>k027c^`0Qlk/000000060?ooo`0300000027c^`0Qlk/00d0Qlk/00<000000?ooo`3o
ool01@3oool01@000000Qlk/08O>k027c^`0000004/0oooo00D0000008O>k027c^`0Qlk/00000007
0?ooo`0300000027c^`0Qlk/00d0Qlk/00<000000?ooo`3oool0103oool01@000000Qlk/08O>k027
c^`0000001H0oooo00D0000008O>k027c^`0Qlk/000000070?ooo`0300000027c^`0Qlk/00d0Qlk/
00<000000?ooo`3oool03P3oool000l0oooo00<0000008O>k027c^`03@27c^`00`000000oooo0?oo
o`050?ooo`0500000027c^`0Qlk/08O>k00000005P3oool01@000000Qlk/08O>k027c^`0000000L0
oooo00<0000008O>k027c^`03027c^`00`000000oooo0?ooo`050?ooo`0500000027c^`0Qlk/08O>
k0000000B`3oool01@000000Qlk/08O>k027c^`0000000L0oooo00<0000008O>k027c^`03027c^`0
0`000000oooo0?ooo`050?ooo`0500000027c^`0Qlk/08O>k00000005P3oool01@000000Qlk/08O>
k027c^`0000000L0oooo00<0000008O>k027c^`03@27c^`00`000000oooo0?ooo`0>0?ooo`00403o
ool00`000000Qlk/08O>k00;08O>k0030000003oool0oooo00H0oooo00D0000008O>k027c^`0Qlk/
0000000F0?ooo`0500000027c^`0Qlk/08O>k00000001`3oool00`000000Qlk/08O>k00;08O>k003
0000003oool0oooo00H0oooo00D0000008O>k027c^`0Qlk/0000001;0?ooo`0500000027c^`0Qlk/
08O>k0000000203oool00`000000Qlk/08O>k00;08O>k0030000003oool0oooo00D0oooo00D00000
08O>k027c^`0Qlk/0000000F0?ooo`0500000027c^`0Qlk/08O>k0000000203oool00`000000Qlk/
08O>k00;08O>k0030000003oool0oooo00l0oooo000A0?ooo`0300000027c^`0Qlk/00T0Qlk/00<0
00000?ooo`3oool01`3oool01@000000Qlk/08O>k027c^`0000001H0oooo00D0000008O>k027c^`0
Qlk/000000080?ooo`0300000027c^`0Qlk/00T0Qlk/00<000000?ooo`3oool01`3oool01@000000
Qlk/08O>k027c^`0000004/0oooo00D0000008O>k027c^`0Qlk/000000090?ooo`0300000027c^`0
Qlk/00T0Qlk/00<000000?ooo`3oool01P3oool01@000000Qlk/08O>k027c^`0000001H0oooo00D0
000008O>k027c^`0Qlk/000000090?ooo`0300000027c^`0Qlk/00T0Qlk/00<000000?ooo`3oool0
403oool00140oooo00<0000008O>k027c^`02@27c^`00`000000oooo0?ooo`070?ooo`0500000027
c^`0Qlk/08O>k00000005P3oool01@000000Qlk/08O>k027c^`0000000P0oooo00<0000008O>k027
c^`02@27c^`00`000000oooo0?ooo`070?ooo`0500000027c^`0Qlk/08O>k0000000B`3oool01@00
0000Qlk/08O>k027c^`0000000T0oooo00<0000008O>k027c^`02@27c^`00`000000oooo0?ooo`06
0?ooo`0500000027c^`0Qlk/08O>k00000005P3oool01@000000Qlk/08O>k027c^`0000000T0oooo
00<0000008O>k027c^`02@27c^`00`000000oooo0?ooo`0@0?ooo`004P3oool00`000000Qlk/08O>
k00708O>k0030000003oool0oooo00P0oooo00D0000008O>k027c^`0Qlk/0000000E0?ooo`030000
0027c^`0Qlk/0080Qlk/00<000000?ooo`3oool01`3oool00`000000Qlk/08O>k00708O>k0030000
003oool0oooo00P0oooo00D0000008O>k027c^`0Qlk/0000001;0?ooo`0500000027c^`0Qlk/08O>
k00000002P3oool00`000000Qlk/08O>k00708O>k0030000003oool0oooo00L0oooo00<0000008O>
k027c^`00P27c^`00`000000oooo0?ooo`0C0?ooo`0500000027c^`0Qlk/08O>k00000002P3oool0
0`000000Qlk/08O>k00708O>k0030000003oool0oooo0140oooo000B0?ooo`0300000027c^`0Qlk/
00L0Qlk/00<000000?ooo`3oool0203oool00`000000Qlk/08O>k00208O>k0030000003oool0oooo
0180oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`080?ooo`0300000027c^`0Qlk/
00H0Qlk/00<000000?ooo`3oool0203oool00`000000Qlk/08O>k00208O>k0030000003oool0oooo
04L0oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`080?ooo`0300000027c^`0Qlk/
00H0Qlk/00<000000?ooo`3oool0203oool00`000000Qlk/08O>k00208O>k0030000003oool0oooo
0180oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`080?ooo`0300000027c^`0Qlk/
00L0Qlk/00<000000?ooo`3oool04@3oool001<0oooo00<0000008O>k027c^`01@27c^`00`000000
oooo0?ooo`090?ooo`0300000027c^`0Qlk/0080Qlk/00<000000?ooo`3oool04P3oool00`000000
Qlk/08O>k00208O>k0030000003oool0oooo00P0oooo00<0000008O>k027c^`01@27c^`00`000000
oooo0?ooo`090?ooo`0300000027c^`0Qlk/0080Qlk/00<000000?ooo`3oool0A`3oool00`000000
Qlk/08O>k00208O>k0030000003oool0oooo00T0oooo00<0000008O>k027c^`01@27c^`00`000000
oooo0?ooo`080?ooo`0300000027c^`0Qlk/0080Qlk/00<000000?ooo`3oool04P3oool00`000000
Qlk/08O>k00208O>k0030000003oool0oooo00T0oooo00<0000008O>k027c^`01@27c^`00`000000
oooo0?ooo`0B0?ooo`004`3oool00`000000Qlk/08O>k00508O>k0030000003oool0oooo00T0oooo
00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`0B0?ooo`0300000027c^`0Qlk/0080Qlk/
00<000000?ooo`3oool02@3oool00`000000Qlk/08O>k00408O>k0030000003oool0oooo00T0oooo
00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`170?ooo`0300000027c^`0Qlk/0080Qlk/
00<000000?ooo`3oool02@3oool00`000000Qlk/08O>k00408O>k0030000003oool0oooo00T0oooo
00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`0B0?ooo`0300000027c^`0Qlk/0080Qlk/
00<000000?ooo`3oool02@3oool00`000000Qlk/08O>k00508O>k0030000003oool0oooo0180oooo
000D0?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool02P3oool00`000000Qlk/08O>
k00208O>k0030000003oool0oooo0180oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?oo
o`090?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool02P3oool00`000000Qlk/08O>
k00208O>k0030000003oool0oooo04L0oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?oo
o`0:0?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool02@3oool00`000000Qlk/08O>
k00208O>k0030000003oool0oooo0180oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?oo
o`0:0?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool04`3oool001D0oooo00D00000
08O>k027c^`0Qlk/0000000=0?ooo`0300000027c^`0Qlk/0080Qlk/00<000000?ooo`3oool04@3o
ool00`000000Qlk/08O>k00308O>k0030000003oool0oooo00X0oooo00D0000008O>k027c^`0Qlk/
0000000=0?ooo`0300000027c^`0Qlk/0080Qlk/00<000000?ooo`3oool0A`3oool00`000000Qlk/
08O>k00208O>k0030000003oool0oooo00/0oooo00D0000008O>k027c^`0Qlk/0000000<0?ooo`03
00000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool04@3oool00`000000Qlk/08O>k00208O>k003
0000003oool0oooo00/0oooo00D0000008O>k027c^`0Qlk/0000000F0?ooo`005@3oool01@000000
Qlk/08O>k027c^`0000000d0oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`0A0?oo
o`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool02P3oool01@000000Qlk/08O>k027c^`0
000000d0oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`170?ooo`0300000027c^`0
Qlk/0080Qlk/00<000000?ooo`3oool02`3oool01@000000Qlk/08O>k027c^`0000000`0oooo00<0
000008O>k027c^`00`27c^`00`000000oooo0?ooo`0A0?ooo`0300000027c^`0Qlk/0080Qlk/00<0
00000?ooo`3oool02`3oool01@000000Qlk/08O>k027c^`0000001H0oooo000F0?ooo`0300000027
c^`0000000h0oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?ooo`0@0?ooo`0300000027
c^`0Qlk/00<0Qlk/00<000000?ooo`3oool02`3oool00`000000Qlk/0000000>0?ooo`0300000027
c^`0Qlk/00<0Qlk/00<000000?ooo`3oool0A@3oool00`000000Qlk/08O>k00308O>k0030000003o
ool0oooo00`0oooo00<0000008O>k00000003@3oool00`000000Qlk/08O>k00308O>k0030000003o
ool0oooo0100oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?ooo`0<0?ooo`0300000027
c^`0000001L0oooo000F0?ooo`0300000027c^`0000000h0oooo00<0000008O>k027c^`00`27c^`0
0`000000oooo0?ooo`0@0?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool02`3oool0
0`000000Qlk/0000000>0?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool0A@3oool0
0`000000Qlk/08O>k00308O>k0030000003oool0oooo00`0oooo00<0000008O>k00000003@3oool0
0`000000Qlk/08O>k00308O>k0030000003oool0oooo0100oooo00<0000008O>k027c^`01027c^`0
0`000000oooo0?ooo`0;0?ooo`0300000027c^`0000001L0oooo000G0?ooo`030000003oool0oooo
00d0oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?ooo`0@0?ooo`0300000027c^`0Qlk/
00<0Qlk/00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`0300000027c^`0Qlk/
00<0Qlk/00<000000?ooo`3oool0A@3oool00`000000Qlk/08O>k00308O>k0030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000Qlk/08O>k00308O>k0030000003oool0oooo
0100oooo00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
01H0oooo000W0?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool0403oool00`000000
Qlk/08O>k00308O>k0030000003oool0oooo01`0oooo00<0000008O>k027c^`00`27c^`00`000000
oooo0?ooo`150?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool0703oool00`000000
Qlk/08O>k00308O>k0030000003oool0oooo0100oooo00<0000008O>k027c^`01027c^`00`000000
oooo0?ooo`0U0?ooo`009`3oool00`000000Qlk/08O>k00308O>k0030000003oool0oooo00l0oooo
00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`0L0?ooo`0300000027c^`0Qlk/00<0Qlk/
00<000000?ooo`3oool0A@3oool00`000000Qlk/08O>k00308O>k0030000003oool0oooo01`0oooo
00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`0?0?ooo`0300000027c^`0Qlk/00@0Qlk/
00<000000?ooo`3oool09@3oool002L0oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?oo
o`0?0?ooo`0300000027c^`0Qlk/00@0Qlk/00<000000?ooo`3oool0703oool00`000000Qlk/08O>
k00308O>k0030000003oool0oooo04D0oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?oo
o`0L0?ooo`0300000027c^`0Qlk/00@0Qlk/00<000000?ooo`3oool03`3oool00`000000Qlk/08O>
k00408O>k0030000003oool0oooo02D0oooo000W0?ooo`0300000027c^`0Qlk/00@0Qlk/00<00000
0?ooo`3oool03P3oool00`000000Qlk/08O>k00408O>k0030000003oool0oooo01`0oooo00<00000
08O>k027c^`01027c^`00`000000oooo0?ooo`130?ooo`0300000027c^`0Qlk/00@0Qlk/00<00000
0?ooo`3oool0703oool00`000000Qlk/08O>k00408O>k0030000003oool0oooo00h0oooo00<00000
08O>k027c^`01@27c^`00`000000oooo0?ooo`0U0?ooo`009`3oool00`000000Qlk/08O>k00408O>
k0030000003oool0oooo00h0oooo00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`0L0?oo
o`0300000027c^`0Qlk/00@0Qlk/00<000000?ooo`3oool0@`3oool00`000000Qlk/08O>k00408O>
k0030000003oool0oooo01`0oooo00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`0>0?oo
o`0300000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool09@3oool002L0oooo00<0000008O>k027
c^`01027c^`00`000000oooo0?ooo`0>0?ooo`0300000027c^`0Qlk/00@0Qlk/00<000000?ooo`3o
ool0703oool00`000000Qlk/08O>k00408O>k0030000003oool0oooo04<0oooo00<0000008O>k027
c^`01027c^`00`000000oooo0?ooo`0L0?ooo`0300000027c^`0Qlk/00@0Qlk/00<000000?ooo`3o
ool03P3oool00`000000Qlk/08O>k00508O>k0030000003oool0oooo02D0oooo000W0?ooo`030000
0027c^`0Qlk/00@0Qlk/00<000000?ooo`3oool03@3oool00`000000Qlk/08O>k00508O>k0030000
003oool0oooo01`0oooo00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`130?ooo`030000
0027c^`0Qlk/00@0Qlk/00<000000?ooo`3oool0703oool00`000000Qlk/08O>k00508O>k0030000
003oool0oooo00d0oooo00<0000008O>k027c^`01@27c^`00`000000oooo0?ooo`0U0?ooo`009`3o
ool00`000000Qlk/08O>k00408O>k0030000003oool0oooo00d0oooo00<0000008O>k027c^`01@27
c^`00`000000oooo0?ooo`0L0?ooo`0300000027c^`0Qlk/00@0Qlk/00<000000?ooo`3oool0@`3o
ool00`000000Qlk/08O>k00408O>k0030000003oool0oooo01`0oooo00<0000008O>k027c^`01@27
c^`00`000000oooo0?ooo`0=0?ooo`0300000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool09@3o
ool002L0oooo00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`0=0?ooo`0300000027c^`0
Qlk/00D0Qlk/00<000000?ooo`3oool0703oool00`000000Qlk/08O>k00408O>k0030000003oool0
oooo04<0oooo00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`0L0?ooo`0300000027c^`0
Qlk/00D0Qlk/00<000000?ooo`3oool03@3oool00`000000Qlk/08O>k00508O>k0030000003oool0
oooo02D0oooo000W0?ooo`0300000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool0303oool00`00
0000Qlk/08O>k00508O>k0030000003oool0oooo01`0oooo00<0000008O>k027c^`01@27c^`00`00
0000oooo0?ooo`110?ooo`0300000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool0703oool00`00
0000Qlk/08O>k00508O>k0030000003oool0oooo00`0oooo00<0000008O>k027c^`01P27c^`00`00
0000oooo0?ooo`0U0?ooo`009`3oool00`000000Qlk/08O>k00508O>k0030000003oool0oooo00`0
oooo00<0000008O>k027c^`01@27c^`00`000000oooo0?ooo`0L0?ooo`0300000027c^`0Qlk/00D0
Qlk/00<000000?ooo`3oool0@@3oool00`000000Qlk/08O>k00508O>k0030000003oool0oooo01`0
oooo00<0000008O>k027c^`01@27c^`00`000000oooo0?ooo`0<0?ooo`0300000027c^`0Qlk/00H0
Qlk/00<000000?ooo`3oool09@3oool002H0oooo00<0000008O>k027c^`01P27c^`00`000000oooo
0?ooo`0<0?ooo`0300000027c^`0Qlk/00H0Qlk/00<000000?ooo`3oool06P3oool00`000000Qlk/
08O>k00608O>k0030000003oool0oooo0440oooo00<0000008O>k027c^`01P27c^`00`000000oooo
0?ooo`0J0?ooo`0300000027c^`0Qlk/00H0Qlk/00<000000?ooo`3oool0303oool00`000000Qlk/
08O>k00608O>k0030000003oool0oooo02D0oooo000V0?ooo`0300000027c^`0Qlk/00H0Qlk/00<0
00000?ooo`3oool02`3oool00`000000Qlk/08O>k00708O>k0030000003oool0oooo01X0oooo00<0
000008O>k027c^`01P27c^`00`000000oooo0?ooo`110?ooo`0300000027c^`0Qlk/00H0Qlk/00<0
00000?ooo`3oool06P3oool00`000000Qlk/08O>k00708O>k0030000003oool0oooo00/0oooo00<0
000008O>k027c^`01P27c^`00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000Qlk/08O>k006
08O>k0030000003oool0oooo00/0oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`0J
0?ooo`0300000027c^`0Qlk/00H0Qlk/00<000000?ooo`3oool0@@3oool00`000000Qlk/08O>k006
08O>k0030000003oool0oooo01X0oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`0;
0?ooo`0300000027c^`0Qlk/00H0Qlk/00<000000?ooo`3oool09@3oool002H0oooo00<0000008O>
k027c^`01P27c^`00`000000oooo0?ooo`0;0?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?oo
o`3oool06P3oool00`000000Qlk/08O>k00608O>k0030000003oool0oooo0440oooo00<0000008O>
k027c^`01P27c^`00`000000oooo0?ooo`0J0?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?oo
o`3oool02`3oool00`000000Qlk/08O>k00608O>k0030000003oool0oooo02D0oooo000V0?ooo`03
00000027c^`0Qlk/00L0Qlk/00<000000?ooo`3oool02P3oool00`000000Qlk/08O>k00708O>k003
0000003oool0oooo01X0oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`0o0?ooo`03
00000027c^`0Qlk/00L0Qlk/00<000000?ooo`3oool06P3oool00`000000Qlk/08O>k00708O>k003
0000003oool0oooo00X0oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`0U0?ooo`00
9P3oool00`000000Qlk/08O>k00708O>k0030000003oool0oooo00X0oooo00<0000008O>k027c^`0
1`27c^`00`000000oooo0?ooo`0J0?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?ooo`3oool0
?`3oool00`000000Qlk/08O>k00708O>k0030000003oool0oooo01X0oooo00<0000008O>k027c^`0
1`27c^`00`000000oooo0?ooo`0:0?ooo`0300000027c^`0Qlk/00P0Qlk/00<000000?ooo`3oool0
903oool002H0oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`0:0?ooo`0300000027
c^`0Qlk/00L0Qlk/00<000000?ooo`3oool06P3oool00`000000Qlk/08O>k00708O>k0030000003o
ool0oooo03l0oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`0J0?ooo`0300000027
c^`0Qlk/00L0Qlk/00<000000?ooo`3oool02P3oool00`000000Qlk/08O>k00808O>k0030000003o
ool0oooo02@0oooo000V0?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?ooo`3oool02@3oool0
0`000000Qlk/08O>k00808O>k0030000003oool0oooo01X0oooo00<0000008O>k027c^`01`27c^`0
0`000000oooo0?ooo`0o0?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?ooo`3oool06P3oool0
0`000000Qlk/08O>k00808O>k0030000003oool0oooo00T0oooo00<0000008O>k027c^`02027c^`0
0`000000oooo0?ooo`0T0?ooo`009P3oool00`000000Qlk/08O>k00708O>k0030000003oool0oooo
00T0oooo00<0000008O>k027c^`02027c^`00`000000oooo0?ooo`0J0?ooo`0300000027c^`0Qlk/
00L0Qlk/00<000000?ooo`3oool0?`3oool00`000000Qlk/08O>k00708O>k0030000003oool0oooo
01X0oooo00<0000008O>k027c^`02027c^`00`000000oooo0?ooo`090?ooo`0300000027c^`0Qlk/
00P0Qlk/00<000000?ooo`3oool0903oool002H0oooo00<0000008O>k027c^`01`27c^`00`000000
oooo0?ooo`090?ooo`0300000027c^`0Qlk/00P0Qlk/00<000000?ooo`3oool06P3oool00`000000
Qlk/08O>k00708O>k0030000003oool0oooo03l0oooo00<0000008O>k027c^`01`27c^`00`000000
oooo0?ooo`0J0?ooo`0300000027c^`0Qlk/00P0Qlk/00<000000?ooo`3oool02@3oool00`000000
Qlk/08O>k00808O>k0030000003oool0oooo02@0oooo000V0?ooo`0300000027c^`0Qlk/00P0Qlk/
00<000000?ooo`3oool0203oool00`000000Qlk/08O>k00808O>k0030000003oool0oooo01X0oooo
00<0000008O>k027c^`02027c^`00`000000oooo0?ooo`0m0?ooo`0300000027c^`0Qlk/00P0Qlk/
00<000000?ooo`3oool06P3oool00`000000Qlk/08O>k00808O>k0030000003oool0oooo00P0oooo
00<0000008O>k027c^`02@27c^`00`000000oooo0?ooo`0T0?ooo`009P3oool00`000000Qlk/08O>
k00808O>k0030000003oool0oooo00P0oooo00<0000008O>k027c^`02027c^`00`000000oooo0?oo
o`0J0?ooo`0300000027c^`0Qlk/00P0Qlk/00<000000?ooo`3oool0?@3oool00`000000Qlk/08O>
k00808O>k0030000003oool0oooo01X0oooo00<0000008O>k027c^`02027c^`00`000000oooo0?oo
o`080?ooo`0300000027c^`0Qlk/00T0Qlk/00<000000?ooo`3oool0903oool002H0oooo00<00000
08O>k027c^`02027c^`00`000000oooo0?ooo`070?ooo`0300000027c^`0Qlk/00T0Qlk/00<00000
0?ooo`3oool06P3oool00`000000Qlk/08O>k00808O>k0030000003oool0oooo03d0oooo00<00000
08O>k027c^`02027c^`00`000000oooo0?ooo`0J0?ooo`0300000027c^`0Qlk/00T0Qlk/00<00000
0?ooo`3oool01`3oool00`000000Qlk/08O>k00908O>k0030000003oool0oooo02@0oooo000V0?oo
o`0300000027c^`0Qlk/00P0Qlk/00<000000?ooo`3oool01`3oool00`000000Qlk/08O>k00908O>
k0030000003oool0oooo01X0oooo00<0000008O>k027c^`02027c^`00`000000oooo0?ooo`0m0?oo
o`0300000027c^`0Qlk/00P0Qlk/00<000000?ooo`3oool06P3oool00`000000Qlk/08O>k00908O>
k0030000003oool0oooo00L0oooo00<0000008O>k027c^`02@27c^`00`000000oooo0?ooo`0T0?oo
o`009`3oool00`000000Qlk/08O>k00708O>k0030000003oool0oooo00L0oooo00<0000008O>k027
c^`02027c^`00`000000oooo0?ooo`0L0?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?ooo`3o
ool0?@3oool00`000000Qlk/08O>k00708O>k0030000003oool0oooo01`0oooo00<0000008O>k027
c^`02027c^`00`000000oooo0?ooo`070?ooo`0300000027c^`0Qlk/00P0Qlk/00<000000?ooo`3o
ool09@3oool002L0oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`070?ooo`030000
0027c^`0Qlk/00P0Qlk/00<000000?ooo`3oool0703oool00`000000Qlk/08O>k00708O>k0030000
003oool0oooo03d0oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`0L0?ooo`030000
0027c^`0Qlk/00P0Qlk/00<000000?ooo`3oool01`3oool00`000000Qlk/08O>k00808O>k0030000
003oool0oooo02D0oooo000X0?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?ooo`3oool01P3o
ool00`000000Qlk/08O>k00708O>k0030000003oool0oooo01h0oooo00<0000008O>k027c^`01`27
c^`00`000000oooo0?ooo`0k0?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?ooo`3oool07P3o
ool00`000000Qlk/08O>k00708O>k0030000003oool0oooo00H0oooo00<0000008O>k027c^`02027
c^`00`000000oooo0?ooo`0V0?ooo`00:03oool00`000000Qlk/08O>k00708O>k0030000003oool0
oooo00H0oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`0N0?ooo`0300000027c^`0
Qlk/00L0Qlk/00<000000?ooo`3oool0>`3oool00`000000Qlk/08O>k00708O>k0030000003oool0
oooo01h0oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`060?ooo`0300000027c^`0
Qlk/00P0Qlk/00<000000?ooo`3oool09P3oool002T0oooo00<0000008O>k027c^`01P27c^`00`00
0000oooo0?ooo`050?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?ooo`3oool0803oool00`00
0000Qlk/08O>k00608O>k0030000003oool0oooo03/0oooo00<0000008O>k027c^`01P27c^`00`00
0000oooo0?ooo`0P0?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?ooo`3oool01@3oool00`00
0000Qlk/08O>k00708O>k0030000003oool0oooo02L0oooo000Y0?ooo`0300000027c^`0Qlk/00H0
Qlk/00<000000?ooo`3oool01@3oool00`000000Qlk/08O>k00608O>k0030000003oool0oooo0240
oooo00<0000008O>k027c^`01P27c^`00`000000oooo0?ooo`0k0?ooo`0300000027c^`0Qlk/00H0
Qlk/00<000000?ooo`3oool08@3oool00`000000Qlk/08O>k00608O>k0030000003oool0oooo00D0
oooo00<0000008O>k027c^`01P27c^`00`000000oooo0?ooo`0X0?ooo`00:P3oool00`000000Qlk/
08O>k00508O>k0030000003oool0oooo00D0oooo00<0000008O>k027c^`01P27c^`00`000000oooo
0?ooo`0R0?ooo`0300000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool0>`3oool00`000000Qlk/
08O>k00508O>k0030000003oool0oooo0280oooo00<0000008O>k027c^`01P27c^`00`000000oooo
0?ooo`050?ooo`0300000027c^`0Qlk/00H0Qlk/00<000000?ooo`3oool0:03oool002X0oooo00<0
000008O>k027c^`01@27c^`00`000000oooo0?ooo`050?ooo`0300000027c^`0Qlk/00D0Qlk/00<0
00000?ooo`3oool08`3oool00`000000Qlk/08O>k00508O>k0030000003oool0oooo03/0oooo00<0
000008O>k027c^`01@27c^`00`000000oooo0?ooo`0S0?ooo`0300000027c^`0Qlk/00D0Qlk/00<0
00000?ooo`3oool01@3oool00`000000Qlk/08O>k00508O>k0030000003oool0oooo02T0oooo000[
0?ooo`0300000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool0103oool00`000000Qlk/08O>k005
08O>k0030000003oool0oooo02@0oooo00<0000008O>k027c^`01@27c^`00`000000oooo0?ooo`0i
0?ooo`0300000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool0903oool00`000000Qlk/08O>k005
08O>k0030000003oool0oooo00@0oooo00<0000008O>k027c^`01P27c^`00`000000oooo0?ooo`0Y
0?ooo`00;03oool00`000000Qlk/08O>k00408O>k0030000003oool0oooo00<0oooo00<0000008O>
k027c^`01@27c^`00`000000oooo0?ooo`0V0?ooo`0300000027c^`0Qlk/00@0Qlk/00<000000?oo
o`3oool0>@3oool00`000000Qlk/08O>k00408O>k0030000003oool0oooo02H0oooo00<0000008O>
k027c^`01@27c^`00`000000oooo0?ooo`030?ooo`0300000027c^`0Qlk/00D0Qlk/00<000000?oo
o`3oool0:P3oool002`0oooo00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`030?ooo`03
00000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool09P3oool00`000000Qlk/08O>k00408O>k003
0000003oool0oooo03T0oooo00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`0V0?ooo`03
00000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool00`3oool00`000000Qlk/08O>k00508O>k003
0000003oool0oooo02X0oooo000]0?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool0
0`3oool00`000000Qlk/08O>k00408O>k0030000003oool0oooo02P0oooo00<0000008O>k027c^`0
0`27c^`00`000000oooo0?ooo`0i0?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool0
:03oool00`000000Qlk/08O>k00408O>k0030000003oool0oooo00<0oooo00<0000008O>k027c^`0
1027c^`00`000000oooo0?ooo`0[0?ooo`00;@3oool00`000000Qlk/08O>k00308O>k0030000003o
ool0oooo00<0oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?ooo`0Y0?ooo`0300000027
c^`0Qlk/00<0Qlk/00<000000?ooo`3oool0>@3oool00`000000Qlk/08O>k00308O>k0030000003o
ool0oooo02T0oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?ooo`030?ooo`0300000027
c^`0Qlk/00<0Qlk/00<000000?ooo`3oool0;03oool002h0oooo00<0000008O>k027c^`00P27c^`0
0`000000oooo0?ooo`030?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool0:P3oool0
0`000000Qlk/08O>k00208O>k0030000003oool0oooo03T0oooo00<0000008O>k027c^`00P27c^`0
0`000000oooo0?ooo`0Z0?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool00`3oool0
0`000000Qlk/08O>k00308O>k0030000003oool0oooo02`0oooo000^0?ooo`0300000027c^`0Qlk/
00<0Qlk/00<000000?ooo`3oool00P3oool00`000000Qlk/08O>k00208O>k0030000003oool0oooo
02/0oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?ooo`0g0?ooo`0300000027c^`0Qlk/
00<0Qlk/00<000000?ooo`3oool0:`3oool00`000000Qlk/08O>k00208O>k0030000003oool0oooo
0080oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?ooo`0]0?ooo`00;`3oool00`000000
Qlk/08O>k00208O>k0050000003oool0oooo0?ooo`0000001@27c^`00`000000oooo0?ooo`0/0?oo
o`0300000027c^`0Qlk/0080Qlk/00<000000?ooo`3oool0=`3oool00`000000Qlk/08O>k00208O>
k0030000003oool0oooo02`0oooo00<0000008O>k027c^`00`27c^`01@000000oooo0?ooo`3oool0
000000D0Qlk/00<000000?ooo`3oool0;@3oool002l0oooo00<0000008O>k027c^`00P27c^`01@00
0000oooo0?ooo`3oool0000000@0Qlk/00<000000?ooo`3oool0;@3oool00`000000Qlk/08O>k002
08O>k0030000003oool0oooo03L0oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`0]
0?ooo`0300000027c^`0Qlk/0080Qlk/00D000000?ooo`3oool0oooo0000000408O>k0030000003o
ool0oooo02h0oooo000`0?ooo`0500000027c^`0Qlk/08O>k00000000`3oool01@000000Qlk/08O>
k027c^`000000340oooo00D0000008O>k027c^`0Qlk/0000000i0?ooo`0500000027c^`0Qlk/08O>
k0000000<@3oool01@000000Qlk/08O>k027c^`0000000<0oooo00D0000008O>k027c^`0Qlk/0000
000a0?ooo`00<03oool01@000000Qlk/08O>k027c^`0000000<0oooo00D0000008O>k027c^`0Qlk/
0000000a0?ooo`0500000027c^`0Qlk/08O>k0000000>@3oool01@000000Qlk/08O>k027c^`00000
0340oooo00D0000008O>k027c^`0Qlk/000000030?ooo`0500000027c^`0Qlk/08O>k0000000<@3o
ool00340oooo00@0000008O>k027c^`000000`3oool010000000Qlk/08O>k000000c0?ooo`040000
0027c^`0Qlk/000003T0oooo00@0000008O>k027c^`00000<`3oool010000000Qlk/08O>k0000003
0?ooo`0400000027c^`0Qlk/00000380oooo000b0?ooo`0600000027c^`0Qlk/0000003oool00000
0`27c^`00`000000oooo0?ooo`0b0?ooo`0400000027c^`0Qlk/000003L0oooo00@0000008O>k027
c^`00000=03oool01`000000Qlk/08O>k027c^`000000?ooo`0000000`27c^`00`000000oooo0?oo
o`0`0?ooo`00<P3oool01P000000Qlk/08O>k0000000oooo00000080Qlk/00<000000?ooo`3oool0
<`3oool010000000Qlk/08O>k000000g0?ooo`0400000027c^`0Qlk/000003D0oooo00H0000008O>
k027c^`000000?ooo`00000208O>k0030000003oool0oooo0340oooo000c0?ooo`0500000027c^`0
00000?ooo`0000000P27c^`00`000000oooo0?ooo`0d0?ooo`0300000027c^`0000003L0oooo00<0
000008O>k0000000=P3oool01P000000Qlk/08O>k0000000oooo00000080Qlk/00<000000?ooo`3o
ool0<@3oool003<0oooo00L0000008O>k0000000oooo00000027c^`0000003L0oooo00<0000008O>
k0000000=`3oool00`000000Qlk/0000000g0?ooo`0700000027c^`000000?ooo`000000Qlk/0000
000d0?ooo`00=03oool2000000030?ooo`000000000003T0oooo0P00000g0?ooo`800000>@3oool2
000000030?ooo`000000000003D0oooo000d0?ooo`80000000<0oooo000000000000>@3oool20000
03L0oooo0P00000i0?ooo`80000000<0oooo000000000000=@3oool003D0oooo0`00000k0?ooo`80
0000=@3oool2000003/0oooo0`00000f0?ooo`00=@3oool3000003/0oooo0P00000e0?ooo`800000
>`3oool3000003H0oooo000f0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03D0oooo001c0?ooo`800000=@3oool2
000007@0oooo001b0?ooo`800000=`3oool2000007<0oooo001a0?ooo`0300000027c^`0000003L0
oooo00<0000008O>k0000000LP3oool00700oooo00@0000008O>k027c^`00000=`3oool010000000
Qlk/08O>k000001a0?ooo`00K`3oool01@000000Qlk/08O>k027c^`0000003L0oooo00D0000008O>
k027c^`0Qlk/0000001`0?ooo`00KP3oool01@000000Qlk/08O>k027c^`0000003T0oooo00D00000
08O>k027c^`0Qlk/0000001_0?ooo`00K@3oool00`000000Qlk/08O>k00208O>k0030000003oool0
oooo03L0oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`1/0?ooo`00K03oool00`00
0000Qlk/08O>k00308O>k0030000003oool0oooo03L0oooo00<0000008O>k027c^`00`27c^`00`00
0000oooo0?ooo`1[0?ooo`00JP3oool2000000D0Qlk/00<000000?ooo`3oool0>@3oool00`000000
Qlk/08O>k00308O>k0800000J`3oool006T0oooo00<0000008O>k027c^`01@27c^`00`000000oooo
0?ooo`0i0?ooo`0300000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool0J03oool006P0oooo00<0
000008O>k027c^`01P27c^`00`000000oooo0?ooo`0i0?ooo`0300000027c^`0Qlk/00H0Qlk/00<0
00000?ooo`3oool0I`3oool006L0oooo00<0000008O>k027c^`01P27c^`00`000000oooo0?ooo`0k
0?ooo`0300000027c^`0Qlk/00H0Qlk/00<000000?ooo`3oool0IP3oool006H0oooo00<0000008O>
k027c^`01`27c^`00`000000oooo0?ooo`0k0?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?oo
o`3oool0I@3oool006D0oooo00<0000008O>k027c^`02027c^`00`000000oooo0?ooo`0k0?ooo`03
00000027c^`0Qlk/00P0Qlk/00<000000?ooo`3oool0I03oool006@0oooo00<0000008O>k027c^`0
2@27c^`00`000000oooo0?ooo`0k0?ooo`0300000027c^`0Qlk/00T0Qlk/00<000000?ooo`3oool0
H`3oool006<0oooo00<0000008O>k027c^`02@27c^`00`000000oooo0?ooo`0m0?ooo`0300000027
c^`0Qlk/00T0Qlk/00<000000?ooo`3oool0HP3oool00680oooo00<0000008O>k027c^`02P27c^`0
0`000000oooo0?ooo`0m0?ooo`0300000027c^`0Qlk/00X0Qlk/00<000000?ooo`3oool0H@3oool0
0680oooo00<0000008O>k027c^`02P27c^`00`000000oooo0?ooo`0m0?ooo`0300000027c^`0Qlk/
00X0Qlk/00<000000?ooo`3oool0H@3oool00680oooo00<0000008O>k027c^`02@27c^`00`000000
oooo0?ooo`0o0?ooo`0300000027c^`0Qlk/00T0Qlk/00<000000?ooo`3oool0H@3oool00680oooo
00<0000008O>k027c^`02@27c^`00`000000oooo0?ooo`0o0?ooo`0300000027c^`0Qlk/00T0Qlk/
00<000000?ooo`3oool0H@3oool00680oooo00<0000008O>k027c^`02@27c^`00`000000oooo0?oo
o`0o0?ooo`0300000027c^`0Qlk/00T0Qlk/00<000000?ooo`3oool0H@3oool00680oooo00<00000
08O>k027c^`02027c^`00`000000oooo0?ooo`110?ooo`0300000027c^`0Qlk/00P0Qlk/00<00000
0?ooo`3oool0H@3oool00680oooo00<0000008O>k027c^`02027c^`00`000000oooo0?ooo`110?oo
o`0300000027c^`0Qlk/00P0Qlk/00<000000?ooo`3oool0H@3oool00680oooo00<0000008O>k027
c^`02027c^`00`000000oooo0?ooo`110?ooo`0300000027c^`0Qlk/00P0Qlk/00<000000?ooo`3o
ool0H@3oool00680oooo00<0000008O>k027c^`02027c^`00`000000oooo0?ooo`110?ooo`030000
0027c^`0Qlk/00P0Qlk/00<000000?ooo`3oool0H@3oool00640oooo00<0000008O>k027c^`02027
c^`00`000000oooo0?ooo`130?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?ooo`3oool0H@3o
ool00640oooo00<0000008O>k027c^`02027c^`00`000000oooo0?ooo`130?ooo`0300000027c^`0
Qlk/00P0Qlk/00<000000?ooo`3oool0H03oool00640oooo00<0000008O>k027c^`02027c^`00`00
0000oooo0?ooo`130?ooo`0300000027c^`0Qlk/00P0Qlk/00<000000?ooo`3oool0H03oool00640
oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`150?ooo`0300000027c^`0Qlk/00L0
Qlk/00<000000?ooo`3oool0H03oool00640oooo00<0000008O>k027c^`01`27c^`00`000000oooo
0?ooo`150?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?ooo`3oool0H03oool00640oooo00<0
000008O>k027c^`01`27c^`00`000000oooo0?ooo`150?ooo`0300000027c^`0Qlk/00L0Qlk/00<0
00000?ooo`3oool0H03oool00640oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`15
0?ooo`0300000027c^`0Qlk/00L0Qlk/00<000000?ooo`3oool0H03oool00640oooo00<0000008O>
k027c^`01P27c^`00`000000oooo0?ooo`170?ooo`0300000027c^`0Qlk/00H0Qlk/00<000000?oo
o`3oool0H03oool00640oooo00<0000008O>k027c^`01P27c^`00`000000oooo0?ooo`170?ooo`03
00000027c^`0Qlk/00H0Qlk/00<000000?ooo`3oool0H03oool00640oooo00<0000008O>k027c^`0
1P27c^`00`000000oooo0?ooo`170?ooo`0300000027c^`0Qlk/00H0Qlk/00<000000?ooo`3oool0
H03oool00640oooo00<0000008O>k027c^`01@27c^`00`000000oooo0?ooo`190?ooo`0300000027
c^`0Qlk/00D0Qlk/00<000000?ooo`3oool0H03oool00640oooo00<0000008O>k027c^`01@27c^`0
0`000000oooo0?ooo`190?ooo`0300000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool0H03oool0
0640oooo00<0000008O>k027c^`01@27c^`00`000000oooo0?ooo`190?ooo`0300000027c^`0Qlk/
00D0Qlk/00<000000?ooo`3oool0H03oool00640oooo00<0000008O>k027c^`01027c^`00`000000
oooo0?ooo`1;0?ooo`0300000027c^`0Qlk/00@0Qlk/00<000000?ooo`3oool0H03oool00640oooo
00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`1;0?ooo`0300000027c^`0Qlk/00@0Qlk/
00<000000?ooo`3oool0H03oool00640oooo00<0000008O>k027c^`01027c^`00`000000oooo0?oo
o`1;0?ooo`0300000027c^`0Qlk/00@0Qlk/00<000000?ooo`3oool0H03oool00640oooo00<00000
08O>k027c^`01027c^`00`000000oooo0?ooo`1;0?ooo`0300000027c^`0Qlk/00@0Qlk/00<00000
0?ooo`3oool0H03oool00640oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?ooo`1=0?oo
o`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool0H03oool00600oooo00<0000008O>k027
c^`01027c^`00`000000oooo0?ooo`1=0?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3o
ool0H03oool00600oooo00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`1=0?ooo`030000
0027c^`0Qlk/00@0Qlk/00<000000?ooo`3oool0G`3oool00600oooo00<0000008O>k027c^`00`27
c^`00`000000oooo0?ooo`1?0?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool0G`3o
ool00600oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?ooo`1?0?ooo`0300000027c^`0
Qlk/00<0Qlk/00<000000?ooo`3oool0G`3oool00600oooo00<0000008O>k027c^`00`27c^`00`00
0000oooo0?ooo`1?0?ooo`0300000027c^`0Qlk/00<0Qlk/00<000000?ooo`3oool0G`3oool00600
oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?ooo`1?0?ooo`0300000027c^`0Qlk/00<0
Qlk/00<000000?ooo`3oool0G`3oool00600oooo00<0000008O>k027c^`00P27c^`00`000000oooo
0?ooo`1A0?ooo`0300000027c^`0Qlk/0080Qlk/00<000000?ooo`3oool0G`3oool00600oooo00<0
000008O>k027c^`00P27c^`00`000000oooo0?ooo`1A0?ooo`0300000027c^`0Qlk/0080Qlk/00<0
00000?ooo`3oool0G`3oool00600oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`1A
0?ooo`0300000027c^`0Qlk/0080Qlk/00<000000?ooo`3oool0G`3oool00600oooo00D0000008O>
k027c^`0Qlk/0000001E0?ooo`0500000027c^`0Qlk/08O>k0000000H@3oool00600oooo00D00000
08O>k027c^`0Qlk/0000001E0?ooo`0500000027c^`0Qlk/08O>k0000000H@3oool00600oooo00D0
000008O>k027c^`0Qlk/0000001E0?ooo`0500000027c^`0Qlk/08O>k0000000H@3oool00600oooo
00@0000008O>k027c^`00000E`3oool010000000Qlk/08O>k000001Q0?ooo`00H03oool010000000
Qlk/08O>k000001G0?ooo`0400000027c^`0Qlk/00000640oooo001P0?ooo`0400000027c^`0Qlk/
000005L0oooo00@0000008O>k027c^`00000H@3oool00600oooo00@0000008O>k027c^`00000E`3o
ool010000000Qlk/08O>k000001Q0?ooo`00H03oool00`000000Qlk/0000001I0?ooo`0300000027
c^`000000640oooo001P0?ooo`0300000027c^`0000005T0oooo00<0000008O>k0000000H@3oool0
05l0oooo00@0000008O>k027c^`00000F@3oool00`000000Qlk/0000001Q0?ooo`00G`3oool00`00
0000Qlk/0000001K0?ooo`0300000027c^`000000600oooo001O0?ooo`0300000027c^`0000005/0
oooo00<0000008O>k0000000H03oool005l0oooo00<0000008O>k0000000F`3oool00`000000Qlk/
0000001P0?ooo`00G`3oool2000005d0oooo0P00001P0?ooo`00G`3oool2000005d0oooo0P00001P
0?ooo`00G`3oool2000005d0oooo0P00001P0?ooo`00G`3oool2000005d0oooo0P00001P0?ooo`00
G`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05h0oooo001O0?ooob<000006`3o
oolS00000600oooo001P0?ooo`0300000027c^`0Qlk/01d0Qlk/0P00000K0?ooo`8000007`27c^`0
0`000000oooo0?ooo`1O0?ooo`00H03oool00`000000Qlk/08O>k00M08O>k08000006`3oool20000
01l0Qlk/00<000000?ooo`3oool0G`3oool00640oooo00<0000008O>k027c^`06`27c^`010000000
oooo00000000000I0?ooo`80000000<0oooo00000027c^`07027c^`00`000000oooo0?ooo`1P0?oo
o`00H@3oool00`000000Qlk/08O>k00K08O>k0040000003oool00000000001T0oooo0P0000000`3o
ool0000008O>k00L08O>k0030000003oool0oooo0600oooo001R0?ooo`0300000027c^`0Qlk/01T0
Qlk/00<000000?ooo`3oool00P00000I0?ooo`8000000P3oool00`000000Qlk/08O>k00I08O>k003
0000003oool0oooo0640oooo001S0?ooo`0300000027c^`0Qlk/01L0Qlk/00@000000?ooo`3oool0
oooo0P00000I0?ooo`8000000`3oool00`000000Qlk/08O>k00G08O>k0030000003oool0oooo0680
oooo001S0?ooo`0300000027c^`0Qlk/01L0Qlk/00@000000?ooo`3oool0oooo0P00000I0?ooo`80
00000`3oool00`000000Qlk/08O>k00G08O>k0030000003oool0oooo0680oooo001T0?ooo`030000
0027c^`0Qlk/01D0Qlk/00<000000?ooo`3oool00P3oool2000001T0oooo0P0000040?ooo`030000
0027c^`0Qlk/01D0Qlk/00<000000?ooo`3oool0H`3oool006@0oooo00<0000008O>k027c^`05@27
c^`01@000000oooo0?ooo`3oool000000080Qlk/00<000000?ooo`3oool05@3oool00`000000Qlk/
000000040?ooo`0300000027c^`0Qlk/01D0Qlk/00<000000?ooo`3oool0H`3oool006D0oooo00<0
000008O>k027c^`04`27c^`00`000000oooo0?ooo`020?ooo`0400000027c^`0Qlk/000001L0oooo
00@0000008O>k027c^`00000103oool00`000000Qlk/08O>k00C08O>k0030000003oool0oooo06@0
oooo001U0?ooo`0300000027c^`0Qlk/01<0Qlk/00<000000?ooo`3oool00P3oool010000000Qlk/
08O>k000000G0?ooo`0400000027c^`0Qlk/000000@0oooo00<0000008O>k027c^`04`27c^`00`00
0000oooo0?ooo`1T0?ooo`00IP3oool00`000000Qlk/08O>k00A08O>k0030000003oool0oooo00<0
oooo00@0000008O>k027c^`000005`3oool010000000Qlk/08O>k00000050?ooo`0300000027c^`0
Qlk/0140Qlk/00<000000?ooo`3oool0I@3oool006L0oooo00<0000008O>k027c^`03`27c^`00`00
0000oooo0?ooo`040?ooo`0400000027c^`0Qlk/000001L0oooo00@0000008O>k027c^`000001P3o
ool00`000000Qlk/08O>k00?08O>k0030000003oool0oooo06H0oooo001W0?ooo`0300000027c^`0
Qlk/00l0Qlk/00<000000?ooo`3oool0103oool010000000Qlk/08O>k000000G0?ooo`0400000027
c^`0Qlk/000000H0oooo00<0000008O>k027c^`03`27c^`00`000000oooo0?ooo`1V0?ooo`00J03o
ool00`000000Qlk/08O>k00=08O>k0030000003oool0oooo00D0oooo00D0000008O>k027c^`0Qlk/
0000000E0?ooo`0500000027c^`0Qlk/08O>k00000001`3oool00`000000Qlk/08O>k00=08O>k003
0000003oool0oooo06L0oooo001X0?ooo`0300000027c^`0Qlk/00d0Qlk/00<000000?ooo`3oool0
1@3oool01@000000Qlk/08O>k027c^`0000001D0oooo00D0000008O>k027c^`0Qlk/000000070?oo
o`0300000027c^`0Qlk/00d0Qlk/00<000000?ooo`3oool0I`3oool006T0oooo00<0000008O>k027
c^`02`27c^`00`000000oooo0?ooo`060?ooo`0500000027c^`0Qlk/08O>k00000005@3oool01@00
0000Qlk/08O>k027c^`0000000P0oooo00<0000008O>k027c^`02`27c^`00`000000oooo0?ooo`1X
0?ooo`00JP3oool00`000000Qlk/08O>k00908O>k0030000003oool0oooo00L0oooo00D0000008O>
k027c^`0Qlk/0000000E0?ooo`0500000027c^`0Qlk/08O>k00000002@3oool00`000000Qlk/08O>
k00908O>k0030000003oool0oooo06T0oooo001Z0?ooo`0300000027c^`0Qlk/00T0Qlk/00<00000
0?ooo`3oool01`3oool01@000000Qlk/08O>k027c^`0000001D0oooo00D0000008O>k027c^`0Qlk/
000000090?ooo`0300000027c^`0Qlk/00T0Qlk/00<000000?ooo`3oool0J@3oool006/0oooo00<0
000008O>k027c^`01`27c^`00`000000oooo0?ooo`080?ooo`0500000027c^`0Qlk/08O>k0000000
5@3oool01@000000Qlk/08O>k027c^`0000000X0oooo00<0000008O>k027c^`01`27c^`00`000000
oooo0?ooo`1Z0?ooo`00J`3oool00`000000Qlk/08O>k00708O>k0030000003oool0oooo00P0oooo
00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`0A0?ooo`0300000027c^`0Qlk/0080Qlk/
00<000000?ooo`3oool0203oool00`000000Qlk/08O>k00708O>k0030000003oool0oooo06X0oooo
001/0?ooo`0300000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool02@3oool00`000000Qlk/08O>
k00208O>k0030000003oool0oooo0140oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?oo
o`090?ooo`0300000027c^`0Qlk/00D0Qlk/00<000000?ooo`3oool0J`3oool006`0oooo00<00000
08O>k027c^`01@27c^`00`000000oooo0?ooo`090?ooo`0300000027c^`0Qlk/0080Qlk/00<00000
0?ooo`3oool04@3oool00`000000Qlk/08O>k00208O>k0030000003oool0oooo00T0oooo00<00000
08O>k027c^`01@27c^`00`000000oooo0?ooo`1[0?ooo`00K@3oool00`000000Qlk/08O>k00308O>
k0030000003oool0oooo00X0oooo00<0000008O>k027c^`00P27c^`00`000000oooo0?ooo`0A0?oo
o`0300000027c^`0Qlk/0080Qlk/00<000000?ooo`3oool02P3oool00`000000Qlk/08O>k00308O>
k0030000003oool0oooo06`0oooo001^0?ooo`0500000027c^`0Qlk/08O>k00000003@3oool00`00
0000Qlk/08O>k00208O>k0030000003oool0oooo0140oooo00<0000008O>k027c^`00P27c^`00`00
0000oooo0?ooo`0;0?ooo`0500000027c^`0Qlk/08O>k0000000K`3oool006h0oooo00D0000008O>
k027c^`0Qlk/0000000=0?ooo`0300000027c^`0Qlk/0080Qlk/00<000000?ooo`3oool04@3oool0
0`000000Qlk/08O>k00208O>k0030000003oool0oooo00/0oooo00D0000008O>k027c^`0Qlk/0000
001_0?ooo`00K`3oool00`000000Qlk/0000000=0?ooo`0300000027c^`0Qlk/00@0Qlk/00<00000
0?ooo`3oool03`3oool00`000000Qlk/08O>k00308O>k0030000003oool0oooo00`0oooo00<00000
08O>k0000000L03oool006l0oooo00<0000008O>k00000003@3oool00`000000Qlk/08O>k00408O>
k0030000003oool0oooo00l0oooo00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`0;0?oo
o`0300000027c^`000000700oooo001`0?ooo`030000003oool0oooo00`0oooo00<0000008O>k027
c^`01027c^`00`000000oooo0?ooo`0?0?ooo`0300000027c^`0Qlk/00@0Qlk/00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1_0?ooo`00O`3oool00`000000Qlk/08O>k00408O>k0030000
003oool0oooo00l0oooo00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`1n0?ooo`00O`3o
ool00`000000Qlk/08O>k00408O>k0030000003oool0oooo00l0oooo00<0000008O>k027c^`01027
c^`00`000000oooo0?ooo`1n0?ooo`00O`3oool00`000000Qlk/08O>k00408O>k0030000003oool0
oooo00l0oooo00<0000008O>k027c^`01027c^`00`000000oooo0?ooo`1n0?ooo`00O`3oool00`00
0000Qlk/08O>k00508O>k0030000003oool0oooo00d0oooo00<0000008O>k027c^`01@27c^`00`00
0000oooo0?ooo`1n0?ooo`00O`3oool00`000000Qlk/08O>k00508O>k0030000003oool0oooo00d0
oooo00<0000008O>k027c^`01@27c^`00`000000oooo0?ooo`1n0?ooo`00O`3oool00`000000Qlk/
08O>k00508O>k0030000003oool0oooo00d0oooo00<0000008O>k027c^`01@27c^`00`000000oooo
0?ooo`1n0?ooo`00O`3oool00`000000Qlk/08O>k00508O>k0030000003oool0oooo00d0oooo00<0
000008O>k027c^`01@27c^`00`000000oooo0?ooo`1n0?ooo`00O`3oool00`000000Qlk/08O>k005
08O>k0030000003oool0oooo00d0oooo00<0000008O>k027c^`01@27c^`00`000000oooo0?ooo`1n
0?ooo`00O`3oool00`000000Qlk/08O>k00508O>k0030000003oool0oooo00d0oooo00<0000008O>
k027c^`01@27c^`00`000000oooo0?ooo`1n0?ooo`00O`3oool00`000000Qlk/08O>k00608O>k003
0000003oool0oooo00/0oooo00<0000008O>k027c^`01P27c^`00`000000oooo0?ooo`1n0?ooo`00
O`3oool00`000000Qlk/08O>k00608O>k0030000003oool0oooo00/0oooo00<0000008O>k027c^`0
1P27c^`00`000000oooo0?ooo`1n0?ooo`00O`3oool00`000000Qlk/08O>k00608O>k0030000003o
ool0oooo00/0oooo00<0000008O>k027c^`01P27c^`00`000000oooo0?ooo`1n0?ooo`00O`3oool0
0`000000Qlk/08O>k00608O>k0030000003oool0oooo00/0oooo00<0000008O>k027c^`01P27c^`0
0`000000oooo0?ooo`1n0?ooo`00O`3oool00`000000Qlk/08O>k00608O>k0030000003oool0oooo
00/0oooo00<0000008O>k027c^`01P27c^`00`000000oooo0?ooo`1n0?ooo`00O`3oool00`000000
Qlk/08O>k00608O>k0030000003oool0oooo00/0oooo00<0000008O>k027c^`01P27c^`00`000000
oooo0?ooo`1n0?ooo`00OP3oool00`000000Qlk/08O>k00808O>k0030000003oool0oooo00T0oooo
00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`1n0?ooo`00OP3oool00`000000Qlk/08O>
k00808O>k0030000003oool0oooo00T0oooo00<0000008O>k027c^`02027c^`00`000000oooo0?oo
o`1m0?ooo`00OP3oool00`000000Qlk/08O>k00808O>k0030000003oool0oooo00T0oooo00<00000
08O>k027c^`02027c^`00`000000oooo0?ooo`1m0?ooo`00OP3oool00`000000Qlk/08O>k00808O>
k0030000003oool0oooo00T0oooo00<0000008O>k027c^`02027c^`00`000000oooo0?ooo`1m0?oo
o`00OP3oool00`000000Qlk/08O>k00808O>k0030000003oool0oooo00T0oooo00<0000008O>k027
c^`02027c^`00`000000oooo0?ooo`1m0?ooo`00OP3oool00`000000Qlk/08O>k00808O>k0030000
003oool0oooo00T0oooo00<0000008O>k027c^`02027c^`00`000000oooo0?ooo`1m0?ooo`00OP3o
ool00`000000Qlk/08O>k00908O>k0030000003oool0oooo00L0oooo00<0000008O>k027c^`02@27
c^`00`000000oooo0?ooo`1m0?ooo`00OP3oool00`000000Qlk/08O>k00908O>k0030000003oool0
oooo00L0oooo00<0000008O>k027c^`02@27c^`00`000000oooo0?ooo`1m0?ooo`00OP3oool00`00
0000Qlk/08O>k00908O>k0030000003oool0oooo00L0oooo00<0000008O>k027c^`02@27c^`00`00
0000oooo0?ooo`1m0?ooo`00OP3oool00`000000Qlk/08O>k00908O>k0030000003oool0oooo00L0
oooo00<0000008O>k027c^`02@27c^`00`000000oooo0?ooo`1m0?ooo`00O`3oool00`000000Qlk/
08O>k00808O>k0030000003oool0oooo00L0oooo00<0000008O>k027c^`02027c^`00`000000oooo
0?ooo`1n0?ooo`00O`3oool00`000000Qlk/08O>k00808O>k0030000003oool0oooo00L0oooo00<0
000008O>k027c^`02027c^`00`000000oooo0?ooo`1n0?ooo`00P03oool00`000000Qlk/08O>k008
08O>k0030000003oool0oooo00D0oooo00<0000008O>k027c^`02027c^`00`000000oooo0?ooo`1o
0?ooo`00P03oool00`000000Qlk/08O>k00808O>k0030000003oool0oooo00D0oooo00<0000008O>
k027c^`02027c^`00`000000oooo0?ooo`1o0?ooo`00P@3oool00`000000Qlk/08O>k00708O>k003
0000003oool0oooo00D0oooo00<0000008O>k027c^`01`27c^`00`000000oooo0?ooo`200?ooo`00
PP3oool00`000000Qlk/08O>k00608O>k0030000003oool0oooo00D0oooo00<0000008O>k027c^`0
1P27c^`00`000000oooo0?ooo`210?ooo`00PP3oool00`000000Qlk/08O>k00608O>k0030000003o
ool0oooo00D0oooo00<0000008O>k027c^`01P27c^`00`000000oooo0?ooo`210?ooo`00P`3oool0
0`000000Qlk/08O>k00508O>k0030000003oool0oooo00D0oooo00<0000008O>k027c^`01@27c^`0
0`000000oooo0?ooo`220?ooo`00P`3oool00`000000Qlk/08O>k00608O>k0030000003oool0oooo
00<0oooo00<0000008O>k027c^`01P27c^`00`000000oooo0?ooo`220?ooo`00Q03oool00`000000
Qlk/08O>k00508O>k0030000003oool0oooo00<0oooo00<0000008O>k027c^`01@27c^`00`000000
oooo0?ooo`230?ooo`00Q03oool00`000000Qlk/08O>k00508O>k0030000003oool0oooo00<0oooo
00<0000008O>k027c^`01@27c^`00`000000oooo0?ooo`230?ooo`00Q@3oool00`000000Qlk/08O>
k00408O>k0030000003oool0oooo00<0oooo00<0000008O>k027c^`01027c^`00`000000oooo0?oo
o`240?ooo`00QP3oool00`000000Qlk/08O>k00308O>k0030000003oool0oooo00<0oooo00<00000
08O>k027c^`00`27c^`00`000000oooo0?ooo`250?ooo`00QP3oool00`000000Qlk/08O>k00308O>
k0030000003oool0oooo00<0oooo00<0000008O>k027c^`00`27c^`00`000000oooo0?ooo`250?oo
o`00Q`3oool00`000000Qlk/08O>k00308O>k0050000003oool0oooo0?ooo`0000001@27c^`00`00
0000oooo0?ooo`260?ooo`00Q`3oool00`000000Qlk/08O>k00308O>k0050000003oool0oooo0?oo
o`0000001@27c^`00`000000oooo0?ooo`260?ooo`00R03oool00`000000Qlk/08O>k00208O>k005
0000003oool0oooo0?ooo`0000001027c^`00`000000oooo0?ooo`270?ooo`00R@3oool01@000000
Qlk/08O>k027c^`0000000<0oooo00D0000008O>k027c^`0Qlk/0000002:0?ooo`00R@3oool01@00
0000Qlk/08O>k027c^`0000000<0oooo00D0000008O>k027c^`0Qlk/0000002:0?ooo`00RP3oool0
10000000Qlk/08O>k00000030?ooo`0400000027c^`0Qlk/000008/0oooo002:0?ooo`0700000027
c^`0Qlk/08O>k0000000oooo0000000308O>k0030000003oool0oooo08T0oooo002;0?ooo`060000
0027c^`0Qlk/0000003oool000000P27c^`00`000000oooo0?ooo`2:0?ooo`00R`3oool01P000000
Qlk/08O>k0000000oooo00000080Qlk/00<000000?ooo`3oool0RP3oool008`0oooo00L0000008O>
k0000000oooo00000027c^`0000008d0oooo002=0?ooo`80000000<0oooo000000000000SP3oool0
08d0oooo0P0000000`3oool000000000002>0?ooo`00SP3oool3000008l0oooo002>0?ooo`<00000
S`3oool008l0oooo00<000000?ooo`3oool0SP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {248.375, 0}} -> {-0.0507529, -0.0433105, \
0.00732233, 0.00732233}}]
}, Open  ]],

Cell["ANIMATION", "Text",
  FontSize->18,
  FontColor->RGBColor[0.0299992, 0.179995, 0.329992],
  Background->RGBColor[0.737301, 0.5608, 0.5608]],

Cell[BoxData[
    \(\(Map[\(Show[Graphics[osgood[{0, 0}, {2, 0}, {1, \@3}, #, 6]]];\) &, 
        Join[Range[\(-5\), 5, 0.1], 
          Range[5, \(-5\), \(-0.1\)]]];\)\)], "Input",
  CellLabel->"In[69]:="],

Cell[TextData[{
  "Another example of an L system is the Dragon Curve , wherein \[Theta] = ",
  Cell[BoxData[
      \(TraditionalForm\`90\^0\)]],
  " , the axiom is FX and the productions are:"
}], "Text"],

Cell["\<\
X \[Rule] X+YF+
Y\[Rule] -FX-Y\
\>", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
In this case the symbols X and Y are ignored when presented to the turtle. \
Their purpose is to provide the mechanism to \[OpenCurlyDoubleQuote]grow\
\[CloseCurlyDoubleQuote] the string to be fed to the turtle.  \
\>", "Text"],

Cell[BoxData[
    \(dragon[s_String] := 
      StringJoin[
        Characters[
            s]\  /. \ {"\<X\>" \[Rule] "\<X+YF+\>", "\<Y\>" \[Rule] \
"\<-FX-Y\>"}]\)], "Input",
  CellLabel->"In[79]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(d = 
        logo[Nest[dragon, "\<FX\>", 10], 
          80.0  \[Degree]];\)\), "\[IndentingNewLine]", 
    \(\(Show[Graphics[Line[d]]];\)\)}], "Input",
  CellLabel->"In[80]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.16931 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.155383 0.0140388 0.360534 0.0140388 [
[ 0 0 0 0 ]
[ 1 1.16931 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.15538 .36053 m
.16942 .36053 L
.17186 .37436 L
.15867 .37916 L
.16111 .39299 L
.14791 .39779 L
.14089 .38563 L
.1277 .39043 L
.13014 .40426 L
.11695 .40906 L
.10993 .3969 L
.12068 .38788 L
.11366 .37572 L
.10047 .38052 L
.09345 .36836 L
.08026 .37316 L
.0827 .38699 L
.0695 .39179 L
.06249 .37963 L
.07324 .37061 L
.06622 .35845 L
.07697 .34943 L
.08773 .35845 L
.09848 .34943 L
.09146 .33727 L
.07827 .34207 L
.07125 .32991 L
.08201 .32089 L
.07499 .30873 L
.06179 .31353 L
.05478 .30137 L
.04158 .30618 L
.04402 .32 L
.03083 .3248 L
.02381 .31265 L
.03456 .30362 L
.02754 .29146 L
.0383 .28244 L
.04905 .29146 L
.05981 .28244 L
.05279 .27028 L
.06354 .26126 L
.0743 .27028 L
.06728 .28244 L
.07803 .29146 L
.08879 .28244 L
.09954 .29146 L
.11029 .28244 L
.10328 .27028 L
.09008 .27508 L
Mistroke
.08306 .26293 L
.09382 .2539 L
.0868 .24174 L
.09755 .23272 L
.10831 .24174 L
.11906 .23272 L
.11204 .22056 L
.09885 .22536 L
.09183 .2132 L
.10259 .20418 L
.09557 .19202 L
.08237 .19682 L
.07535 .18467 L
.06216 .18947 L
.0646 .20329 L
.05141 .20809 L
.04439 .19594 L
.05514 .18691 L
.04812 .17476 L
.05888 .16573 L
.06963 .17476 L
.08039 .16573 L
.07337 .15357 L
.08412 .14455 L
.09488 .15357 L
.08786 .16573 L
.09861 .17476 L
.10937 .16573 L
.12012 .17476 L
.13087 .16573 L
.12385 .15357 L
.13461 .14455 L
.14536 .15357 L
.13834 .16573 L
.1491 .17476 L
.14208 .18691 L
.12889 .18211 L
.12187 .19427 L
.13262 .20329 L
.14338 .19427 L
.15413 .20329 L
.14711 .21545 L
.15787 .22448 L
.16862 .21545 L
.17937 .22448 L
.19013 .21545 L
.18311 .20329 L
.16992 .20809 L
.1629 .19594 L
.17365 .18691 L
Mistroke
.16663 .17476 L
.17739 .16573 L
.18814 .17476 L
.1989 .16573 L
.19188 .15357 L
.20263 .14455 L
.21338 .15357 L
.20637 .16573 L
.21712 .17476 L
.22787 .16573 L
.23863 .17476 L
.24938 .16573 L
.24236 .15357 L
.22917 .15837 L
.22215 .14622 L
.23291 .13719 L
.22589 .12503 L
.23664 .11601 L
.2474 .12503 L
.25815 .11601 L
.25113 .10385 L
.23794 .10865 L
.23092 .0965 L
.24167 .08747 L
.23465 .07531 L
.22146 .08012 L
.21444 .06796 L
.20125 .07276 L
.20369 .08658 L
.1905 .09139 L
.18348 .07923 L
.19423 .0702 L
.18721 .05805 L
.19797 .04902 L
.20872 .05805 L
.21947 .04902 L
.21245 .03686 L
.22321 .02784 L
.23396 .03686 L
.22694 .04902 L
.2377 .05805 L
.24845 .04902 L
.25921 .05805 L
.26996 .04902 L
.26294 .03686 L
.2737 .02784 L
.28445 .03686 L
.27743 .04902 L
.28819 .05805 L
.28117 .0702 L
Mistroke
.26797 .0654 L
.26095 .07756 L
.27171 .08658 L
.28246 .07756 L
.29322 .08658 L
.2862 .09874 L
.29695 .10777 L
.30771 .09874 L
.31846 .10777 L
.32922 .09874 L
.3222 .08658 L
.33295 .07756 L
.34371 .08658 L
.33669 .09874 L
.34744 .10777 L
.34042 .11992 L
.32723 .11512 L
.32021 .12728 L
.33096 .13631 L
.32394 .14846 L
.31075 .14366 L
.31319 .12984 L
.3 .12503 L
.29298 .13719 L
.27979 .13239 L
.27277 .14455 L
.28352 .15357 L
.29428 .14455 L
.30503 .15357 L
.29801 .16573 L
.30876 .17476 L
.30175 .18691 L
.28855 .18211 L
.28153 .19427 L
.29229 .20329 L
.30304 .19427 L
.3138 .20329 L
.30678 .21545 L
.31753 .22448 L
.32829 .21545 L
.33904 .22448 L
.34979 .21545 L
.34278 .20329 L
.32958 .20809 L
.32256 .19594 L
.33332 .18691 L
.3263 .17476 L
.33705 .16573 L
.34781 .17476 L
.35856 .16573 L
Mistroke
.35154 .15357 L
.3623 .14455 L
.37305 .15357 L
.36603 .16573 L
.37679 .17476 L
.38754 .16573 L
.39829 .17476 L
.40905 .16573 L
.40203 .15357 L
.41278 .14455 L
.42354 .15357 L
.41652 .16573 L
.42727 .17476 L
.42025 .18691 L
.40706 .18211 L
.40004 .19427 L
.4108 .20329 L
.42155 .19427 L
.43231 .20329 L
.42529 .21545 L
.43604 .22448 L
.44679 .21545 L
.45755 .22448 L
.4683 .21545 L
.46128 .20329 L
.44809 .20809 L
.44107 .19594 L
.45183 .18691 L
.44481 .17476 L
.45556 .16573 L
.46632 .17476 L
.47707 .16573 L
.47005 .15357 L
.48081 .14455 L
.49156 .15357 L
.48454 .16573 L
.49529 .17476 L
.50605 .16573 L
.5168 .17476 L
.52756 .16573 L
.52054 .15357 L
.50735 .15837 L
.50033 .14622 L
.51108 .13719 L
.50406 .12503 L
.51482 .11601 L
.52557 .12503 L
.53633 .11601 L
.52931 .10385 L
.51611 .10865 L
Mistroke
.50909 .0965 L
.51985 .08747 L
.51283 .07531 L
.49964 .08012 L
.49262 .06796 L
.47943 .07276 L
.48186 .08658 L
.46867 .09139 L
.46165 .07923 L
.47241 .0702 L
.46539 .05805 L
.47614 .04902 L
.4869 .05805 L
.49765 .04902 L
.49063 .03686 L
.50138 .02784 L
.51214 .03686 L
.50512 .04902 L
.51587 .05805 L
.52663 .04902 L
.53738 .05805 L
.54814 .04902 L
.54112 .03686 L
.55187 .02784 L
.56263 .03686 L
.55561 .04902 L
.56636 .05805 L
.55934 .0702 L
.54615 .0654 L
.53913 .07756 L
.54988 .08658 L
.56064 .07756 L
.57139 .08658 L
.56437 .09874 L
.57513 .10777 L
.58588 .09874 L
.59664 .10777 L
.60739 .09874 L
.60037 .08658 L
.61113 .07756 L
.62188 .08658 L
.61486 .09874 L
.62562 .10777 L
.6186 .11992 L
.6054 .11512 L
.59838 .12728 L
.60914 .13631 L
.60212 .14846 L
.58893 .14366 L
.59137 .12984 L
Mistroke
.57817 .12503 L
.57115 .13719 L
.55796 .13239 L
.55094 .14455 L
.5617 .15357 L
.57245 .14455 L
.58321 .15357 L
.57619 .16573 L
.58694 .17476 L
.57992 .18691 L
.56673 .18211 L
.55971 .19427 L
.57046 .20329 L
.58122 .19427 L
.59197 .20329 L
.58495 .21545 L
.59571 .22448 L
.60646 .21545 L
.61722 .22448 L
.62797 .21545 L
.62095 .20329 L
.63171 .19427 L
.64246 .20329 L
.63544 .21545 L
.64619 .22448 L
.63918 .23663 L
.62598 .23183 L
.61896 .24399 L
.62972 .25301 L
.6227 .26517 L
.60951 .26037 L
.61194 .24654 L
.59875 .24174 L
.59173 .2539 L
.57854 .2491 L
.57152 .26126 L
.58228 .27028 L
.57526 .28244 L
.56206 .27764 L
.5645 .26381 L
.55131 .25901 L
.55375 .24519 L
.56779 .24519 L
.57022 .23136 L
.55703 .22656 L
.55001 .23872 L
.53682 .23391 L
.53926 .22009 L
.52607 .21529 L
.51905 .22745 L
Mistroke
.50585 .22264 L
.49883 .2348 L
.50959 .24383 L
.52034 .2348 L
.5311 .24383 L
.52408 .25598 L
.53483 .26501 L
.52781 .27717 L
.51462 .27236 L
.5076 .28452 L
.51836 .29355 L
.51134 .3057 L
.49814 .3009 L
.50058 .28708 L
.48739 .28228 L
.48037 .29443 L
.46718 .28963 L
.46016 .30179 L
.47091 .31081 L
.48167 .30179 L
.49242 .31081 L
.4854 .32297 L
.49616 .332 L
.48914 .34415 L
.47595 .33935 L
.46893 .35151 L
.47968 .36053 L
.49043 .35151 L
.50119 .36053 L
.49417 .37269 L
.50492 .38172 L
.51568 .37269 L
.52643 .38172 L
.53719 .37269 L
.53017 .36053 L
.51698 .36534 L
.50996 .35318 L
.52071 .34415 L
.51369 .332 L
.52445 .32297 L
.5352 .332 L
.54595 .32297 L
.53893 .31081 L
.54969 .30179 L
.56044 .31081 L
.55342 .32297 L
.56418 .332 L
.57493 .32297 L
.58569 .332 L
.59644 .32297 L
Mistroke
.58942 .31081 L
.60018 .30179 L
.61093 .31081 L
.60391 .32297 L
.61467 .332 L
.60765 .34415 L
.59445 .33935 L
.58743 .35151 L
.59819 .36053 L
.60894 .35151 L
.6197 .36053 L
.61268 .37269 L
.62343 .38172 L
.63419 .37269 L
.64494 .38172 L
.6557 .37269 L
.64868 .36053 L
.65943 .35151 L
.67019 .36053 L
.66317 .37269 L
.67392 .38172 L
.6669 .39387 L
.65371 .38907 L
.64669 .40123 L
.65744 .41025 L
.65042 .42241 L
.63723 .41761 L
.63967 .40379 L
.62648 .39898 L
.61946 .41114 L
.60627 .40634 L
.59925 .4185 L
.61 .42752 L
.62076 .4185 L
.63151 .42752 L
.62449 .43968 L
.63524 .4487 L
.62823 .46086 L
.61503 .45606 L
.60801 .46822 L
.61877 .47724 L
.62952 .46822 L
.64028 .47724 L
.63326 .4894 L
.64401 .49842 L
.65477 .4894 L
.66552 .49842 L
.67627 .4894 L
.66926 .47724 L
.65606 .48204 L
Mistroke
.64904 .46989 L
.6598 .46086 L
.65278 .4487 L
.66353 .43968 L
.67429 .4487 L
.68504 .43968 L
.67802 .42752 L
.68878 .4185 L
.69953 .42752 L
.69251 .43968 L
.70327 .4487 L
.71402 .43968 L
.72477 .4487 L
.73553 .43968 L
.72851 .42752 L
.73926 .4185 L
.75002 .42752 L
.743 .43968 L
.75375 .4487 L
.74673 .46086 L
.73354 .45606 L
.72652 .46822 L
.73728 .47724 L
.74803 .46822 L
.75879 .47724 L
.75177 .4894 L
.76252 .49842 L
.77327 .4894 L
.78403 .49842 L
.79478 .4894 L
.78776 .47724 L
.77457 .48204 L
.76755 .46989 L
.77831 .46086 L
.77129 .4487 L
.78204 .43968 L
.7928 .4487 L
.80355 .43968 L
.79653 .42752 L
.80729 .4185 L
.81804 .42752 L
.81102 .43968 L
.82177 .4487 L
.83253 .43968 L
.84328 .4487 L
.85404 .43968 L
.84702 .42752 L
.83383 .43232 L
.82681 .42017 L
.83756 .41114 L
Mistroke
.83054 .39898 L
.8413 .38996 L
.85205 .39898 L
.86281 .38996 L
.85579 .3778 L
.84259 .3826 L
.83557 .37045 L
.84633 .36142 L
.83931 .34926 L
.82612 .35407 L
.8191 .34191 L
.80591 .34671 L
.80834 .36053 L
.79515 .36534 L
.78813 .35318 L
.79889 .34415 L
.79187 .332 L
.80262 .32297 L
.81338 .332 L
.82413 .32297 L
.81711 .31081 L
.82786 .30179 L
.83862 .31081 L
.8316 .32297 L
.84235 .332 L
.85311 .32297 L
.86386 .332 L
.87462 .32297 L
.8676 .31081 L
.87835 .30179 L
.88911 .31081 L
.88209 .32297 L
.89284 .332 L
.88582 .34415 L
.87263 .33935 L
.86561 .35151 L
.87636 .36053 L
.88712 .35151 L
.89787 .36053 L
.89085 .37269 L
.90161 .38172 L
.91236 .37269 L
.92312 .38172 L
.93387 .37269 L
.92685 .36053 L
.93761 .35151 L
.94836 .36053 L
.94134 .37269 L
.9521 .38172 L
.94508 .39387 L
Mistroke
.93188 .38907 L
.92486 .40123 L
.93562 .41025 L
.9286 .42241 L
.91541 .41761 L
.91785 .40379 L
.90465 .39898 L
.89763 .41114 L
.88444 .40634 L
.87742 .4185 L
.88818 .42752 L
.89893 .4185 L
.90969 .42752 L
.90267 .43968 L
.91342 .4487 L
.9064 .46086 L
.89321 .45606 L
.88619 .46822 L
.89694 .47724 L
.9077 .46822 L
.91845 .47724 L
.91143 .4894 L
.92219 .49842 L
.93294 .4894 L
.9437 .49842 L
.95445 .4894 L
.94743 .47724 L
.95819 .46822 L
.96894 .47724 L
.96192 .4894 L
.97267 .49842 L
.96566 .51058 L
.95246 .50578 L
.94544 .51794 L
.9562 .52696 L
.94918 .53912 L
.93599 .53432 L
.93842 .52049 L
.92523 .51569 L
.91821 .52785 L
.90502 .52305 L
.898 .53521 L
.90876 .54423 L
.90174 .55639 L
.88854 .55159 L
.89098 .53776 L
.87779 .53296 L
.88023 .51913 L
.89427 .51913 L
.8967 .50531 L
Mistroke
.88351 .50051 L
.87649 .51267 L
.8633 .50786 L
.86574 .49404 L
.85255 .48924 L
.84553 .50139 L
.83233 .49659 L
.82531 .50875 L
.83607 .51778 L
.84682 .50875 L
.85758 .51778 L
.85056 .52993 L
.86131 .53896 L
.85429 .55112 L
.8411 .54631 L
.83408 .55847 L
.84484 .5675 L
.83782 .57965 L
.82462 .57485 L
.82706 .56103 L
.81387 .55622 L
.80685 .56838 L
.79366 .56358 L
.78664 .57574 L
.79739 .58476 L
.80815 .57574 L
.8189 .58476 L
.81188 .59692 L
.82264 .60595 L
.81562 .6181 L
.80243 .6133 L
.79541 .62546 L
.80616 .63448 L
.81691 .62546 L
.82767 .63448 L
.82065 .64664 L
.8314 .65567 L
.84216 .64664 L
.85291 .65567 L
.86367 .64664 L
.85665 .63448 L
.8674 .62546 L
.87816 .63448 L
.87114 .64664 L
.88189 .65567 L
.87487 .66782 L
.86168 .66302 L
.85466 .67518 L
.86541 .6842 L
.8584 .69636 L
Mistroke
.8452 .69156 L
.84764 .67773 L
.83445 .67293 L
.82743 .68509 L
.81424 .68029 L
.80722 .69245 L
.81797 .70147 L
.81095 .71363 L
.79776 .70883 L
.8002 .695 L
.78701 .6902 L
.78944 .67638 L
.80348 .67638 L
.80592 .66255 L
.79273 .65775 L
.78571 .66991 L
.77252 .6651 L
.77495 .65128 L
.76176 .64648 L
.75474 .65864 L
.74155 .65383 L
.73453 .66599 L
.74529 .67502 L
.73827 .68717 L
.72507 .68237 L
.72751 .66855 L
.71432 .66375 L
.71676 .64992 L
.7308 .64992 L
.73323 .63609 L
.72004 .63129 L
.72248 .61747 L
.73652 .61747 L
.73896 .63129 L
.753 .63129 L
.75543 .61747 L
.76947 .61747 L
.77191 .60364 L
.75872 .59884 L
.7517 .611 L
.73851 .6062 L
.74094 .59237 L
.72775 .58757 L
.73019 .57374 L
.74423 .57374 L
.74667 .55992 L
.73347 .55512 L
.72645 .56727 L
.71326 .56247 L
.7157 .54865 L
Mistroke
.70251 .54385 L
.69549 .556 L
.6823 .5512 L
.67528 .56336 L
.68603 .57238 L
.69679 .56336 L
.70754 .57238 L
.70052 .58454 L
.71128 .59357 L
.70426 .60572 L
.69106 .60092 L
.68404 .61308 L
.6948 .6221 L
.68778 .63426 L
.67459 .62946 L
.67702 .61564 L
.66383 .61083 L
.65681 .62299 L
.64362 .61819 L
.6366 .63035 L
.64736 .63937 L
.64034 .65153 L
.62714 .64673 L
.62958 .6329 L
.61639 .6281 L
.61883 .61428 L
.63287 .61428 L
.6353 .60045 L
.62211 .59565 L
.61509 .60781 L
.6019 .60301 L
.60434 .58918 L
.59115 .58438 L
.58413 .59654 L
.57093 .59173 L
.56392 .60389 L
.57467 .61292 L
.58542 .60389 L
.59618 .61292 L
.58916 .62507 L
.59991 .6341 L
.59289 .64626 L
.5797 .64146 L
.57268 .65361 L
.58344 .66264 L
.57642 .6748 L
.56322 .66999 L
.56566 .65617 L
.55247 .65137 L
.54545 .66352 L
Mistroke
.53226 .65872 L
.52524 .67088 L
.53599 .6799 L
.54675 .67088 L
.5575 .6799 L
.55048 .69206 L
.56124 .70109 L
.55422 .71324 L
.54103 .70844 L
.53401 .7206 L
.54476 .72963 L
.55552 .7206 L
.56627 .72963 L
.55925 .74178 L
.57 .75081 L
.58076 .74178 L
.59151 .75081 L
.60227 .74178 L
.59525 .72963 L
.58206 .73443 L
.57504 .72227 L
.58579 .71324 L
.57877 .70109 L
.58953 .69206 L
.60028 .70109 L
.61103 .69206 L
.60402 .6799 L
.61477 .67088 L
.62552 .6799 L
.6185 .69206 L
.62926 .70109 L
.64001 .69206 L
.65077 .70109 L
.66152 .69206 L
.6545 .6799 L
.66526 .67088 L
.67601 .6799 L
.66899 .69206 L
.67975 .70109 L
.67273 .71324 L
.65953 .70844 L
.65252 .7206 L
.66327 .72963 L
.67402 .7206 L
.68478 .72963 L
.67776 .74178 L
.68851 .75081 L
.69927 .74178 L
.71002 .75081 L
.72078 .74178 L
Mistroke
.71376 .72963 L
.72451 .7206 L
.73527 .72963 L
.72825 .74178 L
.739 .75081 L
.73198 .76297 L
.71879 .75816 L
.71177 .77032 L
.72252 .77935 L
.7155 .7915 L
.70231 .7867 L
.70475 .77288 L
.69156 .76807 L
.68454 .78023 L
.67135 .77543 L
.66433 .78759 L
.67508 .79661 L
.68584 .78759 L
.69659 .79661 L
.68957 .80877 L
.70033 .8178 L
.69331 .82995 L
.68011 .82515 L
.67309 .83731 L
.68385 .84633 L
.6946 .83731 L
.70536 .84633 L
.69834 .85849 L
.70909 .86752 L
.71985 .85849 L
.7306 .86752 L
.74136 .85849 L
.73434 .84633 L
.74509 .83731 L
.75584 .84633 L
.74883 .85849 L
.75958 .86752 L
.75256 .87967 L
.73937 .87487 L
.73235 .88703 L
.7431 .89605 L
.73608 .90821 L
.72289 .90341 L
.72533 .88958 L
.71214 .88478 L
.70512 .89694 L
.69193 .89214 L
.68491 .9043 L
.69566 .91332 L
.68864 .92548 L
Mistroke
.67545 .92068 L
.67789 .90685 L
.66469 .90205 L
.66713 .88823 L
.68117 .88823 L
.68361 .8744 L
.67042 .8696 L
.6634 .88176 L
.65021 .87695 L
.65264 .86313 L
.63945 .85833 L
.63243 .87049 L
.61924 .86568 L
.61222 .87784 L
.62297 .88687 L
.63373 .87784 L
.64448 .88687 L
.63746 .89902 L
.64822 .90805 L
.6412 .92021 L
.62801 .9154 L
.62099 .92756 L
.63174 .93659 L
.62472 .94874 L
.61153 .94394 L
.61397 .93012 L
.60078 .92532 L
.59376 .93747 L
.58056 .93267 L
.57354 .94483 L
.5843 .95385 L
.59505 .94483 L
.60581 .95385 L
.59879 .96601 L
.60954 .97504 L
.60252 .98719 L
.58933 .98239 L
.58231 .99455 L
.59307 1.00357 L
.60382 .99455 L
.61457 1.00357 L
.60755 1.01573 L
.61831 1.02476 L
.62906 1.01573 L
.63982 1.02476 L
.65057 1.01573 L
.64355 1.00357 L
.63036 1.00838 L
.62334 .99622 L
.6341 .98719 L
Mistroke
.62708 .97504 L
.63783 .96601 L
.64859 .97504 L
.65934 .96601 L
.65232 .95385 L
.66307 .94483 L
.67383 .95385 L
.66681 .96601 L
.67756 .97504 L
.68832 .96601 L
.69907 .97504 L
.70983 .96601 L
.70281 .95385 L
.71356 .94483 L
.72432 .95385 L
.7173 .96601 L
.72805 .97504 L
.72103 .98719 L
.70784 .98239 L
.70082 .99455 L
.71157 1.00357 L
.72233 .99455 L
.73308 1.00357 L
.72606 1.01573 L
.73682 1.02476 L
.74757 1.01573 L
.75833 1.02476 L
.76908 1.01573 L
.76206 1.00357 L
.77282 .99455 L
.78357 1.00357 L
.77655 1.01573 L
.78731 1.02476 L
.78029 1.03691 L
.76709 1.03211 L
.76007 1.04427 L
.77083 1.05329 L
.76381 1.06545 L
.75062 1.06065 L
.75306 1.04683 L
.73986 1.04202 L
.73284 1.05418 L
.71965 1.04938 L
.71263 1.06154 L
.72339 1.07056 L
.73414 1.06154 L
.7449 1.07056 L
.73788 1.08272 L
.74863 1.09174 L
.74161 1.1039 L
Mistroke
.72842 1.0991 L
.7214 1.11126 L
.73215 1.12028 L
.74291 1.11126 L
.75366 1.12028 L
.74664 1.13244 L
.7574 1.14146 L
.76815 1.13244 L
.77891 1.14146 L
.78966 1.13244 L
.78264 1.12028 L
.76945 1.12508 L
.76243 1.11293 L
.77318 1.1039 L
.76616 1.09174 L
.77692 1.08272 L
.78767 1.09174 L
.79843 1.08272 L
.79141 1.07056 L
.80216 1.06154 L
.81292 1.07056 L
.8059 1.08272 L
.81665 1.09174 L
.82741 1.08272 L
.83816 1.09174 L
.84891 1.08272 L
.8419 1.07056 L
.85265 1.06154 L
.8634 1.07056 L
.85638 1.08272 L
.86714 1.09174 L
.86012 1.1039 L
.84693 1.0991 L
.83991 1.11126 L
.85066 1.12028 L
.86142 1.11126 L
.87217 1.12028 L
.86515 1.13244 L
.87591 1.14146 L
.88666 1.13244 L
.89741 1.14146 L
.90817 1.13244 L
.90115 1.12028 L
.88796 1.12508 L
.88094 1.11293 L
.89169 1.1039 L
.88467 1.09174 L
.89543 1.08272 L
.90618 1.09174 L
.91694 1.08272 L
Mistroke
.90992 1.07056 L
.92067 1.06154 L
.93143 1.07056 L
.92441 1.08272 L
.93516 1.09174 L
.94591 1.08272 L
.95667 1.09174 L
.96742 1.08272 L
.9604 1.07056 L
.94721 1.07536 L
.94019 1.06321 L
.95095 1.05418 L
.94393 1.04202 L
.95468 1.033 L
.96544 1.04202 L
.97619 1.033 L
.96917 1.02084 L
.95598 1.02564 L
.94896 1.01349 L
.95971 1.00446 L
.95269 .9923 L
.9395 .99711 L
.93248 .98495 L
.91929 .98975 L
.92173 1.00357 L
Mfstroke
0 0 m
1 0 L
1 1.16931 L
0 1.16931 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[80]:=",
  ImageSize->{246.25, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003f00017b000`400?l00000o`00003omP3oool0
0?H0oooo003f0?ooo`00mP3oool00?H0oooo003f0?ooo`00=P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?oo
o`00=@3oool00`000000oooo0000000:0?ooo`030000003oool0000003@0oooo00<000000?ooo`00
00002P3oool00`000000oooo0000001]0?ooo`00=@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000003@0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
001]0?ooo`00=03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06X0oooo000d0?oo
o`050000003oool0oooo0?ooo`000000203oool01@000000oooo0?ooo`3oool0000003<0oooo00@0
00000?ooo`3oool00000203oool01@000000oooo0?ooo`3oool0000006`0oooo000e0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000=03oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000006d0oooo000`0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000002l0oooo00<00000
0?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000001]
0?ooo`00;P3oool2000000050?ooo`00000000000?ooo`0000000`3oool2000000030?ooo`000000
oooo0080000000<0oooo0000000000000`3oool00`000000oooo0?ooo`0[0?ooo`050000003oool0
00000000003oool00P0000020?ooo`80000000H0oooo000000000000oooo0000003oool2000000<0
oooo00<000000?ooo`3oool0JP3oool002d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J@3oool002h0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0J@3oool002h0oooo00<000000?ooo`3oool00P3oool2000000`0oooo0P000002
0?ooo`030000003oool0oooo02/0oooo00@000000?ooo`3oool0oooo0P00000<0?ooo`8000000P3o
ool00`000000oooo0?ooo`1Z0?ooo`00;`3oool010000000oooo0000000000020?ooo`030000003o
ool0oooo00T0oooo00@000000?ooo`0000000000;P3oool010000000oooo0000000000020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`0000000P00001/0?ooo`00;P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo008000001P3oool00`000000oooo0?ooo`0_0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool0oooo
06l0oooo000]0?ooo`050000003oool0oooo0?ooo`000000103oool200000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool07@3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo05h0oooo000]0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`04
0?ooo`060000003oool000000000003oool000002@3oool010000000oooo00000000000M0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`05
0000003oool000000000003oool00P0000080?ooo`040000003oool00000000005h0oooo000^0?oo
o`040000003oool00000000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00800000203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo05/0oooo000^0?ooo`8000002@3oool2000000`0oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool0000001h0oooo0`0000080?ooo`800000303oool00`000000oooo0?ooo`05
0?ooo`050000003oool0oooo0?ooo`000000GP3oool003P0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo000002P0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000005h0oooo000i0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000002X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`000000G`3oool003T0oooo00<000000?ooo`3oool00P000009
0?ooo`050000003oool000000000003oool00P0000000`3oool000000?ooo`020?ooo`800000:03o
ool00`000000oooo0?ooo`02000000T0oooo0P0000000`3oool000000?ooo`02000000030?ooo`00
0000oooo0080oooo0P00001M0?ooo`00>P3oool200000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09P3oool2
00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0FP3oool003h0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0F`3oool003X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`8000000P3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool200000080
oooo00<000000?ooo`3oool0F`3oool003P0oooo0P0000000`3oool000000?ooo`0200000100oooo
00<000000?ooo`3oool00P00000X0?ooo`80000000<0oooo0000003oool00P00000@0?ooo`030000
003oool0oooo00800000GP3oool003L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0:0?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool2000000@0oooo00<000000?ooo`3oool0H03oool003P0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo02`0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo00000003000006<0oooo000h0?ooo`030000003oool0oooo
00T0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool2000002/0oooo00<00000
0?ooo`3oool02@3oool200000080oooo00<000000?ooo`3oool00P3oool010000000oooo00000000
001Q0?ooo`00>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00800000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo00000002000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1N
0?ooo`00>03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo0000000[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool000000640oooo000D0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo
0P0000020?ooo`030000003oool0oooo05l0oooo000B0?ooo`80000000<0oooo000000000000203o
ool2000000030?ooo`000000oooo00`0oooo00@000000?ooo`00000000000P3oool00`000000oooo
0?ooo`0:0?ooo`80000000D0oooo000000000000oooo000000040?ooo`8000001`3oool010000000
oooo0000000000080?ooo`80000000<0oooo0000003oool0303oool010000000oooo000000000002
0?ooo`030000003oool0oooo00/0oooo00D000000?ooo`00000000000?ooo`02000000<0oooo0P00
001R0?ooo`004@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool2000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06@0oooo
000B0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo0?ooo`00000<0?ooo`05
0000003oool0oooo0?ooo`000000103oool200000080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000203oool01@000000oooo0?ooo`3o
ool0000000`0oooo00@000000?ooo`3oool00000103oool200000080oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1U0?ooo`004P3oool01@000000oooo0?ooo`3oool0000000P0oooo
00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000d0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo06D0oooo000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`030?ooo`8000001@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0IP3o
ool000d0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool000000080oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0I@3oool000`0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000040?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool00000
00@0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000>0?ooo`030000003oool0oooo
00@0oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`030000003oool000000080oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`040?ooo`060000003oool0oooo0000003oool0
0000103oool00`000000oooo000000020?ooo`030000003oool0000000h0oooo00<000000?ooo`3o
ool0I@3oool000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1T0?ooo`00303oool00`000000oooo
0?ooo`0@0?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo
0P0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool200000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`8000000P3oool00`000000oooo
0?ooo`1U0?ooo`003@3oool010000000oooo0?ooo`3oool2000000/0oooo00<000000?ooo`3oool0
0P0000070?ooo`030000003oool0oooo01T0oooo00<000000?ooo`0000000P0000060?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`0000000P0000060?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`0000000P00001W0?ooo`00303oool00`000000oooo0?ooo`0200000080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1Z0?ooo`002`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`1I0?ooo`002P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo00<0oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool0703oool01P000000oooo
0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool04@3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool06`3oool01P000000oooo0?ooo`000000oooo000000T0
oooo00<000000?ooo`000000FP3oool000/0oooo00D000000?ooo`3oool0oooo000000080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
01d0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001<0oooo00<00000
0?ooo`0000000`3oool010000000oooo0?ooo`00000M0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool01P3oool010000000oooo0?ooo`00001I0?ooo`002`3oool00`000000oooo0?oo
o`02000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo0P00000J0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000020?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo0P00000I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo000<0?ooo`8000002@3oool2000000/0
oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`020?ooo`<0000000<0oooo0000003oool04`3oool010000000oooo0?ooo`3oool30000
00030?ooo`000000oooo01d0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00001I
0?ooo`005P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000FP3oool001L0oooo00<000000?ooo`3o
ool02`3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0703oool0
1P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool04P3oool01P000000oooo
0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0303oool010000000oooo00000000000<
0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00001I0?ooo`00
5`3oool00`000000oooo0?ooo`02000000T0oooo00<000000?ooo`0000000P3oool00`000000oooo
0000000O0?ooo`030000003oool0000000<0oooo00<000000?ooo`000000503oool00`000000oooo
000000030?ooo`030000003oool0000000X0oooo0P0000020?ooo`050000003oool0oooo0?ooo`00
0000303oool00`000000oooo000000020?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool0EP3oool001P0oooo0P0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P0000040?ooo`040000003oool0oooo0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0E@3oool001`0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000d0
oooo00D000000?ooo`3oool0oooo0000001H0?ooo`005`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool20000
0080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`060000003oool000000000003oool00000
F03oool001H0oooo00D000000?ooo`00000000000?ooo`02000005h0oooo00D000000?ooo`000000
00000?ooo`02000000<0oooo0P0000040?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3o
ool0oooo0000001I0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05l0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo0P0000030?ooo`030000003oool0oooo05`0oooo000F0?ooo`030000003oool0oooo06P0oooo
00<000000?ooo`3oool00`3oool5000000H0oooo00<000000?ooo`0000000P0000000`3oool00000
0?ooo`1L0?ooo`005P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00001L0?ooo`005`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo00000002000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1I0?ooo`005@3oool2000006X0oooo00<000000?ooo`3oool00`3oool2
000000<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000005`0oooo000?
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`04
0?ooo`80000000<0oooo0000003oool0203oool2000000030?ooo`000000oooo05/0oooo000=0?oo
o`80000000<0oooo0000000000000`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`1K0?ooo`00303oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0P00001T0?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06D0oooo000=
0?ooo`050000003oool0oooo0?ooo`000000103oool200000080oooo00<000000?ooo`3oool0H03o
ool01P000000oooo000000000000oooo000000H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1U0?ooo`003@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool0H03oool01@000000oooo0?ooo`3oool0000000L0oooo0P0000020?ooo`030000003oool0oooo
06H0oooo00090?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo05T0oooo0P0000030?ooo`030000003oool0oooo00`0
oooo0`00001X0?ooo`001`3oool2000000050?ooo`00000000000?ooo`0000000`3oool200000003
0?ooo`000000oooo0080000000<0oooo000000000000F`3oool00`000000oooo0?ooo`0200000080
oooo00<000000?ooo`3oool0MP3oool000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0E`3oool200000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo07D0oooo00070?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0M03oool000L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`000000M`3oool000P0oooo00@000000?ooo`3oool0oooo
0P00001R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2000000030?oo
o`000000oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0703oool000H0oooo0P0000020?ooo`8000000P3o
ool01@000000oooo0?ooo`3oool0000005h0oooo0P0000001@3oool000000000003oool0000000D0
oooo00<000000?ooo`3oool01@3oool010000000oooo0000000000080?ooo`80000000<0oooo0000
003oool0<`3oool2000000030?ooo`000000oooo00L0oooo0P0000000`3oool000000000000L0?oo
o`001@3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`000000oooo0P000000
0`3oool000000?ooo`1N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00060?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000006@0oooo00<000000?ooo`3oool02@3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`04
0000003oool0oooo000000P0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`001P3oool00`00
0000oooo0?ooo`02000000T0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0;0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000=03oool010000000oooo0?oo
o`0000080?ooo`050000003oool0oooo0?ooo`000000703oool000L0oooo0P00000:0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000_0?ooo`030000
003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
7@3oool00180oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`030?ooo`80000000D0
oooo000000000000oooo000000030?ooo`80000000H0oooo000000000000oooo0000003oool20000
00<0oooo00<000000?ooo`3oool0:`3oool01@000000oooo000000000000oooo008000000P3oool2
000000060?ooo`00000000000?ooo`000000oooo0P0000030?ooo`030000003oool0oooo01X0oooo
000A0?ooo`030000003oool0oooo06D0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`004P3o
ool01@000000oooo0?ooo`3oool000000640oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0I0?ooo`004P3oool01P000000oooo000000000000oooo000005`0oooo0P0000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool200000080oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo0P0000000`3oool0
00000?ooo`0K0?ooo`004`3oool01@000000oooo0?ooo`3oool0000005`0oooo00@000000?ooo`00
000000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000000800000;@3oool00`00
0000oooo0?ooo`02000000030?ooo`000000oooo00X0oooo00<000000?ooo`3oool00P00000L0?oo
o`004P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02l0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`02000000L0oooo00<000000?ooo`3oool07P3oool00140
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo0?oo
o`000000103oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00140oooo00H000000?ooo`3o
ool000000?ooo`00001M0?ooo`060000003oool000000000003oool000000`3oool00`000000oooo
0?ooo`0A0?ooo`060000003oool000000000003oool000002@3oool010000000oooo00000000000N
0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool000000000003oool00P0000080?ooo`040000003oool00000000000h0oooo000@0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03P3oool4000004/0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool000000080oooo0P00000?0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool00P0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00100oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1>0?ooo`040000
003oool0oooo0?ooo`<0000000<0oooo0000003oool04`3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`0000007`3oool2000000P0oooo0P00000<0?ooo`030000003oool0oooo
00H0oooo00@000000?ooo`3oool000003P3oool00140oooo00@000000?ooo`3oool0oooo0P00000C
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000003P3oool00140oooo00@0
00000?ooo`00000000000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000002X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
0P00000?0?ooo`00403oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00800000
303oool200000500oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`000000oooo01<0
oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`000000oooo0080oooo0P00000X0?oo
o`030000003oool0oooo008000002@3oool2000000030?ooo`000000oooo0080000000<0oooo0000
000000000P3oool2000000d0oooo000?0?ooo`050000003oool0oooo0?ooo`000000103oool20000
0080oooo00<000000?ooo`3oool01`3oool2000005<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0V0?ooo`8000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`00403oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?oo
o`3oool0N`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool02`3oool00100oooo00<000000?ooo`3oool00P0000080?ooo`040000003oool000000000
0080oooo00D000000?ooo`3oool0oooo0000001h0?ooo`8000000P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool200000080oooo00<00000
0?ooo`3oool02`3oool00140oooo0P0000080?ooo`8000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo0P00001g0?ooo`030000003oool0oooo00800000:03oool2000000030?ooo`000000
oooo00800000403oool00`000000oooo0?ooo`02000000h0oooo000J0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool2000007<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000K0?ooo`050000003oool0oooo0?oo
o`000000N03oool010000000oooo0000000000020?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool03P3oool300000080oooo00<000000?ooo`3oool04@3oool001/0oooo00<000000?oo
o`3oool00P00001d0?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000080oooo0P00000[
0?ooo`030000003oool0oooo00T0oooo0P0000020?ooo`040000003oool0oooo0?ooo`80000000<0
oooo0000000000004@3oool001`0oooo0P00001e0?ooo`030000003oool0oooo00800000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo00000002000000@0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`00T`3oool0
0`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000:`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`00TP3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`3oool200000080oooo00<000000?ooo`3oool03`3oool009<0oooo0P0000001@3oool00000
0000003oool0000000@0oooo0P0000070?ooo`040000003oool00000000000P0oooo0P0000000`3o
ool000000?ooo`0<0?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool02`3oool0
1@000000oooo000000000000oooo008000000`3oool200000180oooo002E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0503oool009X0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`0000080?ooo`050000003oool0oooo0?ooo`000000303oool010000000oooo
0?ooo`0000030?ooo`060000003oool000000000003oool000003@3oool00`000000oooo0?ooo`0E
0?ooo`00V@3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000003@3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`00
00003@3oool00`000000oooo0?ooo`0E0?ooo`00V@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
203oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool009X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000000`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0E0?ooo`00VP3oool00`000000oooo0?ooo`040?ooo`060000003oool0oooo0000
003oool00000103oool00`000000oooo000000020?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool0103oool01P000000oooo0?ooo`000000oooo000000@0oooo00<000000?ooo`000000
0P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo01@0oooo002K0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool04`3oool009H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo0000
000F0?ooo`00UP3oool3000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool03`3oool3
000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool06@3oool01P000000oooo00000000
0000oooo000001H0oooo002E0?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000oooo
0?ooo`0>0?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000oooo0?ooo`0I0?ooo`05
0000003oool0oooo0?ooo`0000005`3oool009D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo002F0?ooo`060000003oool0oooo0000003o
ool000000`3oool00`000000oooo0?ooo`0A0?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo0?ooo`0K0?ooo`060000003oool0oooo0000003oool000002@3oool00`000000
oooo0000000:0?ooo`00UP3oool00`000000oooo000000030?ooo`040000003oool0oooo000001<0
oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`00000M0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000090?ooo`00U`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0P00000?0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000P3oool2000001T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool009`0oooo00@000000?ooo`3oool0oooo0`0000000`3oool000000?ooo`0C0?ooo`040000003o
ool0oooo0?ooo`<0000000<0oooo0000003oool07@3oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000000T0oooo002L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
1P3oool010000000oooo0?ooo`0000090?ooo`00V`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool2000000`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`8000002P3oool009`0oooo00D000000?ooo`0000000000
0?ooo`02000000030?ooo`000000oooo01<0oooo0P0000000`3oool000000?ooo`02000000030?oo
o`000000oooo00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000002`3oool200000003
0?ooo`000000oooo0080000000<0oooo0000000000000P3oool2000000P0oooo002M0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00H000000?ooo`00000000000?ooo`0000030?ooo`050000003oool0oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00</0oooo00D000000?ooo`3oool0oooo000000030?ooo`060000003oool0
oooo0?ooo`000000oooo0P00000B0?ooo`030000003oool0oooo00H0oooo003:0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`050000003oool0oooo0?ooo`00
00003@3oool200000080oooo00<000000?ooo`3oool01P3oool00</0oooo00H000000?ooo`3oool0
00000?ooo`0000040?ooo`800000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
008000002@3oool00<`0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00@0oooo0P0000040?ooo`030000003oool0oooo00/0oooo003=0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool5000000H0oooo00<000000?ooo`000000
0`00000>0?ooo`00d@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P00
00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`0000000000303oool00=40oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool00000008000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo003@0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`000000303oool00=40oooo0P0000050?ooo`8000000P3oool00`000000oooo0?ooo`06
0?ooo`8000000P3oool00`000000oooo0?ooo`0:0?ooo`00d`3oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo000000T0oooo0P00000=0?ooo`00[03oool2000002@0oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool0000001L0oooo002[0?ooo`030000003oool0oooo
008000007P3oool200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01D0oooo002W0?ooo`8000000P3oool01@000000oooo0?ooo`3oool00000
01d0oooo00<000000?ooo`3oool00P0000070?ooo`8000000P3oool00`000000oooo0?ooo`0F0?oo
o`00YP3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P3oool200000180
oooo0P0000040?ooo`030000003oool0oooo00/0oooo0`00000H0?ooo`00YP3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P00000>0?ooo`030000
003oool0oooo0080000000<0oooo0000003oool0:03oool00:D0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000080oooo0P00000W0?ooo`00
YP3oool2000000030?ooo`000000oooo008000000`3oool3000000<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0T0?ooo`00Z03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo1000
000:0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000W0?ooo`00[03o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool09@3oool00:`0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`80000000D0oooo000000000000oooo
000000040?ooo`800000:03oool00900oooo0P00000I0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo002@
0?ooo`030000003oool00000008000005`3oool2000000@0oooo0P00000D0?ooo`030000003oool0
oooo02/0oooo002<0?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00<0oooo0P00000A0?ooo`030000003oool0oooo02`0oooo002;0?ooo`03
0000003oool0oooo008000000`3oool00`000000oooo0?ooo`020?ooo`8000004`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;03oool008/0oooo
00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo0P00000=0?ooo`80
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P00000<0?ooo`03
0000003oool0oooo02/0oooo002:0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`020000
00P0oooo0P0000020?ooo`030000003oool0oooo008000002`3oool00`000000oooo0?ooo`0Z0?oo
o`00R`3oool01@000000oooo000000000000oooo008000000`3oool2000000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo0P0000040?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:P3oool008`0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`D000001P3oool300000080oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`0[0?ooo`00
T@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`040000
003oool0oooo0?ooo`80000000<0oooo0000000000001`3oool4000000@0oooo100000070?ooo`03
0000003oool0000000800000;@3oool00940oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000800000103oool01@000000oooo0?ooo`3oool0000000H0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0300oooo002@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01l0oooo002A0?ooo`800000103oool2000000<0oooo00<000000?oo
o`3oool01P3oool200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`@000002`3oool01P000000oooo000000000000oooo000000T0oooo00@000000?ooo`0000000000
7`3oool009<0oooo00<000000?ooo`3oool00`3oool200000080oooo00<000000?ooo`3oool01`3o
ool2000000P0oooo0P00000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo002B0?ooo`030000003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000001l0oooo002>0?ooo`8000000P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
7`3oool008d0oooo00<000000?ooo`3oool00P0000070?ooo`8000000P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00@0oooo0P00000=0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0000000P0?ooo`00Q`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00/0oooo0`00000A0?ooo`D000001P3oool00`000000oooo00000002
000000/0oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`000000oooo0080oooo0P00
000N0?ooo`00QP3oool010000000oooo0000000000020?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool00`3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0K0?ooo`00PP3oool200000080oooo00D000000?ooo`3oool0oooo000000020?ooo`800000803o
ool00`000000oooo0?ooo`030?ooo`030000003oool00000008000000`3oool00`000000oooo0?oo
o`020?ooo`8000004`3oool00`000000oooo0?ooo`0L0?ooo`00P@3oool00`000000oooo0?ooo`02
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo0P00
000=0?ooo`8000000P3oool00`000000oooo0?ooo`0L0?ooo`00P@3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`0000008@3oool200000080oooo00<000000?ooo`3oool01P3o
ool200000080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00800000
7`3oool00800oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool200000080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo
00@000000?ooo`3oool000002@3oool2000000@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0Q0?ooo`00P@3oool2000000050?ooo`00000000000?ooo`000000103oool2000000L0
oooo00@000000?ooo`0000000000203oool2000000030?ooo`000000oooo00`0oooo00D000000?oo
o`3oool0oooo0000000>0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0
oooo0280oooo00230?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool50000
00030?ooo`000000oooo0080oooo00<000000?ooo`3oool00P0000020?ooo`8000008P3oool008P0
oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000P0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0080oooo00H000000?ooo`00000000000?ooo`0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool07`3oool008L0oooo00<000000?ooo`3oool02`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000h0oooo0`00000;0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000008P3oool0
08L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000L0?ooo`8000000P3oool00`00
0000oooo0?ooo`070?ooo`8000000P3oool00`000000oooo0?ooo`0P0?ooo`00R03oool00`000000
oooo0?ooo`040?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`80000000<0oooo
0000003oool02@3oool2000002<0oooo00280?ooo`030000003oool0oooo00<0oooo00L000000?oo
o`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00040?ooo`030000003oool0oooo01`0oooo00@000000?ooo`3oool00000;P3oool008T0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0[0?ooo`00Q03oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000001d0oooo00D000000?ooo`3o
ool0oooo0000000^0?ooo`00P`3oool01P000000oooo000000000000oooo000000D0oooo00<00000
0?ooo`3oool0403oool3000000030?ooo`000000oooo01d0oooo0P0000000`3oool000000?ooo`0]
0?ooo`00P`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool03P3oool0
1@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3oool0;@3oool00880oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo00230?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0140oooo00H0
00000?ooo`3oool000000?ooo`0000090?ooo`030000003oool0000004<0oooo00240?ooo`030000
003oool000000080oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000120?ooo`00Q@3oool00`000000
oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`000000oooo0P00000@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo03l0oooo002:0?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000120?ooo`00R@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`0000120?ooo`00R@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`000000@`3oool008X0oooo00D000000?ooo`00000000000?ooo`02
000000030?ooo`000000oooo01<0oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`00
0000oooo0080oooo0P0000110?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03h0oooo002d0?ooo`030000003oool0oooo03l0oooo002`0?ooo`8000000P3oool00`000000
oooo0?ooo`0o0?ooo`00[`3oool00`000000oooo0?ooo`0200000480oooo002Y0?ooo`800000103o
ool00`000000oooo0?ooo`140?ooo`00Z03oool00`000000oooo0?ooo`02000000030?ooo`000000
oooo04H0oooo002T0?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000080oooo0P000015
0?ooo`00X`3oool00`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`120?ooo`00X`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`000000A@3oool00:80oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool20000
0080oooo00<000000?ooo`3oool0@`3oool00:<0oooo0P0000001@3oool000000000003oool00000
00@0oooo0P0000160?ooo`00Y@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04T0
oooo002Z0?ooo`030000003oool0oooo04T0oooo002Y0?ooo`030000003oool0oooo04X0oooo002Y
0?ooo`030000003oool0oooo04X0oooo002Z0?ooo`030000003oool0oooo04T0oooo002[0?ooo`03
0000003oool0oooo04P0oooo002[0?ooo`030000003oool0oooo04P0oooo002V0?ooo`8000000P3o
ool00`000000oooo0?ooo`190?ooo`00YP3oool00`000000oooo00000002000004/0oooo002U0?oo
o`030000003oool0oooo04h0oooo002U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0m0?ooo`00YP3oool01P000000oooo000000000000oooo0000
00T0oooo00@000000?ooo`0000000000?@3oool00:L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool00:`0
oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000003d0oooo002[0?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool00000?@3oool009`0oooo0P00000=0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000n0?ooo`00
W03oool00`000000oooo00000002000000/0oooo00D000000?ooo`00000000000?ooo`0200000003
0?ooo`000000oooo0080oooo0P00000l0?ooo`00U`3oool200000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0i0?ooo`00U`3oool00`000000oooo00000002000000<0oooo00<0
00000?ooo`3oool00P3oool2000001<0oooo00<000000?ooo`3oool0>P3oool009H0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo0P00000=0?ooo`8000000P3o
ool00`000000oooo0?ooo`0j0?ooo`00UP3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo0?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0
0P00000m0?ooo`00U`3oool01@000000oooo000000000000oooo008000000`3oool2000000@0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0o0?ooo`00V03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo1@0000060?ooo`8000000`3oool00`000000oooo0?oo
o`100?ooo`00W@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`8000000P3oool200000400oooo002M0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01P000000oooo000000000000oooo000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`00W03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
003oool0oooo0?ooo`000000@03oool009d0oooo00<000000?ooo`3oool00`3oool200000080oooo
00<000000?ooo`3oool01`3oool200000080oooo00<000000?ooo`3oool0?P3oool009h0oooo00<0
00000?ooo`3oool0103oool2000000030?ooo`000000oooo00T0oooo0P0000110?ooo`00WP3oool0
0`000000oooo0?ooo`050?ooo`040000003oool0oooo000004`0oooo002J0?ooo`80000000<0oooo
0000003oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04T0oooo002I0?oo
o`030000003oool0oooo008000001`3oool01@000000oooo0?ooo`3oool0000004`0oooo002I0?oo
o`030000003oool0oooo00X0oooo0P0000000`3oool000000?ooo`1;0?ooo`00T`3oool2000000<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1;0?ooo`00SP3oool01@000000oooo
0?ooo`3oool000000080oooo0P0000020?ooo`030000003oool0oooo05X0oooo002=0?ooo`060000
003oool000000000003oool000000`3oool01@000000oooo0?ooo`3oool0000005/0oooo002=0?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo05T0oooo002<0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`14
0?ooo`00S@3oool01P000000oooo0?ooo`000000oooo000000@0oooo0`0000070?ooo`030000003o
ool0000000X0oooo00<000000?ooo`000000A@3oool008h0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo0?oo
o`0000150?ooo`00S`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0@P3oool009<0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00@000000?ooo`3oool00000A@3oool009<0oooo00<000000?ooo`3oool02P3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000A@3oool00980oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool00`3oool2000004H0oooo002C0?ooo`8000001@3oool2000000050?ooo`00
000000000?ooo`0000000`3oool2000000030?ooo`000000oooo0080000000<0oooo000000000000
0P3oool2000004@0oooo002E0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`110?ooo`00U03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0@P3oool00900oooo0P0000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0403oool200000080oooo00<000000?ooo`3oool0;`3oool200000140oooo002?0?oo
o`030000003oool0oooo008000001`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00800000<03oool200000080oooo00<000000?ooo`3oool03P3oool008l0oooo00<000000?ooo`3o
ool01`3oool200000140oooo00<000000?ooo`3oool0<P3oool01@000000oooo0?ooo`3oool00000
0080oooo0P00000<0?ooo`00SP3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000004P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`090?oo
o`00S`3oool2000000050?ooo`00000000000?ooo`0000000`3oool00`000000oooo0?ooo`0@0?oo
o`80000000D0oooo000000000000oooo000000080?ooo`80000000<0oooo0000000000008P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo002A0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool200000100oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo002F0?ooo`040000003oool0oooo
0?ooo`8000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00D00000
0?ooo`3oool0oooo0000000Y0?ooo`8000002`3oool009D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000
000X0?ooo`030000003oool0oooo00/0oooo002E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo00X0oooo002F0?oo
o`070000003oool000000000003oool000000?ooo`02000001@0oooo00L000000?ooo`0000000000
0?ooo`000000oooo008000000`3oool2000002P0oooo00<000000?ooo`3oool00P0000080?ooo`00
U`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0oooo0P0000020?ooo`030000
003oool0oooo00D0oooo00300?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3o
ool00;`0oooo0P0000020?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`00^`3oool00`000000oooo0?ooo`02000002P0oooo0P0000000`3o
ool000000?ooo`02000000L0oooo002e0?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00;@0oooo00<000000?ooo`3oool0
0P0000000`3oool000000?ooo`0/0?ooo`030000003oool0oooo00/0oooo002`0?ooo`8000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo0P00000[0?ooo`030000003oool0oooo00/0oooo
002_0?ooo`030000003oool0oooo00800000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool02P3oool00:l0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000002X0oooo0P00000=0?ooo`00[P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo002_0?ooo`80000000D0oooo000000000000oooo000000040?ooo`8000001`3o
ool010000000oooo0000000000080?ooo`80000000<0oooo0000003oool0303oool010000000oooo
0000000000030?ooo`030000003oool0oooo00`0oooo002a0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool2000000X0oooo002e0?ooo`030000003oool0oooo00X0oooo
00D000000?ooo`3oool0oooo000000080?ooo`050000003oool0oooo0?ooo`0000002`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo0P0000020?ooo`030000003oool0oooo00L0oooo002e0?oo
o`030000003oool0oooo00/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
000=0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01`3oool00;@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo002e
0?ooo`8000001@3oool2000000050?ooo`00000000000?ooo`0000000`3oool2000000030?ooo`00
0000oooo0080000000<0oooo0000000000000`3oool00`000000oooo0?ooo`030?ooo`80000000D0
oooo000000000000oooo000000030?ooo`80000000<0oooo0000003oool00P0000000`3oool00000
000000090?ooo`00]`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`00]P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`00/P3oool200000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`8000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01X0oooo002a0?ooo`030000003oool0oooo008000001`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo008000001`3oool00`000000oooo0?ooo`0I
0?ooo`00/@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0J0?ooo`00/03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00;40oooo0P0000001@3oool00000
0000003oool000000080oooo00<000000?ooo`3oool04@3oool2000000050?ooo`00000000000?oo
o`0000000`3oool00`000000oooo0?ooo`0K0?ooo`00/`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool05P3oool00;P0oooo00D000000?oo
o`3oool000000?ooo`02000000030?ooo`000000oooo01<0oooo00H000000?ooo`3oool0oooo0000
003oool3000001P0oooo002g0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
0000000C0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo01D0oooo
002g0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0E0?ooo`00^03oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0
4P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool05P3oool00;P0
oooo00<000000?ooo`0000000`3oool00`000000oooo0000000D0?ooo`030000003oool0000000<0
oooo00<000000?ooo`000000603oool00;T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00?H0oooo003f
0?ooo`00mP3oool00?H0oooo003f0?ooo`00mP3oool00001\
\>"],
  ImageRangeCache->{{{0, 245.25}, {286.938, 0}} -> {-11.0685, -25.7055, \
0.290446, 0.290446}}]
}, Open  ]],

Cell["ANIMATION", "Text",
  FontSize->18,
  FontColor->RGBColor[0.0299992, 0.179995, 0.329992],
  Background->RGBColor[0.737301, 0.5608, 0.5608]],

Cell[BoxData[
    \(\(Map[\(Show[
              Graphics[
                Line[logo[Nest[dragon, "\<FX\>", 10], #  \[Degree]]]]];\) &, 
        Range[0.0, 360.0, 3.0]];\)\)], "Input",
  CellLabel->"In[97]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.- From Binary Numbers to Compositions", "Section",
  FontColor->RGBColor[1, 0.889998, 0.00999466],
  Background->RGBColor[0.4392, 0.502007, 0.564706]],

Cell[TextData[{
  "It is well-known the fact that there exist isomorphisms between 1) the set \
of all subsets of {1, 2, \[Ellipsis], n},  2) the first ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " binary words starting from ",
  Cell[BoxData[
      \(TraditionalForm\`0\^n\)]],
  " and ending at ",
  Cell[BoxData[
      \(TraditionalForm\`1\^n\)]],
  " , 3) the integer numbers from 0 to ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  "-1 and 4) the compositions of n+1. The table below shows these \
isomorphisms for the case n=4. We illustrate the use of RS in the translation \
from a binary word to a composition, that is, given a binary word we will set \
up an RS in such a way that the normal form to which it converges is the \
required composition. This is accomplished by the rules "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`1\^n\)]],
  "0 \[Rule] (n+1)+\n\"+  \" \[Rule] \"\"  "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
(note the space after the plus sign in the last production) or \
equivalently:\
\>", "Text"],

Cell["\<\
10 \[Rule] 2+
1x+ \[Rule] (x+1)+
0 \[Rule] 1+
\"+  \" \[Rule] \"\"\
\>", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
We will append a 0 at a given binary string before applying these \
productions. 

For instance, to find out which composition corresponds to the binary \
sequence 111011 the productions act as follows:\
\>", "Text"],

Cell["\<\
1110110 \[Rule] 112+110 \[Rule] 112+12+ \[Rule] 13+12+ \[Rule]  4+12+ \
\[RightArrow] 4+3+ \[Rule]  4+3\
\>", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["So, the associated composition is 4+3.", "Text"],

Cell[BoxData[{
    \(subSets[0] := {{}}\), "\n", 
    \(\(\(subSets[n_] := 
      Module[{s = subSets[n - 1]}, 
        Join[s, Map[Append[#, n] &, s]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(binary[n_, s_] := 
      Module[{bn = Table[0, {n}]}, 
        bn\_\(\(\[LeftDoubleBracket]\)\(s\)\(\[RightDoubleBracket]\)\) = 1; 
        bn]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(dec[{}] := 0\), "\n", 
    \(\(\(dec[{x___, t_}] := 2\ dec[{x}] + t\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(compositions[u_] := \ 
      Module[{v = 
            Append[u, 
              0]}, \[IndentingNewLine]v = \((v\  //. \ \ {{a___, 1, 0, 
                    c___} \[Rule] {a, 2, "\<+\>", 
                    c}, \[IndentingNewLine]{a___, 1, b_, "\<+\>", 
                    c___} \[Rule] {a, b + 1, "\<+\>", 
                    c}, \[IndentingNewLine]{a___, 0, c___} \[Rule] {a, 
                    1, "\<+\>", c}})\); \[IndentingNewLine]StringJoin[
          ToString\  /@ \ Drop[v, \(-1\)]]]\)}], "Input",
  CellLabel->"In[105]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 4;\)\), "\n", 
    \(m = 
      Map[{#, u = binary[n, #]; \ StringJoin[ToString\  /@ \ u], dec[u], 
              compositions[u]} &, subSets[n]]\  // \ MatrixForm\)}], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({}\), "\<\"0000\"\>", "0", "\<\"1+1+1+1+1\"\>"},
            {\({1}\), "\<\"1000\"\>", "8", "\<\"2+1+1+1\"\>"},
            {\({2}\), "\<\"0100\"\>", "4", "\<\"1+2+1+1\"\>"},
            {\({1, 2}\), "\<\"1100\"\>", "12", "\<\"3+1+1\"\>"},
            {\({3}\), "\<\"0010\"\>", "2", "\<\"1+1+2+1\"\>"},
            {\({1, 3}\), "\<\"1010\"\>", "10", "\<\"2+2+1\"\>"},
            {\({2, 3}\), "\<\"0110\"\>", "6", "\<\"1+3+1\"\>"},
            {\({1, 2, 3}\), "\<\"1110\"\>", "14", "\<\"4+1\"\>"},
            {\({4}\), "\<\"0001\"\>", "1", "\<\"1+1+1+2\"\>"},
            {\({1, 4}\), "\<\"1001\"\>", "9", "\<\"2+1+2\"\>"},
            {\({2, 4}\), "\<\"0101\"\>", "5", "\<\"1+2+2\"\>"},
            {\({1, 2, 4}\), "\<\"1101\"\>", "13", "\<\"3+2\"\>"},
            {\({3, 4}\), "\<\"0011\"\>", "3", "\<\"1+1+3\"\>"},
            {\({1, 3, 4}\), "\<\"1011\"\>", "11", "\<\"2+3\"\>"},
            {\({2, 3, 4}\), "\<\"0111\"\>", "7", "\<\"1+4\"\>"},
            {\({1, 2, 3, 4}\), "\<\"1111\"\>", "15", "\<\"5\"\>"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[112]//MatrixForm="]
}, Open  ]],

Cell["\<\
By interpreting the numbers appearing in the last column as distances to be \
traversed by the LOGO interpreter, we can get a visualization of the set of \
compositions of a given number. By changing the angular value and/or the \
parameter n we get a variety of interesting tree-like diagrams.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(tr[s_] := 
      StringJoin[
        Flatten[Map[If[# == "\<+\>", #, Table["\<F\>", {ToExpression[#]}]] &, 
            s]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(n = 8;\)\), "\n", 
    \(\(m = 
        Map[{#, u = binary[n, #]; \ StringJoin[ToString\  /@ \ u], dec[u], 
              compositions[u]} &, subSets[n]];\)\), "\[IndentingNewLine]", 
    \(\(m = Last\  /@ \ m;\)\), "\[IndentingNewLine]", 
    \(\(u = Map[Characters[Last\  /@ \ #] &, m];\)\), "\[IndentingNewLine]", 
    \(\(v = \(Line[logo[tr[#], 72.0\ \[Degree]]] &\)\  /@ \ 
          u;\)\), "\[IndentingNewLine]", 
    \(\(Show[Graphics[v]];\)\)}], "Input",
  CellLabel->"In[171]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85462 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.334333 0.0713175 0.291656 0.0713175 [
[ 0 0 0 0 ]
[ 1 .85462 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.35637 .35948 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .35948 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.27664 .33358 L
.34795 .33358 L
.36999 .4014 L
.31229 .44332 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .42731 L
.42769 .35948 L
.49901 .35948 L
.52104 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .49514 L
.37841 .42731 L
.44973 .42731 L
.47177 .49514 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.58394 .4014 L
.52625 .35948 L
.54829 .29166 L
.6196 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.27664 .24974 L
.34795 .24974 L
.36999 .31756 L
.31229 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .4014 L
.34795 .33358 L
.41927 .33358 L
.44131 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .46923 L
.29867 .4014 L
.36999 .4014 L
.39203 .46923 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.53467 .46923 L
.47697 .42731 L
.49901 .35948 L
.57032 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .44332 L
.21894 .37549 L
.29026 .37549 L
.31229 .44332 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.48539 .53706 L
.42769 .49514 L
.44973 .42731 L
.52104 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.43611 .60488 L
.37841 .56296 L
.40045 .49514 L
.47177 .49514 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.71296 .35948 L
.65526 .4014 L
.59756 .35948 L
.6196 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.35637 .22383 L
.42769 .22383 L
.44973 .29166 L
.39203 .33358 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.32592 .31756 L
.34795 .24974 L
.41927 .24974 L
.44131 .31756 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.27664 .38539 L
.29867 .31756 L
.36999 .31756 L
.39203 .38539 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .44332 L
.39723 .4014 L
.41927 .33358 L
.49059 .33358 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.1969 .35948 L
.21894 .29166 L
.29026 .29166 L
.31229 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .51115 L
.34795 .46923 L
.36999 .4014 L
.44131 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .57898 L
.29867 .53706 L
.32071 .46923 L
.39203 .46923 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.66368 .42731 L
.60598 .46923 L
.54829 .42731 L
.57032 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.1969 .27564 L
.21894 .20782 L
.29026 .20782 L
.31229 .27564 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .48524 L
.26822 .44332 L
.29026 .37549 L
.36157 .37549 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .55307 L
.21894 .51115 L
.24098 .44332 L
.31229 .44332 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.6144 .49514 L
.5567 .53706 L
.49901 .49514 L
.52104 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .52716 L
.1392 .48524 L
.16124 .41741 L
.23256 .41741 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.56512 .56296 L
.50742 .60488 L
.44973 .56296 L
.47177 .49514 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.51584 .63079 L
.45815 .67271 L
.40045 .63079 L
.42249 .56296 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.76224 .29166 L
.78428 .35948 L
.72658 .4014 L
.66888 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.40565 .29166 L
.42769 .22383 L
.49901 .22383 L
.52104 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.35637 .35948 L
.37841 .29166 L
.44973 .29166 L
.47177 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .35948 L
.39723 .31756 L
.41927 .24974 L
.49059 .24974 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.27664 .33358 L
.29867 .26575 L
.36999 .26575 L
.39203 .33358 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .42731 L
.34795 .38539 L
.36999 .31756 L
.44131 .31756 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .49514 L
.29867 .45322 L
.32071 .38539 L
.39203 .38539 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.58394 .4014 L
.52625 .44332 L
.46855 .4014 L
.49059 .33358 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.27664 .24974 L
.29867 .18191 L
.36999 .18191 L
.39203 .24974 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .4014 L
.26822 .35948 L
.29026 .29166 L
.36157 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .46923 L
.21894 .42731 L
.24098 .35948 L
.31229 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.53467 .46923 L
.47697 .51115 L
.41927 .46923 L
.44131 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .44332 L
.1392 .4014 L
.16124 .33358 L
.23256 .33358 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.48539 .53706 L
.42769 .57898 L
.36999 .53706 L
.39203 .46923 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.43611 .60488 L
.37841 .6468 L
.32071 .60488 L
.34275 .53706 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.71296 .35948 L
.735 .42731 L
.6773 .46923 L
.6196 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.35637 .22383 L
.37841 .156 L
.44973 .156 L
.47177 .22383 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.32592 .31756 L
.26822 .27564 L
.29026 .20782 L
.36157 .20782 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.27664 .38539 L
.21894 .34347 L
.24098 .27564 L
.31229 .27564 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .44332 L
.39723 .48524 L
.33954 .44332 L
.36157 .37549 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.1969 .35948 L
.1392 .31756 L
.16124 .24974 L
.23256 .24974 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .51115 L
.34795 .55307 L
.29026 .51115 L
.31229 .44332 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .57898 L
.29867 .62089 L
.24098 .57898 L
.26302 .51115 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.66368 .42731 L
.68572 .49514 L
.62802 .53706 L
.57032 .49514 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.1969 .27564 L
.1392 .23372 L
.16124 .1659 L
.23256 .1659 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .48524 L
.26822 .52716 L
.21052 .48524 L
.23256 .41741 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .55307 L
.21894 .59499 L
.16124 .55307 L
.18328 .48524 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.6144 .49514 L
.63644 .56296 L
.57874 .60488 L
.52104 .56296 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .52716 L
.1392 .56908 L
.08151 .52716 L
.10354 .45933 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.56512 .56296 L
.58716 .63079 L
.52946 .67271 L
.47177 .63079 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.51584 .63079 L
.53788 .69862 L
.48018 .74054 L
.42249 .69862 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.76224 .29166 L
.83356 .29166 L
.85559 .35948 L
.7979 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.35637 .35948 L
.42769 .35948 L
.49901 .35948 L
.52104 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .35948 L
.47697 .29166 L
.49901 .22383 L
.57032 .22383 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.27664 .33358 L
.34795 .33358 L
.41927 .33358 L
.44131 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .42731 L
.42769 .35948 L
.44973 .29166 L
.52104 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .49514 L
.37841 .42731 L
.40045 .35948 L
.47177 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.58394 .4014 L
.52625 .35948 L
.46855 .31756 L
.49059 .24974 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.27664 .24974 L
.34795 .24974 L
.41927 .24974 L
.44131 .31756 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .4014 L
.34795 .33358 L
.36999 .26575 L
.44131 .26575 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .46923 L
.29867 .4014 L
.32071 .33358 L
.39203 .33358 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.53467 .46923 L
.47697 .42731 L
.41927 .38539 L
.44131 .31756 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .44332 L
.21894 .37549 L
.24098 .30767 L
.31229 .30767 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.48539 .53706 L
.42769 .49514 L
.36999 .45322 L
.39203 .38539 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.43611 .60488 L
.37841 .56296 L
.32071 .52104 L
.34275 .45322 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.71296 .35948 L
.65526 .4014 L
.59756 .44332 L
.53987 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.35637 .22383 L
.42769 .22383 L
.49901 .22383 L
.52104 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.32592 .31756 L
.34795 .24974 L
.36999 .18191 L
.44131 .18191 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.27664 .38539 L
.29867 .31756 L
.32071 .24974 L
.39203 .24974 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .44332 L
.39723 .4014 L
.33954 .35948 L
.36157 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.1969 .35948 L
.21894 .29166 L
.24098 .22383 L
.31229 .22383 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .51115 L
.34795 .46923 L
.29026 .42731 L
.31229 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .57898 L
.29867 .53706 L
.24098 .49514 L
.26302 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.66368 .42731 L
.60598 .46923 L
.54829 .51115 L
.49059 .46923 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.1969 .27564 L
.21894 .20782 L
.24098 .13999 L
.31229 .13999 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .48524 L
.26822 .44332 L
.21052 .4014 L
.23256 .33358 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .55307 L
.21894 .51115 L
.16124 .46923 L
.18328 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.6144 .49514 L
.5567 .53706 L
.49901 .57898 L
.44131 .53706 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .52716 L
.1392 .48524 L
.08151 .44332 L
.10354 .37549 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.56512 .56296 L
.50742 .60488 L
.44973 .6468 L
.39203 .60488 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.51584 .63079 L
.45815 .67271 L
.40045 .71463 L
.34275 .67271 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.76224 .29166 L
.78428 .35948 L
.80631 .42731 L
.74862 .46923 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.40565 .29166 L
.42769 .22383 L
.44973 .156 L
.52104 .156 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.35637 .35948 L
.37841 .29166 L
.40045 .22383 L
.47177 .22383 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .35948 L
.39723 .31756 L
.33954 .27564 L
.36157 .20782 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.27664 .33358 L
.29867 .26575 L
.32071 .19792 L
.39203 .19792 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .42731 L
.34795 .38539 L
.29026 .34347 L
.31229 .27564 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .49514 L
.29867 .45322 L
.24098 .4113 L
.26302 .34347 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.58394 .4014 L
.52625 .44332 L
.46855 .48524 L
.41085 .44332 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.27664 .24974 L
.29867 .18191 L
.32071 .11408 L
.39203 .11408 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .4014 L
.26822 .35948 L
.21052 .31756 L
.23256 .24974 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .46923 L
.21894 .42731 L
.16124 .38539 L
.18328 .31756 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.53467 .46923 L
.47697 .51115 L
.41927 .55307 L
.36157 .51115 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .44332 L
.1392 .4014 L
.08151 .35948 L
.10354 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.48539 .53706 L
.42769 .57898 L
.36999 .62089 L
.31229 .57898 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.43611 .60488 L
.37841 .6468 L
.32071 .68872 L
.26302 .6468 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.71296 .35948 L
.735 .42731 L
.75704 .49514 L
.69934 .53706 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.35637 .22383 L
.37841 .156 L
.40045 .08818 L
.47177 .08818 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.32592 .31756 L
.26822 .27564 L
.21052 .23372 L
.23256 .1659 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.27664 .38539 L
.21894 .34347 L
.16124 .30155 L
.18328 .23372 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .44332 L
.39723 .48524 L
.33954 .52716 L
.28184 .48524 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.1969 .35948 L
.1392 .31756 L
.08151 .27564 L
.10354 .20782 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .51115 L
.34795 .55307 L
.29026 .59499 L
.23256 .55307 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .57898 L
.29867 .62089 L
.24098 .66281 L
.18328 .62089 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.66368 .42731 L
.68572 .49514 L
.70776 .56296 L
.65006 .60488 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.1969 .27564 L
.1392 .23372 L
.08151 .19181 L
.10354 .12398 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .48524 L
.26822 .52716 L
.21052 .56908 L
.15282 .52716 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .55307 L
.21894 .59499 L
.16124 .63691 L
.10354 .59499 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.6144 .49514 L
.63644 .56296 L
.65848 .63079 L
.60078 .67271 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .52716 L
.1392 .56908 L
.08151 .611 L
.02381 .56908 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.56512 .56296 L
.58716 .63079 L
.6092 .69862 L
.5515 .74054 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.51584 .63079 L
.53788 .69862 L
.55992 .76644 L
.50222 .80836 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.76224 .29166 L
.83356 .29166 L
.90487 .29166 L
.92691 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.35637 .35948 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .35948 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.27664 .33358 L
.34795 .33358 L
.36999 .4014 L
.39203 .46923 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .42731 L
.42769 .35948 L
.49901 .35948 L
.57032 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .49514 L
.37841 .42731 L
.44973 .42731 L
.52104 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.58394 .4014 L
.52625 .35948 L
.54829 .29166 L
.57032 .22383 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.27664 .24974 L
.34795 .24974 L
.36999 .31756 L
.39203 .38539 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .4014 L
.34795 .33358 L
.41927 .33358 L
.49059 .33358 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .46923 L
.29867 .4014 L
.36999 .4014 L
.44131 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.53467 .46923 L
.47697 .42731 L
.49901 .35948 L
.52104 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .44332 L
.21894 .37549 L
.29026 .37549 L
.36157 .37549 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.48539 .53706 L
.42769 .49514 L
.44973 .42731 L
.47177 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.43611 .60488 L
.37841 .56296 L
.40045 .49514 L
.42249 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.71296 .35948 L
.65526 .4014 L
.59756 .35948 L
.53987 .31756 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.35637 .22383 L
.42769 .22383 L
.44973 .29166 L
.47177 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.32592 .31756 L
.34795 .24974 L
.41927 .24974 L
.49059 .24974 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.27664 .38539 L
.29867 .31756 L
.36999 .31756 L
.44131 .31756 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .44332 L
.39723 .4014 L
.41927 .33358 L
.44131 .26575 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.1969 .35948 L
.21894 .29166 L
.29026 .29166 L
.36157 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .51115 L
.34795 .46923 L
.36999 .4014 L
.39203 .33358 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .57898 L
.29867 .53706 L
.32071 .46923 L
.34275 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.66368 .42731 L
.60598 .46923 L
.54829 .42731 L
.49059 .38539 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.1969 .27564 L
.21894 .20782 L
.29026 .20782 L
.36157 .20782 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .48524 L
.26822 .44332 L
.29026 .37549 L
.31229 .30767 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .55307 L
.21894 .51115 L
.24098 .44332 L
.26302 .37549 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.6144 .49514 L
.5567 .53706 L
.49901 .49514 L
.44131 .45322 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .52716 L
.1392 .48524 L
.16124 .41741 L
.18328 .34959 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.56512 .56296 L
.50742 .60488 L
.44973 .56296 L
.39203 .52104 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.51584 .63079 L
.45815 .67271 L
.40045 .63079 L
.34275 .58887 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.76224 .29166 L
.78428 .35948 L
.72658 .4014 L
.66888 .44332 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.40565 .29166 L
.42769 .22383 L
.49901 .22383 L
.57032 .22383 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.35637 .35948 L
.37841 .29166 L
.44973 .29166 L
.52104 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .35948 L
.39723 .31756 L
.41927 .24974 L
.44131 .18191 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.27664 .33358 L
.29867 .26575 L
.36999 .26575 L
.44131 .26575 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .42731 L
.34795 .38539 L
.36999 .31756 L
.39203 .24974 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .49514 L
.29867 .45322 L
.32071 .38539 L
.34275 .31756 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.58394 .4014 L
.52625 .44332 L
.46855 .4014 L
.41085 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.27664 .24974 L
.29867 .18191 L
.36999 .18191 L
.44131 .18191 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .4014 L
.26822 .35948 L
.29026 .29166 L
.31229 .22383 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .46923 L
.21894 .42731 L
.24098 .35948 L
.26302 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.53467 .46923 L
.47697 .51115 L
.41927 .46923 L
.36157 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .44332 L
.1392 .4014 L
.16124 .33358 L
.18328 .26575 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.48539 .53706 L
.42769 .57898 L
.36999 .53706 L
.31229 .49514 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.43611 .60488 L
.37841 .6468 L
.32071 .60488 L
.26302 .56296 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.71296 .35948 L
.735 .42731 L
.6773 .46923 L
.6196 .51115 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.35637 .22383 L
.37841 .156 L
.44973 .156 L
.52104 .156 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.32592 .31756 L
.26822 .27564 L
.29026 .20782 L
.31229 .13999 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.27664 .38539 L
.21894 .34347 L
.24098 .27564 L
.26302 .20782 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .44332 L
.39723 .48524 L
.33954 .44332 L
.28184 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.1969 .35948 L
.1392 .31756 L
.16124 .24974 L
.18328 .18191 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .51115 L
.34795 .55307 L
.29026 .51115 L
.23256 .46923 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .57898 L
.29867 .62089 L
.24098 .57898 L
.18328 .53706 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.66368 .42731 L
.68572 .49514 L
.62802 .53706 L
.57032 .57898 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.1969 .27564 L
.1392 .23372 L
.16124 .1659 L
.18328 .09807 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .48524 L
.26822 .52716 L
.21052 .48524 L
.15282 .44332 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .55307 L
.21894 .59499 L
.16124 .55307 L
.10354 .51115 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.6144 .49514 L
.63644 .56296 L
.57874 .60488 L
.52104 .6468 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .52716 L
.1392 .56908 L
.08151 .52716 L
.02381 .48524 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.56512 .56296 L
.58716 .63079 L
.52946 .67271 L
.47177 .71463 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.51584 .63079 L
.53788 .69862 L
.48018 .74054 L
.42249 .78246 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.76224 .29166 L
.83356 .29166 L
.85559 .35948 L
.87763 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.35637 .35948 L
.42769 .35948 L
.49901 .35948 L
.57032 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .35948 L
.47697 .29166 L
.49901 .22383 L
.52104 .156 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.27664 .33358 L
.34795 .33358 L
.41927 .33358 L
.49059 .33358 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .42731 L
.42769 .35948 L
.44973 .29166 L
.47177 .22383 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .49514 L
.37841 .42731 L
.40045 .35948 L
.42249 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.58394 .4014 L
.52625 .35948 L
.46855 .31756 L
.41085 .27564 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.27664 .24974 L
.34795 .24974 L
.41927 .24974 L
.49059 .24974 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .4014 L
.34795 .33358 L
.36999 .26575 L
.39203 .19792 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .46923 L
.29867 .4014 L
.32071 .33358 L
.34275 .26575 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.53467 .46923 L
.47697 .42731 L
.41927 .38539 L
.36157 .34347 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .44332 L
.21894 .37549 L
.24098 .30767 L
.26302 .23984 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.48539 .53706 L
.42769 .49514 L
.36999 .45322 L
.31229 .4113 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.43611 .60488 L
.37841 .56296 L
.32071 .52104 L
.26302 .47913 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.71296 .35948 L
.65526 .4014 L
.59756 .44332 L
.53987 .48524 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.35637 .22383 L
.42769 .22383 L
.49901 .22383 L
.57032 .22383 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.32592 .31756 L
.34795 .24974 L
.36999 .18191 L
.39203 .11408 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.27664 .38539 L
.29867 .31756 L
.32071 .24974 L
.34275 .18191 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .44332 L
.39723 .4014 L
.33954 .35948 L
.28184 .31756 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.1969 .35948 L
.21894 .29166 L
.24098 .22383 L
.26302 .156 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .51115 L
.34795 .46923 L
.29026 .42731 L
.23256 .38539 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .57898 L
.29867 .53706 L
.24098 .49514 L
.18328 .45322 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.66368 .42731 L
.60598 .46923 L
.54829 .51115 L
.49059 .55307 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.1969 .27564 L
.21894 .20782 L
.24098 .13999 L
.26302 .07216 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .48524 L
.26822 .44332 L
.21052 .4014 L
.15282 .35948 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .55307 L
.21894 .51115 L
.16124 .46923 L
.10354 .42731 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.6144 .49514 L
.5567 .53706 L
.49901 .57898 L
.44131 .62089 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .52716 L
.1392 .48524 L
.08151 .44332 L
.02381 .4014 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.56512 .56296 L
.50742 .60488 L
.44973 .6468 L
.39203 .68872 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.51584 .63079 L
.45815 .67271 L
.40045 .71463 L
.34275 .75655 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.76224 .29166 L
.78428 .35948 L
.80631 .42731 L
.82835 .49514 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.40565 .29166 L
.42769 .22383 L
.44973 .156 L
.47177 .08818 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.35637 .35948 L
.37841 .29166 L
.40045 .22383 L
.42249 .156 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .35948 L
.39723 .31756 L
.33954 .27564 L
.28184 .23372 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.27664 .33358 L
.29867 .26575 L
.32071 .19792 L
.34275 .13009 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .42731 L
.34795 .38539 L
.29026 .34347 L
.23256 .30155 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .49514 L
.29867 .45322 L
.24098 .4113 L
.18328 .36938 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.58394 .4014 L
.52625 .44332 L
.46855 .48524 L
.41085 .52716 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.27664 .24974 L
.29867 .18191 L
.32071 .11408 L
.34275 .04626 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .4014 L
.26822 .35948 L
.21052 .31756 L
.15282 .27564 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .46923 L
.21894 .42731 L
.16124 .38539 L
.10354 .34347 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.53467 .46923 L
.47697 .51115 L
.41927 .55307 L
.36157 .59499 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .44332 L
.1392 .4014 L
.08151 .35948 L
.02381 .31756 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.48539 .53706 L
.42769 .57898 L
.36999 .62089 L
.31229 .66281 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.43611 .60488 L
.37841 .6468 L
.32071 .68872 L
.26302 .73064 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.71296 .35948 L
.735 .42731 L
.75704 .49514 L
.77907 .56296 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.33433 .29166 L
.35637 .22383 L
.37841 .156 L
.40045 .08818 L
.42249 .02035 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .35948 L
.32592 .31756 L
.26822 .27564 L
.21052 .23372 L
.15282 .19181 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .42731 L
.27664 .38539 L
.21894 .34347 L
.16124 .30155 L
.10354 .25963 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.51263 .4014 L
.45493 .44332 L
.39723 .48524 L
.33954 .52716 L
.28184 .56908 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .4014 L
.1969 .35948 L
.1392 .31756 L
.08151 .27564 L
.02381 .23372 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.46335 .46923 L
.40565 .51115 L
.34795 .55307 L
.29026 .59499 L
.23256 .63691 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.41407 .53706 L
.35637 .57898 L
.29867 .62089 L
.24098 .66281 L
.18328 .70473 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.64164 .35948 L
.66368 .42731 L
.68572 .49514 L
.70776 .56296 L
.72979 .63079 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .35948 L
.2546 .31756 L
.1969 .27564 L
.1392 .23372 L
.08151 .19181 L
.02381 .14989 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.44131 .4014 L
.38361 .44332 L
.32592 .48524 L
.26822 .52716 L
.21052 .56908 L
.15282 .611 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.39203 .46923 L
.33433 .51115 L
.27664 .55307 L
.21894 .59499 L
.16124 .63691 L
.10354 .67883 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.57032 .35948 L
.59236 .42731 L
.6144 .49514 L
.63644 .56296 L
.65848 .63079 L
.68052 .69862 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.36999 .4014 L
.31229 .44332 L
.2546 .48524 L
.1969 .52716 L
.1392 .56908 L
.08151 .611 L
.02381 .65292 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.49901 .35948 L
.52104 .42731 L
.54308 .49514 L
.56512 .56296 L
.58716 .63079 L
.6092 .69862 L
.63124 .76644 L
s
.33433 .29166 m
.40565 .29166 L
.42769 .35948 L
.44973 .42731 L
.47177 .49514 L
.4938 .56296 L
.51584 .63079 L
.53788 .69862 L
.55992 .76644 L
.58196 .83427 L
s
.33433 .29166 m
.40565 .29166 L
.47697 .29166 L
.54829 .29166 L
.6196 .29166 L
.69092 .29166 L
.76224 .29166 L
.83356 .29166 L
.90487 .29166 L
.97619 .29166 L
s
0 0 m
1 0 L
1 .85462 L
0 .85462 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[171]:=",
  ImageSize->{288, 246.125},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000mR000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00N@3oool00`000000oooo0?ooo`2T0?ooo`00N@3oool00`000000oooo0?ooo`2T0?ooo`00
N03oool00`000000oooo0?ooo`2U0?ooo`00N03oool00`000000oooo0?ooo`2U0?ooo`00N03oool0
0`000000oooo0?ooo`2U0?ooo`00M`3oool00`000000oooo0?ooo`2V0?ooo`00M`3oool00`000000
oooo0?ooo`2V0?ooo`00M`3oool00`000000oooo0?ooo`2V0?ooo`00HP3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0:L0oooo001R0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0Y`3oool00640oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2X0?oo
o`00H@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0:P0oooo001Q0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0Z03oool00600oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`2Y0?ooo`00H03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0:T0oooo001;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`2Y0?ooo`00B`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0ZP3oool004X0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0:X0oooo001:0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`2Z0?ooo`00BP3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0Z`3oool004T0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0A0?oooaH00000V03oool004T0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0UP3oool004T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0U`3oool003@0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`2G0?ooo`00=03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo09L0oooo000c0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0V03oool003<0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2H0?ooo`00<`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0180oooo5@00000D0?ooo`030000003oool0oooo09P0oooo
000b0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0@0?ooo`8000004`3oool00`000000oooo0?ooo`2I0?ooo`00<P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo09T0oooo000M0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`2I0?ooo`007@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0V@3oool001`0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
VP3oool001`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0VP3oool001`0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0VP3oool0
01/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?oooaD000001`3oool00`00
0000oooo0?ooo`090?ooo`8000004`3oool00`000000oooo0?ooo`2K0?ooo`006`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`2K0?ooo`001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo09/0oooo
00070?ooo`8000004@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo0P00
000C0?ooo`030000003oool0oooo09`0oooo00090?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo:P00002:
0?ooo`002P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo08P0oooo000;0?ooo`80
00003@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02@3oool2000000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000A0?ooo`03
0000003oool0oooo08T0oooo000=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
4P3ooolE000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000
003oool000000140oooo00<000000?ooo`3oool0R@3oool000h0oooo0P0000090?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000A0?ooo`030000003o
ool0oooo08T0oooo000@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02@3oool2000000/0oooo00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`00000@0?ooo`030000003oool0oooo08X0oooo000A0?ooo`8000001@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool2
000000/0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000l0oooo00<0
00000?ooo`3oool0RP3oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`8000001`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0RP3o
ool001@0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool2000000L0oooo00<000000?ooo`3oool02@3ooolZ000000@0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`2:0?ooo`005@3oool3000001@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool2000000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0R`3oool001L0oooo00<000000?oo
o`3oool04@3oool2000000H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00T0oooo0P0000070?ooo`050000003oool0oooo0?ooo`0000001`3oool0
0`000000oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo08/0oooo000H0?ooo`8000004@3oool30000
00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2;0?ooo`006P3oool00`000000
oooo0?ooo`0>0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3ooolE0000
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0S03oool001/0oooo00<000000?ooo`3oool03@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00T0oooo0P0000070?ooo`050000003oool0oooo0?ooo`0000001`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2<0?ooo`00703o
ool2000000d0oooo00<000000?ooo`3oool00P3oool3000000/0oooo0P0000070?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0S03oool001d0oooo0P00000;0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3ooolZ000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`2=0?ooo`007@3oool010000000oooo0000000000090?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`00000000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool2000000L0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2=0?oo
o`00703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool0000000L0oooo0P0000070?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool2000000D0oooo0P0000040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08d0oooo000L0?oo
o`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool2000000D0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
000000L0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo0P0000050?ooo`800000103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2=0?ooo`00703oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool20000
00<0oooo00<000000?ooo`3oool01@3oool2000000/0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2>0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo008000001`3ooolE0000
00@0oooo00<000000?ooo`3oool0103ooolo000007`0oooo000K0?ooo`030000003oool0oooo00P0
oooo0`0000070?ooo`030000003oool0oooo00L0oooo0`0000080?ooo`050000003oool0oooo0?oo
o`0000001`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`8000001P3oool2000000<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1j0?ooo`001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P000003
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`<000002P3oool00`000000oooo0?oo
o`050?ooo`030000003oool000000140oooo00<000000?ooo`3oool0N`3oool000L0oooo0P00000A
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`00000000001@3oool01@000000oooo0?oo
o`3oool0000000L0oooo0`0000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
103oool2000000L0oooo00D000000?ooo`000000oooo000000070?ooo`030000003oool0000000X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000A0?ooo`030000003oool0oooo07/0
oooo00090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool2000000<0oooo
00D000000?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0103oool2000000H0oooo00H0
00000?ooo`3oool000000?ooo`0000070?ooo`030000003oool0000000X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0000000A0?ooo`030000003oool0oooo07/0oooo000:0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00H000000?ooo`3oool0oooo0000003oool2000000D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00800000
1`3oool200000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`1l0?ooo`002`3oool2000000d0oooo
00<000000?ooo`3oool0403oool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`<00000103oool00`000000oooo000000040?ooo`800000103oool3000000@0oooo
00<000000?ooo`3oool0103oool2000000L0oooo00D000000?ooo`3oool0oooo000000070?ooo`05
0000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo
0?ooo`0000003`3oool00`000000oooo0?ooo`1l0?ooo`003@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0180oooo5P0000030?ooo`040000003oool0oooo000000@0oooo?P000004
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0O03oool000h0oooo0P0000090?oo
o`030000003oool0oooo0180oooo00D000000?ooo`000000oooo000000070?ooo`030000003oool0
oooo00D0oooo00H000000?ooo`00000000000?ooo`0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool400000080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`040000003oool0oooo0?ooo`8000001P3oool2000000@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1m0?ooo`00403oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0140oooo00@000000?ooo`3oool0oooo0P0000070?ooo`030000003oool0oooo00@0
oooo0P0000030?ooo`80000000<0oooo0000003oool00`3oool2000000H0oooo0P0000020?ooo`80
00001P3oool3000000H0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo07d0oooo000A0?ooo`8000001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool2000000D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`@00000103oool00`000000
oooo0?ooo`050?ooo`030000003oool000000080oooo0P0000050?ooo`030000003oool0000000H0
oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`1m0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo0P00000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo0P0000001`3oool000000?ooo`3o
ool000000?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0O@3oool001@0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000<0oooo
00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3oool00P0000020?ooo`800000
1P3ooolZ000000@0oooo00<000000?ooo`3oool0103oool2000000L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`1n0?ooo`005@3oool3000000T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool00`0000070?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool3000000L0oooo00@000000?ooo`3o
ool0oooo0P0000040?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo07h0oooo000G0?ooo`030000003oool0oooo00P0oooo0P0000070?ooo`8000000`3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
oolE000000L0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo00000080
oooo00<000000?ooo`3oool0103oool2000000<0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo07h0oooo000H0?ooo`8000002P3oool00`000000oooo0?ooo`040?oo
o`<000000P3oool010000000oooo0?ooo`0000050?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo100000020?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000070?ooo`<000000`3oool00`000000oooo000000020?ooo`030000003oool00000
00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
07l0oooo000J0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`060000003oool0oooo0000
003oool000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000103o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo008000000`3oool010000000oooo
0?ooo`3oool2000000H0oooo0P0000020?ooo`030000003oool000000080oooo00D000000?ooo`00
0000oooo000000070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1o0?ooo`006`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`0000090?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`040000003oool000000000
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool00000
000000<0oooo0P0000070?ooo`060000003oool0oooo0?ooo`000000oooo0P0000030?ooo`030000
003oool0000000H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo07l0oooo000L0?ooo`8000002P3oool2000000030?ooo`000000oooo0080oooo1000
000:0?ooo`<00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo
0P0000040?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`<000000`3oool2000000H0oooo
0P0000040?ooo`<00000103oool00`000000oooo0?ooo`040?ooo`8000002`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0800oooo000M0?ooo`8000002`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000/0oooof`0000070?ooo`007@3oool010000000oooo0000
000000090?ooo`8000000`3oool010000000oooo0000003oool2000000T0oooo00H000000?ooo`00
000000000?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2
000000040?ooo`000000oooo000000L0oooo00<000000?ooo`3oool01@3oool4000000030?ooo`00
0000000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000006000000H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`00703oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000P0000020?ooo`050000003oool0
oooo0?ooo`0000001`3oool2000000<0oooo0P0000020?ooo`040000003oool0oooo0?ooo`800000
1P3oool010000000oooo0000003oool2000000H0oooo0P0000060?ooo`<000000P3oool3000000D0
oooo0`0000020?ooo`030000003oool0oooo0080000000H0oooo00000000000000000?ooo`000004
0?ooo`<000002P3oool00`000000oooo0?ooo`050?ooo`030000003oool000000140oooo00<00000
0?ooo`000000503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`00703oool00`000000oooo0?ooo`030?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P000005
0?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`000000oooo0`0000050?ooo`8000001P3oool01@000000oooo0?oo
o`000000oooo00<000001@3oool00`000000oooo000000020?ooo`060000003oool0oooo0000003o
ool000000P3oool3000000@0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`050?oo
o`030000003oool000000140oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?oo
o`00703oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool4000000@0oooo00<000000?ooo`3oool01@3oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool00P3oool2000000H0oooo00L000000?ooo`3oool000000?ooo`00
0000oooo00800000103oool00`000000oooo000000020?ooo`030000003oool0oooo00<000000P3o
ool00`000000oooo000000040?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0000000A0?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3o
ool001/0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000H0oooo0P00
00070?ooo`030000003oool0oooo008000000`3oool010000000oooo0?ooo`3ooolF00000080oooo
0P0000060?ooo`8000000P3oool300000080oooo0P0000020?ooo`8000000P3oool200000080oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo008000000P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000?
0?ooo`050000003oool0oooo0?ooo`000000503oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?ooo`006`3oool0
0`000000oooo0?ooo`080?ooo`<000001`3oool00`000000oooo000000070?ooo`<00000103oool0
10000000oooo0?ooo`3oool5000000L0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000
003oool0000000<000001P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`00
0000oooo0`0000030?ooo`D000000`3oool2000000<0oooo100000030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000l0oooo00D00000
0?ooo`3oool0oooo0000000D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00060?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo008000001`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo0`00
00060?ooo`8000000`3ooolZ000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo
00070?ooo`8000004@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool2000000D0oooo00H000000?ooo`00000000000?ooo`0000030?ooo`04
0000003oool0oooo0?ooo`<000001@3oool300000080oooo0P0000000`3oool000000?ooo`020?oo
o`@000000P3oool00`000000oooo000000030?ooo`<00000103oool01P000000oooo0000003oool0
00000?ooo`<0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`80000000<0
oooo0000000000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0`00
00030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01L0oooo00090?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool2000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`060000003oool0oooo0?ooo`00
0000oooo0`0000030?ooo`030000003oool0oooo00@0000000<0oooo0000003oool00P3oool20000
0080oooo0P0000020?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`030000
003oool000000080oooo100000000`3oool000000?ooo`020?ooo`8000001@3oool2000000<0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool05`3oool000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0?0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`3o
ool200000080oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo0P0000030?ooo`06
0000003oool0oooo0000003oool000000P3oool00`000000oooo000000030?ooo`060000003oool0
00000?ooo`000000oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00@0oooo
0P0000040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool01@3oool01`000000oooo
0?ooo`3oool000000?ooo`0000003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool05`3oool000/0oooo0P00000=0?ooo`030000003oool0oooo0100
oooo0P0000040?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000?ooo`020?ooo`03
0000003oool0000000800000103oool00`000000oooo0?ooo`020?ooo`@000000`3oool4000000@0
oooo00<000000?ooo`3oool00P3oool5000000<0oooo00<000000?ooo`000000103oool300000080
oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`040?ooo`8000001@3oool20000
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`8000003@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool000d0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?oooaH000000`3oool00`000000
oooo0?ooo`050?ooocl000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool05P3oool000h0oooo0P0000090?ooo`030000003oool0oooo0180oooo
00D000000?ooo`000000oooo000000070?ooo`8000000`3oool01@000000oooo0?ooo`000000oooo
0080000000<0oooo0000003oool01P3oool3000000040?ooo`00000000000?ooo`@0000000<0oooo
0000000000000`3oool4000000050?ooo`00000000000?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001`3oool2
000000H0oooo100000000`3oool000000?ooo`060?ooo`030000003oool0oooo00D0oooo0`000009
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F
0?ooo`00403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00@000000?oo
o`3oool0oooo0P0000070?ooo`030000003oool00000008000000P3oool2000000<0oooo0P000006
0?ooo`80000000@0oooo00000000000000000P3oool200000080oooo0P0000040?ooo`030000003o
ool00000008000000P3oool2000000<0oooo00<000000?ooo`3oool00P0000030?ooo`030000003o
ool0oooo00<0000000<0oooo0000000000001`3oool2000000D0oooo00<000000?ooo`0000000P3o
ool2000000L0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`004@3o
ool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0080oooo0P0000050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool300000080oooo00@000000?ooo`3oool00000103oool2000000050?ooo`000000oooo0000
003oool00`000000203oool00000000000000000oooo0000003oool000000P3oool300000080oooo
00@000000?ooo`3oool000000`3oool020000000oooo0?ooo`3oool000000?ooo`000000oooo0`00
00050?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool000000?ooo`03000000D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02000000D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo000C0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000d0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool3000000@0
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`060000003oool0oooo0?ooo`000000oooo
0`0000000`3oool000000?ooo`02000000040?ooo`000000oooo00000080oooo00<000000?ooo`00
00000P3oool400000080oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool001@0
oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool0103oool20000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool00`000000oooo0?ooo`02
000000070?ooo`000000oooo0000003oool000000?ooo`02000000030?ooo`00000000000080oooo
0`0000020?ooo`80000000@0oooo00000000000000000`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
2@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo000E0?ooo`<000002@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool000000?ooo`03000000L0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`@00000103oool01@000000
oooo0?ooo`000000oooo00D000000`3oool3000000<0oooo0P0000040?ooo`@000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo0P0000040?ooo`<00000103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo0`00000;0?ooo`030000003oool0oooo00<0oooo0`00
000<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0503oool001L0oooo00<00000
0?ooo`3oool0203oool2000000L0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0H000000<0oooo00@000000?ooo`3oool00000
0`3ooolo000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0503oool001P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`050000003oool0oooo0?ooo`00
00000`3oool200000080oooo00@000000?ooo`3oool00000103oool2000000<0oooo00<000000?oo
o`3oool00P0000020?ooo`8000001`3oool200000080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`800000203oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo
0P0000080?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`030000003oool0oooo00P0oooo
0P0000070?ooo`030000003oool0oooo00P0oooo0P00000C0?ooo`8000004P3oool2000002X0oooo
000I0?ooo`8000002P3oool2000000@0oooo00H000000?ooo`00000000000?ooo`0000020?ooo`03
0000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo0080oooo00H000000?ooo`00
000000000?ooo`0000020?ooo`030000003oool0oooo00<000000P3oool010000000oooo0?ooo`3o
ool2000000070?ooo`00000000000?ooo`000000oooo000000020?ooo`@000001P3oool5000000<0
oooo00<000000?ooo`000000100000080?ooo`<000000P3oool00`000000oooo0?ooo`0300000003
0?ooo`000000oooo00L0oooo0P0000050?ooo`<0000000<0oooo0000003oool01`3oool2000000H0
oooo0P0000020?ooo`030000003oool0oooo00D0oooo0P0000060?ooo`8000000P3oool00`000000
oooo0?ooo`0>0?ooo`8000000P3oool00`000000oooo0?ooo`0=0?ooo`8000000P3oool00`000000
oooo0?ooo`0W0?ooo`006`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`00
00000`3oool01P000000oooo0?ooo`000000oooo000000L0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`3oool200000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool200000080oooo00<000000?ooo`3oool00P3oool20000
00H0oooo0P0000020?ooo`8000000P3oool200000080oooo00<000000?ooo`0000002P3oool01P00
0000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`0000002P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0W0?ooo`00703o
ool00`000000oooo0?ooo`090?ooo`80000000<0oooo0000003oool00P3oool2000000040?ooo`00
0000oooo0?ooo`8000001P3oool3000000@0oooo00@000000?ooo`3oool0oooo0`0000000`3oool0
00000?ooo`020?ooo`040000003oool00000000000@0oooo00<000000?ooo`3oool00P3oool20000
00030?ooo`000000oooo0080oooo100000050?ooo`040000003oool000000?ooo`<0000000<0oooo
0000003oool00P3oool3000000X0oooo0P0000000`3oool00000000000030?ooo`030000003oool0
000000/0oooo00<000000?ooo`0000000`3oool00`000000oooo0000000;0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool09`3oool001d0oooo0P00000;0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`040?ooob/00000
0`3oool00`000000oooo0?ooo`02000000<0oooo00@000000?ooo`3oool0oooo0P0000000`3oool0
0000000000080?ooo`030000003oool0oooo008000000`3oool010000000oooo0?ooo`00000<0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`8000001P3oool0
0`000000oooo0?ooo`090?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`8000001P3oool0
0`000000oooo0?ooo`090?ooo`8000001P3oool00`000000oooo0?ooo`0W0?ooo`007@3oool00`00
0000oooo0000000:0?ooo`8000000`3oool01@000000oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P0000030?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`0300000080oooo00<00000
0?ooo`3oool00P0000020?ooo`<000000P3oool200000080oooo0P0000070?ooo`060000003oool0
00000000003oool000000P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0V0?ooo`00703oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`0000000P0000020?ooo`040000003oool0oooo000000@0oooo0P0000020?ooo`8000000P3o
ool00`000000oooo000000040?ooo`050000003oool000000000003oool00`0000020?ooo`030000
003oool0000000<00000103oool01@000000oooo0?ooo`000000oooo00@0000000P0oooo0000003o
ool000000?ooo`000000oooo000000<0oooo0`0000000`3oool000000?ooo`03000000<0oooo00<0
00000?ooo`0000001P3oool2000000070?ooo`000000oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00H0oooo0P0000030?ooo`<000000`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`80
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool09P3oool001`0oooo00<000000?ooo`3oool00P3oool2000000H0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000030?ooo`800000103oool00`000000oooo000000040?ooo`80
00000`3oool010000000oooo0?ooo`0000040?ooo`060000003oool0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`020?oooaD000000P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo0?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo00<0oooo
0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool01@000000oooo
0?ooo`3oool0000000L0oooo0P0000060?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo00D0oooo0P00000;0?ooo`03
0000003oool0oooo00@0oooo0P00000;0?ooo`030000003oool0oooo02H0oooo000L0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0`0000020?ooo`040000
003oool0oooo000000D0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3o
ool00`000000oooo000000040?ooo`@000000P3oool01P000000oooo0000003oool000000?ooo`80
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01P000000oooo0?ooo`3o
ool000000?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
02D0oooo000K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`8000001P3oool010000000oooo0?ooo`3oool300000080oooo00P000000?oo
o`3oool0oooo0000003oool000000?ooo`8000001P3oool2000000040?ooo`000000oooo00000080
oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo0P0000020?oo
o`030000003oool000000080oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool2
000000030?ooo`000000oooo00<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003o
ool0oooo02D0oooo000K0?ooo`030000003oool0oooo00L0oooo0P0000020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`0000001P3oool2000000040?ooo`00000000000?ooo`<00000103o
ool2000000030?ooo`000000000000H0oooo00@000000?ooo`000000oooo0P0000030?ooo`800000
0P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000P0000001@3oool0
0000000000000000oooo008000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo10000000
103oool000000000003oool200000080oooo00D000000?ooo`3oool0oooo000000040?ooo`<00000
0P3oool2000000T0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`8000003P3oool300000080
oooo0P00000=0?ooo`<000000P3oool200000100oooo00@000000?ooo`0000000000403oool00`00
0000oooo0?ooo`0U0?ooo`006`3oool00`000000oooo0?ooo`090?ooo`8000001`3oool010000000
oooo0?ooo`0000070?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@000001`3oool00`00
0000oooo0?ooo`02000000D0oooo0`0000040?ooo`040000003oool0oooo00000080oooo10000002
0?ooo`80000000<0oooo0000000000000`3oool00`000000oooo0?ooo`040?ooo`<000000`3oool0
10000000oooo0000000000040?ooo`030000003oool0oooo00<0oooo1000000:0?ooo`030000003o
ool0oooo00@0oooo0`00000B0?ooo`<000004@3oool3000001<0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0T0?ooo`001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`8000001P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000060?ooo`80
00000`3oool[000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`8000004`3oool00`000000oooo0?ooo`0T0?ooo`001`3oool200000140oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
0000103oool01P000000oooo000000000000oooo00000080oooo0`0000020?ooo`040000003oool0
0000000000@0oooo0`0000020?ooo`<000000P3oool010000000oooo0?ooo`3oool2000000050?oo
o`00000000000?ooo`0000000`3oool5000000030?ooo`000000oooo00<0oooo00@000000?ooo`3o
ool000001P3oool400000080oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`05
0?ooo`D000001@3oool200000080oooo00<000000?ooo`3oool0103oool200000180oooo0`00000A
0?ooo`<00000503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02@0oooo00090?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool2000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000@0oooo00@0
00000?ooo`3oool000000P3oool2000000<0oooo00<000000?ooo`3oool00P0000000`3oool00000
0?ooo`02000000H0oooo0P0000020?ooo`090000003oool0oooo0000003oool000000?ooo`000000
oooo008000001@3oool2000000D0oooo0`0000000`3oool000000?ooo`02000000H0oooo0P000005
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool2000000D0oooo0P00
00000`3oool000000?ooo`0@0?ooo`040000003oool0oooo00000100oooo00@000000?ooo`3oool0
0000503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02@0oooo000:0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo000000040?ooo`030000
003oool0oooo0080oooo0P0000000`3oool000000?ooo`020?ooo`8000001@3oool00`000000oooo
000000040?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo000000020?ooo`<00000
103oool200000080oooo00<000000?ooo`0000000P3oool010000000oooo0000003oool3000000D0
oooo0P0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`00000000001@3oool2
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02<0oooo000;0?oo
o`800000303oool00`000000oooo0?ooo`0A0?oooaH00000103oool2000000D0oooo0P0000040?oo
o`@0000000<0oooo0000003oool00P0000030?ooo`H000000`3oool01@000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`0000000`0000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool3000000030?ooo`000000oooo
00@0oooo00<000000?ooo`3oool02`3oool2000000D0oooo00<000000?ooo`3oool02P3oool20000
00D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
02<0oooo000=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool200000080
oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool00P0000030?ooo`03
0000003oool0000000D0oooo0P0000020?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`03
0000003oool0oooo008000000`3oool010000000oooo0?ooo`3oool2000000<0oooo00H000000?oo
o`3oool0oooo0000003oool300000080oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`8000001P3oool00`000000oooo0?ooo`030?oo
o`060000003oool0oooo0?ooo`000000oooo0P0000060?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02<0oooo000>
0?ooo`8000002@3oool00`000000oooo0?ooo`0A0?ooo`060000003oool0oooo0000003oool00000
1`3oool00`000000oooo0000000200000080oooo00<000000?ooo`3oool00P0000001@3oool00000
0?ooo`3oool0000000@0oooo00<000000?ooo`0000000P0000030?ooo`<000000`3oool700000005
0?ooo`00000000000?ooo`0000000`3oool2000000@0oooo0`0000000`3oool000000?ooo`020?oo
o`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool3000000030?ooo`0000000000
0080oooo0P0000050?ooo`030000003oool0oooo00<0oooo0`000000103oool000000?ooo`3oool2
000000D0oooo00<000000?ooo`3oool01`3oool2000000T0oooo00<000000?ooo`3oool01P3oool2
000000T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0280oooo000@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0=0?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`00
0000oooo0080oooo0P0000030?ooo`80000000<0oooo0000003oool00`3oool2000000030?ooo`00
0000oooo00<0oooo00<000000?ooo`3oool00P3ooolZ000000L0oooo0P0000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool2000000/0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0R0?ooo`004@3oool2000000D0oooo00<000000?ooo`3oool00`3oool2
000000d0oooo00@000000?ooo`3oool0oooo0`0000050?ooo`030000003oool0oooo00<0oooo0`00
00040?ooo`<000000P3oool010000000oooo0000000000030?ooo`<000000P3oool200000080oooo
0P0000000`3oool0000000000003000000@0oooo0`0000020?ooo`8000001@3oool3000000<0oooo
00<000000?ooo`0000000P000000103oool000000000000000050?ooo`@000001P3oool5000000H0
oooo0`0000060?ooo`80000000<0oooo0000000000001P3oool4000000P0oooo0`0000050?ooo`80
00002`3oool200000180oooo0`00000h0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3o
ool00P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool4000000@0oooo00<000000?oo
o`0000000P3oool2000000<0oooo00<000000?ooo`3oool0100000040?ooo`040000003oool0oooo
0?ooo`<000000P3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0`0000000`3oool000000?ooo`030?ooo`04
0000003oool0oooo0?ooo`8000001@3oool200000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00T0oooo0P0000020?ooo`030000003oool0oooo00h0oooo00D00000
0?ooo`3oool0oooo0000000g0?ooo`00503oool01@000000oooo0?ooo`3oool0000000P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`<0000000<0oooo0000003oool00P3oool3000000<0oooo00@000000?ooo`00
000000000P3oool5000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?oo
o`070000003oool0oooo0000003oool000000?ooo`02000000050?ooo`000000oooo0?ooo`000000
1P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=@3oool001D0oooo0`00000:
0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`000007
0?ooo`030000003oool0oooo00<00000103oool4000000<0oooo0P0000030?ooo`H000000`3oool3
00000080oooo0`0000040?ooo`<0000000<0oooo0000000000001`3oool2000000030?ooo`000000
000000<0oooo1@0000080?ooo`@000000`3oool3000000030?ooo`000000000000P0oooo00<00000
0?ooo`000000103oool2000000030?ooo`000000000000P0oooo100000050?ooo`<000002`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo0P0000050?ooo`030000003oool0
oooo03D0oooo000G0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool20000
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo5P0000030?ooo`040000003oool0oooo000000@0oooo0P0000020?ooo`8000000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool000000080oooo0P0000030?ooo`030000003oool0
oooo008000002P3oool2000000<0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`<000001P3o
ool00`000000oooo0?ooo`090?ooo`8000001P3oool2000000X0oooo0P0000070?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0d0?ooo`00603oool2
000000/0oooo0P0000040?ooo`<000000P3oool00`000000oooo0?ooo`060?ooo`800000103oool0
0`000000oooo0?ooo`030?ooo`<0000000<0oooo0000003oool00`3oool01@000000oooo0?ooo`00
0000oooo00<000000P3oool2000000050?ooo`000000oooo0?ooo`0000000`3oool2000000030?oo
o`000000oooo00@0000000<0oooo0000000000000`0000050?ooo`D0000000T0oooo0000003oool0
oooo0000003oool000000?ooo`000000203oool200000080oooo0P0000000`3oool000000?ooo`03
000000T0oooo00D000000?ooo`3oool0oooo000000030?ooo`<000002@3oool200000080oooo0P00
00050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`8000002@3oool00`000000oooo0?ooo`0d0?ooo`006P3oool00`000000oooo0?ooo`0:
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0?ooo`80
00001@3oool3000000<0oooo100000030?ooo`030000003oool0000000<0oooo00@000000?ooo`00
000000000`3oool300000080oooo00@000000?ooo`3oool00000103oool3000000040?ooo`000000
oooo0?ooo`@000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0`00
00020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool001/0oooo00<00000
0?ooo`3oool02P3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00`3oool2
000000D0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`3oool3000000D0oooo
0P0000030?ooo`@00000103oool2000000<0oooo00@000000?ooo`00000000000`3oool3000000<0
oooo00<000000?ooo`3oool00P0000000`3oool00000000000020?ooo`030000003oool0oooo0080
oooo0`0000030?ooo`030000003oool0oooo0080oooo0P0000070?ooo`<000000`3oool00`000000
oooo0?ooo`030?ooo`8000001`3oool2000000<0oooo00<000000?ooo`3oool00`3oool2000000P0
oooo0P0000030?ooo`030000003oool0oooo00<0oooo0P00000<0?ooo`030000003oool0oooo00<0
oooo0P00000=0?ooo`030000003oool0oooo03<0oooo000L0?ooo`800000303oool00`000000oooo
0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`8000001@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000`0000020?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo00000002
0?ooo`<0000000@0oooo000000000000oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000
203oool200000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`80
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00X0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0c0?ooo`007@3oool2000000/0oooo0P0000030?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00`3oool2000000<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P00
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P0000020?ooo`030000003o
ool0oooo00<000000`3oool3000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
0002000000<0oooo0P0000001@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo00000100oooo00<000000?oo
o`3oool0<`3oool001`0oooo00<000000?ooo`3oool00P0000090?ooo`030000003oool000000080
0000103oool2000000@0oooo0P0000030?ooo`060000003oool000000000003oool00000103oool0
0`000000oooo0?ooo`020?ooo`<0000000<0oooo0000003oool00P3oool00`000000oooo00000002
0?ooo`<00000103oool3000000030?ooo`00000000000080oooo0P0000030?ooo`D000000P3oool4
000000040?ooo`000000oooo0?ooo`8000000`3oool5000000L0oooo0P0000020?ooo`030000003o
ool0oooo0080oooo0P0000000`3oool00000000000060?ooo`8000001`3oool500000100oooo0P00
00000`3oool000000000000A0?ooo`<000004@3oool00`000000oooo0?ooo`0c0?ooo`00703oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`800000103ooolF
000000<0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0000000@0oooo0P000006
0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0b0?ooo`00703oool00`000000oooo0?ooo`030?oo
o`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P0000040?oo
o`800000103oool300000080oooo00<000000?ooo`3oool0103oool3000000D0oooo0`0000030?oo
o`<0000000<0oooo0000003oool0100000020?ooo`040000003oool0oooo0?ooo`D0000000@0oooo
0000003oool000000P3oool300000080oooo00@000000?ooo`3oool0oooo0P0000000`3oool00000
0?ooo`03000000<0oooo100000020?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`800000
2`3oool00`000000oooo0000000A0?ooo`<00000503oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0380oooo000K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`8000000`3o
ool01P000000oooo0?ooo`000000oooo000000D0oooo00@000000?ooo`3oool0oooo0P0000030?oo
o`060000003oool0oooo0000003oool000000`3oool3000000@0oooo00<000000?ooo`000000103o
ool3000000<0oooo0P0000000`3oool000000?ooo`020?ooo`<00000103oool200000080oooo00H0
00000?ooo`3oool000000?ooo`0000040?ooo`030000003oool0000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`090?ooo`8000000P3oool00`000000oooo0?ooo`0>0?oo
o`040000003oool0oooo000001@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b
0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000203oool0
0`000000oooo0?ooo`040?ooo`060000003oool0oooo0?ooo`000000oooo0`0000040?ooo`030000
003oool0oooo0080oooo0P0000060?ooo`040000003oool0oooo000000<0oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0`0000050?oo
o`8000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo008000001@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<@3o
ool001/0oooo00<000000?ooo`3oool0203oool3000000X0oooo00<000000?ooo`3oool0103oool3
000000@0oooo00<000000?ooo`3oool00P3oool3000000030?ooo`0000000000008000001P3oool0
0`000000oooo000000040?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`02
0?ooo`D000000`3oool3000000050?ooo`00000000000?ooo`000000103oool01@000000oooo0000
003oool0000000@0oooo1@0000020?ooo`030000003oool0oooo0080oooo1@0000050?ooo`<00000
2`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P0000050?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0a0?ooo`001P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool2000000H0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo000000040?ooo`8000000`3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00H000000?ooo`3oool0oooo0000003oool2000000<0oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`060000003oool0oooo0?ooo`000000oooo0`0000060?ooo`030000003oool0oooo
00<0oooo00H000000?ooo`3oool0oooo0000003oool2000000H0oooo00<000000?ooo`3oool02@3o
ool2000000L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0a0?ooo`001`3oool2
00000140oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0
000000H0oooo0P000000103oool000000?ooo`3oool3000000040?ooo`00000000000?ooo`800000
0`3oool010000000oooo0000000000020?ooo`030000003oool000000080oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`D000000P3oool2000000030?ooo`000000oooo00<0
00001@3oool3000000030?ooo`000000oooo0080oooo00@000000?ooo`3oool0oooo0P0000000`3o
ool000000?ooo`040?ooo`D000000P3oool2000000D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0`0?ooo`002@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo0P0000070?ooo`050000003oool0oooo0?oo
o`0000001`3oool2000000@0oooo0P0000050?ooo`040000003oool0oooo0?ooo`80000000@0oooo
0000003oool000000P3oool400000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`<000000P3ooolF000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo0P00000;0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000000D0oooo0P000004
0?ooo`8000001P3oool2000000<0oooo00<000000?ooo`000000103oool300000080oooo00<00000
0?ooo`3oool00`3oool2000000030?ooo`000000oooo00@0oooo0`0000020?ooo`030000003oool0
oooo00@0oooo100000050?ooo`80000000@0oooo00000000000000001@3oool2000000030?ooo`00
0000oooo00D0oooo0P0000000`3oool00000000000060?ooo`@00000203oool3000000D0oooo0P00
000;0?ooo`8000004P3oool3000004H0oooo000;0?ooo`800000303oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000<000000P3oool2000000H0oooo00@000000?ooo`3oool0oooo1000
0000103oool000000000003oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
0P3oool200000080oooo0P0000020?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo008000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool2000000D0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`090?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo
0?ooo`000000A@3oool000d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?oo
o`8000000P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool2
000000D0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool5000000<0oooo0P00
00040?ooo`030000003oool0oooo00D0oooo0P0000000`3oool000000?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool2000000<0oooo00H000000?ooo`0000000000
0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`13
0?ooo`003P3oool2000000T0oooo00<000000?ooo`3oool0503oool00`000000oooo000000090?oo
o`<0000000<0oooo0000000000000P3oool2000000@0oooo00<000000?ooo`3oool0103oool30000
00030?ooo`000000000000<000000`3oool5000000L0oooo0`0000000`3oool000000?ooo`020?oo
o`<0000000<0oooo0000000000001P3oool6000000<0oooo1@0000090?ooo`030000003oool00000
00@0oooo0P0000000`3oool00000000000080?ooo`@000001@3oool3000000/0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`8000001@3oool00`000000oooo0?ooo`130?oo
o`00403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool04@3oool2000000/0oooo0P0000060?ooo`030000003oool0oooo0080oooo0P0000060?ooo`80
00000`3oool00`000000oooo000000020?ooo`040000003oool00000000000H0oooo0P0000030?oo
o`8000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool0oooo0P00
00030?ooo`040000003oool0oooo000000/0oooo0`0000060?ooo`030000003oool0oooo00T0oooo
0P0000060?ooo`030000003oool0oooo00T0oooo0P0000070?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`130?ooo`004@3oool2000000D0oooo00<0
00000?ooo`3oool00`3oool200000140oooo0`0000090?ooo`@000001P3oool200000080oooo00<0
00000?ooo`000000103oool300000080oooo00@000000?ooo`000000oooo100000020?ooo`800000
0`3oool400000080oooo00H000000?ooo`000000oooo0000003oool2000000H0oooo0P0000020?oo
o`8000000P3oool2000000060?ooo`000000oooo0000003oool000002@3oool01@000000oooo0?oo
o`3oool0000000<0oooo0`0000090?ooo`8000000P3oool2000000D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0P0000090?ooo`030000
003oool0oooo0480oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool010000000oooo0?ooo`0000030?ooo`<0
00000P3oool4000000D0oooo00<000000?ooo`000000103oool00`000000oooo000000020?ooo`<0
00001`3oool01@000000oooo0?ooo`3oool0000000H0oooo0`0000020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0@P3oool001@0oooo00D000000?ooo`3oool0oooo000000080?oo
o`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool2
000000<0oooo0P0000000`3oool000000?ooo`040?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`8000001P3oool00`000000oooo0?ooo`02000000L0oooo0`0000020?ooo`030000003oool0
oooo00@0oooo0P0000070?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`800000203oool2
00000080oooo00<000000?ooo`3oool0103oool2000000`0oooo00<000000?ooo`3oool00`3oool2
000000`0oooo00<000000?ooo`3oool0@P3oool001D0oooo0`00000:0?ooo`8000003@3oool00`00
0000oooo0?ooo`020?ooo`80000000<0oooo000000000000203oool2000000D0oooo0`0000001@3o
ool000000000003oool0000000@0oooo00D000000?ooo`000000oooo000000020?ooo`050000003o
ool000000000003oool00P0000020?ooo`030000003oool0oooo0080oooo1@0000000`3oool00000
000000030?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`8000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0440oooo000G0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`3o
ool000000?ooo`<000000`3oool2000000030?ooo`000000oooo00@0oooo00H000000?ooo`3oool0
oooo0000003oool3000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?oo
o`80000000<0oooo0000003oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo
0?ooo`000000403oool00`000000oooo0?ooo`110?ooo`00603oool2000000/0oooo0P0000050?oo
o`8000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo0P0000000`3o
ool000000?ooo`02000000H0oooo0`0000000`3oool000000?ooo`020?ooo`040000003oool0oooo
0?ooo`8000001`3oool500000080oooo0P0000030?ooo`80000000<0oooo0000000000001`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo0P0000000`3oool00000000000060?ooo`8000001`3o
ool500000100oooo0P0000000`3oool000000000000A0?ooo`<000004@3oool00`000000oooo0?oo
o`110?ooo`006P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`0000000`3oool300000140oooo0`00000:0?ooo`8000001@3oool00`000000oooo00000002
0?ooo`8000001`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo
0P0000070?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`100?ooo`006`3oool00`000000oooo0?oo
o`0:0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`<000004@3oool3000000T0oooo1000
00050?ooo`8000000`3oool2000000@0oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo
0P000000103oool000000?ooo`0000050?ooo`@000000P3oool00`000000oooo0?ooo`030?ooo`<0
00001@3oool2000000/0oooo00<000000?ooo`0000004@3oool3000001@0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`100?ooo`00703oool2000000`0oooo00<000000?ooo`3oool0
0P3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool03@3oool200000080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00800000
0P3oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo0`0000040?ooo`80
00000`3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool02@3oool200000080oooo00<000000?oo
o`3oool03P3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0@03oool001h0oooo00<000000?ooo`3oool02P3oool01P000000oooo0?ooo`3oool0
00000?ooo`8000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`8000001@3oool2000000<0oooo0P00
00060?ooo`8000000`3oool010000000oooo0?ooo`0000040?ooo`8000001P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool00000
01@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`100?ooo`007`3oool2000000/0
oooo0`000000103oool000000?ooo`3oool2000000@0oooo0P0000090?ooo`8000000P3oool00`00
0000oooo0?ooo`020?ooo`80000000<0oooo0000000000001P3oool4000000D0oooo0P0000000`3o
ool0000000000002000000D0oooo00D000000?ooo`000000oooo000000040?ooo`80000000<0oooo
0000000000000P0000050?ooo`D000001@3oool3000000/0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0:0?ooo`8000001@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0?`3oool00240oooo00<000000?ooo`3oool02P3oool20000
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool00000008000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`090?ooo`8000001`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03l0oooo000R0?ooo`8000002@3oool3
000000H0oooo0P0000040?ooo`8000000`3oool400000080oooo00<000000?ooo`3oool00`3oool2
000000H0oooo0P0000060?ooo`80000000@0oooo0000003oool000001P3oool010000000oooo0?oo
o`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`040000003oool0oooo0?oo
o`8000000P3oool2000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo0P0000080?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0o0?ooo`00903oool00`000000oooo0?ooo`050?ooo`04
0000003oool0oooo0?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00@0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00P0oooo0`0000080?ooo`@000001@3oool00`000000oooo000000090?ooo`<000001P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo03h0oooo000U0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`090?ooo`<000002@3oool2000000L0oooo0P0000030?ooo`030000003oool0oooo00<0
oooo0`0000070?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`800000303oool00`000000
oooo0?ooo`030?ooo`800000303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0?P3oool002H0oooo0P0000000`3oool00000000000080?ooo`030000
003oool0oooo00@0oooo0P0000000`3oool00000000000020?ooo`030000003oool0oooo0080oooo
1@0000000`3oool00000000000030?ooo`8000002`3oool200000080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`02000000<0oooo0P0000020?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000080?ooo`<000001@3oool00`000000oooo0?ooo`020000
00P0oooo0`0000040?ooo`030000003oool0oooo00/0oooo0P00000B0?ooo`<00000E03oool000H0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`8000001P3oool00`000000
oooo0?ooo`030?ooo`060000003oool0oooo0?ooo`000000oooo0P0000040?ooo`030000003oool0
000000/0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000050?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`8000001@3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0:0?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`000000
D`3oool000L0oooo0P00000M0?ooo`8000003P3oool010000000oooo0?ooo`3oool2000000L0oooo
1@0000020?ooo`8000000`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`00
0000103oool2000000030?ooo`000000000000H0oooo0P0000070?ooo`80000000<0oooo00000000
0000203oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000000`3oool00000000000070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool3000000`0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0D@3oool000T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0000000/0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool20000
00L0oooo0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`02000000D0oooo00<000000?ooo`0000002`3oool00`000000oooo000000050?oo
o`8000002P3oool4000000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00/0oooo0P0000050?ooo`030000003oool0oooo0540oooo000:0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool2000000T0oooo0P0000000`3oool0
00000?ooo`050?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`@000000P3oool00`000000
oooo0?ooo`030?ooo`8000001P3oool2000000D0oooo00L000000?ooo`3oool0oooo0000003oool0
000000`0oooo0`0000040?ooo`<000002`3oool2000000L0oooo00<000000?ooo`3oool0203oool2
000000L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0500oooo000;0?ooo`8000005@3oool200000180oooo0P0000020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool2000000H0oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo0P0000000`3oool000000000000<0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000090?ooo`8000000P3oool2000000D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
0P0000090?ooo`030000003oool0oooo0500oooo000=0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P00
00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool2000000@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`1@0?ooo`003P3oool2000000l0oooo0P00000B
0?ooo`8000001`3oool2000000030?ooo`000000000000T0oooo00<000000?ooo`3oool0103oool2
000000030?ooo`0000000000008000001@3oool5000000030?ooo`000000oooo00<0oooo0P00000;
0?ooo`@000002@3oool2000000D0oooo100000030?ooo`030000003oool0oooo00<0oooo0P000008
0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`800000303oool00`000000oooo0?ooo`03
0?ooo`8000003@3oool00`000000oooo0?ooo`1?0?ooo`00403oool00`000000oooo0?ooo`0:0?oo
o`8000004`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo0P0000060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo000000000003
0?ooo`80000000<0oooo0000003oool02P3oool2000000050?ooo`000000oooo0?ooo`0000001`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0C`3oool00140oooo0P0000090?ooo`@00000403oool2000000/0oooo00<000000?ooo`3oool0
3@3oool010000000oooo0?ooo`3oool2000000H0oooo00@000000?ooo`3oool0oooo0P0000020?oo
o`8000000`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`8000001P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`0=0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`1?0?ooo`004`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`090?ooo`8000004@3oool00`000000oooo000000090?ooo`<000001P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo000000050?ooo`80
000000<0oooo0000000000001@3oool00`000000oooo0?ooo`070?ooo`D00000403oool200000003
0?ooo`00000000000100oooo00@000000?ooo`00000000004@3oool00`000000oooo0?ooo`1?0?oo
o`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo0P0000090?ooo`<0
00001`3oool200000080oooo0P0000050?ooo`800000103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo0P00000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04h0oooo000E0?ooo`800000
00<0oooo000000000000203oool2000000P0oooo0P00000;0?ooo`030000003oool0oooo0140oooo
0P0000020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000080?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo
00D0oooo0P0000050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000004@3oool30000
01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1>0?ooo`005`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool2000001<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo0P0000070?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`8000001@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P0000020?ooo`030000003oool0
oooo00h0oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo04h0oooo000E0?ooo`8000003P3oool2000000l0oooo00<000000?ooo`3oool04@3oool2
000000L0oooo0P0000000`3oool00000000000080?ooo`030000003oool0oooo00D0oooo0P000000
103oool000000000000000050?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000303o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0C@3o
ool001@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`8000004`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000000`0000050?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`8000001@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0C@3o
ool001<0oooo00<000000?ooo`3oool04P3oool2000000T0oooo1000000@0?ooo`8000002`3oool0
0`000000oooo0?ooo`0;0?ooo`800000103oool2000000D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`8000004P3oool2000000L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`1=0?ooo`004@3oool2000001L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool200000100oooo00@00000
0?ooo`3oool00000203oool3000000030?ooo`00000000000080oooo0P00000?0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool2000000T0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04`0oooo000@0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool2
000000H0oooo00<000000?ooo`3oool02P3oool2000000/0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`1<0?ooo`003P3oool2000001`0oooo0P0000000`3oool00000000000080?oo
o`800000203oool2000000/0oooo00<000000?ooo`3oool04@3oool4000000T0oooo100000060?oo
o`8000002@3oool3000000T0oooo0`0000050?ooo`8000002P3oool300000180oooo0P00001S0?oo
o`003@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`090?ooo`8000004`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000003`3o
ool200000080oooo00<000000?ooo`3oool0H03oool000/0oooo0P00000O0?ooo`8000003P3oool2
000000l0oooo00<000000?ooo`3oool04@3oool2000000H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0600oooo000:0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool01`3oool2000000030?ooo`000000000000P0oooo0P000006
0?ooo`80000000<0oooo000000000000203oool010000000oooo0000000000050?ooo`<000002P3o
ool2000000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0600oooo00090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3oool2
000000T0oooo0P00000B0?ooo`800000303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02@3oool2000000H0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo0P0000070?ooo`030000003oool0
oooo05l0oooo00070?ooo`8000007`3oool2000001L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`02000000l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`8000000`3oool2000000X0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool2000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo05l0oooo00060?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0:0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo05l0oooo000U0?ooo`800000703oool2000000030?ooo`000000000000L0oooo
00<000000?ooo`3oool0203oool2000000`0oooo00<000000?ooo`3oool04P3oool2000000T0oooo
0P0000070?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`800000303oool00`000000oooo
0?ooo`040?ooo`800000303oool00`000000oooo0?ooo`1N0?ooo`00903oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00P0oooo0P0000070?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool04@3oool200000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1N0?ooo`008P3o
ool200000200oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`8000004`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0
oooo0000000?0?ooo`030000003oool0oooo05h0oooo000Q0?ooo`030000003oool0oooo01h0oooo
0P00000?0?ooo`8000003`3oool00`000000oooo0?ooo`0A0?ooo`8000001`3oool2000000030?oo
o`000000000000l0oooo1@00000A0?ooo`040000003oool0000000000140oooo00<000000?ooo`3o
ool0G@3oool00200oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00X0oooo0P00000C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
4@3oool2000001<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1M0?ooo`007P3o
ool200000200oooo00<000000?ooo`3oool04`3oool2000000T0oooo0`00000A0?ooo`8000002P3o
ool2000001<0oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo05`0oooo000M0?ooo`030000003oool0oooo01h0oooo0P00000H0?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`3oool0oooo0P00000>0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04@3oool200000080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo05`0oooo000m0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05`0oooo000l0?oo
o`030000003oool0oooo01/0oooo0P0000000`3oool00000000000080?ooo`030000003oool0oooo
00L0oooo0P00000:0?ooo`8000004`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1K0?ooo`00>P3oool200000200
oooo00<000000?ooo`3oool02@3oool2000000H0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0A0?ooo`8000001`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0F`3oool003T0oooo00<000000?ooo`3oool07P3oool2000000h0oooo
00<000000?ooo`3oool03@3oool2000001<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F`3oool003P0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`1J0?ooo`00=P3oool200000200oooo00<00000
0?ooo`3oool04@3oool2000000T0oooo0`00000B0?ooo`800000303oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0FP3oool003D0oooo00<000000?oo
o`3oool07P3oool2000001H0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0
00000100oooo00<000000?ooo`3oool02P3oool300000180oooo0P00001a0?ooo`00=03oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`8000003@3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo
0?ooo`0000003`3oool200000080oooo00<000000?ooo`3oool0KP3oool005<0oooo0P00000K0?oo
o`80000000<0oooo000000000000203oool00`000000oooo0?ooo`080?ooo`800000303oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1^0?ooo`00DP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`8000001@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0KP3oool00500oooo
0P00000O0?ooo`030000003oool0oooo00/0oooo0P00000B0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0203oool2000000L0oooo00<000000?ooo`3oool0K@3oool004l0oooo00<0
00000?ooo`3oool07@3oool200000100oooo00<000000?ooo`3oool03@3oool2000000T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06d0oooo001>
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo06`0oooo001<0?ooo`8000007`3oool00`000000oooo0?ooo`0C0?oo
o`8000002@3oool2000000d0oooo00<000000?ooo`3oool00`3oool2000000`0oooo00<000000?oo
o`3oool0K03oool004/0oooo00<000000?ooo`3oool07@3oool2000001P0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1/0?ooo`00JP3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool000000100
oooo00<000000?ooo`3oool0J`3oool006T0oooo00<000000?ooo`3oool06`3oool2000000030?oo
o`00000000000140oooo00@000000?ooo`00000000004@3oool00`000000oooo0?ooo`1[0?ooo`00
I`3oool200000200oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo06/0oooo001V0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06X0oooo001U0?ooo`030000003oool0
oooo01h0oooo0P00000F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0JP3oool0
06<0oooo0P00000P0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`1Y0?ooo`00HP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1Y0?ooo`00PP3oool2000001/0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1Y0?ooo`00P@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0J03oool00800oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06P0oooo001n0?oo
o`8000007`3oool2000007l0oooo001m0?ooo`030000003oool0oooo01d0oooo0P0000020?ooo`03
0000003oool0oooo07`0oooo001l0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1l0?ooo`00NP3oool2000001l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1l0?ooo`00N@3oool00`000000oooo0?ooo`0M0?ooo`8000001`3oool0
0`000000oooo0?ooo`1k0?ooo`00V03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
07/0oooo002G0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0N`3oool009D0oooo
0P00000<0?ooo`030000003oool0oooo07X0oooo002D0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0NP3oool009<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1j
0?ooo`00T@3oool200000140oooo00<000000?ooo`3oool0N@3oool00900oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`1i0?ooo`00Y@3oool00`000000oooo0?ooo`1h0?ooo`00Y@3o
ool00`000000oooo0?ooo`1h0?ooo`00Y@3oool00`000000oooo0?ooo`1h0?ooo`00YP3oool00`00
0000oooo0?ooo`1g0?ooo`00YP3oool00`000000oooo0?ooo`1g0?ooo`00YP3oool00`000000oooo
0?ooo`1g0?ooo`00Y`3oool00`000000oooo0?ooo`1f0?ooo`00Y`3oool00`000000oooo0?ooo`1f
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {245.125, 0}} -> {-4.69234, -4.0896, 0.048887, \
0.048887}}]
}, Open  ]],

Cell["ANIMATION", "Text",
  FontSize->18,
  FontColor->RGBColor[0.0299992, 0.179995, 0.329992],
  Background->RGBColor[0.737301, 0.5608, 0.5608]],

Cell[BoxData[
    \(\(Map[\((i = #; 
            Show[Graphics[
                Map[Line[logo[tr[#], \(i\ \[Pi]\)\/180.0\ ]] &\ , u]], 
              PlotRange \[Rule] {{\(-8\), 9}, {\(-9\), 9}}];)\) &, 
        Range[0.0, 360.0, 5.0]];\)\)], "Input",
  CellLabel->"In[183]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.- Huffman Coding", "Section",
  FontColor->RGBColor[1, 0.889998, 0.00999466],
  Background->RGBColor[0.4392, 0.502007, 0.564706]],

Cell[TextData[{
  "In dealing with the storage of a great amount of textual information we \
face the task of encoding it so that any redundancy in the text can be \
exploited to our advantage. Dictionaries like the Mexican Spanish Dictionary, \
a major on-going project that started about twenty years ago at El Colegio de \
Mexico, a prestigious research institution in Mexico City, faced this \
important challenge. The author was then a member of the team that suggested, \
implemented and tested a variety of approaches to alleviate the computational \
burden of dealing with massive amounts of textual information when we came \
across the fact that the optimal way to accomplish the compression that \
exploits the inherent redundancy in any discrete interchange of information \
was already discovered by D.Huffman and reported on his paper \"A Method for \
the construction of minimum-redundancy codes\" at the Proceedings of the IRE, \
vol.40, 1952.\n\nHuffman coding involves the building of a tree of \
frequencies of each of the symbols forming the original message. Once this \
tree is constructed, the leave nodes can be coded to a binary specification \
of the path needed to reach them from the root.\n\nThe details are now part \
of the standard content of any undergraduate course on algorithm design and \
here we want to illustrate the application of transformational grammars, as \
RS are called in this context, to this type of problems (for an alternative \
way of implementing run-length encoding consult Version 3.0 Programming \
Features by Roman Maeder, the Mathematica Journal vol.6 issue 4, Fall 1996, \
p. 40-43). First we design function ",
  StyleBox["frequencies", "Input"],
  " to count the frequencies of the symbols appearing in a given sentence."
}], "Text"],

Cell[BoxData[
    \(frequencies[mesg_String] := 
      With[{m = 
            Characters[mesg]}, \[IndentingNewLine]\(({#, Count[m, #]} &)\) /@ 
          Union[m]]\)], "Input",
  CellLabel->"In[41]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(message = "\<Hi there, glad you could make it\>";\)\), "\
\[IndentingNewLine]", 
    \(frequencies[message]\)}], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \({{",", 1}, {" ", 6}, {"a", 2}, {"c", 1}, {"d", 2}, {"e", 3}, {"g", 
        1}, {"h", 1}, {"H", 1}, {"i", 2}, {"k", 1}, {"l", 2}, {"m", 1}, {"o", 
        2}, {"r", 1}, {"t", 2}, {"u", 2}, {"y", 1}}\)], "Output",
  CellLabel->"Out[45]="]
}, Open  ]],

Cell[TextData[StyleBox["or, alternatively",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[BoxData[
    \(runEncode[mesg_String] := 
      Map[{#, \ 1}\  &, \ \n\ \ \ \ \ \ Characters[
            mesg]]\  //. {x___, {a_, \ i_}, \ y___, {a_, \ j_}, 
            z___}\  \[Rule] \ {x, \ {a, \ i\  + \ j}, \ y, \ z}\)], "Input",
  CellLabel->"In[46]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(runEncode[message]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \({{"H", 1}, {"i", 2}, {" ", 6}, {"t", 2}, {"h", 1}, {"e", 3}, {"r", 
        1}, {",", 1}, {"g", 1}, {"l", 2}, {"a", 2}, {"d", 2}, {"y", 1}, {"o", 
        2}, {"u", 2}, {"c", 1}, {"m", 1}, {"k", 1}}\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[TextData[StyleBox["We use nested lists for the encoding of trees; for \
instance, the tree",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000A7000251000`40O003
h00OogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomo
oomood]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mo
oomooomooomood]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;
Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo003oOoooOooo
OoooOom;Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo003o
OoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogooogoo
Bgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogoo
ogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00
ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomo
od]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomo
oomooomood]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool0
0?mooomooomooomood]oo`00ogooogooogooogooBgoo003oOoooOoooOooo
Oom;Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo003oOooo
OoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo
003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogoo
ogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogoo
ogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]o
o`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomo
oomood]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mo
oomooomooomood]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;
Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo003oOoooOooo
OoooOom;Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo003o
OoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogooogoo
Bgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogoo
ogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00
ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomo
od]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomo
oomooomood]oo`00dGoo00=>Lcg_?Nl00`000Sg_00=>LgooOol0NWoo1P00
17oo00=>Lcg_00000`0000<mkdicOol047oo00=Nmdic?Nl010000Sg_00=N
mgooOol047oo00=Nmcg_0000100000<mkdicG_L02Goo00=Nmcg_?Nl00`00
00<mkdicG_L00goo00=Nm`000000100000<mkgooOol0ogoob7oo1`00X7oo
1`0057oo003?Ool00dic0000000900000dicOomoo`1hOol60002Ool00dic
0000000800000dicOomoo`0;Ool00ekg0000000:00000ekgOomoo`0=Ool0
0cg_000000080008Ool00cg_00000007000013g_Oomoodic1P0000=Nmgoo
Ool0ogoob7oo1`00X7oo1`0057oo003>Ool00cg_0000000;00000cg_Oomo
o`1gOol600000goo?Nl0000;00000cg_Oomoo`09Ool00cg_0000000<0000
0dicOomoo`0;Ool00cg_0000000800000cg_Oomoo`05Ool00cg_0000000:
00000ekg?Nl0000400000cg_Oomoo`3oOoo9Ool7002POol7000DOol00<eo
o`03?Nl0000000d00003?Nmoogoo07Ioo`H00003?Nl0000000`00003?Nmo
ogoo00Moo`03?Nl0000000h00003CW=oogoo00Uoo`03CW<0000000T00003
?Nmoogoo00Aoo`03?Nl0000001800003CW=oogoo0?moolUoo`L00:1oo`03
?Nl0000000@00003G_Moogoo015oo`00c7oo00<mk`0000003`0000<mkgoo
Ool0MGoo5P0000=>LgooOol01Goo00=>L`000000400000=NmgooOol027oo
00<mk`0000002@0000<mkgooOol00goo00=Nm`0000004`0000=NmgooOol0
ogoobGoo1`00X7oo00<mk`000000100000=NmgooOol04Goo003;Ool00dic
0000000A00000dicOomoo`1dOol:00001Cg_G_MoogooCW<0200000=Nmgoo
Ool00goo00=Nm`0000001@0000DmkekgOomooekg00P000Yoo`03?Nl00000
00@00006?NmNmgooG_M>Lekg1Goo00<mk`0000001@0000DmkekgOomNmcg_
00T00003G_Moogoo0?moolUoo`L00:1oo`03CW<0000000@00003CW=oogoo
015oo`00bgoo200000E>LgooOomNmdic00P007Ioo`T00003CW=oogoo00=o
o`03G_L0000000D00003?Nmoogoo00=oo`03?Nl0000000@00003?Nmoogoo
00Aoo`L00003CW=oogoo00Moo`L00003G_Moogoo00Qoo`03?Nl0000000@0
0003?Nmoogoo00=oo`03CW<0000000H00?moolaoo`L00:1oo`03CW<00000
00@00003CW=oogoo015oo`00bWoo00=>L`000000100000<mkgooOol017oo
00=Nm`0000001@0000=NmgooOol0Lgoo200000=>LgooOol01Goo00=Nm`00
00001@001Goo1`0000=NmgooOol017oo00=>L`000000100000<mkgooOol0
1goo1`002goo1`0000=NmgooOol017oo00<mk`0000001@00ogoo_Woo6P00
Vgoo00=Nm`000000100000<mkgooOol04Goo003:Ool00cg_000000040008
Ool00cg_0000000400000dicOomoo`1cOol80009Ool00cg_000000040000
1EkgOomoogooG_L01P0000<mkgooOol01Goo00ANm`00?Nlmk`9>L`03G_Mo
ogoo00Qoo`L000]oo`L000Moo`03G_L0000000D00?mookiooaX009aoo`L0
01=oo`00bWoo1P0000=>LgooOol01Woo00=Nm`000000100000<mkgooOol0
Lgoo1`0000<mkgooOol01goo00=>L`000000100000E>LgooOomoodic00H0
0003G_Moogoo01Ioo`L000]oo`L000Moo`03G_L0000000D00?mookiooaX0
09aoo`03?Nl0000000@00003G_Moogoo011oo`00bGoo00=Nm`0000001000
00=NmgooOol01goo1`00MGoo1`0000=NmgooOol01goo00=Nm`0000001000
00DmkgooOomoocg_00H00003G_Moogoo01Ioo`L000]oo`03?Nl0000000@0
0003CW=oogoo00Eoo`L00?mookiooaX009aoo`03CW<0000000@00003G_Mo
ogoo011oo`00bGoo00=>L`00000010002Woo1`00MGoo1`0000=NmgooOol0
1goo00=Nm`000000100000@mkgooOomoo`L001Uoo`L000]oo`03CW<00000
00D00003G_Moogoo00Aoo`L00?mookiooaX009aoo`03G_L0000000@00003
CW=oogoo011oo`00bGoo00<mk`00000010002Woo1`00MGoo1`002goo1`00
0goo600027oo1`0037oo200000<mkdicG_L00goo1`00ogoo_Woo6P00WGoo
1P0000<mkgooOol047oo0039Ool00cg_000000040009Ool00ekg00000005
001eOol7000;Ool70003OolH0008Ool7000<Ool00dic0000000900000dic
G_L00006003oOonnOol00cg_000000030008Ool7002ROol00cg_00000004
00000ekgOomoo`0?Ool00<Uoo`03?Nl0000000@00003G_Moogoo00Ioo`03
G_L0000000@00003?Nmoogoo07=oo`L000]oo`L000=ooaP000Qoo`L000eo
o`03CW<0000001400?mookioo`03G_L0000000<00003?Nmoogoo00Eoo`L0
0:9oo`03G_L0000000@00003CW=oogoo00moo`00bGoo1`0000<mkgooOol0
1Woo00<mk`000000100000<mkgooOol0Lgoo1`002goo1`000goo600027oo
1`003Woo00=Nm`0000004000ogoo_goo00=>L`0000000`0000=NmgooOol0
17oo1`00Xgoo1P0000<mkgooOol03goo0039Ool800000dicOomoo`04Ool0
0dic0000000500000dicOomoo`1cOol7000:Ool00ekg000000050003Ool0
0cg_0000000400000ekgOomoo`07Ool600000cg_Oomoo`06Ool7000@Ool0
0ekgCW<0000>003oOoo0Ool00cg_000000030006Ool7002SOol00dic0000
000400000ekgOomoo`0>Ool00<Uoo`T00006?NmNmgooOomNmcg_2000MWoo
1`0000=NmgooOol01goo00=Nm`000000100000DmkgooOomoocg_00H00003
G_Moogoo00Moo`H00003?Nmoogoo00Ioo`L001=oo`9Nm`03CW<mk`0000T0
0?mool1oo`03G_L0000000<00003CW=oogoo00=oo`L00:=oo`03G_L00000
00@00003CW=oogoo00ioo`00bGoo5P0000=>LgooOol0M7oo1`0000=>Lgoo
Ool01goo00=>L`000000100000DmkgooOomoodic00H00003CW=oogoo00Io
o`03G_L0000000@00003CW=oogoo00Ioo`L001Moo`03G_M>Lcg_00L00?mo
ol5oo`03CW<0000000<00003G_Moogoo009oo`L00:Aoo`03?Nl0000000@0
011oo`00bGoo5@0000<mkgooOol0MGoo1`0000<mkgooOol01goo1`0000E>
LgooOomooekg00H00003?Nmoogoo00Ioo`03CW<0000000@00003G_Moogoo
00Ioo`L001Yoo`L00?mool9oo`D00003?Nmoogoo009oo`L00:Aoo`03G_L0
000000@00003G_Moogoo00eoo`00bGoo5@00N7oo200000=NmgooOol01Goo
00=Nm`0000001@0000=NmgooOol00Woo1`0000=NmgooOol01Goo1`002Goo
1`003Goo00INmdicCW<mk`00G_L7Ool7003oOoo2Ool00ekg000000030000
14icOomoogoo1`00YGoo00<mk`0000000`0000<mkgooOol03Goo0039Ool6
00000dic?Nl0000:00000cg_G_Moo`1gOol900000ekgOomoo`03Ool00ekg
0000000500000cg_Oomoo`03Ool00dic0000000400000cg_Oomoo`04Ool0
0cg_0000000400000dicOomoo`07Ool7000<Ool600000cg_Oomoo`04Ool0
0dic0000000400000cg_Oomoo`3oOoo1Ool00cg_000000030003Ool7002U
Ool00ekg0000000400000ekgOomoo`0<Ool00<Uoo`03?Nl0000000<00003
CW=oocg_00T00003CW=oogoo07Qoo`X00005CW=NmgooG_M>L`0800000ekg
Oomoo`04Ool700001Sg_G_MoogooG_Lmk`L000Moo`l000Moo`03CW<00000
00@00006?NmNmgooOomNmdic1`0000<mkgooOol0ogoo`Goo00=Nm`000000
0`0000<mkgooOol01`00YWoo00<mk`0000000`0000<mkgooOol037oo0039
Ool00cg_0000000300001Cg_Oomooekg?Nl0100000<mkdicG_L0Ngoo5P00
00<mkgooOol01Goo00=Nm`000000400000=NmgooOol01Goo3`0027oo4`00
00=NmgooOol0ogoo`Woo00=>L`0000000`0000=Nmgoo00001P00YWoo00=N
m`000000100000=NmgooOol02goo0039Ool00dic0000000300000cg_Oomo
o`24Ool700000cg_0000000;00000cg_Oomoo`07Ool00dic0000000>0000
0dicOomoo`06Ool?0008Ool00dic0000000?00000cg_Oomoo`3oOoo4Ool0
0cg_0000000200000cg_Ool00006002WOol00cg_0000000300000cg_Oomo
o`0;Ool00<Uoo`03CW<0000000@008Ioo`L00003Oolmk`0000X00003?Nmo
ogoo00Uoo`03CW<0000000`00003CW=oogoo00Moo`l000Uoo`03CW<00000
00d00003?Nmoogoo0?moolEoo`03G_L0000000<00003CW<0000000D00:Qo
o`H00003G_Moogoo00Yoo`00bGoo00=Nm`000000100000=NmgooOol0Pgoo
1`000Woo00=>L`0000001`0000=>LgooOol02goo00=Nmcg_00002@0000<m
kekgOol02Goo3`002Woo00=Nm`0000002`0000<mkgooOol0ogooagoo00=>
L`0000002P00Z7oo00=>L`000000100037oo003:Ool600000dicOomoo`06
Ool01000?Nlmkcg_0Tic00=NmgooOol0M7oo1`000goo00=Nmdic?Nl00`00
00<mkdicG_L047oo00=Nmdic?Nl0100000<mkdicG_L03goo1`004Goo00=N
mdic?Nl01@000Sg_00=>LekgOol0ogoobWoo3000ZGoo00<mk`0000000`00
00=>LgooOol02Goo003:Ool00cg_000000040007Ool00dic00000005001f
Ool7000eOol7003oOooXOol00ekg00000009002ZOol600000ekgOomoo`08
Ool00<Yoo`03G_L0000000@00003?Nmoogoo00Aoo`03?Nl0000000@00003
?Nmoogoo07Aoo`L003Eoo`L00?moonUoo`03?Nl0000000P00:Yoo`03G_L0
000000@000Yoo`00bgoo00<mk`000000100000HmkekgOomooekg?Nl70000
0ekgOomoo`1dOol7000eOol7003oOooYOol00ekg00000008002KOolF0000
0cg_Oomoo`07Ool00<]oo`03G_L00000014007Moo`L003Eoo`L00?moonYo
o`03CW<0000000L009]ooaL00003?Nmoogoo00Ioo`00c7oo00=>L`000000
3`0000=>LgooOol0MGoo1`00=Goo00=Nm`0000001000ogoojgoo2@00Vgoo
600027oo003=Ool00cg_0000000=00000cg_Oomoo`1fOol7000gOol00dic
00000002003oOoo[Ool00ekg00000006002KOolH0008Ool00<ioo`03CW<0
000000/00003?Nmoogoo07Moo`L003Uoo`03CW<000000?moonaoo`03?Nl0
000000D009]ooaP000Qoo`00cgoo00=Nmcg_00002@0000=>LgooOol0N7oo
1`00>Woo00=Nmcg_Ool0ogook7oo1`00Vgoo600027oo003AOol00ekgCW<m
k`0400000cg_CW=oo`1kOol7003oOoooOolZOol00dic00000004002KOolH
0008Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo003oOooo
OoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo
003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogoo
ogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogoo
ogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]o
o`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomo
oomood]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mo
oomooomooomood]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;
Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo003oOoooOooo
OoooOom;Ool00?mooomooomooomood]oo`00ogooJWoo00<007ooOol0ogoo
ogoo]7oo00<007ooOol09Woo003oOomZOol00`00Oomoo`3oOoooOondOol0
0`00Oomoo`0VOol00>eoo`03001oogoo07Qoo`03001oogoo0?mooomookAo
o`03001oogoo02Moo`00kGoo00<007ooOol0N7oo00<007ooOol0ogooogoo
=Goo00<007ooOol0O7oo00<007ooOol09goo003^Ool00`00Oomoo`1fOol0
0`00Oomoo`3oOoooOolfOol00`00Oomoo`1kOol00`00Oomoo`0XOol00>io
o`03001oogoo07Ioo`03001oogoo0?mooomoocMoo`03001oogoo07Yoo`03
001oogoo02Qoo`00kgoo00<007ooOol0M7oo00<007ooOol0ogooogoo>7oo
00<007ooOol0NGoo00<007ooOol0:Goo003_Ool00`00Oomoo`1dOol00`00
Oomoo`3oOoooOoliOol00`00Oomoo`1hOol00`00Oomoo`0YOol00?1oo`03
001oogoo079oo`03001oogoo0?mooomoocYoo`03001oogoo07Moo`03001o
ogoo02Yoo`00l7oo00<007ooOol0LWoo00<007ooOol0ogooogoo>goo00<0
07ooOol0MWoo00<007ooOol0:Woo003aOol00`00Oomoo`1`Ool00`00Oomo
o`3oOoooOollOol00`00Oomoo`1eOol00`00Oomoo`0[Ool00?5oo`03001o
ogoo071oo`03001oogoo0?mooomooceoo`03001oogoo07Aoo`03001oogoo
02]oo`00lWoo00<007ooOol0KWoo00<007ooOol0ogooogoo?Woo00<007oo
Ool0Lgoo00<007ooOol0;7oo003bOol00`00Oomoo`1^Ool00`00Oomoo`3o
OoooOoloOol00`00Oomoo`1bOol00`00Oomoo`0/Ool00?9oo`03001oogoo
06eoo`03001oogoo0?mooomood5oo`03001oogoo071oo`03001oogoo02eo
o`00lgoo00<007ooOol0K7oo00<007ooOol0ogooogoo@Goo00<007ooOol0
L7oo00<007ooOol0;Goo003cOol00`00Oomoo`1[Ool00`00Oomoo`3oOooo
Oom3Ool00`00Oomoo`1^Ool00`00Oomoo`0^Ool00?Aoo`03001oogoo06Yo
o`03001oogoo0?mooomood=oo`03001oogoo06ioo`03001oogoo02ioo`00
m7oo00<007ooOol0JGoo00<007ooOol0ogooogooAGoo00<007ooOol0K7oo
00<007ooOol0;goo003eOol00`00Oomoo`1XOol00`00Oomoo`3oOoooOom5
Ool00`00Oomoo`1/Ool00`00Oomoo`0_Ool00?Eoo`03001oogoo06Moo`03
001oogoo0?mooomoodMoo`03001oogoo06Yoo`03001oogoo031oo`00mWoo
00<007ooOol0IWoo00<007ooOol0ogooogooAgoo00<007ooOol0JWoo00<0
07ooOol0<7oo003fOol00`00Oomoo`1UOol00`00Oomoo`3oOoooOom9Ool0
0`00Oomoo`1XOol00`00Oomoo`0aOol00?Moo`03001oogoo06Aoo`03001o
ogoo0?mooomoodUoo`03001oogoo06Qoo`03001oogoo035oo`00mgoo00<0
07ooOol0Hgoo00<007ooOol0ogooogooBgoo00<007ooOol0IWoo00<007oo
Ool0<Woo003hOol00`00Oomoo`1ROol00`00Oomoo`3oOoooOom;Ool00`00
Oomoo`1VOol00`00Oomoo`0bOol00?Qoo`03001oogoo065oo`03001oogoo
0?mooomoodeoo`03001oogoo06Aoo`03001oogoo03=oo`00nGoo00<007oo
Ool0H7oo00<007ooOol0ogooogooCGoo00<007ooOol0I7oo00<007ooOol0
<goo003iOol00`00Oomoo`1OOol00`00Oomoo`3oOoooOom?Ool00`00Oomo
o`1ROol00`00Oomoo`0dOol00?Yoo`03001oogoo05ioo`03001oogoo0?mo
oomoodmoo`03001oogoo069oo`03001oogoo03Aoo`00nWoo00<007ooOol0
GGoo00<007ooOol0ogooogooDGoo00<007ooOol0H7oo00<007ooOol0=Goo
003kOol00`00Oomoo`1LOol00`00Oomoo`3oOoooOomAOol00`00Oomoo`1P
Ool00`00Oomoo`0eOol00?]oo`03001oogoo05]oo`03001oogoo0?mooomo
oe=oo`03001oogoo05ioo`03001oogoo03Ioo`00o7oo00<007ooOol0FWoo
00<007ooOol0ogooogooDgoo00<007ooOol0GWoo00<007ooOol0=Woo003l
Ool00`00Oomoo`1IOol00`00Oomoo`3oOoooOomEOol00`00Oomoo`1LOol0
0`00Oomoo`0gOol00?eoo`03001oogoo05Qoo`03001oogoo0?mooomooeEo
o`03001oogoo05aoo`03001oogoo03Moo`00oGoo00<007ooOol0Egoo00<0
07ooOol0ogooogooEgoo00<007ooOol0FWoo00<007ooOol0>7oo003nOol0
0`00Oomoo`1FOol00`00Oomoo`3oOoooOomGOol00`00Oomoo`1JOol00`00
Oomoo`0hOol00?ioo`03001oogoo05Eoo`03001oogoo0?mooomooeUoo`03
001oogoo05Qoo`03001oogoo03Uoo`00ogoo00<007ooOol0E7oo00<007oo
Ool0ogooogooFGoo00<007ooOol0F7oo00<007ooOol0>Goo003oOol00`00
Oomoo`1COol00`00Oomoo`3oOoooOomKOol00`00Oomoo`1FOol00`00Oomo
o`0jOol00?moo`5oo`03001oogoo059oo`03001oogoo0?mooomooe]oo`03
001oogoo05Ioo`03001oogoo03Yoo`00ogoo0Goo00<007ooOol0DGoo00<0
07ooOol0ogooogooGGoo00<007ooOol0E7oo00<007ooOol0>goo003oOol1
Ool00`00Oomoo`1AOol00`00Oomoo`3oOoooOomNOol00`00Oomoo`1COol0
0`00Oomoo`0kOol00?moo`9oo`03001oogoo051oo`03001oogoo0?mooomo
oeioo`03001oogoo05=oo`03001oogoo03]oo`00ogoo0Woo00<007ooOol0
Cgoo00<007ooOol0ogooogooH7oo00<007ooOol0DGoo00<007ooOol0?7oo
003oOol3Ool00`00Oomoo`1>Ool00`00Oomoo`3oOoooOomPOol00`00Oomo
o`1AOol00`00Oomoo`0lOol00?moo`=oo`03001oogoo04eoo`03001oogoo
0?mooomoof9oo`03001oogoo04moo`03001oogoo03eoo`00ogoo17oo00<0
07ooOol0C7oo00<007ooOol0ogooogooHWoo00<007ooOol0Cgoo00<007oo
Ool0?Goo003oOol4Ool00`00Oomoo`1;Ool00`00Oomoo`3oOoooOomTOol0
0`00Oomoo`1=Ool00`00Oomoo`0nOol00?moo`Eoo`03001oogoo04Yoo`03
001oogoo0?mooomoofAoo`03001oogoo04eoo`03001oogoo03ioo`00ogoo
1Goo00<007ooOol0BGoo00<007ooOol0ogooogooIWoo00<007ooOol0Bgoo
00<007ooOol0?goo003oOol6Ool00`00Oomoo`18Ool00`00Oomoo`3oOooo
OomVOol00`00Oomoo`1;Ool00`00Oomoo`0oOol00?moo`Ioo`03001oogoo
04Moo`03001oogoo0?mooomoofQoo`03001oogoo04Uoo`03001oogoo041o
o`00ogoo1goo00<007ooOol0AWoo00<007ooOol0ogooogooJ7oo00<007oo
Ool0BGoo00<007ooOol0@7oo003oOol7Ool00`00Oomoo`15Ool00`00Oomo
o`3oOoooOomZOol00`00Oomoo`17Ool00`00Oomoo`11Ool00?moo`Qoo`03
001oogoo04Aoo`03001oogoo0?mooomoofYoo`03001oogoo04Moo`03001o
ogoo045oo`00ogoo27oo00<007ooOol0@goo00<007ooOol0ogooogooK7oo
00<007ooOol0AGoo00<007ooOol0@Woo003oOol9Ool00`00Oomoo`12Ool0
0`00Oomoo`3oOoooOom/Ool00`00Oomoo`15Ool00`00Oomoo`12Ool00?mo
o`Uoo`03001oogoo045oo`03001oogoo0?mooomoofioo`03001oogoo04=o
o`03001oogoo04=oo`00ogoo2Woo00<007ooOol0@7oo00<007ooOol0ogoo
ogooKWoo00<007ooOol0@goo00<007ooOol0@goo003oOol:Ool00`00Oomo
o`0oOol00`00Oomoo`3oOoooOom`Ool00`00Oomoo`11Ool00`00Oomoo`14
Ool00?moo`]oo`03001oogoo03ioo`03001oogoo0?mooomoog1oo`03001o
ogoo045oo`03001oogoo04Aoo`00ogoo2goo00<007ooOol0?Goo00<007oo
Ool0ogooogooLWoo00<007ooOol0?goo00<007ooOol0AGoo003oOol<Ool0
0`00Oomoo`0lOol00`00Oomoo`3oOoooOombOol00`00Oomoo`0oOol00`00
Oomoo`15Ool00?moo`aoo`03001oogoo03]oo`03001oogoo0?mooomoogAo
o`03001oogoo03eoo`03001oogoo04Ioo`00ogoo3Goo00<007ooOol0>Woo
00<007ooOol0ogooogooM7oo00<007ooOol0?Goo00<007ooOol0AWoo003o
Ool=Ool00`00Oomoo`0iOol00`00Oomoo`3oOoooOomfOol00`00Oomoo`0k
Ool00`00Oomoo`17Ool00?moo`ioo`03001oogoo03Qoo`03001oogoo0?mo
oomoogIoo`03001oogoo03]oo`03001oogoo04Moo`00ogoo3Woo00<007oo
Ool0=goo00<007ooOol0ogooogooN7oo00<007ooOol0>Goo00<007ooOol0
B7oo003oOol?Ool00`00Oomoo`0fOol00`00Oomoo`3oOoooOomhOol00`00
Oomoo`0iOol00`00Oomoo`18Ool00?moo`moo`03001oogoo03Eoo`03001o
ogoo0?mooomoogYoo`03001oogoo03Moo`03001oogoo04Uoo`00ogoo3goo
00<007ooOol0=Goo00<007ooOol0ogooogooNgoo00<007ooOol0=Woo00<0
07ooOol0BGoo003oOol@Ool00`00Oomoo`0cOol00`00Oomoo`3oOoooOoml
Ool00`00Oomoo`0eOol00`00Oomoo`1:Ool00?mooa1oo`03001oogoo03=o
o`03001oogoo0?mooomoogeoo`03001oogoo03Aoo`03001oogoo04Yoo`00
ogoo4Goo00<007ooOol0<Goo00<007ooOol0ogooogooOWoo00<007ooOol0
<goo00<007ooOol0Bgoo003oOolAOol00`00Oomoo`0aOol00`00Oomoo`3o
OoooOomoOol00`00Oomoo`0bOol00`00Oomoo`1;Ool00?mooa9oo`03001o
ogoo02moo`03001oogoo0?mooomooh1oo`03001oogoo035oo`03001oogoo
04aoo`00ogoo4Woo00<007ooOol0;goo00<007ooOol0ogooogooPGoo00<0
07ooOol0<7oo00<007ooOol0C7oo003oOolCOol00`00Oomoo`0]Ool00`00
Oomoo`3oOoooOon2Ool00`00Oomoo`0_Ool00`00Oomoo`1=Ool00?mooa=o
o`03001oogoo02eoo`03001oogoo0?mooomooh=oo`03001oogoo02ioo`03
001oogoo04eoo`00ogoo57oo00<007ooOol0ogooogoo/Woo00<007ooOol0
;Goo00<007ooOol0CWoo003oOolDOol00`00Oomoo`3oOoooOoooOoldOol0
0?mooaEoo`03001oogoo0?mooomooomooc=oo`00ogooogooogooogooBgoo
003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogoo
ogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogoo
ogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]o
o`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomo
oomood]oo`00ogooogooogooogooBgoo003oOoooOolZOol7003oOoooOolJ
Ool00?mooomoobYoo`L00?mooomooaYoo`00ogooogoo:Woo1`00ogooogoo
6Woo003oOoooOolZOol7003oOoooOolJOol00?mooomoobYoo`L00?mooomo
oaYoo`00ogooogoo:Woo1`00ogooogoo6Woo003oOoooOolZOol7003oOooo
OolJOol00?mooomoobYoo`L00?mooomooaYoo`00ogooogoo:Woo1`00ogoo
ogoo6Woo003oOoooOolZOol7003oOoooOolJOol001]oo`L000aooaP00=io
o`03G_Lmkcg_00@00003?Nm>Lekg0<moo`03G_Lmkcg_00<00003?Nm>Lekg
00=oo`03G_L0000000@00003?Nmoogoo00Ioo`L000Qoo`L000=oo`03G_M>
Lcg_00<00003?Nm>Lgoo00Yoo`L000Yoo`L000Qoo`03G_Lmkcg_00<00003
?Nm>Lekg00=oo`03G_L0000000@00003?Nmoogoo04EooaP000eoo`03G_M>
Lcg_00@0008mk`03CW=oogoo0=eoo`L001Moo`L005Aoo`006goo1`0037oo
00<mk`0000005@00g7oo00=Nm`0000002@0000<mkekgOol0bgoo00<mk`00
00001`0000@mkgooOom>L`H00003G_Moogoo00Ioo`L000Qoo`L0009oo`03
CW<0000000L00003CW=oogoo00Moo`L000Yoo`L000Moo`03?Nl0000000L0
0004?NmoogooCW<600000ekgOomoo`15Ool00cg_0000000E000;Ool00dic
0000000:00000dicOomoo`3KOol7000GOol7001DOol001]oo`L000aoo`03
CW<0000001D00=]oo`03?Nl0000000`00003G_Moogoo0<Qoo`03?Nl00000
00X00003G_Lmk`0000@00003?Nmoogoo00Moo`L000Qoo`L00003Oolmk`00
00X00003?Nmoogoo00Ioo`L000Yoo`L000Ioo`03?Nl0000000X00003G_Lm
k`0000@00003?Nmoogoo04Ioo`03CW<0000001D000Uoo`03G_Lmk`0000h0
0003G_Moogoo0=Uoo`L001Moo`L005Aoo`006goo1`0037oo00=Nm`000000
5@00fWoo00<mk`0000003P0000=>LgooOol0aWoo00<mk`0000004P0000=>
LgooOol01goo1`0027oo1`0000<mk`0000002`0000<mkgooOol01Goo1`00
2Woo1`001Goo00<mk`0000004P0000=>LgooOol0AWoo00=Nm`0000005@00
27oo00=Nm`000000400000=NmgooOol0f7oo1`005goo1`00E7oo000KOol7
000=OolG003IOol00dic0000000@00000ekgOomoo`34Ool00ekg0000000C
00000ekgOomoo`07Ool70008OolF00000dicOomoo`04Ool7000:Ool70004
Ool00ekg0000000C00000ekgOomoo`17OolG0008OolD003JOol7000GOol7
001DOol001]oo`L000eoo`03CW<0000001@00=Qoo`03G_L0000001800<Io
o`03?Nl0000000D00005?NmNmgooG_Lmk`0900000ekgOomoo`07Ool70008
Ool:00001Cg_G_MoogooCW<0200000=NmgooOol00goo1`002Woo1`0017oo
00<mk`0000001@0000DmkekgOomNmcg_00T00003G_Moogoo04Moo`03CW<0
000001@000Moo`03?Nl0000001800003CW=oogoo0=Moo`L001Moo`L005Ao
o`006goo1`003Woo5P00f7oo00<mk`0000001@0000HmkekgOomooekg?Nl7
00000dicOomoo`33Ool00cg_0000000400000cg_Oomoo`03Ool00dic0000
0006000:Ool70008Ool900000dicOomoo`03Ool00ekg0000000500000cg_
Oomoo`03Ool7000:Ool70004Ool00cg_0000000400000cg_Oomoo`03Ool0
0dic00000006001;OolF0006Ool00ekg0000000600001Sg_G_MoogooG_Lm
k`P00003G_Moogoo0=Ioo`L001Moo`L005Aoo`006goo1`003Woo00=>L`00
00001@0000=>LgooOol0hWoo00=Nm`0000001@0000<mkgooOol017oo00<m
k`0000001@00aGoo1`0000=NmgooOol017oo00<mk`0000001@002Woo1`00
27oo200000=>LgooOol01Goo00=Nm`0000001@001Goo1`002Woo1`0017oo
1`0000=NmgooOol017oo00<mk`0000001@00Bgoo00=>L`0000001@0000=>
LgooOol04Goo00=>L`0000001@0000=>LgooOol017oo00=>L`0000001@00
00=>LgooOol0eWoo1`005goo1`00E7oo000KOol7000?Ool00cg_00000005
00000ekgOomoo`3QOol00dic0000000500000ekgOomoo`05Ool700000ekg
Oomoo`32Ool70007Ool00ekg00000005000:Ool70008Ool80009Ool00cg_
0000000400000ekgOomoo`02Ool7000:Ool70004Ool70007Ool00ekg0000
0005001<Ool00cg_0000000500000ekgOomoo`0@Ool00cg_000000040000
0cg_Oomoo`06Ool00cg_0000000400000cg_Oomoo`3FOol7000GOol7001D
Ool001]oo`L0011oo`P00003G_Moogoo0>1oo`03?Nl0000000@00003?Nmo
ogoo00Ioo`03CW<0000000@00003?Nmoogoo0<9oo`L000Moo`03G_L00000
00D000Yoo`L000Qoo`L00003?Nmoogoo00Moo`03CW<0000000@00003CW=o
ogoo009oo`L000Yoo`L000Aoo`L000Moo`03G_L0000000D004eoo`P00003
G_Moogoo00moo`L00003G_Moogoo00Ioo`03G_L0000000D00=Qoo`L001Mo
o`L005Aoo`006goo1`0047oo00=Nm`0000001P0000=NmgooOol0ggoo1`00
00=NmgooOol01Woo00=Nm`000000100000<mkgooOol0`Woo00<mk`000000
100000=>LgooOol01Goo1`002Woo1`0027oo1`0000=>LgooOol01goo00=N
m`000000100000<mkgooOol00Woo1`002Woo1`0017oo00<mk`0000001000
00=>LgooOol01Goo1`00CGoo00=Nm`0000001P0000=NmgooOol03Woo1`00
2Woo1`00f7oo1`005goo1`00E7oo000KOol7000AOol00ekg000000060000
0ekgOomoo`3NOol2G_L2CW<2?Nl00`00Oomoo`08Ool70034Ool00dic0000
000500000ekgOomoo`04Ool7000:Ool70008Ool700000ekgOomoo`07Ool0
0ekg000000050004Ool7000:Ool70004Ool00dic0000000500000ekgOomo
o`04Ool7001>Ool00ekg0000000600000ekgOomoo`0=Ool7000:Ool7003H
Ool7000GOol7001DOol001]oo`L0019oo`03CW<0000000H00003CW=oogoo
0>ioo`L00<Eoo`P00003?Nm>Lekg00=oo`L000Yoo`L000Qoo`L000]oo`L0
00Aoo`L000Yoo`L000Eoo`P00003?Nm>Lekg00=oo`L004moo`03CW<00000
00H00003CW=oogoo00aoo`L000Yoo`L00=Qoo`L001Moo`L005Aoo`006goo
1`004goo00=>L`0000001P0000=>LgooOol0kGoo1`00aGoo00=>L`000000
2@0000=>Lekg00001P002Woo1`0027oo1`002goo1`0017oo1`002Woo1`00
1Goo00=>L`0000002@0000=>Lekg00001P00D7oo00=>L`0000001P0000=>
LgooOol02goo00<mk`000000100000=NmgooOol01Woo00=Nm`0000001000
00<mkgooOol0eWoo1`005goo1`00E7oo000KOol7000DOol00dic00000006
00000dicOomoo`3[Ool00ekg000000050036Ool00dic0000000A000:Ool7
0008Ool7000;Ool70004Ool7000:Ool70006Ool00dic0000000A001AOol0
0dic0000000600000dicOomoo`0:Ool00dic0000000400000cg_Oomoo`06
Ool00cg_0000000400000dicOomoo`3FOol7000GOol7001DOol001]oo`L0
01Eoo`03CW<0000000H00003?Nmoogoo0>Yoo`03CW<0000000@00003?Nmo
ogoo0<Eoo`03G_L00000010000Yoo`L000Qoo`L000]oo`L000Aoo`L000Yo
o`L000Moo`03G_L000000100059oo`03CW<0000000H00003?Nmoogoo00Yo
o`L00003CW=oogoo00Aoo`03CW<0000000D00003G_Moogoo0=Ioo`L001Mo
o`L005Aoo`006goo1`005Woo00=>L`0000001P0000=>LgooOol0fWoo0Ukg
0Tic00<mk`00CW<027oo00<mk`000000100000<mkgooOol0agoo00=Nmdic
00003P002Woo1`0027oo1`002Woo00=Nm`0000001@0017oo1`002Woo1`00
2Goo00=Nmdic00003P00Dgoo00=>L`0000001P0000=>LgooOol02Goo00=>
L`0000001@0000HmkekgOomooekg?Nl700000dicOomoo`3GOol7000GOol7
001DOol001]oo`L001Moo`03CW<0000000H00003CW=oogoo0=Uoo`L00003
CW=oogoo00Aoo`03CW<0000000D00003G_Moogoo0<Yoo`9Nm`03CW<mk`00
00T000Yoo`L000Qoo`L00003G_Moogoo00Moo`03G_L0000000@00003?Nmo
ogoo009oo`L00003G_Moogoo00Moo`L000aoo`9Nm`03CW<mk`0000T005Ao
o`03CW<0000000H00003CW=oogoo00Uoo`03?Nl0000001000003?Nmoogoo
0=Qoo`L001Moo`L005Aoo`006goo1`0067oo00=>L`0000001P0000=Nmgoo
Ool0f7oo00<mk`0000001@0000HmkekgOomooekg?Nl8003AOol00ekgCW<m
k`07000:Ool70008Ool700000dicOomoo`07Ool00dic0000000400000dic
Oomoo`02Ool700000dicOomoo`07Ool7000@Ool00ekgCW<mk`07001EOol0
0dic0000000600000ekgOomoo`09Ool00cg_0000000>00000cg_Oomoo`3I
Ool7000GOol7001DOol001]oo`L001Uoo`03CW<0000000D00003?Nmoogoo
0=Qoo`03CW<0000001800003CW=oogoo0=9oo`L000Yoo`L000Qoo`P000Uo
o`L00003CW=oogoo009oo`L00003?Nmoogoo00Ioo`03G_L0000000D001=o
o`L005Ioo`03CW<0000000D00003?Nmoogoo00Yoo`03G_L0000000`00003
G_Moogoo0=Yoo`L001Moo`L005Aoo`006goo1`006Woo00=>L`0000001@00
00=>LgooOol0egoo00=Nm`0000004P00b7oo00INmdicCW<mk`00G_L7Ool7
000:Ool70008Ool800000dicOomoo`05Ool00dic000000050005Ool80000
0ekgOomoo`05Ool00dic0000000400000cg_Oomoo`04Ool01UkgCW=>Lcg_
001Nm`Moo`L005Moo`03CW<0000000D00003CW=oogoo00Yoo`03CW<00000
00X00003CW=oogoo0=]oo`L001Moo`L005Aoo`006goo1`006goo00<mk`00
00001@00fWoo4`0000=NmgooOol0aGoo1P0000<mkgooOol017oo00=>L`00
0000100000<mkgooOol027oo1`0027oo2@0000=NmgooOol00goo00=Nm`00
00001@0000<mkgooOol00goo200000<mkgooOol01Goo1`0000<mkgooOol0
0goo1P0000<mkgooOol017oo00=>L`000000100000<mkgooOol0EWoo00<m
k`0000001@002Woo00=Nm`0000003@0000<mkekgOol0fWoo1`005goo1`00
E7oo000BOol00`00CW=Nm`06Ool7000LOol700000ekgOomoo`3GOolB0000
0ekgOomoo`36Ool00dic0000000400001Sg_G_MoogooG_M>L`L00003?Nmo
ogoo00Qoo`L000Qoo`X00005CW=NmgooG_M>L`0800000ekgOomoo`03Ool:
00001DicG_MoogooG_L0200000=>LgooOol00goo00=>L`000000100000Hm
kekgOomooekgCW<700000cg_Oomoo`1GOol700000ekgOomoo`06Ool00ekg
0000000@00000ekgOomoo`3?Ool00`00CW=Nm`06Ool7000>Ool00`00CW=N
m`06Ool7001DOol0019oo`<00003?NmNmgoo00=oo`L001aoo`03CW<00000
00@00003CW=oogoo0=Moo`03?Nl0000000d00003?NmNmgoo0<Uooa<00003
G_Moogoo00Qoo`L000Qoo`H00003?Nl0000000d00003CW=oogoo00AooaL0
00Mooa<00003G_Moogoo05Moo`03CW<0000000@00003CW=oogoo00Ioo`L0
0006?NmNmgooOomNmcg_1P0000<mkgooOol0cgoo0`0000<mkekgOol00goo
1`003Woo0`0000<mkekgOol00goo1`00E7oo000BOol5000014icOomoogoo
1`0077oo00=Nm`000000100000<mkgooOol0egoo00=>L`000000100000=>
Lekg?Nl0100000<mkekgOol0bgoo00=>L`0000003`0000<mkgooOol02Goo
1`0027oo1P0000=oocg_0000300000<mkgooOol01Goo1`0000=Nm`000000
300000=>LgooOol01Goo00=>L`0000003`0000<mkgooOol0F7oo00=Nm`00
0000100000<mkgooOol01Goo00=>L`000000100000<mkgooOol017oo00<m
k`000000100000=>LgooOol0cWoo1@0000A>LgooOomoo`L000ioo`D00004
CW=oogooOol7001DOol0019oo`L00003G_Moo`0000H000eoo`03G_M>Ldic
00<mk`03001oogoo00Moo`L00=Uoo`03G_L0000000@00003?Nmoogoo0==o
o`03CW<0000000d00003?Nmoogoo00Yoo`L000Qoo`H0009oo`03?Nl00000
00T00003?Nmoogoo00Ioo`L00003OomNm`0000/00003?Nmoogoo00Moo`03
CW<0000000d00003?Nmoogoo04Yoo`03G_M>Ldic00<mk`03001oogoo00Mo
o`L000Moo`03?Nl0000000@00003G_Moogoo00Aoo`03G_L0000000@00003
?Nmoogoo0<ioo`L00003G_Moo`0000H000ioo`L00003G_Moo`0000H005Ao
o`004Woo200000=>L`0000001@003Goo1`0000=NmgooOol01Woo1`00fWoo
1`00eWoo00=Nm`0000002`0000<mkgooOol02goo1`0027oo1P000goo00=>
L`0000001`0000=>LgooOol01goo1`000Woo00=Nmcg_0000200000=>Lgoo
Ool02Goo00=Nm`0000002`0000<mkgooOol0Bgoo1`0000=NmgooOol01Woo
1`001goo1`0027oo1`00d7oo200000=>L`0000001@003Woo200000=>L`00
00001@00E7oo000BOol@000=Ool00cg_0000000400000dicOomoo`05Ool0
0ekg00000005003JOol700000ekgOomoo`3EOol00ekgCW<mk`050002?Nl0
0dicG_Moo`0=Ool7000BOol00ekg?Nlmk`0300000cg_CW=oo`0:Ool70004
Ool00ekg?Nl0000300000cg_CW=oo`0>Ool00ekgCW<mk`050002?Nl00dic
G_Moo`1=Ool00cg_0000000400000dicOomoo`05Ool00ekg000000050007
Ool70008Ool7003@Ool@000>Ool@001DOol0019oo`03G_Lmk`0000d000eo
o`03CW<0000000@00003?Nmoogoo00Eoo`03CW<0000000D00=Yoo`03?Nl0
000000@00003CW=oogoo0>moo`L002Eoo`L007Eoo`03CW<0000000@00003
?Nmoogoo00Eoo`03CW<0000000D000Moo`L00003G_Moogoo00Aoo`03G_L0
000000D00=1oo`03G_Lmk`0000d000ioo`03G_Lmk`0000d005Aoo`0057oo
00=Nmcg_00002`003Goo00=Nm`0000001@0000=>LgooOol017oo1`0000<m
kgooOol0f7oo00=>L`000000100000<mkgooOol0kgoo1`009Goo1`00MGoo
00=Nm`0000001@0000=>LgooOol017oo1`0000<mkgooOol01Goo00<mk`00
0000100000<mkgooOol017oo00<mk`000000100000<mkgooOol0d7oo00=N
mcg_00002`0047oo00=Nmcg_00002`00E7oo000FOol00ekg00000009000>
Ool800001DicG_MoogooCW<0200000=>LgooOol0f7oo00=Nm`0000004000
iWoo1`009Goo1`00MWoo200000E>LekgOomoodic00P00003CW=oogoo00Eo
o`03?Nl0000000D00006?NmNmgooOomNmcg_1`0000<mkgooOol0dWoo00=N
m`0000002@004Woo00=Nm`0000002@00E7oo000HOol00cg_00000007000>
Ool00dic0000000B003LOolB003VOol7000UOol7001fOol00dic0000000B
0008Ool00ekg0000000B00000ekgOomoo`3DOol00cg_00000007000DOol0
0cg_00000007001DOol001Uoo`03?Nl0000000H000moo`03?Nl000000100
0003G_Moogoo0=Yooa800>Ioo`L002Eoo`L007Moo`03?Nl0000001000003
G_Moogoo00Moo`03?Nl0000001000003?Nmoogoo0=Ioo`03?Nl0000000H0
01Eoo`03?Nl0000000H005Aoo`006Woo00<mk`0000001@003goo00=Nm`00
00003`0000<mkgooOol0fgoo00<mk`0000003`00iWoo1`009Goo1`00Mgoo
00=Nm`0000003`0000<mkgooOol02Goo4@0000<mkgooOol0f7oo00<mk`00
00001@005Woo00<mk`0000001@00E7oo000KOol7000@Ool00ekg0000000=
00000dicOomoo`3LOol00dic0000000?003VOol7000UOol7001hOol00ekg
0000000=00000dicOomoo`0:Ool00ekg?Nl0000=00000cg_Oomoo`3JOol7
000GOol7001DOol001]oo`03CW<0000000@0019oo`03CW<0000000X00003
G_Moogoo0=eoo`03G_L0000000l00>Ioo`L002Eoo`L007Yoo`03CW<00000
00X00003G_Moogoo00eoo`03CW<0000000X00003CW=oogoo0=]oo`03CW<0
000000@001Moo`03CW<0000000@005Aoo`0077oo1P0057oo00=>Lcg_?Nl0
100000<mkdicG_L0hWoo4@00iWoo1`009Goo1`00O7oo00=>Lcg_?Nl01000
00<mkdicG_L04goo00=>Lcg_?Nl010000Sg_00=>LgooOol0gWoo1P0067oo
1P00E7oo003oOoooOoooOoooOom;Ool005Uoo`03001oogoo0?mooomooomo
onioo`00FWoo0`00ogooogooogookGoo001MOol3003oOoooOoooOooZOol0
061oo`<00?mooomooomoodioo`03001oogoo09Ioo`00Hgoo0`00ogooogoo
ogooB7oo0`00VGoo001VOol3003oOoooOoooOom3Ool2002LOol006Uoo`<0
0?mooomooomooceoo`<009ioo`00K7oo0`00ogooogooogoo>7oo0P00XGoo
001_Ool3003oOoooOoooOolbOol3002SOol0079oo`<00?mooomooomoobeo
o`800:Ioo`00MGoo0`00ogooogooogoo9goo0`00Z7oo001hOol3003oOooo
OoooOolQOol3002[Ool007]oo`@00=Ioo`03001oogoo0?mooomood5oo`80
0:ioo`00Ogoo0`00e7oo0P00ogooogoo?Woo0`00/7oo0022Ool3003COol0
0`00Oomoo`3oOoooOoliOol2002cOol008Eoo`<00=5oo`800?mooomoocIo
o`<00;Eoo`00R7oo0`00d7oo00<007ooOol0ogooogoo<Goo0P00^7oo002;
Ool3003>Ool2003oOoooOol^Ool3002jOol008ioo`<00<eoo`03001oogoo
0?mooomoobUoo`800;eoo`00TGoo0`00bgoo0P00ogooogoo9Woo0`00_goo
002DOol3003:Ool00`00Oomoo`3oOoooOolQOol20032Ool009Moo`<00<Qo
o`800?mooe=oo`03001oogoo0<Moo`<00<Aoo`00VWoo0`00agoo00<007oo
Ool0ogooCgoo00<007ooOol0aGoo0`00agoo002MOol30035Ool2003oOom>
Ool00`00Oomoo`34Ool2003:Ool00:1oo`<00<Aoo`03001oogoo0?moodYo
o`03001oogoo0<9oo`<00<aoo`00Xgoo0`00`Woo0P00ogooBGoo00<007oo
Ool0`Goo0P00cgoo002VOol30031Ool00`00Oomoo`3oOom5Ool00`00Oomo
o`2oOol3003AOol00:Uoo`<00;moo`800?moodAoo`03001oogoo0;ioo`80
0=Aoo`00[7oo0`00_Woo0P00ogoo@Goo00<007ooOol0_7oo0`00eWoo002_
Ool3002mOol00`00Oomoo`3oOolmOol00`00Oomoo`2kOol2003IOol00;9o
o`<00;]oo`800?moocaoo`03001oogoo0;Uoo`<00=]oo`00]Goo1000^Goo
00<007ooOol0ogoo>7oo00<007ooOol0^7oo0P00gWoo002iOol3002gOol2
003oOolgOol00`00Oomoo`2fOol3003POol00;aoo`<00;Ioo`03001oogoo
0?mooc=oo`03001oogoo0;Aoo`<00>=oo`00_goo0`00]7oo0P00ogoo<Woo
00<007ooOol0/goo0P00iWoo0032Ool3002cOol00`00Oomoo`2cOol00`00
Oomoo`1gOol00`00Oomoo`2aOol3003XOol00<Eoo`<00;5oo`800;=oo`03
001oogoo07Ioo`03001oogoo0;1oo`800>]oo`00b7oo0`00/7oo00<007oo
Ool0/7oo00<007ooOol0MGoo00<007ooOol0[Woo0`00kGoo003;Ool3002^
Ool2002`Ool00`00Oomoo`1dOol00`00Oomoo`2]Ool2003`Ool00<ioo`<0
0:eoo`03001oogoo0:eoo`03001oogoo07=oo`03001oogoo0:]oo`<00?9o
o`00dGoo0`00Zgoo0P00[Goo00<007ooOol0LWoo00<007ooOol0ZWoo0P00
mGoo003DOol3002ZOol00`00Oomoo`2ZOol00`00Oomoo`1aOol00`00Oomo
o`2XOol3003gOol00=Moo`<00:Qoo`800:Yoo`03001oogoo071oo`03001o
ogoo0:Ioo`<00?Yoo`00fWoo0`00Ygoo00<007ooOol0Ygoo00<007ooOol0
Kgoo00<007ooOol0YGoo0P00oGoo003MOol3002UOol2002WOol00`00Oomo
o`1^Ool00`00Oomoo`2SOol3003oOol00>1oo`<00:Aoo`800:Eoo`03001o
ogoo06eoo`03001oogoo0:9oo`800?moo`=oo`00hgoo0`00Xgoo00<007oo
Ool0XWoo00<007ooOol0K7oo00<007ooOol0X7oo0`00ogoo1Goo003VOol3
002QOol2002ROol00`00Oomoo`1[Ool00`00Oomoo`2OOol2003oOol8Ool0
0>Uoo`<00:1oo`03001oogoo09moo`03001oogoo06Uoo`8009moo`<00?mo
o`Yoo`00k7oo0`00WWoo0P00Wgoo00<007ooOol0J7oo00<007ooOol0WGoo
0P00ogoo3Goo003_Ool4002LOol00`00Oomoo`2LOol00`00Oomoo`1WOol0
0`00Oomoo`2KOol3003oOol?Ool00?=oo`<009Yoo`8009aoo`03001oogoo
06Ioo`03001oogoo09Yoo`800?mooa9oo`00mWoo0`00VGoo00<007ooOol0
VGoo00<007ooOol0IGoo00<007ooOol0V7oo0`00ogoo57oo003iOol3002G
Ool2002IOol00`00Oomoo`1TOol00`00Oomoo`2FOol3003oOolGOol00?ao
o`<009Ioo`03001oogoo09Ioo`03001oogoo06=oo`03001oogoo09Eoo`80
0?mooaYoo`00ogoo0`00U7oo0P00UWoo00<007ooOol0HWoo00<007ooOol0
Tgoo0`00ogoo77oo003oOol3Ool3002COol00`00Oomoo`2COol00`00Oomo
o`1QOol00`00Oomoo`2BOol2003oOolOOol00?moo`Ioo`<0095oo`8009=o
o`03001oogoo061oo`03001oogoo091oo`<00?moob5oo`00ogoo2Goo0`00
T7oo00<007ooOol0T7oo00<007ooOol0Ggoo00<007ooOol0Sgoo0P00ogoo
97oo003oOol<Ool3002>Ool2002@Ool00`00Oomoo`1NOol00`00Oomoo`2=
Ool3003oOolVOol00?moo`moo`<008eoo`03001oogoo08eoo`03001oogoo
05eoo`03001oogoo08aoo`800?moobUoo`00ogoo4Woo0`00Rgoo0P00SGoo
00<007ooOol0G7oo00<007ooOol0RWoo0`00ogoo:goo003oOolEOol3002:
Ool2002;Ool00`00Oomoo`1KOol00`00Oomoo`29Ool2003oOol^Ool00?mo
oaQoo`<008Uoo`03001oogoo08Qoo`03001oogoo05Yoo`03001oogoo08Mo
o`<00?mooc1oo`00ogoo6goo0`00Qgoo0P00R7oo00<007ooOol0FGoo00<0
07ooOol0QGoo0`00ogoo<goo003oOolNOol30026Ool00`00Oomoo`25Ool0
0`00Oomoo`1HOol00`00Oomoo`24Ool2003oOolfOol00?moob5oo`<008Ao
o`8008Eoo`03001oogoo05Moo`03001oogoo089oo`<00?moocQoo`00ogoo
97oo0`00Pgoo00<007ooOol0PWoo00<007ooOol0EWoo00<007ooOol0PGoo
0P00ogoo>goo003oOolWOol30021Ool20022Ool00`00Oomoo`1EOol00`00
Oomoo`1oOol3003oOolmOol00?moobYoo`@007moo`03001oogoo07moo`03
001oogoo05Aoo`03001oogoo07ioo`800?mood1oo`00ogoo;Woo0`00OGoo
0P00Ogoo00<007ooOol0Dgoo00<007ooOol0O7oo0`00ogoo@Woo003oOola
Ool3001lOol00`00Oomoo`1lOol00`00Oomoo`1BOol00`00Oomoo`1kOol2
003oOom5Ool00?moocAoo`<007Yoo`8007aoo`03001oogoo055oo`03001o
ogoo07Uoo`<00?moodMoo`00ogoo=goo0`00NGoo00<007ooOol0NGoo00<0
07ooOol0D7oo00<007ooOol0N7oo0P00ogooBWoo003oOoljOol3001gOol2
001iOol00`00Oomoo`1?Ool00`00Oomoo`1fOol3003oOom<Ool00?mooceo
o`<007Ioo`03001oogoo07Ioo`03001oogoo04ioo`03001oogoo07Aoo`<0
0?moodmoo`00ogoo@7oo0`00M7oo0P00MWoo00<007ooOol0CGoo00<007oo
Ool0Lgoo0P00ogooDWoo003oOom3Ool3001cOol00`00Oomoo`1cOol00`00
Oomoo`1<Ool00`00Oomoo`1aOol3003oOomDOol00?moodIoo`<0075oo`80
07=oo`03001oogoo04]oo`03001oogoo071oo`800?mooeMoo`00ogooBGoo
0`00L7oo0P00LGoo00<007ooOol0BWoo00<007ooOol0KWoo0`00ogooFGoo
003oOom<Ool3001_Ool00`00Oomoo`1^Ool00`00Oomoo`19Ool00`00Oomo
o`1]Ool2003oOomLOol00?moodmoo`<006eoo`8006ioo`03001oogoo04Qo
o`03001oogoo06]oo`<00?mooeioo`00ogooDWoo0`00K7oo00<007ooOol0
Jgoo00<007ooOol0Agoo00<007ooOol0JWoo0P00ogooHGoo003oOomEOol3
001ZOol2001[Ool00`00Oomoo`16Ool00`00Oomoo`1XOol3003oOomSOol0
0?mooeQoo`<006Uoo`03001oogoo06Qoo`03001oogoo04Eoo`03001oogoo
06Moo`800?moofIoo`00ogooFgoo0`00Igoo0P00J7oo00<007ooOol0A7oo
00<007ooOol0IGoo0`00ogooJ7oo003oOomNOol3001VOol00`00Oomoo`1U
Ool00`00Oomoo`13Ool00`00Oomoo`1SOol3003oOom[Ool00?moof5oo`<0
06Aoo`8006Eoo`03001oogoo049oo`03001oogoo069oo`800?moofioo`00
ogooI7oo1000HWoo00<007ooOol0HWoo00<007ooOol0@Goo00<007ooOol0
H7oo0`00ogooL7oo003oOomXOol3001POol2001ROol00`00Oomoo`10Ool0
0`00Oomoo`1OOol2003oOomcOol00?moof]oo`<005moo`03001oogoo05mo
o`03001oogoo03ioo`8005moo`<00?moogEoo`00ogooKWoo0`00GGoo0P00
Ggoo00<007ooOol0?Goo00<007ooOol0GGoo0P00ogooN7oo003oOomaOol3
001LOol00`00Oomoo`1LOol00`00Oomoo`0lOol00`00Oomoo`1KOol3003o
OomjOol00?moogAoo`<005Yoo`8005aoo`03001oogoo03]oo`03001oogoo
05Yoo`800?moogeoo`00ogooMgoo0`00FGoo00<007ooOol0FGoo00<007oo
Ool0>Woo00<007ooOol0F7oo0`00ogooOgoo003oOomjOol3001GOol2001I
Ool00`00Oomoo`0iOol00`00Oomoo`1GOol2003oOon2Ool00?moogeoo`<0
05Ioo`8005Moo`03001oogoo03Qoo`03001oogoo05Eoo`<00?moohAoo`00
ogooP7oo0`00EGoo00<007ooOol0E7oo00<007ooOol0=goo00<007ooOol0
Dgoo0`00ogooQgoo003oOon3Ool3001COol2001DOol00`00Oomoo`0fOol0
0`00Oomoo`1BOol2003oOon:Ool00?moohIoo`<0059oo`03001oogoo055o
o`03001oogoo03Eoo`03001oogoo051oo`<00?moohaoo`00ogooRGoo0`00
D7oo0P00DGoo00<007ooOol0=7oo00<007ooOol0Cgoo0P00ogooSgoo003o
Oon<Ool3001?Ool00`00Oomoo`1>Ool00`00Oomoo`0cOol00`00Oomoo`1=
Ool3003oOonAOol00?moohmoo`<004eoo`8004ioo`03001oogoo039oo`03
001oogoo04aoo`800?mooiAoo`00ogooTWoo0`00C7oo00<007ooOol0Bgoo
00<007ooOol0<Goo00<007ooOol0BWoo0`00ogooUWoo003oOonEOol3001:
Ool2001;Ool00`00Oomoo`0`Ool00`00Oomoo`19Ool2003oOonIOol00?mo
oiQoo`<004Uoo`03001oogoo07Yoo`03001oogoo04Moo`<00?mooi]oo`00
ogooVgoo0`00Agoo0P00NGoo00<007ooOol0AGoo0`00ogooWWoo003oOonN
Ool40015Ool00`00Oomoo`1eOol00`00Oomoo`14Ool2003oOonQOol00?mo
oj9oo`<004=oo`8007Aoo`03001oogoo049oo`<00?mooj=oo`00ogooYGoo
0`00@Woo00<007ooOol0L7oo00<007ooOol0@Goo0P00ogooYWoo003oOonX
Ool30010Ool2001_Ool00`00Oomoo`0oOol3003oOonXOol00?mooj]oo`<0
03moo`03001oogoo06]oo`03001oogoo03ioo`800?mooj]oo`00ogoo[Woo
0`00?Goo0P00JWoo00<007ooOol0?7oo0`00ogoo[Goo003oOonaOol3000l
Ool2001WOol00`00Oomoo`0kOol2003oOon`Ool00?mookAoo`<003]oo`03
001oogoo06=oo`03001oogoo03Uoo`<00?mook9oo`00ogoo]goo0`00>Goo
0P00HWoo00<007ooOol0>7oo0P00ogoo]Goo003oOonjOol3000hOol00`00
Oomoo`1NOol00`00Oomoo`0fOol3003oOongOol00?mookeoo`<003Ioo`80
05eoo`03001oogoo03Aoo`<00?mookYoo`00ogoo`7oo0`00=Goo00<007oo
Ool0Sgoo0P00ogoo_Goo003oOoo3Ool3000cOol2002<Ool3003oOonoOol0
0?moolIoo`<0039oo`03001oogoo08Moo`800?mool9oo`00ogoobGoo0`00
<7oo0P00Q7oo0`00ogooa7oo003oOoo<Ool3000_Ool00`00Oomoo`1oOol2
003oOoo7Ool00?moolmoo`<002eoo`8007aoo`<00?moolUoo`00ogoodWoo
0`00;7oo00<007ooOol0Mgoo0P00ogooc7oo003oOooEOol3000ZOol2001d
Ool3003oOoo>Ool00?moomQoo`@002Qoo`03001oogoo06moo`800?moom5o
o`00ogoog7oo0`009Woo00<007ooOol0Jgoo0`00ogoodgoo003oOooOOol3
002>Ool3003oOooFOol00?moon9oo`<008Uoo`800?moomUoo`00ogooiGoo
0`00Pgoo0`00ogoofgoo003oOooXOol3001nOol2003oOooNOol00?moon]o
o`<007Qoo`<00?moon1oo`00ogookWoo0`00Lgoo0P00ogoohgoo003oOooa
Ool3001]Ool3003oOooUOol00?moooAoo`<006Qoo`800?moonQoo`00ogoo
mgoo0`00ogooogooD7oo003oOoojOol30004Ool7000AOol00dic00000005
00000cg_Oomoo`0;Ool00ekgCW<mk`0500000cg_CW=Nm`0COol00ekgCW<m
k`0500000cg_CW=Nm`0?Ool00ekg?Nl0000400000cg_CW=Nm`3oOooHOol0
0?moooeoo`<00003Ool0000000D0011oo`03G_L0000000H000aoo`03G_Lm
k`0000X00003?NmNmgoo00ioo`03G_Lmk`0000X00003?NmNmgoo00]oo`03
?Nl0000000P00?moomQoo`00ogooogoo0Woo1`0047oo00<mk`0000001@00
00=>LgooOol02Goo00<mk`0000003@0000=>LgooOol02goo00<mk`000000
3@0000=>LgooOol027oo00<mk`000000200000<mkgooOol0ogooeWoo003o
OoooOol2Ool7000?Ool00ekg0000000500000cg_Oomoo`09Ool00cg_0000
000?00000cg_Oomoo`09Ool00cg_0000000?00000cg_Oomoo`06Ool00dic
0000000900000cg_Oomoo`3oOooFOol00?mooomoo`9oo`L000moo`P00003
G_Moogoo00Qoo`03?Nl0000001400003?Nmoogoo00Moo`03?Nl000000140
0003?Nmoogoo00Eoo`03?Nl0000000T00003?Nmoogoo0?moomIoo`00ogoo
ogoo0Woo1`003Woo00=>L`0000001@0000=>LgooOol027oo00<mk`000000
1P0000I>LgooOomoodic?Nl700000dicOomoo`05Ool00cg_000000060000
1TicOomoogooCW<mk`L00003CW=oogoo00Aoo`03?Nl0000000@00006?NmN
mgooG_M>Lekgogoof7oo003oOoooOol2Ool7000=Ool00ekg000000050000
0cg_Oomoo`08Ool00ekg0000000500000cg_Oomoo`05Ool00cg_00000005
00000ekgOomoo`03Ool00ekg0000000500000cg_Oomoo`05Ool00cg_0000
000500000ekgOomoo`03Ool700000ekgOomoo`3oOooKOol00?mooomoo`9o
o`L000eoo`P00003G_Moogoo00Qoo`03?Nl0000000@00003?Nmoogoo00Mo
o`03?Nl0000000@00003?Nmoogoo00=oo`03?Nl0000000@00003?Nmoogoo
00Moo`03?Nl0000000@00003?Nmoogoo00=oo`L00?moomioo`00ogooogoo
0Woo1`0037oo00=>L`0000001@0000=>LgooOol027oo00=Nm`0000001@00
00=NmgooOol01goo00=Nm`0000001@0017oo00=Nm`0000001@0000=Nmgoo
Ool01goo00=Nm`0000001@001Goo1`00ogoogWoo003oOoooOol2Ool7000;
Ool00dic00000006000;Ool00dic0000000400000cg_Oomoo`09Ool00cg_
0000000400001DicOomoogooCW<01P0000<mkgooOol02Goo00<mk`000000
100000=>LgooOol00Woo1`00ogoogWoo003oOoooOol2Ool7000:Ool00ekg
0000000600000ekgOomoo`09Ool00cg_0000000400000dicOomoo`09Ool0
0dic0000000400001Cg_Oomoogoo?Nl01P0000=>LgooOol02Goo00=>L`00
0000100000<mkgooOol00Woo1`00ogoogWoo003oOoooOol2Ool70009Ool0
0ekg0000000600000cg_Oomoo`0:Ool00cg_0000000400000ekgOomoo`09
Ool00ekg0000000400001Cg_Oomoogoo?Nl01P0000=NmgooOol02Goo00=N
m`000000100000<mkgooOol00Woo1`00ogoogWoo003oOoooOol2Ool70009
Ool800000cg_Oomoo`0;Ool7000=Ool70003Ool7000=Ool70004Ool7003o
OooNOol00?mooomoo`9oo`L000Moo`03G_L0000000H00003?Nmoogoo00ao
o`L000eoo`L000=oo`L000eoo`L000Aoo`L00?moomioo`00ogooogoo0Woo
1`0017oo0Ukg00<mk`0000001P0000<mkgooOol03Goo1`003Goo1`000goo
1`003Goo1`0017oo1`00ogoogWoo003oOoooOol2OolE00000dicOomoo`0>
Ool7000=Ool70003Ool7000=Ool70004Ool7003oOooNOol00?mooomoo`9o
oaH00003?Nm>Lgoo00eoo`03?Nl0000000@00003G_Moogoo00Uoo`03G_L0
000000@00005?NmoogooOolmk`0600000ekgOomoo`09Ool00ekg00000004
00000cg_Oomoo`02Ool7003oOooNOol00?mooomoo`9ooaT00003CW=oogoo
00Yoo`03?Nl0000000@00003CW=oogoo00Uoo`03CW<0000000@00005?Nmo
ogooOolmk`0600000dicOomoo`09Ool00dic0000000400000cg_Oomoo`02
Ool7003oOooNOol00?mooomoo`9ooaX00003?Nmoogoo00Uoo`03CW<00000
00@00003?Nmoogoo00Uoo`03?Nl0000000@00005CW=oogooOom>L`060000
0cg_Oomoo`09Ool00cg_0000000400000dicOomoo`02Ool7003oOooNOol0
0?mooomoo`9ooa/00003?Nmoogoo00Uoo`L00003G_Moogoo00Moo`03G_L0
000000D00003G_Moogoo009oo`L00003G_Moogoo00Moo`03G_L0000000D0
0003G_Moogoo009oo`L00?moomioo`00ogooogoo0Woo700000=>LgooOol0
27oo00<mk`000000100000<mkgooOol01goo00<mk`000000100000<mkgoo
Ool00goo00<mk`000000100000<mkgooOol01goo00<mk`000000100000<m
kgooOol00goo1`00ogoogWoo003oOoooOol2Ool7000:Ool2G_L00dic?Nl0
0007000:Ool00ekg0000000500000cg_Oomoo`05Ool00cg_000000050000
0ekgOomoo`03Ool00ekg0000000500000cg_Oomoo`05Ool00cg_00000005
00000ekgOomoo`03Ool7003oOooNOol00?mooomoo`9oo`L000ioo`03CW<0
000000D00003CW=oogoo00Qoo`03CW<0000000H00006CW=oogooOom>Lcg_
1`0000=>LgooOol01Goo00=>L`0000001P0000I>LgooOomoodic?Nl70000
14icOomoogoo3`00ogoofGoo003oOoooOol2Ool7000?Ool00cg_00000004
00000cg_Oomoo`09Ool00cg_0000000A00000cg_Oomoo`07Ool00cg_0000
000A00000cg_Oomoo`02Ool?003oOooIOol00?mooomoo`9oo`L000moo`03
G_L0000000D000aoo`03?Nl0000000l00003?Nmoogoo00Uoo`03?Nl00000
00l00003?Nmoogoo00=oo`l00?moomUoo`00ogooogoo0Woo1`0047oo1`00
3Goo00=>L`0000003@0000=>LgooOol02goo00=>L`0000003@0000=>Lgoo
Ool017oo3`00ogoofGoo003oOoooOol2Ool7000@Ool7000>Ool00ekg?Nl0
000:00000cg_G_Moo`0>Ool00ekg?Nl0000:00000cg_G_Moo`06Ool?003o
OooIOol00?mooomoo`9oo`L000moo`03G_L0000000D0011oo`03G_M>Lcg_
00D00003?Nm>Lekg01=oo`03G_M>Lcg_00D00003?Nm>Lekg00aoo`L00?mo
omioo`00ogooogoo0Woo1`003goo00=>L`000000100000<mkgooOol0@goo
1`00ogoogWoo003oOoooOol2Ool7000>Ool00ekg0000000500000cg_Oomo
o`13Ool7003oOooNOol00?mooomoo`9oo`L000aoo`03G_Lmk`0000L00003
G_Moogoo04=oo`L00?moomioo`00ogooogoo0Woo7@00AWoo1`00ogoogWoo
003oOoooOol2OolL00000ekgOomoo`14Ool00ekg00000004003oOooNOol0
0?mooomoo`9ooa/00003?Nmoogoo04Moo`03CW<0000000800?moomioo`00
ogooogoo0Woo6P0000<mkgooOol0BWoo00=>L`000000ogoogWoo003oOooo
Ool2OolI00000ekgOomoo`1<Ool00ekg?Nmoo`3oOooMOol00?mooomoo`9o
oa<000<mk`03CW=Nmgoo0?mooomooc1oo`00ogooogooogooogooBgoo003o
OoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogooogoo
Bgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogoo
ogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00
ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomo
od]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomo
oomooomood]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool0
0?mooomooomooomood]oo`00ogooogooogooogooBgoo003oOoooOoooOooo
Oom;Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo003oOooo
OoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo
003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogoo
ogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogoo
ogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]o
o`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomo
oomood]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mo
oomooomooomood]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;
Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo003oOoooOooo
OoooOom;Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo003o
OoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogooogoo
Bgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogoo
ogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00
ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomo
od]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomo
oomooomood]oo`00ogooogooogooogooBgoo003oOoooOoooOoooOom;Ool0
0?mooomooomooomood]oo`00ogooogooogooogooBgoo003oOoooOoooOooo
Oom;Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo003oOooo
OoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogooogooBgoo
003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogooogooogoo
ogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]oo`00ogoo
ogooogooogooBgoo003oOoooOoooOoooOom;Ool00?mooomooomooomood]o
o`00ogooogooogooogooBgoo0000\
\>"], "PlacedGraphics",
  ImageSize->{281, 136.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["is represented by the list: ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["\:f35f",
    FormatType->StandardForm,
    FontFamily->"Courier New",
    FontSize->10]
}], "Text"],

Cell[BoxData[
    \(\(t = {Root, {12, {5, {6, "\<beta\>"}}, "\<alpha\>", 
            28, {11, {4, 7}}}};\)\)], "Input",
  CellLabel->"In[48]:="],

Cell[TextData[{
  StyleBox["We also need function ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["sons", "InlineInput",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox[" to obtain all the sons of a given tree:",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(sons[s_] := s\), "\n", 
    \(sons[{a___, {b_, c__}, d___}] := sons[{a, b, d}]\)}], "Input",
  CellLabel->"In[49]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(sons[Last[t]]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \({12, 5, "alpha", 28, 11}\)], "Output",
  CellLabel->"Out[51]="]
}, Open  ]],

Cell["\<\
We will consider only numeric trees representing the frequencies of their \
respective words. We now set up the patterns comprising the Huffman \
algorithm. All of them implement one step of the iterative process which will \
build the Huffman tree. This process can be described as follows. Given the \
two smallest elements x, y of a list, we encapsulate them to form a subtree \
labeled x+y.\
\>", "Text"],

Cell[BoxData[
    \(patterns[x_, 
        y_] := {{a___, x, b___, y, c___} | {a___, y, b___, x, 
              c___} \[Rule] {a, b, {x + y, {x, y}}, c}, {a___, {x, t__}, 
            b___, {y, g__}, c___} \[Rule] {a, b, {x + y, {{x, t}, {y, g}}}, 
            c}, {a___, {y, t__}, b___, {x, g__}, c___} \[Rule] {a, 
            b, {x + y, {{y, t}, {x, g}}}, c}, {a___, {x, t__}, b___, y, 
            c___} \[Rule] {a, b, {x + y, {{x, t}, y}}, c}, {a___, {y, t__}, 
            b___, x, c___} \[Rule] {a, b, {x + y, {{y, t}, x}}, c}, {a___, x, 
            b___, {y, g__}, c___} \[Rule] {a, b, {x + y, {x, {y, g}}}, 
            c}, {a___, y, b___, {x, g__}, c___} \[Rule] {a, 
            b, {x + y, {y, {x, g}}}, c}}\)], "Input",
  CellLabel->"In[52]:="],

Cell[TextData[{
  StyleBox["using those transformations in processing the given vector of \
frequencies we arrive at function ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["huffman", "InlineInput",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[".",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["\:f35f",
    FormatType->StandardForm,
    FontFamily->"Courier New",
    FontSize->10]
}], "Text"],

Cell[BoxData[
    \(huffman[frec_] := 
      Module[{x, 
          y}, \[IndentingNewLine]FixedPoint[\(({x, y} = 
                Take[Sort[sons[#]], 2]; # /. patterns[x, y])\) &, frec, 
          Length[frec] - 1]]\)], "Input",
  CellLabel->"In[53]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(huffman[{20, 28, 4, 17, 12, 7}]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \({{88, {{37, {17, 
              20}}, {51, {28, {23, {12, {11, {4, 7}}}}}}}}}\)], "Output",
  CellLabel->"Out[54]="]
}, Open  ]],

Cell[TextData[StyleBox["The successive steps of the process to arrive at this \
result are the following:",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({20, 28, 4, 17, 12, 7}\)},
            {\({20, 28, 17, 12, {11, {4, 7}}}\)},
            {\({20, 28, 17, {23, {12, {11, {4, 7}}}}}\)},
            {\({28, {37, {17, 20}}, {23, {12, {11, {4, 7}}}}}\)},
            {\({{37, {17, 20}}, {51, {28, {23, {12, {11, {4, 7}}}}}}}\)},
            {\({{88, {{37, {17, 
                        20}}, {51, {28, {23, {12, {11, {4, 7}}}}}}}}}\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{20, 28, 4, 17, 12, 7}, {20, 28, 17, 12, {11, {4, 7}}}, {
        20, 28, 17, {23, {12, {11, {4, 7}}}}}, {28, {37, {17, 20}}, {23, {
        12, {11, {4, 7}}}}}, {{37, {17, 20}}, {51, {28, {23, {12, {11, {4, 
        7}}}}}}}, {{88, {{37, {17, 20}}, {51, {28, {23, {12, {11, {4, 
        7}}}}}}}}}}]]], "Output"],

Cell[TextData[{
  "To recover the original labels, i.e., substitute the numerical labels for \
their original characters at the leaves nodes, we need to apply rewriting on \
the Huffman tree. Function ",
  StyleBox["lettersTree", "Input"],
  " below receives a sentence, obtains its frequencies, obtains its Huffman \
tree and performs this rewriting."
}], "Text"],

Cell[BoxData[
    \(lettersTree[mesg_] := 
      Module[{f = frequencies[mesg], t, i, j, k, p, q, x, y, 
          z}, \[IndentingNewLine]t = 
          First[huffman[Last /@ \ f]]; \[IndentingNewLine]t = 
          t\  //. \ {i_Integer, {x___, j_Integer, y___}} \[Rule] {i, {x, 
                  j + 0.1, y}}; \[IndentingNewLine]While[
          f \[NotEqual] {}, \[IndentingNewLine]{i, j} = 
            First[f]; \[IndentingNewLine]p = 
            First[Position[t, j + 0.1]]; \[IndentingNewLine]t = 
            ReplacePart[t, i, p]; \[IndentingNewLine]f = 
            Rest[f]]; \[IndentingNewLine]t]\)], "Input",
  CellLabel->"In[55]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(t1 = lettersTree[message]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \({32, {{14, {" ", {8, {{4, {{2, {",", "c"}}, {2, {"g", 
                        "h"}}}}, {4, {"a", "d"}}}}}}, {18, {{8, {{4, {"i", 
                    "l"}}, {4, {{2, {"H", "k"}}, {2, {"m", 
                        "r"}}}}}}, {10, {{4, {"o", 
                    "t"}}, {6, {"e", {3, {"y", "u"}}}}}}}}}}\)], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell[TextData[StyleBox["Which corresponds to the tree (Note the blank space \
at the leftmost node):",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007c0001M1000`40O003
h00Oogoom7oo003oOoodOol00?moooAoo`00ogoom7oo003oOoodOol00?mo
ooAoo`00ogoom7oo003oOoodOol00?moooAoo`00ogoom7oo003oOoodOol0
0?moooAoo`00ogoom7oo003oOoodOol00?moooAoo`00ogoom7oo003oOood
Ool00?moooAoo`00ogoom7oo003oOoodOol00?moooAoo`00ogoom7oo003o
OoodOol00?moooAoo`00ogoom7oo003oOoodOol00?moooAoo`00ogoom7oo
003oOoodOol00?moooAoo`00ogoom7oo003oOoodOol00?moooAoo`00ogoo
m7oo003oOoodOol00?moooAoo`00ogoom7oo003oOoodOol00?moooAoo`00
ogoom7oo003oOoodOol00?moooAoo`00ogoom7oo003oOoodOol00?moooAo
o`00ogoom7oo003oOoodOol00?moooAoo`00ogoom7oo003oOoodOol00?mo
ooAoo`00ogoom7oo003oOomFOol3001@Ool40017Ool00?mooc9oo`<000Eo
o`<000Aoo`<0019oo`<0051oo`D004Ioo`00ogoo<Woo0`001Goo0`0017oo
0`004Woo0`00DGoo1000AWoo0024Ool7002VOol30005Ool30004Ool3000B
Ool3001COol3000aOol9000;Ool008=oo`T00:Eoo`<000Eoo`<000Aoo`<0
019oo`<005=oo`<0031oo`X000]oo`00PWoo1@0000=oo`0000000`0057oo
0`001Goo0`00QGoo0`001Goo0`0017oo0`004Woo0`00Dgoo0`00;goo1@00
0Woo10002goo0022Ool30005Ool3000DOol30004Ool40025Ool30005Ool3
0004Ool3000BOol3001DOol3000^Ool40004Ool3000;Ool008Yoo`<001Ao
o`<000=oo`D008Eoo`<000Eoo`<000Aoo`<0019oo`<005=oo`D002eoo`<0
00Eoo`<000]oo`00Jgoo1`004Woo2@0057oo0`000Woo1@00QWoo0`001Goo
0`0017oo0`004Woo0`00Dgoo1@00;Goo0`001Goo0`002goo001@Ool2000G
Ool;000>Ool;000DOol30002Ool30028Ool30005Ool30004Ool3000BOol4
001BOol6000/Ool30005Ool3000;Ool0055oo`8001Ioo`D0009oo`@000io
o`D00003Ool0000000<001Aoo`P008Qoo`@000=oo`@000=oo`@0019oo`P0
04eoo`L002aoo`<000Eoo`<000]oo`00D7oo0`005Goo10001Goo0`003Goo
10001Goo0`0057oo2000R7oo4@004goo2000CGoo0`0000Aoo`00000002ao
o`<000Eoo`<000]oo`00D7oo0`005Goo0`005Woo0`001Woo0`0057oo1P00
RWoo2P0000=oo`00000010004goo0`0000=oo`0000000P00C7oo0`000goo
0`00:goo0`001Goo0`002goo001@Ool3000EOol3000FOol30006Ool3000D
Ool70029Ool300000goo000000020003Ool5001WOol40003Ool4000ZOol3
0005Ool3000;Ool006Qoo`<001Ioo`<000Ioo`<001Aoo`<00003Ool00000
00800?moo`<000Eoo`<002Yoo`<000Eoo`<000]oo`00J7oo0`005Woo0`00
1Woo0`0057oo0`000Woo1000oWoo0`001Woo0`00:Goo0`001Goo0`002goo
001XOol40005Ool3000=Ool40005Ool3000DOol30003Ool4003mOol30006
Ool3000oOol006Qoo`@000Eoo`<000eoo`@000Eoo`<001Aoo`<000Aoo`<0
0?eoo`<000Ioo`<003moo`00JGoo2`003Woo2`0057oo0`00V7oo00<007oo
Ool05goo00<007ooOol0VWoo001ZOol:000?Ool:000DOol3002HOol00`00
Oomoo`0GOol00`00Oomoo`2JOol006]oo`L0019oo`T001Aoo`<009Uoo`03
001oogoo01Eoo`03001oogoo09]oo`00Dgoo00<007ooOol0Bgoo0`00VGoo
00<007ooOol05Goo00<007ooOol0QGoo00<007ooOol04goo001COol00`00
Oomoo`1;Ool3002IOol00`00Oomoo`0DOol00`00Oomoo`25Ool00`00Oomo
o`0DOol005Aoo`03001oogoo0>Moo`03001oogoo01=oo`03001oogoo08Eo
o`03001oogoo01Aoo`00E7oo00<007ooOol047oo00<007ooOol0e7oo00<0
07ooOol04goo00<007ooOol0Q7oo00<007ooOol05Goo001DOol00`00Oomo
o`0@Ool00`00Oomoo`3DOol00`00Oomoo`0BOol00`00Oomoo`1MOol00`00
Oomoo`0TOol00`00Oomoo`0FOol005Aoo`03001oogoo00moo`03001oogoo
01aoo`03001oogoo01Eoo`03001oogoo09moo`03001oogoo015oo`03001o
ogoo05ioo`03001oogoo02=oo`03001oogoo01Ioo`00EGoo00<007ooOol0
3Woo00<007ooOol077oo00<007ooOol05Goo00<007ooOol0Wgoo00<007oo
Ool047oo00<007ooOol0Ggoo00<007ooOol08Woo00<007ooOol05goo001E
Ool00`00Oomoo`0=Ool00`00Oomoo`0NOol00`00Oomoo`0COol00`00Oomo
o`2POol00`00Oomoo`0@Ool00`00Oomoo`1POol00`00Oomoo`0POol00`00
Oomoo`0HOol005Eoo`03001oogoo00eoo`03001oogoo01ioo`03001oogoo
01=oo`03001oogoo0:5oo`03001oogoo00moo`03001oogoo061oo`03001o
ogoo021oo`03001oogoo01Qoo`00EWoo00<007ooOol02goo00<007ooOol0
87oo00<007ooOol04Goo00<007ooOol0XWoo00<007ooOol03Woo00<007oo
Ool0HWoo00<007ooOol07Woo00<007ooOol06Goo001FOol00`00Oomoo`0;
Ool00`00Oomoo`0POol00`00Oomoo`0AOol00`00Oomoo`2ROol00`00Oomo
o`0>Ool00`00Oomoo`1SOol00`00Oomoo`0MOol00`00Oomoo`0IOol005Io
o`03001oogoo00Yoo`03001oogoo029oo`03001oogoo00moo`03001oogoo
0:Aoo`03001oogoo00aoo`03001oogoo06Aoo`03001oogoo01aoo`03001o
ogoo01Yoo`00EWoo00<007ooOol02Woo00<007ooOol08Woo00<007ooOol0
3goo00<007ooOol0Y7oo00<007ooOol037oo00<007ooOol0IGoo00<007oo
Ool06Woo00<007ooOol06goo001GOol00`00Oomoo`08Ool00`00Oomoo`0T
Ool00`00Oomoo`0=Ool00`00Oomoo`2UOol00`00Oomoo`0<Ool00`00Oomo
o`1UOol00`00Oomoo`0JOol00`00Oomoo`0KOol005Moo`03001oogoo00Qo
o`03001oogoo02Aoo`03001oogoo00eoo`03001oogoo0:Ioo`03001oogoo
00Yoo`03001oogoo06Moo`03001oogoo01Qoo`03001oogoo01aoo`00Egoo
00<007ooOol027oo00<007ooOol09Goo00<007ooOol02goo00<007ooOol0
Ygoo00<007ooOol02Woo00<007ooOol0Igoo00<007ooOol05goo00<007oo
Ool07Goo001HOol00`00Oomoo`06Ool00`00Oomoo`0VOol00`00Oomoo`0;
Ool00`00Oomoo`2WOol00`00Oomoo`0:Ool00`00Oomoo`1XOol00`00Oomo
o`0FOol00`00Oomoo`0MOol005Qoo`03001oogoo00Ioo`03001oogoo02Mo
o`03001oogoo00Yoo`03001oogoo0:Qoo`03001oogoo00Qoo`03001oogoo
06Yoo`03001oogoo01Aoo`03001oogoo01ioo`00F7oo00<007ooOol01Goo
00<007ooOol0:7oo00<007ooOol02Goo00<007ooOol0ZGoo00<007ooOol0
27oo00<007ooOol0JWoo00<007ooOol04goo00<007ooOol07goo001HOol0
0`00Oomoo`05Ool00`00Oomoo`0YOol00`00Oomoo`08Ool00`00Oomoo`2Y
Ool00`00Oomoo`07Ool00`00Oomoo`1/Ool00`00Oomoo`0BOol00`00Oomo
o`0OOol005Uoo`03001oogoo00=oo`03001oogoo02Yoo`03001oogoo00Mo
o`03001oogoo0:]oo`03001oogoo00Ioo`03001oogoo06aoo`03001oogoo
015oo`03001oogoo021oo`00FGoo00<007ooOol00goo00<007ooOol0:goo
00<007ooOol01Woo00<007ooOol0Zgoo00<007ooOol01Woo00<007ooOol0
KGoo00<007ooOol03goo00<007ooOol08Goo001NOol00`00Oomoo`0/Ool0
0`00Oomoo`05Ool00`00Oomoo`2/Ool00`00Oomoo`05Ool00`00Oomoo`1_
Ool00`00Oomoo`0>Ool00`00Oomoo`0QOol005ioo`03001oogoo02eoo`03
001oogoo00Aoo`03001oogoo0:eoo`03001oogoo00Aoo`03001oogoo06mo
o`03001oogoo00eoo`03001oogoo029oo`00SWoo00<007ooOol00goo00<0
07ooOol0[Woo00<007ooOol00goo00<007ooOol0LGoo00<007ooOol037oo
00<007ooOol08Woo002DOol00`00Oomoo`2dOol00`00Oomoo`1aOol00`00
Oomoo`0;Ool00`00Oomoo`0SOol00?mool5oo`03001oogoo00Uoo`03001o
ogoo02Aoo`00ogoo`Goo00<007ooOol02Goo00<007ooOol097oo003oOoo2
Ool00`00Oomoo`07Ool00`00Oomoo`0UOol00?moooAoo`00ogoom7oo000l
Ool9000FOol=003oOon<Ool003Yoo`/001Ioo`d00?moo`Yoo`<007moo`00
7Woo1P000Woo0`004Goo1@0000=oo`0000000`005Woo3@009Woo3@00Z7oo
3@0087oo1000DWoo1@00:7oo000LOol=000@Ool40005Ool3000GOol3000_
Ool=000MOol30005Ool3000LOol3000MOol30011Ool=000OOol4000MOol6
000^Ool:000UOol001]oo`@000Aoo`D0015oo`<000Ioo`<001Qoo`@002eo
o`d001eoo`<000Eoo`<001aoo`<001eoo`<0045oo`d001moo`<001aoo`/0
02Yoo`/002Eoo`006goo0`001Woo0`004Woo0`001Woo0`0067oo1000;Woo
0`009Woo0`001Goo0`0077oo0`007Goo0`006Woo1`008Goo0`00:7oo0`00
77oo1@0000=oo`0000000`00:Woo100017oo0`009Goo000KOol40005Ool3
000BOol30006Ool3000IOol4000^Ool4000TOol30005Ool3000LOol3000M
Ool3000HOol;000POol4000VOol3000KOol40005Ool3000YOol30007Ool3
000TOol001aoo`@000Aoo`<0019oo`<000Ioo`<001Yoo`H002]oo`@002Ao
o`<000Eoo`<001aoo`<001eoo`<001Qoo`D0009oo`@0021oo`@002Ioo`<0
01]oo`<0039oo`<000Moo`<002Aoo`0077oo2`004Woo10001Goo0`006goo
1P00:goo10008goo0`001Goo0`0077oo0`007Goo0`005goo10001Goo1000
87oo10009Goo0`006goo0`00?7oo0`0097oo000NOol9000BOol40005Ool3
000LOol6000[Ool6000POol30005Ool3000LOol3000MOol3000GOol30007
Ool3000QOol6000ROol3000KOol<000bOol3000UOol002Aoo`<001=oo`/0
01moo`<002aoo`H001moo`<000Eoo`<001aoo`<001eoo`<001Moo`<000Mo
o`<0029oo`H0025oo`<001]oo``002moo`H002Eoo`0077oo0`001Goo0`00
57oo2P007goo0`00;Goo1P007Woo0`001Goo0`0077oo0`007Goo0`005goo
0`001goo0`008goo1P007Woo1`006Goo10001Goo0`00;goo1P009Goo000M
Ool:000EOol9000GOol30005Ool3000`Ool3000NOol40004Ool3000LOol3
000MOol3000GOol30007Ool3000VOol3000NOol7000IOol40005Ool3000_
Ool6000UOol001eoo`X001]oo`<001Moo`@000Aoo`<0031oo`<001ioo`/0
01aoo`<001eoo`<001Moo`@000Eoo`@002Ioo`<001ioo`L001Yoo`/0039o
o`<002Eoo`007Woo1`007Goo0`0067oo10000Woo1000:7oo0`001Goo0`00
7Woo2`0077oo0`007Goo0`005goo10001Goo10007Woo0`001Goo0`0087oo
0`007Goo2@00:goo0`001Goo0`009Goo0012Ool3000HOol:000XOol40004
Ool3000NOol300000goo00000003000NOol3000MOol3000HOol;000OOol4
0004Ool3000POol3000NOol6000]Ool40004Ool3000UOol0049oo`<001Uo
o`L002]oo`@0009oo`@001ioo`<004Aoo`<001Uoo`X0021oo`@0009oo`@0
021oo`<0059oo`@0009oo`@002Eoo`00@Woo0`006goo1000;7oo2P007Woo
0`00A7oo0`006Woo1`008Woo2P0087oo0`00DWoo2P009Goo000lOol00`00
Oomoo`1BOol7000POol3000TOol3000MOol30014Ool7001aOol00`00Oomo
o`04Ool7000WOol003aoo`03001oogoo05Aoo`@0025oo`<002Aoo`<001eo
o`<004Ioo`@004]oo`03001oogoo02=oo`03001oogoo00Moo`@002Qoo`00
>goo00<007ooOol0:Woo00<007ooOol08goo00<007ooOol09goo0`000goo
00<007ooOol07Woo0`007Goo0`00UGoo00<007ooOol08goo00<007ooOol0
<goo000kOol00`00Oomoo`0[Ool00`00Oomoo`0QOol00`00Oomoo`0_Ool0
0`00Oomoo`3FOol00`00Oomoo`0QOol00`00Oomoo`0dOol002Aoo`03001o
ogoo01Aoo`03001oogoo02]oo`03001oogoo025oo`03001oogoo02moo`03
001oogoo01Moo`03001oogoo03moo`03001oogoo04aoo`03001oogoo02]o
o`03001oogoo021oo`03001oogoo03Eoo`009Goo00<007ooOol04Woo00<0
07ooOol0;Goo00<007ooOol07goo00<007ooOol0<Goo00<007ooOol05Goo
00<007ooOol0@7oo00<007ooOol0C7oo00<007ooOol0;7oo00<007ooOol0
7goo00<007ooOol0=Goo000UOol00`00Oomoo`0BOol00`00Oomoo`0^Ool0
0`00Oomoo`0NOol00`00Oomoo`0aOol00`00Oomoo`0EOol00`00Oomoo`0o
Ool00`00Oomoo`1<Ool00`00Oomoo`0]Ool00`00Oomoo`0NOol00`00Oomo
o`0fOol002Ioo`03001oogoo015oo`03001oogoo02moo`03001oogoo01ao
o`03001oogoo03=oo`03001oogoo01=oo`03001oogoo02Moo`03001oogoo
01Ioo`03001oogoo031oo`03001oogoo01Uoo`03001oogoo02ioo`03001o
ogoo01aoo`03001oogoo03Moo`009Woo00<007ooOol047oo00<007ooOol0
<7oo00<007ooOol077oo00<007ooOol0<goo00<007ooOol04goo00<007oo
Ool0:7oo00<007ooOol057oo00<007ooOol0<Goo00<007ooOol067oo00<0
07ooOol0;goo00<007ooOol077oo00<007ooOol0=goo000WOol00`00Oomo
o`0?Ool00`00Oomoo`0aOol00`00Oomoo`0JOol00`00Oomoo`0eOol00`00
Oomoo`0AOol00`00Oomoo`0YOol00`00Oomoo`0DOol00`00Oomoo`0bOol0
0`00Oomoo`0GOol00`00Oomoo`0`Ool00`00Oomoo`0JOol00`00Oomoo`0h
Ool002Moo`03001oogoo00moo`03001oogoo039oo`03001oogoo01Uoo`03
001oogoo03Eoo`03001oogoo015oo`03001oogoo02Yoo`03001oogoo019o
o`03001oogoo03=oo`03001oogoo01Ioo`03001oogoo035oo`03001oogoo
01Uoo`03001oogoo03Uoo`00:7oo00<007ooOol03Goo00<007ooOol0=7oo
00<007ooOol05goo00<007ooOol0=goo00<007ooOol03goo00<007ooOol0
;7oo00<007ooOol04Goo00<007ooOol0=7oo00<007ooOol05Goo00<007oo
Ool0<Woo00<007ooOol067oo00<007ooOol0>Goo000XOol00`00Oomoo`0=
Ool00`00Oomoo`0dOol00`00Oomoo`0GOol00`00Oomoo`0gOol00`00Oomo
o`0>Ool00`00Oomoo`0]Ool00`00Oomoo`0AOol00`00Oomoo`0dOol00`00
Oomoo`0DOol00`00Oomoo`0cOol00`00Oomoo`0GOol00`00Oomoo`0jOol0
02Uoo`03001oogoo00aoo`03001oogoo03Eoo`03001oogoo01Eoo`03001o
ogoo03Uoo`03001oogoo00eoo`03001oogoo02ioo`03001oogoo00moo`03
001oogoo03Eoo`03001oogoo01Aoo`03001oogoo03Aoo`03001oogoo01Eo
o`03001oogoo03]oo`00:Goo00<007ooOol037oo00<007ooOol0=Woo00<0
07ooOol057oo00<007ooOol0>Goo00<007ooOol037oo00<007ooOol0;goo
00<007ooOol03goo00<007ooOol0=Woo00<007ooOol04Woo00<007ooOol0
=Goo00<007ooOol05Goo00<007ooOol0>goo000ZOol00`00Oomoo`0:Ool0
0`00Oomoo`0hOol00`00Oomoo`0BOol00`00Oomoo`0kOol00`00Oomoo`0;
Ool00`00Oomoo`0`Ool00`00Oomoo`0=Ool00`00Oomoo`0gOol00`00Oomo
o`0BOol00`00Oomoo`0fOol00`00Oomoo`0COol00`00Oomoo`0lOol002Yo
o`03001oogoo00Yoo`03001oogoo03Qoo`03001oogoo019oo`03001oogoo
03]oo`03001oogoo00Yoo`03001oogoo039oo`03001oogoo00aoo`03001o
ogoo03Qoo`03001oogoo011oo`03001oogoo03Moo`03001oogoo019oo`03
001oogoo03eoo`00:goo00<007ooOol02Goo00<007ooOol0>Goo00<007oo
Ool047oo00<007ooOol0?Goo00<007ooOol027oo00<007ooOol0<goo00<0
07ooOol02goo00<007ooOol0>Goo00<007ooOol047oo00<007ooOol0>7oo
00<007ooOol04Goo00<007ooOol0?Goo000[Ool00`00Oomoo`08Ool00`00
Oomoo`0kOol00`00Oomoo`0?Ool00`00Oomoo`0mOol00`00Oomoo`08Ool0
0`00Oomoo`0dOol00`00Oomoo`0:Ool00`00Oomoo`0jOol00`00Oomoo`0>
Ool00`00Oomoo`0iOol00`00Oomoo`0@Ool00`00Oomoo`0nOol002aoo`03
001oogoo00Moo`03001oogoo03aoo`03001oogoo00eoo`03001oogoo03mo
o`03001oogoo00Ioo`03001oogoo03Ioo`03001oogoo00Uoo`03001oogoo
03Yoo`03001oogoo00ioo`03001oogoo03Yoo`03001oogoo00ioo`03001o
ogoo03moo`00;7oo00<007ooOol01goo00<007ooOol0?7oo00<007ooOol0
3Goo00<007ooOol0?goo00<007ooOol01Woo00<007ooOol0=Woo00<007oo
Ool027oo00<007ooOol0>goo00<007ooOol03Goo00<007ooOol0>goo00<0
07ooOol03Woo00<007ooOol0?goo000]Ool00`00Oomoo`05Ool00`00Oomo
o`0nOol00`00Oomoo`0;Ool00`00Oomoo`11Ool00`00Oomoo`04Ool00`00
Oomoo`0hOol00`00Oomoo`07Ool00`00Oomoo`0lOol00`00Oomoo`0<Ool0
0`00Oomoo`0lOol00`00Oomoo`0<Ool00`00Oomoo`10Ool002eoo`03001o
ogoo00Eoo`03001oogoo03moo`03001oogoo00Yoo`03001oogoo045oo`03
001oogoo00Aoo`03001oogoo03Qoo`03001oogoo00Ioo`03001oogoo03eo
o`03001oogoo00]oo`03001oogoo03eoo`03001oogoo00]oo`03001oogoo
045oo`00;Woo00<007ooOol0Agoo00<007ooOol0CWoo00<007ooOol00Woo
00<007ooOol0>Woo00<007ooOol01Goo00<007ooOol0?Woo00<007ooOol0
2Woo00<007ooOol0?Woo00<007ooOol02Woo00<007ooOol0@Goo000^Ool0
0`00Oomoo`17Ool00`00Oomoo`2AOol00`00Oomoo`03Ool00`00Oomoo`0o
Ool00`00Oomoo`09Ool00`00Oomoo`0oOol00`00Oomoo`09Ool00`00Oomo
o`12Ool007Uoo`03001oogoo091oo`03001oogoo00=oo`03001oogoo03mo
o`03001oogoo00Uoo`03001oogoo041oo`03001oogoo00Moo`03001oogoo
04=oo`00ogoo3Woo00<007ooOol0AGoo00<007ooOol0Bgoo00<007ooOol0
1goo00<007ooOol0@goo003oOomFOol00`00Oomoo`1DOol00`00Oomoo`14
Ool00?mooeMoo`03001oogoo09Yoo`00P7oo0`00C7oo0`00Q7oo00<007oo
Ool0VWoo000hOol30015Ool3001<Ool3003oOolROol003Qoo`<004Eoo`<0
04aoo`<00?moob9oo`00>7oo0`00AGoo0`00C7oo0`00?Woo0`00BWoo0`00
Tgoo000hOol3000mOol=0012Ool=000lOol3001:Ool30015Ool4001:Ool0
031oo`d003]oo`d0049oo`d003aoo`<004Yoo`<004=oo`T004Moo`00<7oo
3@00>goo3@00@Woo3@00?7oo0`00BWoo0`00@Woo2P00Agoo000`Ool=000l
Ool40003Ool30015Ool40003Ool3000fOol=0010Ool=0010Ool40002Ool4
0017Ool0035oo`@000=oo`<003ioo`@000=oo`<004Eoo`@000=oo`<003Io
o`d0041oo`d003moo`@000Aoo`@004Ioo`00<Goo10000goo0`00?goo1000
0Woo0`00AWoo10000Woo0`00=Woo3@00@7oo3@00?goo0`001Woo0`00AWoo
000bOol40002Ool30010Ool30002Ool30017Ool30002Ool3000gOol40003
Ool30013Ool40003Ool30011Ool30006Ool30016Ool003=oo`<0009oo`<0
041oo`@00004Ool000000017Ool4000017oo00000000=goo10000goo0`00
@goo10000goo0`00@Goo100017oo1000AWoo000cOol4000017oo00000000
@7oo2000Agoo2000>7oo10000Woo0`00A7oo10000Woo0`00@Goo1@000Woo
1000Agoo000cOol80012Ool60019Ool6000iOol30002Ool30015Ool30002
Ool30011Ool;0017Ool003Eoo`H0049oo`H004Uoo`H003Uoo`@00004Ool0
00000015Ool4000017oo00000000@Goo2P00B7oo000eOol60013Ool5001:
Ool5000iOol80015Ool80011Ool30002Ool3001:Ool003Ioo`D004=oo`D0
04Yoo`D003]oo`H004Moo`H0045oo`<004moo`00=Woo1@00?Goo00<007oo
Ool017oo1000Bgoo1000>goo1P00Agoo1P00@Goo100017oo0`00Agoo000g
Ool40003Ool00`00Oomoo`0fOol00`00Oomoo`2DOol50018Ool50012Ool4
0002Ool40017Ool003moo`03001oogoo03Eoo`03001oogoo09Aoo`D004Qo
o`D0049oo`X004Moo`00?goo00<007ooOol0=7oo00<007ooOol0G7oo00<0
07ooOol0=goo1000BGoo1000@goo2000B7oo0010Ool00`00Oomoo`0bOol0
0`00Oomoo`1NOol00`00Oomoo`2;Ool00`00Oomoo`0nOol4001:Ool0045o
o`03001oogoo035oo`03001oogoo05ioo`03001oogoo031oo`03001oogoo
05Uoo`03001oogoo03Aoo`03001oogoo05Aoo`00@Woo00<007ooOol0;goo
00<007ooOol0H7oo00<007ooOol0;Woo00<007ooOol0Fgoo00<007ooOol0
<Woo00<007ooOol0EGoo0012Ool00`00Oomoo`0^Ool00`00Oomoo`1QOol0
0`00Oomoo`0^Ool00`00Oomoo`1LOol00`00Oomoo`0`Ool00`00Oomoo`1F
Ool004=oo`03001oogoo02eoo`03001oogoo069oo`03001oogoo02aoo`03
001oogoo05ioo`03001oogoo02ioo`03001oogoo05Moo`00A7oo00<007oo
Ool0:goo00<007ooOol0I7oo00<007ooOol0:Woo00<007ooOol0Ggoo00<0
07ooOol0;Goo00<007ooOol0F7oo0015Ool00`00Oomoo`0ZOol00`00Oomo
o`1TOol00`00Oomoo`0ZOol00`00Oomoo`1POol00`00Oomoo`0[Ool00`00
Oomoo`1IOol004Eoo`03001oogoo02Uoo`03001oogoo06Ioo`03001oogoo
02Qoo`03001oogoo069oo`03001oogoo02Uoo`03001oogoo05Yoo`00AWoo
00<007ooOol09goo00<007ooOol0J7oo00<007ooOol09Woo00<007ooOol0
I7oo00<007ooOol09goo00<007ooOol0Fgoo0017Ool00`00Oomoo`0VOol0
0`00Oomoo`1XOol00`00Oomoo`0VOol00`00Oomoo`1UOol00`00Oomoo`0U
Ool00`00Oomoo`1LOol004Qoo`03001oogoo02Aoo`03001oogoo06Yoo`03
001oogoo02Aoo`03001oogoo06Moo`03001oogoo02=oo`03001oogoo05eo
o`00B7oo00<007ooOol08goo00<007ooOol0Jgoo00<007ooOol097oo00<0
07ooOol0J7oo00<007ooOol08Goo00<007ooOol0GWoo0019Ool00`00Oomo
o`0ROol00`00Oomoo`1/Ool00`00Oomoo`0ROol00`00Oomoo`1ZOol00`00
Oomoo`0OOol00`00Oomoo`1OOol004Yoo`03001oogoo021oo`03001oogoo
06ioo`03001oogoo021oo`03001oogoo06]oo`03001oogoo01eoo`80069o
o`00Bgoo00<007ooOol07Woo00<007ooOol0Kgoo00<007ooOol087oo00<0
07ooOol0K7oo00<007ooOol06goo00<007ooOol0HWoo001;Ool00`00Oomo
o`0NOol00`00Oomoo`1`Ool00`00Oomoo`0NOol00`00Oomoo`1^Ool00`00
Oomoo`0IOol00`00Oomoo`1SOol004aoo`03001oogoo01aoo`03001oogoo
075oo`03001oogoo01eoo`03001oogoo071oo`03001oogoo01Moo`03001o
ogoo06Aoo`00CGoo00<007ooOol06Woo00<007ooOol0Lgoo00<007ooOol0
77oo00<007ooOol0LGoo00<007ooOol05Goo00<007ooOol0IGoo001=Ool0
0`00Oomoo`0JOol00`00Oomoo`1dOol00`00Oomoo`0JOol00`00Oomoo`1c
Ool00`00Oomoo`0COol00`00Oomoo`1VOol004ioo`03001oogoo01Qoo`03
001oogoo07Eoo`03001oogoo01Uoo`03001oogoo07Eoo`03001oogoo015o
o`03001oogoo06Moo`00Cgoo00<007ooOol05Woo00<007ooOol0Mgoo00<0
07ooOol067oo00<007ooOol0MWoo00<007ooOol03goo00<007ooOol0J7oo
001@Ool00`00Oomoo`0EOol00`00Oomoo`1gOol00`00Oomoo`0GOol00`00
Oomoo`1gOol00`00Oomoo`0>Ool00`00Oomoo`1YOol0051oo`03001oogoo
01Aoo`03001oogoo07Uoo`03001oogoo01Eoo`03001oogoo07Uoo`03001o
ogoo00aoo`03001oogoo06Yoo`00DGoo00<007ooOol04goo00<007ooOol0
NWoo00<007ooOol057oo00<007ooOol0NWoo00<007ooOol02Woo00<007oo
Ool0Jgoo001BOol00`00Oomoo`0AOol00`00Oomoo`1kOol00`00Oomoo`0C
Ool00`00Oomoo`1lOol00`00Oomoo`08Ool00`00Oomoo`1/Ool005=oo`03
001oogoo00moo`03001oogoo07eoo`03001oogoo019oo`03001oogoo07eo
o`03001oogoo00Ioo`03001oogoo06eoo`00Dgoo00<007ooOol03goo00<0
07ooOol0OWoo00<007ooOol047oo00<007ooOol0mgoo001DOol00`00Oomo
o`0=Ool00`00Oomoo`1oOol00`00Oomoo`0?Ool00`00Oomoo`3hOol005Eo
o`03001oogoo00]oo`03001oogoo085oo`03001oogoo00ioo`03001oogoo
0?Qoo`00EWoo00<007ooOol02Woo00<007ooOol0PGoo00<007ooOol03Goo
00<007ooOol0nGoo001FOol00`00Oomoo`09Ool00`00Oomoo`23Ool00`00
Oomoo`3oOol9Ool005Moo`03001oogoo0?mooiYoo`00ogoom7oo003oOomj
Ool30009Ool4001ZOol00?moogYoo`<000Moo`P006Qoo`00kWoo1@00QWoo
0`001Woo2P00Igoo001KOol5002<Ool:0023Ool30006Ool40002Ool4001W
Ool005Uoo`X008Qoo`/008=oo`<000Eoo`@000Aoo`<006Moo`00F7oo2`00
R7oo100017oo0`00Pgoo0`001Goo0`001Goo0`00Igoo001HOol40004Ool3
0027Ool30007Ool30022Ool30005Ool30005Ool3001WOol005Moo`<000Mo
o`<008Ioo`<000Moo`<0089oo`<000Eoo`<000Eoo`<006Moo`00Egoo0`00
1goo0`00QWoo0`001goo0`00PWoo0`001Goo0`001Goo0`00Igoo001GOol3
0007Ool30027Ool40004Ool30023Ool30005Ool30005Ool3001WOol005Qo
o`@000Aoo`<008Qoo`/008=oo`<000Eoo`<000Eoo`<006Moo`0057oo00<0
07ooOol0@Goo2`00RGoo2P00Pgoo0`001Goo0`001Goo0`00Igoo000EOol0
0`00Oomoo`11Ool:0029Ool:0021Ool50005Ool30005Ool3001WOol001Io
o`03001oogoo041oo`X008Qoo`@000Aoo`<0085oo`D000Eoo`@000Aoo`<0
06Moo`005goo00<007ooOol0?Woo100017oo0`00R7oo0`001Goo0`00PGoo
1@001Woo10000Woo1000Igoo000GOol00`00Oomoo`0nOol30005Ool30028
Ool40004Ool30022Ool40006Ool:001WOol001Qoo`03001oogoo03eoo`@0
00Aoo`<008Uoo`@0009oo`@008Aoo`8000Moo`L006Uoo`006Goo00<007oo
Ool0?Goo10000Woo1000RGoo2P00Q7oo0P002Goo1000JWoo000JOol00`00
Oomoo`0eOol00`00Oomoo`04Ool:002:Ool7003oOol001]oo`03001oogoo
03=oo`03001oogoo00Ioo`L008ioo`@00?moo`5oo`0077oo00<007ooOol0
<Woo00<007ooOol027oo1000Vgoo00<007ooOol0mGoo000LOol00`00Oomo
o`0aOol00`00Oomoo`2YOol2001aOol00`00Oomoo`21Ool001eoo`03001o
ogoo02moo`03001oogoo0:aoo`03001oogoo06eoo`03001oogoo089oo`00
7Woo00<007ooOol0;Woo00<007ooOol0[Goo00<007ooOol0JWoo0P00QGoo
000OOol00`00Oomoo`0/Ool00`00Oomoo`2_Ool2001YOol00`00Oomoo`25
Ool0021oo`03001oogoo02]oo`03001oogoo0;5oo`03001oogoo06Eoo`03
001oogoo08Ioo`008Goo00<007ooOol0:Goo00<007ooOol0/goo00<007oo
Ool0HWoo0P00RGoo000ROol00`00Oomoo`0WOol00`00Oomoo`2eOol2001Q
Ool00`00Oomoo`29Ool0029oo`03001oogoo02Moo`03001oogoo0;Moo`03
001oogoo05eoo`03001oogoo08Yoo`008goo00<007ooOol09Goo00<007oo
Ool0^Goo00<007ooOol0Fgoo00<007ooOol0Rgoo000TOol00`00Oomoo`0S
Ool00`00Oomoo`2kOol2001IOol2002>Ool002Eoo`03001oogoo029oo`03
001oogoo0;eoo`03001oogoo05Eoo`03001oogoo08ioo`009Woo00<007oo
Ool087oo00<007ooOol0_goo00<007ooOol0Dgoo00<007ooOol0Sgoo000W
Ool00`00Oomoo`0OOol00`00Oomoo`30Ool2001AOol2002BOol002Moo`03
001oogoo01ioo`03001oogoo0<=oo`03001oogoo04eoo`03001oogoo099o
o`00:7oo00<007ooOol077oo00<007ooOol0aGoo00<007ooOol0Bgoo00<0
07ooOol0Tgoo000YOol00`00Oomoo`0KOol00`00Oomoo`36Ool2001:Ool0
0`00Oomoo`2DOol002Yoo`03001oogoo01Uoo`03001oogoo0<Uoo`03001o
ogoo04Eoo`8009Moo`00:goo00<007ooOol05goo00<007ooOol0bgoo00<0
07ooOol0@goo00<007ooOol0Ugoo000/Ool00`00Oomoo`0FOol00`00Oomo
o`3<Ool20012Ool00`00Oomoo`2HOol002eoo`03001oogoo01Aoo`03001o
ogoo0<moo`03001oogoo03eoo`8009]oo`00;Goo00<007ooOol057oo00<0
07ooOol0d7oo00<007ooOol0>goo00<007ooOol0Vgoo000^Ool00`00Oomo
o`0BOol00`00Oomoo`3BOol2000jOol00`00Oomoo`2LOol002moo`03001o
ogoo011oo`03001oogoo0=Eoo`03001oogoo03Eoo`8009moo`00<7oo00<0
07ooOol03goo00<007ooOol0eWoo00<007ooOol0<goo00<007ooOol0Wgoo
000aOol00`00Oomoo`0=Ool00`00Oomoo`3HOol2000bOol00`00Oomoo`2P
Ool0039oo`03001oogoo00]oo`03001oogoo0=]oo`03001oogoo02ioo`03
001oogoo0:5oo`00<Woo00<007ooOol02goo00<007ooOol0g7oo00<007oo
Ool0:goo0P00Y7oo000cOol00`00Oomoo`09Ool00`00Oomoo`3NOol2000Z
Ool00`00Oomoo`2TOol003Aoo`03001oogoo00Qoo`03001oogoo0>1oo`03
001oogoo02Ioo`03001oogoo0:Eoo`00=Goo00<007ooOol01Woo00<007oo
Ool0hWoo00<007ooOol08goo0P00Z7oo003oOolUOol2000ROol00`00Oomo
o`2XOol00?moobMoo`03001oogoo01ioo`03001oogoo0:Uoo`00ogoo:7oo
00<007ooOol077oo00<007ooOol0ZWoo003oOolYOol2000JOol2002]Ool0
0?moob]oo`03001oogoo01Ioo`03001oogoo0:eoo`00ogoo;7oo00<007oo
Ool057oo00<007ooOol0[Woo000fOol3000<Ool3003TOol2000BOol2002a
Ool003Ioo`<000aoo`<00>Ioo`03001oogoo00ioo`03001oogoo0;5oo`00
=Woo0`0037oo0`00mWoo00<007ooOol0/Woo000fOol3000<Ool3003oOon/
Ool003Ioo`<000Aoo`d00?moojYoo`00=Woo0`0017oo3@00ogooZWoo000f
Ool30004Ool=003oOonZOol003Ioo`<000Eoo`@000=oo`<00?moojaoo`00
=Woo0`001Goo10000goo0`00igoo0`0027oo1@00]7oo000fOol30006Ool4
0002Ool3003WOol30006Ool:002aOol003Ioo`<000Moo`<0009oo`<00>Mo
o`<000Eoo`/00;5oo`00=Woo0`001goo100000Aoo`0000000>Moo`<000Eo
o`@000Aoo`<00;5oo`00=7oo1@001goo2000igoo0`0017oo0`001goo0`00
/7oo000dOol50009Ool6003WOol30004Ool30007Ool3002`Ool003Aoo`D0
00Uoo`H00>Moo`<000Aoo`<000Moo`<00;1oo`00=Goo10002Woo1@00igoo
0`001Goo100017oo0`00/Goo000gOol2000:Ool5003WOol30005Ool;002a
Ool003Moo`8000]oo`@00>Moo`<000Ioo`X00;5oo`00ogoo<7oo0`001Woo
2P00/Goo003oOol`Ool30005Ool40004Ool3002aOol004]oo`800>1oo`D0
00Eoo`<000Eoo`<00;5oo`00CGoo0P00gWoo1@001Goo100017oo0`00/Goo
001?Ool3003AOol20008Ool50006Ool40002Ool4002aOol0059oo`<00<]o
o`<000]oo`@000Ioo`X00;5oo`00EGoo0P00aWoo0`0047oo0P001goo1`00
/goo001GOol30030Ool3000COol20009Ool4002dOol005Yoo`800;]oo`<0
0=Uoo`00G7oo0`00]Goo0`00g7oo001OOol3002_Ool3003OOol0069oo`80
0:Yoo`<00>9oo`00I7oo0`00Y7oo0`00iGoo001WOol2002OOol3003XOol0
06Uoo`<009Uoo`<00>]oo`00K7oo0`00Tgoo0`00kWoo001_Ool2002>Ool3
003aOol0075oo`<008Qoo`<00?Aoo`00M7oo0P00Pgoo0`00mgoo001fOol3
001mOol3003jOol007Uoo`<007Ioo`@00?eoo`00O7oo0P00LGoo0`00ogoo
0Woo001nOol3001[Ool3003oOol5Ool0085oo`<006Eoo`<00?moo`Qoo`00
Q7oo0P00H7oo0`00ogoo2goo0026Ool3001JOol3003oOol>Ool008Uoo`80
05Eoo`<00?mooa5oo`00Rgoo0`00Cgoo0`00ogoo57oo002>Ool30019Ool3
003oOolGOol0095oo`8004Aoo`<00?mooaYoo`00Tgoo0`00?Woo0`00ogoo
7Goo002FOol2000iOol3003oOolPOol009Qoo`<003=oo`<00?moob=oo`00
Vgoo0`00;Goo0`00ogoo9Woo002NOol2000XOol3003oOolYOol00:1oo`80
02Aoo`800?moobaoo`00ogoom7oo003oOoodOol00:aoo`D000Eoo`d00?mo
oc5oo`00ZWoo2P000Woo3@00ogoo<Goo002YOol;0002Ool=003oOolaOol0
0:Uoo`@000Aoo`<000=oo`<00?moocYoo`00Z7oo0`001goo0`000Woo1000
ogoo>Goo002XOol30007Ool30002Ool5003oOolhOol00;9oo`<000=oo`D0
0?moocMoo`00/Goo0`001Woo1P00ogoo=7oo002^Ool60006Ool6003oOold
Ool00:ioo`H000Qoo`D00?mooc=oo`00[Woo1P002Woo1000ogoo<Woo002a
Ool3000;Ool3003oOolbOol00:Uoo`<000Eoo`<000=oo`<000Eoo`<00?mo
oc9oo`00ZGoo100017oo0`000goo0`0017oo1000ogoo<Woo002ZOol40002
Ool40003Ool40002Ool4003oOolcOol00:Yoo`X000=oo`X00?mooc=oo`00
Zgoo1`001goo1`00ogoo=7oo002]Ool40009Ool4003oOolfOol00?moooAo
o`00ogoom7oo003oOoodOol00?moooAoo`00ogoom7oo003oOoodOol00?mo
ooAoo`00ogoom7oo003oOoodOol00?moooAoo`00ogoom7oo003oOoodOol0
0?moooAoo`00ogoom7oo003oOoodOol00?moooAoo`00ogoom7oo003oOood
Ool00?moooAoo`00ogoom7oo003oOoodOol00?moooAoo`00ogoom7oo003o
OoodOol00?moooAoo`00ogoom7oo003oOoodOol00?moooAoo`00ogoom7oo
003oOoodOol00?moooAoo`00ogoom7oo003oOoodOol00?moooAoo`00ogoo
m7oo003oOoodOol00001\
\>"], "PlacedGraphics",
  ImageMargins->{{Inherited, 0}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["Finally, function ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["huffmanCode", "Input",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" below computes the code that will minimize the codification of a \
given message.\:f35f",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[
    \(huffmanCode[mesg_] := 
      Module[{t = lettersTree[mesg], h, u}, \[IndentingNewLine]u = 
          Cases[Flatten[
              t], _String]; \[IndentingNewLine]h = \((Position[t, #1] &)\) /@ 
            u; \[IndentingNewLine]h = \(#\[LeftDoubleBracket]
                Range[2, Length[#], 2]\[RightDoubleBracket] &\) /@ 
            Flatten[h, 
              1]; \[IndentingNewLine]c = \((StringJoin[
                  ToString /@ #1] &)\) /@ \((h /. {1 \[Rule] 0, 
                  2 \[Rule] 1})\); \[IndentingNewLine]Thread[
          u \[Rule] c]]\)], "Input",
  CellLabel->"In[57]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(mesg = "\<hi there\>";\)\), "\[IndentingNewLine]", 
    \(huffmanCode[mesg]\)}], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \({"e" \[Rule] "00", "h" \[Rule] "01", " " \[Rule] "100", 
      "i" \[Rule] "101", "r" \[Rule] "110", "t" \[Rule] "111"}\)], "Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell[TextData[StyleBox["The actual codified message is:",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StringReplace[mesg, %]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \("01101100111010011000"\)], "Output",
  CellLabel->"Out[60]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["As a final example, consider the following excerpt from Carlos \
Fuentes\.b4 ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"],
  StyleBox["Terra Nostra",
    FormatType->StandardForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[":",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(m = "\<El cielo abovedado se abri\[OAcute] en la siguiente grada: \
se desintegr\[OAcute] la luz met\[AAcute]lica; pero el paso de las \
r\[AAcute]fagas de viento y de las luces encontradas, resueltas en \
gl\[OAcute]bulos de color puro jam\[AAcute]s visto, en tri\[AAcute]ngulos de \
fuego y columnas de f\[OAcute]sforo, en bloques de asombro total y espirales \
enigm\[AAcute]ticas, impedia ubicarse en ese espacio total, fugitivo e \
infinito, sin principio ni fin.\>";\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(huffmanCode[m]\)}], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \({" " \[Rule] "000", "i" \[Rule] "0010", "r" \[Rule] "00110", 
      "t" \[Rule] "00111", "a" \[Rule] "0100", "s" \[Rule] "0101", 
      "o" \[Rule] "0110", "u" \[Rule] "01110", "d" \[Rule] "01111", 
      "g" \[Rule] "10000", "c" \[Rule] "10001", "n" \[Rule] "1001", 
      "f" \[Rule] "10100", "p" \[Rule] "10101", "\[AAcute]" \[Rule] "101100", 
      "." \[Rule] "10110100", ";" \[Rule] "10110101", ":" \[Rule] "10110110", 
      "E" \[Rule] "10110111", "\[OAcute]" \[Rule] "101110", 
      "v" \[Rule] "101111", "e" \[Rule] "110", "l" \[Rule] "1110", 
      "," \[Rule] "111100", "b" \[Rule] "111101", "m" \[Rule] "111110", 
      "y" \[Rule] "1111110", "j" \[Rule] "111111100", 
      "q" \[Rule] "111111101", "z" \[Rule] "11111111"}\)], "Output",
  CellLabel->"Out[62]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 971}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{838, 816},
WindowMargins->{{60, Automatic}, {Automatic, 19}},
Visible->True,
ShowCellLabel->False,
InputAliases->{"intt"->RowBox[ {"\[Integral]", 
        RowBox[ {"\[SelectionPlaceholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "dintt"->RowBox[ {
        SubsuperscriptBox[ 
        "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
        RowBox[ {"\[Placeholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "sumt"->RowBox[ {
        UnderoverscriptBox[ "\[Sum]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "prodt"->RowBox[ {
        UnderoverscriptBox[ "\[Product]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "dt"->RowBox[ {
        SubscriptBox[ "\[PartialD]", "\[Placeholder]"], " ", 
        "\[SelectionPlaceholder]"}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style. Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None],
  
  Cell[StyleData["Notebook", "Presentation"],
    FontSize->12]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{0.95, 11},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->36],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{25, 30}, {40, 30}},
    CellFrameMargins->{{6, 10}, {10, 14}},
    FontSize->54],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {4, 0}},
    CellFrameMargins->4,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{25, 40}, {55, 10}},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 8}},
    CellMargins->{{25, 30}, {65, 10}},
    FontSize->27],
  
  Cell[StyleData["SectionFirst", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{25, 30}, {30, 15}},
    FontSize->27],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{25, 30}, {30, 20}},
    FontSize->21],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Subsubsection",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{25, 30}, {10, 10}},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    TextJustification->1,
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{25, 10}, {6, 20}},
    FontSize->18],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 50}, {5, 5}},
    PageBreakAbove->False,
    FontSize->10],
  
  Cell[StyleData["Caption", "Presentation"],
    CellMargins->{{80, 50}, {8, 14}},
    FontSize->15],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    Hyphenation->True,
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {5, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{80, 10}, {8, 15}},
    FontSize->18],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {8, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{80, 10}, {30, 12}},
    FontSize->16],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 10}},
    ShowCellLabel->False,
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{80, 10}, {15, 8}},
    FontSize->15],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{80, 10}, {12, 8}},
    FontSize->16],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{80, 10}, {10, 10}},
    FontSize->16],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{45, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{65, 30}, {4, 30}},
    FontSize->21],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{45, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    CellMargins->{{65, 30}, {40, 2}},
    FontSize->18],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Presentation"],
    CellMargins->{{65, 30}, {8, 25}},
    FontSize->18],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Presentation"],
    CellMargins->{{25, 40}, {2, 2}},
    FontSize->18],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    Hyphenation->True,
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["DemosLink", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["DemosLink", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["TourLink", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["TourLink", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MasterIndexLink", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MasterIndexLink", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Presentation"]],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    CellFrameMargins->{{18, 10}, {10, 18}},
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"],
    CellMargins->{{10, 10}, {10, 12}},
    FontSize->36],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"],
    FontSize->26],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "Presentation"],
    CellMargins->{{35, 10}, {15, 12}},
    FontSize->18],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"],
    FontSize->12],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "Presentation"],
    CellMargins->{{25, 10}, {10, 10}},
    FontSize->18],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{80, 10}, {0, 20}},
    FontSize->18],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    CellMargins->{{80, 10}, {0, 20}},
    FontSize->18],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    CellMargins->{{80, 10}, {0, 20}},
    FontSize->18],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{80, 10}, {5, 25}},
    FontSize->18],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{80, 10}, {5, 15}},
    FontSize->18],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{25, 10}, {8, 20}},
    FontSize->16],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 180, 4, 93, "Title"],
Cell[1959, 59, 95, 2, 41, "Author"],
Cell[2057, 63, 184, 10, 123, "Address"],

Cell[CellGroupData[{
Cell[2266, 77, 35, 0, 56, "Section"],
Cell[2304, 79, 723, 12, 109, "Abstract"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3064, 96, 35, 0, 56, "Section"],
Cell[3102, 98, 341, 6, 44, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3480, 109, 71, 1, 56, "Section"],
Cell[3554, 112, 861, 17, 394, "Reference"]
}, Closed]],

Cell[CellGroupData[{
Cell[4452, 134, 36, 0, 36, "SectionFirst"],
Cell[4491, 136, 4636, 111, 417, "Abstract"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9164, 252, 147, 2, 72, "Section"],
Cell[9314, 256, 87, 2, 27, "Text"],
Cell[9404, 260, 104, 5, 44, "Text"],
Cell[9511, 267, 1110, 17, 146, "Text"],
Cell[10624, 286, 168, 4, 32, "Input"],

Cell[CellGroupData[{
Cell[10817, 294, 70, 2, 31, "Input"],
Cell[10890, 298, 212, 4, 49, "Output"]
}, Open  ]],
Cell[11117, 305, 174, 4, 27, "Text"],
Cell[11294, 311, 217, 5, 31, "Input"],
Cell[11514, 318, 202, 7, 28, "Text"],

Cell[CellGroupData[{
Cell[11741, 329, 100, 2, 31, "Input"],
Cell[11844, 333, 110, 2, 30, "Output"]
}, Open  ]],
Cell[11969, 338, 279, 6, 45, "Text"],
Cell[12251, 346, 506, 9, 131, "Input"],
Cell[12760, 357, 340, 7, 46, "Text"],

Cell[CellGroupData[{
Cell[13125, 368, 168, 4, 31, "Input"],
Cell[13296, 374, 524, 8, 106, "Output"]
}, Open  ]],
Cell[13835, 385, 121, 3, 27, "Text"],
Cell[13959, 390, 30665, 505, 237, 30570, 502, "GraphicsData", "Bitmap", \
"PlacedGraphics"],
Cell[44627, 897, 175, 4, 28, "Text"],
Cell[44805, 903, 214, 5, 31, "Input"],
Cell[45022, 910, 240, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[45287, 919, 105, 2, 31, "Input"],
Cell[45395, 923, 186, 3, 49, "Output"]
}, Open  ]],
Cell[45596, 929, 54, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[45675, 933, 167, 5, 31, "Input"],
Cell[45845, 940, 553, 8, 106, "Output"]
}, Open  ]],
Cell[46413, 951, 57, 0, 27, "Text"],
Cell[46473, 953, 807, 13, 112, "Text"],
Cell[47283, 968, 253, 6, 51, "Input"],

Cell[CellGroupData[{
Cell[47561, 978, 167, 4, 51, "Input"],
Cell[47731, 984, 407, 6, 87, "Output"]
}, Open  ]],
Cell[48153, 993, 365, 10, 44, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48555, 1008, 135, 2, 72, "Section"],
Cell[48693, 1012, 705, 16, 61, "Text"],
Cell[49401, 1030, 89, 2, 25, "BulletedList"],
Cell[49493, 1034, 114, 5, 25, "BulletedList"],
Cell[49610, 1041, 55, 0, 25, "BulletedList"],
Cell[49668, 1043, 1468, 25, 188, "Text"],
Cell[51139, 1070, 181, 4, 27, "NumberedEquation"],
Cell[51323, 1076, 182, 4, 27, "NumberedEquation"],
Cell[51508, 1082, 334, 12, 27, "NumberedEquation"],
Cell[51845, 1096, 342, 11, 27, "NumberedEquation"],
Cell[52190, 1109, 223, 5, 27, "NumberedEquation"],
Cell[52416, 1116, 223, 5, 27, "NumberedEquation"],
Cell[52642, 1123, 300, 4, 44, "Text"],
Cell[52945, 1129, 6919, 220, 220, "Text"],
Cell[59867, 1351, 126, 2, 27, "Text"],
Cell[59996, 1355, 5829, 188, 77, "Text"],
Cell[65828, 1545, 441, 13, 61, "Text"],
Cell[66272, 1560, 6733, 214, 144, "Text"],
Cell[73008, 1776, 566, 8, 95, "Text"],
Cell[73577, 1786, 401, 8, 131, "Input"],
Cell[73981, 1796, 311, 8, 45, "Text"],
Cell[74295, 1806, 687, 16, 211, "Input"],

Cell[CellGroupData[{
Cell[75007, 1826, 197, 5, 51, "Input"],
Cell[75207, 1833, 104, 2, 30, "Output"],
Cell[75314, 1837, 153, 3, 30, "Output"]
}, Open  ]],
Cell[75482, 1843, 175, 4, 27, "Text"],

Cell[CellGroupData[{
Cell[75682, 1851, 274, 5, 91, "Input"],
Cell[75959, 1858, 157, 3, 25, "Print"],
Cell[76119, 1863, 541, 11, 44, "Print"],
Cell[76663, 1876, 2070, 35, 139, "Print"]
}, Open  ]],
Cell[78748, 1914, 850, 17, 129, "Text"],
Cell[79601, 1933, 324, 11, 27, "Text"],
Cell[79928, 1946, 153, 3, 27, "Text"],
Cell[80084, 1951, 321, 7, 111, "Input"],

Cell[CellGroupData[{
Cell[80430, 1962, 138, 3, 31, "Input"],
Cell[80571, 1967, 172, 3, 30, "Output"]
}, Open  ]],
Cell[80758, 1973, 40, 0, 27, "Text"],
Cell[80801, 1975, 212, 4, 85, "Input"],

Cell[CellGroupData[{
Cell[81038, 1983, 144, 3, 31, "Input"],
Cell[81185, 1988, 142, 3, 30, "Output"]
}, Open  ]],
Cell[81342, 1994, 99, 4, 27, "Text"],
Cell[81444, 2000, 148, 3, 31, "Input"],
Cell[81595, 2005, 73, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[81693, 2009, 184, 4, 51, "Input"],
Cell[81880, 2015, 1223, 23, 186, "Output"]
}, Open  ]],
Cell[83118, 2041, 320, 5, 44, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83475, 2051, 144, 2, 72, "Section"],
Cell[83622, 2055, 518, 8, 61, "Text"],
Cell[84143, 2065, 399, 8, 91, "Input"],
Cell[84545, 2075, 508, 13, 27, "Text"],
Cell[85056, 2090, 219, 5, 71, "Input"],

Cell[CellGroupData[{
Cell[85300, 2099, 198, 4, 51, "Input"],
Cell[85501, 2105, 90, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[85640, 2113, 153, 2, 72, "Section"],
Cell[85796, 2117, 178, 3, 27, "Text"],
Cell[85977, 2122, 473, 9, 78, "Text"],
Cell[86453, 2133, 321, 5, 44, "Text"],
Cell[86777, 2140, 752, 23, 35, "Text"],
Cell[87532, 2165, 288, 4, 44, "Text"],
Cell[87823, 2171, 79, 2, 31, "Input"],
Cell[87905, 2175, 713, 19, 51, "Input"],
Cell[88621, 2196, 240, 5, 91, "Input"],

Cell[CellGroupData[{
Cell[88886, 2205, 92, 2, 31, "Input"],
Cell[88981, 2209, 220, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89238, 2218, 136, 3, 31, "Input"],
Cell[89377, 2223, 207, 4, 30, "Output"]
}, Open  ]],
Cell[89599, 2230, 143, 3, 27, "Text"],
Cell[89745, 2235, 1193, 32, 114, "Text"],

Cell[CellGroupData[{
Cell[90963, 2271, 78, 2, 31, "Input"],
Cell[91044, 2275, 200, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[91281, 2284, 113, 2, 31, "Input"],
Cell[91397, 2288, 209, 4, 30, "Output"]
}, Open  ]],
Cell[91621, 2295, 85, 2, 27, "Text"],
Cell[91709, 2299, 145, 3, 48, "Text"],
Cell[91857, 2304, 297, 5, 51, "Input"],
Cell[92157, 2311, 1429, 44, 35, "Text"],

Cell[CellGroupData[{
Cell[93611, 2359, 162, 3, 32, "Input"],
Cell[93776, 2364, 80, 2, 31, "Output"]
}, Open  ]],
Cell[93871, 2369, 271, 8, 27, "Text"],
Cell[94145, 2379, 212, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[94382, 2388, 182, 4, 51, "Input"],
Cell[94567, 2394, 83, 2, 30, "Output"],
Cell[94653, 2398, 83, 2, 30, "Output"]
}, Open  ]],
Cell[94751, 2403, 159, 3, 27, "Text"],
Cell[94913, 2408, 896, 25, 41, "Text"],
Cell[95812, 2435, 213, 3, 27, "Text"],
Cell[96028, 2440, 687, 20, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[96752, 2465, 144, 2, 72, "Section"],
Cell[96899, 2469, 171, 3, 27, "Text"],
Cell[97073, 2474, 195, 4, 44, "Text"],
Cell[97271, 2480, 210, 4, 51, "Input"],
Cell[97484, 2486, 954, 21, 103, "Text"],
Cell[98441, 2509, 224, 8, 28, "Text"],

Cell[CellGroupData[{
Cell[98690, 2521, 111, 2, 31, "Input"],
Cell[98804, 2525, 92, 2, 30, "Output"]
}, Open  ]],
Cell[98911, 2530, 2166, 60, 198, "Text"],
Cell[101080, 2592, 2127, 70, 29, "Text"],
Cell[103210, 2664, 2469, 70, 179, "Text"],
Cell[105682, 2736, 2426, 76, 35, "Text"],
Cell[108111, 2814, 341, 10, 61, "Text"],
Cell[108455, 2826, 264, 6, 111, "Input"],
Cell[108722, 2834, 118, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[108865, 2840, 77, 2, 31, "Input"],
Cell[108945, 2844, 94, 2, 30, "Output"]
}, Open  ]],
Cell[109054, 2849, 69, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[109148, 2853, 77, 2, 31, "Input"],
Cell[109228, 2857, 97, 2, 30, "Output"]
}, Open  ]],
Cell[109340, 2862, 290, 11, 27, "Text"],

Cell[CellGroupData[{
Cell[109655, 2877, 80, 2, 31, "Input"],
Cell[109738, 2881, 160, 3, 30, "Output"]
}, Open  ]],
Cell[109913, 2887, 434, 17, 27, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[110384, 2909, 132, 2, 72, "Section"],
Cell[110519, 2913, 1607, 32, 163, "Text"],
Cell[112129, 2947, 151, 3, 31, "Input"],
Cell[112283, 2952, 1310, 28, 106, "Input"],
Cell[113596, 2982, 733, 23, 35, "Text"],
Cell[114332, 3007, 156, 4, 31, "Input"],

Cell[CellGroupData[{
Cell[114513, 3015, 85, 2, 31, "Input"],
Cell[114601, 3019, 117, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[114755, 3026, 102, 2, 31, "Input"],
Cell[114860, 3030, 273, 5, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115170, 3040, 87, 2, 31, "Input"],
Cell[115260, 3044, 6934, 137, 72, 895, 57, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[122209, 3184, 707, 13, 80, "Text"],
Cell[122919, 3199, 1218, 24, 201, "Input"],

Cell[CellGroupData[{
Cell[124162, 3227, 105, 2, 31, "Input"],
Cell[124270, 3231, 16466, 452, 92, 4749, 302, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[140751, 3686, 145, 3, 48, "Text"],
Cell[140899, 3691, 147, 3, 31, "Input"],
Cell[141049, 3696, 517, 10, 61, "Text"],
Cell[141569, 3708, 707, 13, 147, "Input"],

Cell[CellGroupData[{
Cell[142301, 3725, 130, 3, 34, "Input"],
Cell[142434, 3730, 48197, 766, 258, 2591, 198, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[190646, 4499, 145, 3, 48, "Text"],
Cell[190794, 4504, 206, 4, 34, "Input"],
Cell[191003, 4510, 205, 5, 27, "Text"],
Cell[191211, 4517, 103, 5, 44, "Text"],
Cell[191317, 4524, 237, 4, 44, "Text"],
Cell[191557, 4530, 200, 6, 31, "Input"],

Cell[CellGroupData[{
Cell[191782, 4540, 200, 5, 51, "Input"],
Cell[191985, 4547, 69105, 1732, 296, 17104, 1085, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[261105, 6282, 145, 3, 48, "Text"],
Cell[261253, 6287, 208, 5, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261498, 6297, 158, 2, 72, "Section"],
Cell[261659, 6301, 828, 19, 78, "Text"],
Cell[262490, 6322, 172, 6, 44, "Text"],
Cell[262665, 6330, 102, 3, 27, "Text"],
Cell[262770, 6335, 139, 7, 78, "Text"],
Cell[262912, 6344, 226, 6, 61, "Text"],
Cell[263141, 6352, 176, 5, 27, "Text"],
Cell[263320, 6359, 54, 0, 27, "Text"],
Cell[263377, 6361, 1100, 24, 271, "Input"],

Cell[CellGroupData[{
Cell[264502, 6389, 230, 5, 71, "Input"],
Cell[264735, 6396, 1249, 22, 266, "Output"]
}, Open  ]],
Cell[265999, 6421, 318, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[266342, 6430, 706, 15, 171, "Input"],
Cell[267051, 6447, 126283, 3905, 255, 41684, 2855, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[393349, 10355, 145, 3, 48, "Text"],
Cell[393497, 10360, 277, 6, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[393811, 10371, 137, 2, 72, "Section"],
Cell[393951, 10375, 1796, 25, 249, "Text"],
Cell[395750, 10402, 202, 5, 51, "Input"],

Cell[CellGroupData[{
Cell[395977, 10411, 169, 4, 51, "Input"],
Cell[396149, 10417, 257, 4, 49, "Output"]
}, Open  ]],
Cell[396421, 10424, 114, 2, 27, "Text"],
Cell[396538, 10428, 265, 5, 51, "Input"],

Cell[CellGroupData[{
Cell[396828, 10437, 76, 2, 31, "Input"],
Cell[396907, 10441, 257, 4, 49, "Output"]
}, Open  ]],
Cell[397179, 10448, 168, 3, 27, "Text"],
Cell[397350, 10453, 42149, 693, 145, 42054, 690, "GraphicsData", "Bitmap", \
"PlacedGraphics"],
Cell[439502, 11148, 236, 8, 27, "Text"],
Cell[439741, 11158, 145, 3, 31, "Input"],
Cell[439889, 11163, 350, 10, 27, "Text"],
Cell[440242, 11175, 138, 3, 51, "Input"],

Cell[CellGroupData[{
Cell[440405, 11182, 71, 2, 31, "Input"],
Cell[440479, 11186, 83, 2, 30, "Output"]
}, Open  ]],
Cell[440577, 11191, 418, 7, 61, "Text"],
Cell[440998, 11200, 756, 12, 151, "Input"],
Cell[441757, 11214, 562, 17, 27, "Text"],
Cell[442322, 11233, 253, 6, 51, "Input"],

Cell[CellGroupData[{
Cell[442600, 11243, 89, 2, 31, "Input"],
Cell[442692, 11247, 136, 3, 30, "Output"]
}, Open  ]],
Cell[442843, 11253, 178, 3, 27, "Text"],
Cell[443024, 11258, 845, 15, 106, "Output"],
Cell[443872, 11275, 364, 7, 45, "Text"],
Cell[444239, 11284, 645, 12, 191, "Input"],

Cell[CellGroupData[{
Cell[444909, 11300, 83, 2, 31, "Input"],
Cell[444995, 11304, 362, 6, 49, "Output"]
}, Open  ]],
Cell[445372, 11313, 173, 3, 27, "Text"],
Cell[445548, 11318, 23308, 383, 296, 23258, 382, "GraphicsData", "Bitmap", \
"PlacedGraphics"],
Cell[468859, 11703, 466, 13, 27, "Text"],
Cell[469328, 11718, 613, 12, 131, "Input"],

Cell[CellGroupData[{
Cell[469966, 11734, 137, 3, 51, "Input"],
Cell[470106, 11739, 178, 3, 30, "Output"]
}, Open  ]],
Cell[470299, 11745, 128, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[470452, 11751, 80, 2, 31, "Input"],
Cell[470535, 11755, 81, 2, 30, "Output"]
}, Open  ]],
Cell[470631, 11760, 384, 12, 27, "Text"],

Cell[CellGroupData[{
Cell[471040, 11776, 616, 10, 151, "Input"],
Cell[471659, 11788, 796, 12, 87, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

